'''
# AWS::QuickSight Construct Library

This module is part of the [AWS Cloud Development Kit](https://github.com/aws/aws-cdk) project.

```python
import aws_cdk.aws_quicksight as quicksight
```

<!--BEGIN CFNONLY DISCLAIMER-->

There are no official hand-written ([L2](https://docs.aws.amazon.com/cdk/latest/guide/constructs.html#constructs_lib)) constructs for this service yet. Here are some suggestions on how to proceed:

* Search [Construct Hub for QuickSight construct libraries](https://constructs.dev/search?q=quicksight)
* Use the automatically generated [L1](https://docs.aws.amazon.com/cdk/latest/guide/constructs.html#constructs_l1_using) constructs, in the same way you would use [the CloudFormation AWS::QuickSight resources](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/AWS_QuickSight.html) directly.

<!--BEGIN CFNONLY DISCLAIMER-->

There are no hand-written ([L2](https://docs.aws.amazon.com/cdk/latest/guide/constructs.html#constructs_lib)) constructs for this service yet.
However, you can still use the automatically generated [L1](https://docs.aws.amazon.com/cdk/latest/guide/constructs.html#constructs_l1_using) constructs, and use this service exactly as you would using CloudFormation directly.

For more information on the resources and properties available for this service, see the [CloudFormation documentation for AWS::QuickSight](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/AWS_QuickSight.html).

(Read the [CDK Contributing Guide](https://github.com/aws/aws-cdk/blob/main/CONTRIBUTING.md) and submit an RFC if you are interested in contributing to this construct library.)

<!--END CFNONLY DISCLAIMER-->
'''
import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from typeguard import check_type

from .._jsii import *

import constructs as _constructs_77d1e7e8
from .. import (
    CfnResource as _CfnResource_9df397a6,
    CfnTag as _CfnTag_f6864754,
    IInspectable as _IInspectable_c2943556,
    IResolvable as _IResolvable_da3f097b,
    ITaggable as _ITaggable_36806126,
    TagManager as _TagManager_0a598cb3,
    TreeInspector as _TreeInspector_488e0dd5,
)


@jsii.implements(_IInspectable_c2943556, _ITaggable_36806126)
class CfnAnalysis(
    _CfnResource_9df397a6,
    metaclass=jsii.JSIIMeta,
    jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis",
):
    '''Creates an analysis in Amazon QuickSight.

    :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html
    :cloudformationResource: AWS::QuickSight::Analysis
    :exampleMetadata: fixture=_generated

    Example::

        
    '''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.Construct,
        id: builtins.str,
        *,
        analysis_id: builtins.str,
        aws_account_id: builtins.str,
        name: builtins.str,
        definition: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AnalysisDefinitionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        errors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AnalysisErrorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ResourcePermissionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        sheets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SheetProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        source_entity: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AnalysisSourceEntityProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        status: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
        theme_arn: typing.Optional[builtins.str] = None,
        validation_strategy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ValidationStrategyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
    ) -> None:
        '''
        :param scope: Scope in which this resource is defined.
        :param id: Construct identifier for this resource (unique in its scope).
        :param analysis_id: The ID for the analysis that you're creating. This ID displays in the URL of the analysis.
        :param aws_account_id: The ID of the AWS account where you are creating an analysis.
        :param name: A descriptive name for the analysis that you're creating. This name displays for the analysis in the Amazon QuickSight console.
        :param definition: 
        :param errors: Errors associated with the analysis.
        :param parameters: The parameter names and override values that you want to use. An analysis can have any parameter type, and some parameters might accept multiple values.
        :param permissions: A structure that describes the principals and the resource-level permissions on an analysis. You can use the ``Permissions`` structure to grant permissions by providing a list of AWS Identity and Access Management (IAM) action information for each principal listed by Amazon Resource Name (ARN). To specify no permissions, omit ``Permissions`` .
        :param sheets: A list of the associated sheets with the unique identifier and name of each sheet.
        :param source_entity: A source entity to use for the analysis that you're creating. This metadata structure contains details that describe a source template and one or more datasets. Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.
        :param status: Status associated with the analysis.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.
        :param theme_arn: The ARN for the theme to apply to the analysis that you're creating. To see the theme in the Amazon QuickSight console, make sure that you have access to it.
        :param validation_strategy: The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects. When you set this value to ``LENIENT`` , validation is skipped for specific errors.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b3315f05d88d5e66533d2b20616a2e811e05c9fbafca2923d46fac3672de4c3)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnAnalysisProps(
            analysis_id=analysis_id,
            aws_account_id=aws_account_id,
            name=name,
            definition=definition,
            errors=errors,
            parameters=parameters,
            permissions=permissions,
            sheets=sheets,
            source_entity=source_entity,
            status=status,
            tags=tags,
            theme_arn=theme_arn,
            validation_strategy=validation_strategy,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _TreeInspector_488e0dd5) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2ca8147b17b844ffbc3c2a9cd090ca0e94480c6c7ae381cf94ebe71edace477d)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__53b97cfc102fb3684bd66abaed6039a9dfaeaec91be6718e5c5a729fb5bd4bce)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) of the analysis.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="attrCreatedTime")
    def attr_created_time(self) -> builtins.str:
        '''The time that the analysis was created.

        :cloudformationAttribute: CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrDataSetArns")
    def attr_data_set_arns(self) -> typing.List[builtins.str]:
        '''The ARNs of the datasets of the analysis.

        :cloudformationAttribute: DataSetArns
        '''
        return typing.cast(typing.List[builtins.str], jsii.get(self, "attrDataSetArns"))

    @builtins.property
    @jsii.member(jsii_name="attrErrors")
    def attr_errors(self) -> _IResolvable_da3f097b:
        '''
        :cloudformationAttribute: Errors
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrErrors"))

    @builtins.property
    @jsii.member(jsii_name="attrLastUpdatedTime")
    def attr_last_updated_time(self) -> builtins.str:
        '''The time that the analysis was last updated.

        :cloudformationAttribute: LastUpdatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastUpdatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrSheets")
    def attr_sheets(self) -> _IResolvable_da3f097b:
        '''
        :cloudformationAttribute: Sheets
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrSheets"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> _TagManager_0a598cb3:
        '''Tag Manager which manages the tags for this resource.'''
        return typing.cast(_TagManager_0a598cb3, jsii.get(self, "tags"))

    @builtins.property
    @jsii.member(jsii_name="analysisId")
    def analysis_id(self) -> builtins.str:
        '''The ID for the analysis that you're creating.'''
        return typing.cast(builtins.str, jsii.get(self, "analysisId"))

    @analysis_id.setter
    def analysis_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e97a6221e06dbf461b9aa4823e3454ea44abab8e0005d388c8a957afba6a7546)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "analysisId", value)

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> builtins.str:
        '''The ID of the AWS account where you are creating an analysis.'''
        return typing.cast(builtins.str, jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9813c24d422123fdb92156bf969c5184775e9ae04365dcc922fbd64d9a6fa0d4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        '''A descriptive name for the analysis that you're creating.'''
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca318b234683f1f107ce9a5125554a5e0541143b8749b8bfddc3af01f3eec1e2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="definition")
    def definition(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AnalysisDefinitionProperty"]]:
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AnalysisDefinitionProperty"]], jsii.get(self, "definition"))

    @definition.setter
    def definition(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AnalysisDefinitionProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__312c03143f0646ddac921317c4beafd13435a22bac7731ca4c80df7cf1291f07)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "definition", value)

    @builtins.property
    @jsii.member(jsii_name="errors")
    def errors(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AnalysisErrorProperty"]]]]:
        '''Errors associated with the analysis.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AnalysisErrorProperty"]]]], jsii.get(self, "errors"))

    @errors.setter
    def errors(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AnalysisErrorProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c6a0b9f84708043b6388b7cc2507e80b2ec92bee4c20a36299936a33e1260cb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "errors", value)

    @builtins.property
    @jsii.member(jsii_name="parameters")
    def parameters(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParametersProperty"]]:
        '''The parameter names and override values that you want to use.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParametersProperty"]], jsii.get(self, "parameters"))

    @parameters.setter
    def parameters(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParametersProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef1f56dc35400e4931f1653bb22e70cc553ebe1114f5d755d003231b1324cba0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "parameters", value)

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ResourcePermissionProperty"]]]]:
        '''A structure that describes the principals and the resource-level permissions on an analysis.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ResourcePermissionProperty"]]]], jsii.get(self, "permissions"))

    @permissions.setter
    def permissions(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ResourcePermissionProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__66d1950ca4f145650f0bbe6dd03ce20c1892373a45953eeae4c8d1e715e4e59f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "permissions", value)

    @builtins.property
    @jsii.member(jsii_name="sheets")
    def sheets(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetProperty"]]]]:
        '''A list of the associated sheets with the unique identifier and name of each sheet.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetProperty"]]]], jsii.get(self, "sheets"))

    @sheets.setter
    def sheets(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3ae5ac0286f6d69735847f21956cc7a189332cc0ba029898dc97822bc48ef4b8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sheets", value)

    @builtins.property
    @jsii.member(jsii_name="sourceEntity")
    def source_entity(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AnalysisSourceEntityProperty"]]:
        '''A source entity to use for the analysis that you're creating.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AnalysisSourceEntityProperty"]], jsii.get(self, "sourceEntity"))

    @source_entity.setter
    def source_entity(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AnalysisSourceEntityProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6af7e816d0168a8e494393a7d325b33b7608b06408d137df9bb53d12ddb0300)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sourceEntity", value)

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> typing.Optional[builtins.str]:
        '''Status associated with the analysis.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "status"))

    @status.setter
    def status(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__960fdb2a491ce9d35ff5cabbedc58835f6818653fdd7bf86d6f4bc8a77bb74cf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "status", value)

    @builtins.property
    @jsii.member(jsii_name="tagsRaw")
    def tags_raw(self) -> typing.Optional[typing.List[_CfnTag_f6864754]]:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.'''
        return typing.cast(typing.Optional[typing.List[_CfnTag_f6864754]], jsii.get(self, "tagsRaw"))

    @tags_raw.setter
    def tags_raw(self, value: typing.Optional[typing.List[_CfnTag_f6864754]]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__96a82327f73591975826047cd88720f3f49b18acb2dd6e14a4795868ce2805b3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tagsRaw", value)

    @builtins.property
    @jsii.member(jsii_name="themeArn")
    def theme_arn(self) -> typing.Optional[builtins.str]:
        '''The ARN for the theme to apply to the analysis that you're creating.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "themeArn"))

    @theme_arn.setter
    def theme_arn(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__63c9327e4ac918b6b057dc7c2832c61de3e22f29858922ea51482cc4bcc992e8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "themeArn", value)

    @builtins.property
    @jsii.member(jsii_name="validationStrategy")
    def validation_strategy(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ValidationStrategyProperty"]]:
        '''The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ValidationStrategyProperty"]], jsii.get(self, "validationStrategy"))

    @validation_strategy.setter
    def validation_strategy(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ValidationStrategyProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4515d338bad3917a13aa84587ddde591fed0b18d3bc4dfedd4fa0f258fd89eb0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "validationStrategy", value)

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.AggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "attribute_aggregation_function": "attributeAggregationFunction",
            "categorical_aggregation_function": "categoricalAggregationFunction",
            "date_aggregation_function": "dateAggregationFunction",
            "numerical_aggregation_function": "numericalAggregationFunction",
        },
    )
    class AggregationFunctionProperty:
        def __init__(
            self,
            *,
            attribute_aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AttributeAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            categorical_aggregation_function: typing.Optional[builtins.str] = None,
            date_aggregation_function: typing.Optional[builtins.str] = None,
            numerical_aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''An aggregation function aggregates values from a dimension or measure.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param attribute_aggregation_function: Aggregation for attributes.
            :param categorical_aggregation_function: Aggregation for categorical values. - ``COUNT`` : Aggregate by the total number of values, including duplicates. - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.
            :param date_aggregation_function: Aggregation for date values. - ``COUNT`` : Aggregate by the total number of values, including duplicates. - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values. - ``MIN`` : Select the smallest date value. - ``MAX`` : Select the largest date value.
            :param numerical_aggregation_function: Aggregation for numerical values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                aggregation_function_property = quicksight.CfnAnalysis.AggregationFunctionProperty(
                    attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                        simple_attribute_aggregation="simpleAttributeAggregation",
                        value_for_multiple_values="valueForMultipleValues"
                    ),
                    categorical_aggregation_function="categoricalAggregationFunction",
                    date_aggregation_function="dateAggregationFunction",
                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__925d009ba27261c4511ddbb792d28c7eb0661fd2f049ebff6d7260489c45c820)
                check_type(argname="argument attribute_aggregation_function", value=attribute_aggregation_function, expected_type=type_hints["attribute_aggregation_function"])
                check_type(argname="argument categorical_aggregation_function", value=categorical_aggregation_function, expected_type=type_hints["categorical_aggregation_function"])
                check_type(argname="argument date_aggregation_function", value=date_aggregation_function, expected_type=type_hints["date_aggregation_function"])
                check_type(argname="argument numerical_aggregation_function", value=numerical_aggregation_function, expected_type=type_hints["numerical_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if attribute_aggregation_function is not None:
                self._values["attribute_aggregation_function"] = attribute_aggregation_function
            if categorical_aggregation_function is not None:
                self._values["categorical_aggregation_function"] = categorical_aggregation_function
            if date_aggregation_function is not None:
                self._values["date_aggregation_function"] = date_aggregation_function
            if numerical_aggregation_function is not None:
                self._values["numerical_aggregation_function"] = numerical_aggregation_function

        @builtins.property
        def attribute_aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AttributeAggregationFunctionProperty"]]:
            '''Aggregation for attributes.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html#cfn-quicksight-analysis-aggregationfunction-attributeaggregationfunction
            '''
            result = self._values.get("attribute_aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AttributeAggregationFunctionProperty"]], result)

        @builtins.property
        def categorical_aggregation_function(self) -> typing.Optional[builtins.str]:
            '''Aggregation for categorical values.

            - ``COUNT`` : Aggregate by the total number of values, including duplicates.
            - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html#cfn-quicksight-analysis-aggregationfunction-categoricalaggregationfunction
            '''
            result = self._values.get("categorical_aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def date_aggregation_function(self) -> typing.Optional[builtins.str]:
            '''Aggregation for date values.

            - ``COUNT`` : Aggregate by the total number of values, including duplicates.
            - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.
            - ``MIN`` : Select the smallest date value.
            - ``MAX`` : Select the largest date value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html#cfn-quicksight-analysis-aggregationfunction-dateaggregationfunction
            '''
            result = self._values.get("date_aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def numerical_aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericalAggregationFunctionProperty"]]:
            '''Aggregation for numerical values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html#cfn-quicksight-analysis-aggregationfunction-numericalaggregationfunction
            '''
            result = self._values.get("numerical_aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericalAggregationFunctionProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.AggregationSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "sort_direction": "sortDirection",
            "aggregation_function": "aggregationFunction",
        },
    )
    class AggregationSortConfigurationProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            sort_direction: builtins.str,
            aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration options to sort aggregated values.

            :param column: The column that determines the sort order of aggregated values.
            :param sort_direction: The sort direction of values. - ``ASC`` : Sort in ascending order. - ``DESC`` : Sort in descending order.
            :param aggregation_function: The function that aggregates the values in ``Column`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                aggregation_sort_configuration_property = quicksight.CfnAnalysis.AggregationSortConfigurationProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    sort_direction="sortDirection",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                        attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                            simple_attribute_aggregation="simpleAttributeAggregation",
                            value_for_multiple_values="valueForMultipleValues"
                        ),
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__78bad2ac32260dc84e2b7357f78d6b25ee5c88beec8c3afc46099f635c253b9e)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument sort_direction", value=sort_direction, expected_type=type_hints["sort_direction"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "sort_direction": sort_direction,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that determines the sort order of aggregated values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationsortconfiguration.html#cfn-quicksight-analysis-aggregationsortconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def sort_direction(self) -> builtins.str:
            '''The sort direction of values.

            - ``ASC`` : Sort in ascending order.
            - ``DESC`` : Sort in descending order.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationsortconfiguration.html#cfn-quicksight-analysis-aggregationsortconfiguration-sortdirection
            '''
            result = self._values.get("sort_direction")
            assert result is not None, "Required property 'sort_direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AggregationFunctionProperty"]]:
            '''The function that aggregates the values in ``Column`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationsortconfiguration.html#cfn-quicksight-analysis-aggregationsortconfiguration-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AggregationFunctionProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AggregationSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.AnalysisDefaultsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "default_new_sheet_configuration": "defaultNewSheetConfiguration",
        },
    )
    class AnalysisDefaultsProperty:
        def __init__(
            self,
            *,
            default_new_sheet_configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DefaultNewSheetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The configuration for default analysis settings.

            :param default_new_sheet_configuration: The configuration for default new sheet settings.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefaults.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                analysis_defaults_property = quicksight.CfnAnalysis.AnalysisDefaultsProperty(
                    default_new_sheet_configuration=quicksight.CfnAnalysis.DefaultNewSheetConfigurationProperty(
                        interactive_layout_configuration=quicksight.CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty(
                            free_form=quicksight.CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid=quicksight.CfnAnalysis.DefaultGridLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
                
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        ),
                        paginated_layout_configuration=quicksight.CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty(
                            section_based=quicksight.CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                )
                            )
                        ),
                        sheet_content_type="sheetContentType"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__50c31b61023716b7d8ba53618c337c56297b3ca7493ebffe7c2166feb816acf5)
                check_type(argname="argument default_new_sheet_configuration", value=default_new_sheet_configuration, expected_type=type_hints["default_new_sheet_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "default_new_sheet_configuration": default_new_sheet_configuration,
            }

        @builtins.property
        def default_new_sheet_configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DefaultNewSheetConfigurationProperty"]:
            '''The configuration for default new sheet settings.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefaults.html#cfn-quicksight-analysis-analysisdefaults-defaultnewsheetconfiguration
            '''
            result = self._values.get("default_new_sheet_configuration")
            assert result is not None, "Required property 'default_new_sheet_configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DefaultNewSheetConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnalysisDefaultsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.AnalysisDefinitionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier_declarations": "dataSetIdentifierDeclarations",
            "analysis_defaults": "analysisDefaults",
            "calculated_fields": "calculatedFields",
            "column_configurations": "columnConfigurations",
            "filter_groups": "filterGroups",
            "options": "options",
            "parameter_declarations": "parameterDeclarations",
            "sheets": "sheets",
        },
    )
    class AnalysisDefinitionProperty:
        def __init__(
            self,
            *,
            data_set_identifier_declarations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataSetIdentifierDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AnalysisDefaultsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            calculated_fields: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CalculatedFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            column_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            filter_groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilterGroupProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AssetOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            parameter_declarations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sheets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SheetDefinitionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The definition of an analysis.

            :param data_set_identifier_declarations: An array of dataset identifier declarations. This mapping allows the usage of dataset identifiers instead of dataset ARNs throughout analysis sub-structures.
            :param analysis_defaults: 
            :param calculated_fields: An array of calculated field definitions for the analysis.
            :param column_configurations: An array of analysis-level column configurations. Column configurations can be used to set default formatting for a column to be used throughout an analysis.
            :param filter_groups: Filter definitions for an analysis. For more information, see `Filtering Data in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/adding-a-filter.html>`_ in the *Amazon QuickSight User Guide* .
            :param options: An array of option definitions for an analysis.
            :param parameter_declarations: An array of parameter declarations for an analysis. Parameters are named variables that can transfer a value for use by an action or an object. For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .
            :param sheets: An array of sheet definitions for an analysis. Each ``SheetDefinition`` provides detailed information about a sheet within this analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__743f6de00af3d8850478c1cec470f5e4bbc39e00ef3e785c354c25f2a4f0444f)
                check_type(argname="argument data_set_identifier_declarations", value=data_set_identifier_declarations, expected_type=type_hints["data_set_identifier_declarations"])
                check_type(argname="argument analysis_defaults", value=analysis_defaults, expected_type=type_hints["analysis_defaults"])
                check_type(argname="argument calculated_fields", value=calculated_fields, expected_type=type_hints["calculated_fields"])
                check_type(argname="argument column_configurations", value=column_configurations, expected_type=type_hints["column_configurations"])
                check_type(argname="argument filter_groups", value=filter_groups, expected_type=type_hints["filter_groups"])
                check_type(argname="argument options", value=options, expected_type=type_hints["options"])
                check_type(argname="argument parameter_declarations", value=parameter_declarations, expected_type=type_hints["parameter_declarations"])
                check_type(argname="argument sheets", value=sheets, expected_type=type_hints["sheets"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier_declarations": data_set_identifier_declarations,
            }
            if analysis_defaults is not None:
                self._values["analysis_defaults"] = analysis_defaults
            if calculated_fields is not None:
                self._values["calculated_fields"] = calculated_fields
            if column_configurations is not None:
                self._values["column_configurations"] = column_configurations
            if filter_groups is not None:
                self._values["filter_groups"] = filter_groups
            if options is not None:
                self._values["options"] = options
            if parameter_declarations is not None:
                self._values["parameter_declarations"] = parameter_declarations
            if sheets is not None:
                self._values["sheets"] = sheets

        @builtins.property
        def data_set_identifier_declarations(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataSetIdentifierDeclarationProperty"]]]:
            '''An array of dataset identifier declarations.

            This mapping allows the usage of dataset identifiers instead of dataset ARNs throughout analysis sub-structures.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-datasetidentifierdeclarations
            '''
            result = self._values.get("data_set_identifier_declarations")
            assert result is not None, "Required property 'data_set_identifier_declarations' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataSetIdentifierDeclarationProperty"]]], result)

        @builtins.property
        def analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AnalysisDefaultsProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-analysisdefaults
            '''
            result = self._values.get("analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AnalysisDefaultsProperty"]], result)

        @builtins.property
        def calculated_fields(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CalculatedFieldProperty"]]]]:
            '''An array of calculated field definitions for the analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-calculatedfields
            '''
            result = self._values.get("calculated_fields")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CalculatedFieldProperty"]]]], result)

        @builtins.property
        def column_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnConfigurationProperty"]]]]:
            '''An array of analysis-level column configurations.

            Column configurations can be used to set default formatting for a column to be used throughout an analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-columnconfigurations
            '''
            result = self._values.get("column_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnConfigurationProperty"]]]], result)

        @builtins.property
        def filter_groups(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterGroupProperty"]]]]:
            '''Filter definitions for an analysis.

            For more information, see `Filtering Data in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/adding-a-filter.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-filtergroups
            '''
            result = self._values.get("filter_groups")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterGroupProperty"]]]], result)

        @builtins.property
        def options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AssetOptionsProperty"]]:
            '''An array of option definitions for an analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-options
            '''
            result = self._values.get("options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AssetOptionsProperty"]], result)

        @builtins.property
        def parameter_declarations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParameterDeclarationProperty"]]]]:
            '''An array of parameter declarations for an analysis.

            Parameters are named variables that can transfer a value for use by an action or an object.

            For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-parameterdeclarations
            '''
            result = self._values.get("parameter_declarations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParameterDeclarationProperty"]]]], result)

        @builtins.property
        def sheets(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetDefinitionProperty"]]]]:
            '''An array of sheet definitions for an analysis.

            Each ``SheetDefinition`` provides detailed information about a sheet within this analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-sheets
            '''
            result = self._values.get("sheets")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetDefinitionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnalysisDefinitionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.AnalysisErrorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "message": "message",
            "type": "type",
            "violated_entities": "violatedEntities",
        },
    )
    class AnalysisErrorProperty:
        def __init__(
            self,
            *,
            message: typing.Optional[builtins.str] = None,
            type: typing.Optional[builtins.str] = None,
            violated_entities: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.EntityProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''Analysis error.

            :param message: The message associated with the analysis error.
            :param type: The type of the analysis error.
            :param violated_entities: Lists the violated entities that caused the analysis error.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysiserror.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                analysis_error_property = quicksight.CfnAnalysis.AnalysisErrorProperty(
                    message="message",
                    type="type",
                    violated_entities=[quicksight.CfnAnalysis.EntityProperty(
                        path="path"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d24a90ca3aa452a90f96fcfd4a5a877d8b3420dac8dd89194eefc7cf2d995a3e)
                check_type(argname="argument message", value=message, expected_type=type_hints["message"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument violated_entities", value=violated_entities, expected_type=type_hints["violated_entities"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if message is not None:
                self._values["message"] = message
            if type is not None:
                self._values["type"] = type
            if violated_entities is not None:
                self._values["violated_entities"] = violated_entities

        @builtins.property
        def message(self) -> typing.Optional[builtins.str]:
            '''The message associated with the analysis error.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysiserror.html#cfn-quicksight-analysis-analysiserror-message
            '''
            result = self._values.get("message")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of the analysis error.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysiserror.html#cfn-quicksight-analysis-analysiserror-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def violated_entities(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.EntityProperty"]]]]:
            '''Lists the violated entities that caused the analysis error.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysiserror.html#cfn-quicksight-analysis-analysiserror-violatedentities
            '''
            result = self._values.get("violated_entities")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.EntityProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnalysisErrorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.AnalysisSourceEntityProperty",
        jsii_struct_bases=[],
        name_mapping={"source_template": "sourceTemplate"},
    )
    class AnalysisSourceEntityProperty:
        def __init__(
            self,
            *,
            source_template: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AnalysisSourceTemplateProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The source entity of an analysis.

            :param source_template: The source template for the source entity of the analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourceentity.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                analysis_source_entity_property = quicksight.CfnAnalysis.AnalysisSourceEntityProperty(
                    source_template=quicksight.CfnAnalysis.AnalysisSourceTemplateProperty(
                        arn="arn",
                        data_set_references=[quicksight.CfnAnalysis.DataSetReferenceProperty(
                            data_set_arn="dataSetArn",
                            data_set_placeholder="dataSetPlaceholder"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2ecdbd45ff5b11d9790994a68adfcf0f92e2edd71f85a3c48a1682c8262080ba)
                check_type(argname="argument source_template", value=source_template, expected_type=type_hints["source_template"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if source_template is not None:
                self._values["source_template"] = source_template

        @builtins.property
        def source_template(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AnalysisSourceTemplateProperty"]]:
            '''The source template for the source entity of the analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourceentity.html#cfn-quicksight-analysis-analysissourceentity-sourcetemplate
            '''
            result = self._values.get("source_template")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AnalysisSourceTemplateProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnalysisSourceEntityProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.AnalysisSourceTemplateProperty",
        jsii_struct_bases=[],
        name_mapping={"arn": "arn", "data_set_references": "dataSetReferences"},
    )
    class AnalysisSourceTemplateProperty:
        def __init__(
            self,
            *,
            arn: builtins.str,
            data_set_references: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataSetReferenceProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The source template of an analysis.

            :param arn: The Amazon Resource Name (ARN) of the source template of an analysis.
            :param data_set_references: The dataset references of the source template of an analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourcetemplate.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                analysis_source_template_property = quicksight.CfnAnalysis.AnalysisSourceTemplateProperty(
                    arn="arn",
                    data_set_references=[quicksight.CfnAnalysis.DataSetReferenceProperty(
                        data_set_arn="dataSetArn",
                        data_set_placeholder="dataSetPlaceholder"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e49cd94ff28900c4ae630948d7ccea67de75a0db33d071821700a175ccf1c97f)
                check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
                check_type(argname="argument data_set_references", value=data_set_references, expected_type=type_hints["data_set_references"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "arn": arn,
                "data_set_references": data_set_references,
            }

        @builtins.property
        def arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the source template of an analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourcetemplate.html#cfn-quicksight-analysis-analysissourcetemplate-arn
            '''
            result = self._values.get("arn")
            assert result is not None, "Required property 'arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_references(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataSetReferenceProperty"]]]:
            '''The dataset references of the source template of an analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourcetemplate.html#cfn-quicksight-analysis-analysissourcetemplate-datasetreferences
            '''
            result = self._values.get("data_set_references")
            assert result is not None, "Required property 'data_set_references' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataSetReferenceProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnalysisSourceTemplateProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.AnchorDateConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "anchor_option": "anchorOption",
            "parameter_name": "parameterName",
        },
    )
    class AnchorDateConfigurationProperty:
        def __init__(
            self,
            *,
            anchor_option: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The date configuration of the filter.

            :param anchor_option: The options for the date configuration. Choose one of the options below:. - ``NOW``
            :param parameter_name: The name of the parameter that is used for the anchor date configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-anchordateconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                anchor_date_configuration_property = quicksight.CfnAnalysis.AnchorDateConfigurationProperty(
                    anchor_option="anchorOption",
                    parameter_name="parameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5fcc6f6525e366303c9db7e8ff24617e72ce0a488feda6c9ad8187f55d8ab56e)
                check_type(argname="argument anchor_option", value=anchor_option, expected_type=type_hints["anchor_option"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if anchor_option is not None:
                self._values["anchor_option"] = anchor_option
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name

        @builtins.property
        def anchor_option(self) -> typing.Optional[builtins.str]:
            '''The options for the date configuration. Choose one of the options below:.

            - ``NOW``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-anchordateconfiguration.html#cfn-quicksight-analysis-anchordateconfiguration-anchoroption
            '''
            result = self._values.get("anchor_option")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The name of the parameter that is used for the anchor date configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-anchordateconfiguration.html#cfn-quicksight-analysis-anchordateconfiguration-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnchorDateConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ArcAxisConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"range": "range", "reserve_range": "reserveRange"},
    )
    class ArcAxisConfigurationProperty:
        def __init__(
            self,
            *,
            range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ArcAxisDisplayRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reserve_range: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The arc axis configuration of a ``GaugeChartVisual`` .

            :param range: The arc axis range of a ``GaugeChartVisual`` .
            :param reserve_range: The reserved range of the arc axis. Default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                arc_axis_configuration_property = quicksight.CfnAnalysis.ArcAxisConfigurationProperty(
                    range=quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                        max=123,
                        min=123
                    ),
                    reserve_range=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d54e637872882a6173bd225ee587908fd78c7f4daecbf84ec402376d4ffade92)
                check_type(argname="argument range", value=range, expected_type=type_hints["range"])
                check_type(argname="argument reserve_range", value=reserve_range, expected_type=type_hints["reserve_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if range is not None:
                self._values["range"] = range
            if reserve_range is not None:
                self._values["reserve_range"] = reserve_range

        @builtins.property
        def range(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ArcAxisDisplayRangeProperty"]]:
            '''The arc axis range of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisconfiguration.html#cfn-quicksight-analysis-arcaxisconfiguration-range
            '''
            result = self._values.get("range")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ArcAxisDisplayRangeProperty"]], result)

        @builtins.property
        def reserve_range(self) -> typing.Optional[jsii.Number]:
            '''The reserved range of the arc axis.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisconfiguration.html#cfn-quicksight-analysis-arcaxisconfiguration-reserverange
            '''
            result = self._values.get("reserve_range")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcAxisConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"max": "max", "min": "min"},
    )
    class ArcAxisDisplayRangeProperty:
        def __init__(
            self,
            *,
            max: typing.Optional[jsii.Number] = None,
            min: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The arc axis range of a ``GaugeChartVisual`` .

            :param max: The maximum value of the arc axis range.
            :param min: The minimum value of the arc axis range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisdisplayrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                arc_axis_display_range_property = quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                    max=123,
                    min=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ed3f8887663271e93178c46a42a1aeed0fa3ca1be562b706c4a69616b2752b6e)
                check_type(argname="argument max", value=max, expected_type=type_hints["max"])
                check_type(argname="argument min", value=min, expected_type=type_hints["min"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if max is not None:
                self._values["max"] = max
            if min is not None:
                self._values["min"] = min

        @builtins.property
        def max(self) -> typing.Optional[jsii.Number]:
            '''The maximum value of the arc axis range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisdisplayrange.html#cfn-quicksight-analysis-arcaxisdisplayrange-max
            '''
            result = self._values.get("max")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def min(self) -> typing.Optional[jsii.Number]:
            '''The minimum value of the arc axis range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisdisplayrange.html#cfn-quicksight-analysis-arcaxisdisplayrange-min
            '''
            result = self._values.get("min")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcAxisDisplayRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ArcConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"arc_angle": "arcAngle", "arc_thickness": "arcThickness"},
    )
    class ArcConfigurationProperty:
        def __init__(
            self,
            *,
            arc_angle: typing.Optional[jsii.Number] = None,
            arc_thickness: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The arc configuration of a ``GaugeChartVisual`` .

            :param arc_angle: The option that determines the arc angle of a ``GaugeChartVisual`` .
            :param arc_thickness: The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                arc_configuration_property = quicksight.CfnAnalysis.ArcConfigurationProperty(
                    arc_angle=123,
                    arc_thickness="arcThickness"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6467b443ad9493fad2ed833817e6e804c21ec4bb657ad9f80369ad9dc86cb37e)
                check_type(argname="argument arc_angle", value=arc_angle, expected_type=type_hints["arc_angle"])
                check_type(argname="argument arc_thickness", value=arc_thickness, expected_type=type_hints["arc_thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_angle is not None:
                self._values["arc_angle"] = arc_angle
            if arc_thickness is not None:
                self._values["arc_thickness"] = arc_thickness

        @builtins.property
        def arc_angle(self) -> typing.Optional[jsii.Number]:
            '''The option that determines the arc angle of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcconfiguration.html#cfn-quicksight-analysis-arcconfiguration-arcangle
            '''
            result = self._values.get("arc_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def arc_thickness(self) -> typing.Optional[builtins.str]:
            '''The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcconfiguration.html#cfn-quicksight-analysis-arcconfiguration-arcthickness
            '''
            result = self._values.get("arc_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ArcOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"arc_thickness": "arcThickness"},
    )
    class ArcOptionsProperty:
        def __init__(
            self,
            *,
            arc_thickness: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :param arc_thickness: The arc thickness of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                arc_options_property = quicksight.CfnAnalysis.ArcOptionsProperty(
                    arc_thickness="arcThickness"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3f6963705589da3cdf278cf29ec86cc70224eb186ec79d898a87727068b732fc)
                check_type(argname="argument arc_thickness", value=arc_thickness, expected_type=type_hints["arc_thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_thickness is not None:
                self._values["arc_thickness"] = arc_thickness

        @builtins.property
        def arc_thickness(self) -> typing.Optional[builtins.str]:
            '''The arc thickness of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcoptions.html#cfn-quicksight-analysis-arcoptions-arcthickness
            '''
            result = self._values.get("arc_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.AssetOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"timezone": "timezone", "week_start": "weekStart"},
    )
    class AssetOptionsProperty:
        def __init__(
            self,
            *,
            timezone: typing.Optional[builtins.str] = None,
            week_start: typing.Optional[builtins.str] = None,
        ) -> None:
            '''An array of analysis level configurations.

            :param timezone: Determines the timezone for the analysis.
            :param week_start: Determines the week start day for an analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-assetoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                asset_options_property = quicksight.CfnAnalysis.AssetOptionsProperty(
                    timezone="timezone",
                    week_start="weekStart"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b036419146adc925061a8649db3f06ee7cc3a080ffd431d521f4374dda141d4c)
                check_type(argname="argument timezone", value=timezone, expected_type=type_hints["timezone"])
                check_type(argname="argument week_start", value=week_start, expected_type=type_hints["week_start"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if timezone is not None:
                self._values["timezone"] = timezone
            if week_start is not None:
                self._values["week_start"] = week_start

        @builtins.property
        def timezone(self) -> typing.Optional[builtins.str]:
            '''Determines the timezone for the analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-assetoptions.html#cfn-quicksight-analysis-assetoptions-timezone
            '''
            result = self._values.get("timezone")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def week_start(self) -> typing.Optional[builtins.str]:
            '''Determines the week start day for an analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-assetoptions.html#cfn-quicksight-analysis-assetoptions-weekstart
            '''
            result = self._values.get("week_start")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AssetOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.AttributeAggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "simple_attribute_aggregation": "simpleAttributeAggregation",
            "value_for_multiple_values": "valueForMultipleValues",
        },
    )
    class AttributeAggregationFunctionProperty:
        def __init__(
            self,
            *,
            simple_attribute_aggregation: typing.Optional[builtins.str] = None,
            value_for_multiple_values: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Aggregation for attributes.

            :param simple_attribute_aggregation: The built-in aggregation functions for attributes. - ``UNIQUE_VALUE`` : Returns the unique value for a field, aggregated by the dimension fields.
            :param value_for_multiple_values: Used by the ``UNIQUE_VALUE`` aggregation function. If there are multiple values for the field used by the aggregation, the value for this property will be returned instead. Defaults to '*'.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-attributeaggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                attribute_aggregation_function_property = quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                    simple_attribute_aggregation="simpleAttributeAggregation",
                    value_for_multiple_values="valueForMultipleValues"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__239322ef0f76b06b43847222b973f1c2dab05370b2ec6eb4609aa0ded5f6facc)
                check_type(argname="argument simple_attribute_aggregation", value=simple_attribute_aggregation, expected_type=type_hints["simple_attribute_aggregation"])
                check_type(argname="argument value_for_multiple_values", value=value_for_multiple_values, expected_type=type_hints["value_for_multiple_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if simple_attribute_aggregation is not None:
                self._values["simple_attribute_aggregation"] = simple_attribute_aggregation
            if value_for_multiple_values is not None:
                self._values["value_for_multiple_values"] = value_for_multiple_values

        @builtins.property
        def simple_attribute_aggregation(self) -> typing.Optional[builtins.str]:
            '''The built-in aggregation functions for attributes.

            - ``UNIQUE_VALUE`` : Returns the unique value for a field, aggregated by the dimension fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-attributeaggregationfunction.html#cfn-quicksight-analysis-attributeaggregationfunction-simpleattributeaggregation
            '''
            result = self._values.get("simple_attribute_aggregation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_for_multiple_values(self) -> typing.Optional[builtins.str]:
            '''Used by the ``UNIQUE_VALUE`` aggregation function.

            If there are multiple values for the field used by the aggregation, the value for this property will be returned instead. Defaults to '*'.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-attributeaggregationfunction.html#cfn-quicksight-analysis-attributeaggregationfunction-valueformultiplevalues
            '''
            result = self._values.get("value_for_multiple_values")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AttributeAggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.AxisDataOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_axis_options": "dateAxisOptions",
            "numeric_axis_options": "numericAxisOptions",
        },
    )
    class AxisDataOptionsProperty:
        def __init__(
            self,
            *,
            date_axis_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DateAxisOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_axis_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumericAxisOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The data options for an axis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_axis_options: The options for an axis with a date field.
            :param numeric_axis_options: The options for an axis with a numeric field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdataoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_data_options_property = quicksight.CfnAnalysis.AxisDataOptionsProperty(
                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                        missing_date_visibility="missingDateVisibility"
                    ),
                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                            data_driven=data_driven,
                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                maximum=123,
                                minimum=123
                            )
                        ),
                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                step_count=123,
                                step_size=123
                            ),
                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                base=123
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__78edd36053c1005b13a557e025be3a3720bda781507e2e555c70560a0d7e3259)
                check_type(argname="argument date_axis_options", value=date_axis_options, expected_type=type_hints["date_axis_options"])
                check_type(argname="argument numeric_axis_options", value=numeric_axis_options, expected_type=type_hints["numeric_axis_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_axis_options is not None:
                self._values["date_axis_options"] = date_axis_options
            if numeric_axis_options is not None:
                self._values["numeric_axis_options"] = numeric_axis_options

        @builtins.property
        def date_axis_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateAxisOptionsProperty"]]:
            '''The options for an axis with a date field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdataoptions.html#cfn-quicksight-analysis-axisdataoptions-dateaxisoptions
            '''
            result = self._values.get("date_axis_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateAxisOptionsProperty"]], result)

        @builtins.property
        def numeric_axis_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericAxisOptionsProperty"]]:
            '''The options for an axis with a numeric field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdataoptions.html#cfn-quicksight-analysis-axisdataoptions-numericaxisoptions
            '''
            result = self._values.get("numeric_axis_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericAxisOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDataOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"maximum": "maximum", "minimum": "minimum"},
    )
    class AxisDisplayMinMaxRangeProperty:
        def __init__(
            self,
            *,
            maximum: typing.Optional[jsii.Number] = None,
            minimum: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The minimum and maximum setup for an axis display range.

            :param maximum: The maximum setup for an axis display range.
            :param minimum: The minimum setup for an axis display range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayminmaxrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                axis_display_min_max_range_property = quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                    maximum=123,
                    minimum=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4b4c5af5cc74aa0ccdc5a34f6c71e69180d271c0d9deca42d71f6e7519e3b965)
                check_type(argname="argument maximum", value=maximum, expected_type=type_hints["maximum"])
                check_type(argname="argument minimum", value=minimum, expected_type=type_hints["minimum"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if maximum is not None:
                self._values["maximum"] = maximum
            if minimum is not None:
                self._values["minimum"] = minimum

        @builtins.property
        def maximum(self) -> typing.Optional[jsii.Number]:
            '''The maximum setup for an axis display range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayminmaxrange.html#cfn-quicksight-analysis-axisdisplayminmaxrange-maximum
            '''
            result = self._values.get("maximum")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def minimum(self) -> typing.Optional[jsii.Number]:
            '''The minimum setup for an axis display range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayminmaxrange.html#cfn-quicksight-analysis-axisdisplayminmaxrange-minimum
            '''
            result = self._values.get("minimum")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayMinMaxRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.AxisDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_line_visibility": "axisLineVisibility",
            "axis_offset": "axisOffset",
            "data_options": "dataOptions",
            "grid_line_visibility": "gridLineVisibility",
            "scrollbar_options": "scrollbarOptions",
            "tick_label_options": "tickLabelOptions",
        },
    )
    class AxisDisplayOptionsProperty:
        def __init__(
            self,
            *,
            axis_line_visibility: typing.Optional[builtins.str] = None,
            axis_offset: typing.Optional[builtins.str] = None,
            data_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisDataOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            grid_line_visibility: typing.Optional[builtins.str] = None,
            scrollbar_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ScrollBarOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tick_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisTickLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options for the axis label.

            :param axis_line_visibility: Determines whether or not the axis line is visible.
            :param axis_offset: The offset value that determines the starting placement of the axis within a visual's bounds.
            :param data_options: The data options for an axis.
            :param grid_line_visibility: Determines whether or not the grid line is visible.
            :param scrollbar_options: The scroll bar options for an axis.
            :param tick_label_options: The tick label options of an axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_display_options_property = quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                    axis_line_visibility="axisLineVisibility",
                    axis_offset="axisOffset",
                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                            missing_date_visibility="missingDateVisibility"
                        ),
                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                data_driven=data_driven,
                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                    maximum=123,
                                    minimum=123
                                )
                            ),
                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                    step_count=123,
                                    step_size=123
                                ),
                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                    base=123
                                )
                            )
                        )
                    ),
                    grid_line_visibility="gridLineVisibility",
                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                        visibility="visibility",
                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                from=123,
                                to=123
                            )
                        )
                    ),
                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        rotation_angle=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1ce4112654b0cd5421008601c76af6b776bbd67f39c758fb78c8f8dc12fe8eb4)
                check_type(argname="argument axis_line_visibility", value=axis_line_visibility, expected_type=type_hints["axis_line_visibility"])
                check_type(argname="argument axis_offset", value=axis_offset, expected_type=type_hints["axis_offset"])
                check_type(argname="argument data_options", value=data_options, expected_type=type_hints["data_options"])
                check_type(argname="argument grid_line_visibility", value=grid_line_visibility, expected_type=type_hints["grid_line_visibility"])
                check_type(argname="argument scrollbar_options", value=scrollbar_options, expected_type=type_hints["scrollbar_options"])
                check_type(argname="argument tick_label_options", value=tick_label_options, expected_type=type_hints["tick_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_line_visibility is not None:
                self._values["axis_line_visibility"] = axis_line_visibility
            if axis_offset is not None:
                self._values["axis_offset"] = axis_offset
            if data_options is not None:
                self._values["data_options"] = data_options
            if grid_line_visibility is not None:
                self._values["grid_line_visibility"] = grid_line_visibility
            if scrollbar_options is not None:
                self._values["scrollbar_options"] = scrollbar_options
            if tick_label_options is not None:
                self._values["tick_label_options"] = tick_label_options

        @builtins.property
        def axis_line_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the axis line is visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-axislinevisibility
            '''
            result = self._values.get("axis_line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def axis_offset(self) -> typing.Optional[builtins.str]:
            '''The offset value that determines the starting placement of the axis within a visual's bounds.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-axisoffset
            '''
            result = self._values.get("axis_offset")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDataOptionsProperty"]]:
            '''The data options for an axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-dataoptions
            '''
            result = self._values.get("data_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDataOptionsProperty"]], result)

        @builtins.property
        def grid_line_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the grid line is visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-gridlinevisibility
            '''
            result = self._values.get("grid_line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scrollbar_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ScrollBarOptionsProperty"]]:
            '''The scroll bar options for an axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-scrollbaroptions
            '''
            result = self._values.get("scrollbar_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ScrollBarOptionsProperty"]], result)

        @builtins.property
        def tick_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisTickLabelOptionsProperty"]]:
            '''The tick label options of an axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-ticklabeloptions
            '''
            result = self._values.get("tick_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisTickLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.AxisDisplayRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"data_driven": "dataDriven", "min_max": "minMax"},
    )
    class AxisDisplayRangeProperty:
        def __init__(
            self,
            *,
            data_driven: typing.Any = None,
            min_max: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisDisplayMinMaxRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The range setup of a numeric axis display range.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_driven: The data-driven setup of an axis display range.
            :param min_max: The minimum and maximum setup of an axis display range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_display_range_property = quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                    data_driven=data_driven,
                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                        maximum=123,
                        minimum=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9d1f3cfb0e15cf882a7641e844dead6be56b0b912c5ad84ca6fbeb1a3f6708e2)
                check_type(argname="argument data_driven", value=data_driven, expected_type=type_hints["data_driven"])
                check_type(argname="argument min_max", value=min_max, expected_type=type_hints["min_max"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_driven is not None:
                self._values["data_driven"] = data_driven
            if min_max is not None:
                self._values["min_max"] = min_max

        @builtins.property
        def data_driven(self) -> typing.Any:
            '''The data-driven setup of an axis display range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayrange.html#cfn-quicksight-analysis-axisdisplayrange-datadriven
            '''
            result = self._values.get("data_driven")
            return typing.cast(typing.Any, result)

        @builtins.property
        def min_max(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayMinMaxRangeProperty"]]:
            '''The minimum and maximum setup of an axis display range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayrange.html#cfn-quicksight-analysis-axisdisplayrange-minmax
            '''
            result = self._values.get("min_max")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayMinMaxRangeProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.AxisLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "apply_to": "applyTo",
            "custom_label": "customLabel",
            "font_configuration": "fontConfiguration",
        },
    )
    class AxisLabelOptionsProperty:
        def __init__(
            self,
            *,
            apply_to: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisLabelReferenceOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_label: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The label options for a chart axis.

            You must specify the field that the label is targeted to.

            :param apply_to: The options that indicate which field the label belongs to.
            :param custom_label: The text for the axis label.
            :param font_configuration: The font configuration of the axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                axis_label_options_property = quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId"
                    ),
                    custom_label="customLabel",
                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bca9702cb7afaa3a7f9b3ad0e4acb34452f17e91211faa3d6f1d04077ab66e87)
                check_type(argname="argument apply_to", value=apply_to, expected_type=type_hints["apply_to"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if apply_to is not None:
                self._values["apply_to"] = apply_to
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration

        @builtins.property
        def apply_to(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisLabelReferenceOptionsProperty"]]:
            '''The options that indicate which field the label belongs to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabeloptions.html#cfn-quicksight-analysis-axislabeloptions-applyto
            '''
            result = self._values.get("apply_to")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisLabelReferenceOptionsProperty"]], result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The text for the axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabeloptions.html#cfn-quicksight-analysis-axislabeloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"]]:
            '''The font configuration of the axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabeloptions.html#cfn-quicksight-analysis-axislabeloptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "field_id": "fieldId"},
    )
    class AxisLabelReferenceOptionsProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
        ) -> None:
            '''The reference that specifies where the axis label is applied to.

            :param column: The column that the axis label is targeted to.
            :param field_id: The field that the axis label is targeted to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabelreferenceoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                axis_label_reference_options_property = quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5a41941fd4b6c34fbb36f8455884251f8e49d3a1bc0f3144be7b27b47f0d9a85)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the axis label is targeted to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabelreferenceoptions.html#cfn-quicksight-analysis-axislabelreferenceoptions-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field that the axis label is targeted to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabelreferenceoptions.html#cfn-quicksight-analysis-axislabelreferenceoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLabelReferenceOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.AxisLinearScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"step_count": "stepCount", "step_size": "stepSize"},
    )
    class AxisLinearScaleProperty:
        def __init__(
            self,
            *,
            step_count: typing.Optional[jsii.Number] = None,
            step_size: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The liner axis scale setup.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param step_count: The step count setup of a linear axis.
            :param step_size: The step size setup of a linear axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislinearscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                axis_linear_scale_property = quicksight.CfnAnalysis.AxisLinearScaleProperty(
                    step_count=123,
                    step_size=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__de2ed81b442a112dc0e5d3f1eaa2866e34c18bd6582d5dfaf8da256fed592114)
                check_type(argname="argument step_count", value=step_count, expected_type=type_hints["step_count"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if step_count is not None:
                self._values["step_count"] = step_count
            if step_size is not None:
                self._values["step_size"] = step_size

        @builtins.property
        def step_count(self) -> typing.Optional[jsii.Number]:
            '''The step count setup of a linear axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislinearscale.html#cfn-quicksight-analysis-axislinearscale-stepcount
            '''
            result = self._values.get("step_count")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def step_size(self) -> typing.Optional[jsii.Number]:
            '''The step size setup of a linear axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislinearscale.html#cfn-quicksight-analysis-axislinearscale-stepsize
            '''
            result = self._values.get("step_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLinearScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.AxisLogarithmicScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"base": "base"},
    )
    class AxisLogarithmicScaleProperty:
        def __init__(self, *, base: typing.Optional[jsii.Number] = None) -> None:
            '''The logarithmic axis scale setup.

            :param base: The base setup of a logarithmic axis scale.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislogarithmicscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                axis_logarithmic_scale_property = quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                    base=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__381902f283cd7b9a04480082e8bdb608c28e6b8d6c5de55e66eb320c97567350)
                check_type(argname="argument base", value=base, expected_type=type_hints["base"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if base is not None:
                self._values["base"] = base

        @builtins.property
        def base(self) -> typing.Optional[jsii.Number]:
            '''The base setup of a logarithmic axis scale.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislogarithmicscale.html#cfn-quicksight-analysis-axislogarithmicscale-base
            '''
            result = self._values.get("base")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLogarithmicScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.AxisScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"linear": "linear", "logarithmic": "logarithmic"},
    )
    class AxisScaleProperty:
        def __init__(
            self,
            *,
            linear: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisLinearScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            logarithmic: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisLogarithmicScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The scale setup options for a numeric axis display.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param linear: The linear axis scale setup.
            :param logarithmic: The logarithmic axis scale setup.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                axis_scale_property = quicksight.CfnAnalysis.AxisScaleProperty(
                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                        step_count=123,
                        step_size=123
                    ),
                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                        base=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0c88b551eac07288842d97071c3029b47d5623858616e1fe83f80d2048ec76e9)
                check_type(argname="argument linear", value=linear, expected_type=type_hints["linear"])
                check_type(argname="argument logarithmic", value=logarithmic, expected_type=type_hints["logarithmic"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if linear is not None:
                self._values["linear"] = linear
            if logarithmic is not None:
                self._values["logarithmic"] = logarithmic

        @builtins.property
        def linear(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisLinearScaleProperty"]]:
            '''The linear axis scale setup.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisscale.html#cfn-quicksight-analysis-axisscale-linear
            '''
            result = self._values.get("linear")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisLinearScaleProperty"]], result)

        @builtins.property
        def logarithmic(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisLogarithmicScaleProperty"]]:
            '''The logarithmic axis scale setup.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisscale.html#cfn-quicksight-analysis-axisscale-logarithmic
            '''
            result = self._values.get("logarithmic")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisLogarithmicScaleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.AxisTickLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "label_options": "labelOptions",
            "rotation_angle": "rotationAngle",
        },
    )
    class AxisTickLabelOptionsProperty:
        def __init__(
            self,
            *,
            label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rotation_angle: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The tick label options of an axis.

            :param label_options: Determines whether or not the axis ticks are visible.
            :param rotation_angle: The rotation angle of the axis tick labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisticklabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                axis_tick_label_options_property = quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    ),
                    rotation_angle=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cc6f05f510c841613789e96111c71665c3690785353fb7564171d840cff188b8)
                check_type(argname="argument label_options", value=label_options, expected_type=type_hints["label_options"])
                check_type(argname="argument rotation_angle", value=rotation_angle, expected_type=type_hints["rotation_angle"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if label_options is not None:
                self._values["label_options"] = label_options
            if rotation_angle is not None:
                self._values["rotation_angle"] = rotation_angle

        @builtins.property
        def label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LabelOptionsProperty"]]:
            '''Determines whether or not the axis ticks are visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisticklabeloptions.html#cfn-quicksight-analysis-axisticklabeloptions-labeloptions
            '''
            result = self._values.get("label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LabelOptionsProperty"]], result)

        @builtins.property
        def rotation_angle(self) -> typing.Optional[jsii.Number]:
            '''The rotation angle of the axis tick labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisticklabeloptions.html#cfn-quicksight-analysis-axisticklabeloptions-rotationangle
            '''
            result = self._values.get("rotation_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisTickLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.BarChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "colors": "colors",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class BarChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a bar chart.

            :param category: The category (y-axis) field well of a bar chart.
            :param colors: The color (group/color) field well of a bar chart.
            :param small_multiples: The small multiples field well of a bar chart.
            :param values: The value field wells of a bar chart. Values are aggregated by category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__14d09f84e0529894a371328f931fac3530bd776eb35de0075819430e70ff8806)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The category (y-axis) field well of a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html#cfn-quicksight-analysis-barchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The color (group/color) field well of a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html#cfn-quicksight-analysis-barchartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The small multiples field well of a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html#cfn-quicksight-analysis-barchartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The value field wells of a bar chart.

            Values are aggregated by category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html#cfn-quicksight-analysis-barchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.BarChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bars_arrangement": "barsArrangement",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_label_options": "colorLabelOptions",
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "orientation": "orientation",
            "reference_lines": "referenceLines",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_axis": "valueAxis",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class BarChartConfigurationProperty:
        def __init__(
            self,
            *,
            bars_arrangement: typing.Optional[builtins.str] = None,
            category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.BarChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            orientation: typing.Optional[builtins.str] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.BarChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``BarChartVisual`` .

            :param bars_arrangement: Determines the arrangement of the bars. The orientation and arrangement of bars determine the type of bar that is used in the visual.
            :param category_axis: The label display options (grid line, range, scale, axis step) for bar chart category.
            :param category_label_options: The label options (label text, label visibility and sort icon visibility) for a bar chart.
            :param color_label_options: The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.
            :param contribution_analysis_defaults: The contribution analysis (anomaly configuration) setup of the visual.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param orientation: The orientation of the bars in a bar chart visual. There are two valid values in this structure:. - ``HORIZONTAL`` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts. - ``VERTICAL`` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.
            :param reference_lines: The reference line setup of the visual.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a ``BarChartVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param value_axis: The label display options (grid line, range, scale, axis step) for a bar chart value.
            :param value_label_options: The label options (label text, label visibility and sort icon visibility) for a bar chart value.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f82e6ee1add2fdb859f27b13f529aafc1f0a7f416e16682c5d67e2df723a9e71)
                check_type(argname="argument bars_arrangement", value=bars_arrangement, expected_type=type_hints["bars_arrangement"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument orientation", value=orientation, expected_type=type_hints["orientation"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_axis", value=value_axis, expected_type=type_hints["value_axis"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bars_arrangement is not None:
                self._values["bars_arrangement"] = bars_arrangement
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if orientation is not None:
                self._values["orientation"] = orientation
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_axis is not None:
                self._values["value_axis"] = value_axis
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def bars_arrangement(self) -> typing.Optional[builtins.str]:
            '''Determines the arrangement of the bars.

            The orientation and arrangement of bars determine the type of bar that is used in the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-barsarrangement
            '''
            result = self._values.get("bars_arrangement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) for bar chart category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) for a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ContributionAnalysisDefaultProperty"]]]]:
            '''The contribution analysis (anomaly configuration) setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ContributionAnalysisDefaultProperty"]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BarChartFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BarChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def orientation(self) -> typing.Optional[builtins.str]:
            '''The orientation of the bars in a bar chart visual. There are two valid values in this structure:.

            - ``HORIZONTAL`` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts.
            - ``VERTICAL`` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-orientation
            '''
            result = self._values.get("orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineProperty"]]]]:
            '''The reference line setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineProperty"]]]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SmallMultiplesOptionsProperty"]]:
            '''The small multiples setup for the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SmallMultiplesOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BarChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``BarChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BarChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def value_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) for a bar chart value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-valueaxis
            '''
            result = self._values.get("value_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) for a bar chart value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.BarChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_chart_aggregated_field_wells": "barChartAggregatedFieldWells",
        },
    )
    class BarChartFieldWellsProperty:
        def __init__(
            self,
            *,
            bar_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.BarChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``BarChartVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param bar_chart_aggregated_field_wells: The aggregated field wells of a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__57e94b3218a71f9a221c4546912c0125a1236895085ccf54fe565d569bf21a63)
                check_type(argname="argument bar_chart_aggregated_field_wells", value=bar_chart_aggregated_field_wells, expected_type=type_hints["bar_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_chart_aggregated_field_wells is not None:
                self._values["bar_chart_aggregated_field_wells"] = bar_chart_aggregated_field_wells

        @builtins.property
        def bar_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BarChartAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartfieldwells.html#cfn-quicksight-analysis-barchartfieldwells-barchartaggregatedfieldwells
            '''
            result = self._values.get("bar_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BarChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.BarChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class BarChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''sort-configuration-description.

            :param category_items_limit: The limit on the number of categories displayed in a bar chart.
            :param category_sort: The sort configuration of category fields.
            :param color_items_limit: The limit on the number of values displayed in a bar chart.
            :param color_sort: The sort configuration of color fields in a bar chart.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                bar_chart_sort_configuration_property = quicksight.CfnAnalysis.BarChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9bfd09e91f4971d3675d55e8b7c84cc7b2d5d2b84f29fec31127f56611a737cf)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories displayed in a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of values displayed in a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of color fields in a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of small multiples panels that are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the small multiples field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.BarChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class BarChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.BarChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A bar chart.

            The ``BarChartVisual`` structure describes a visual that is a member of the bar chart family. The following charts can be described using this structure:

            - Horizontal bar chart
            - Vertical bar chart
            - Horizontal stacked bar chart
            - Vertical stacked bar chart
            - Horizontal stacked 100% bar chart
            - Vertical stacked 100% bar chart

            For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ad3846bbad8b69a74a650c9a66c96d4c5617a1d4379c57502d538c2439700765)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BarChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BarChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.BinCountOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"value": "value"},
    )
    class BinCountOptionsProperty:
        def __init__(self, *, value: typing.Optional[jsii.Number] = None) -> None:
            '''The options that determine the bin count of a histogram.

            :param value: The options that determine the bin count value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bincountoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                bin_count_options_property = quicksight.CfnAnalysis.BinCountOptionsProperty(
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1c9a0dbb5a09986420c28ddb1fa6dbe46b74b4966dcd5e2134c71ddfe180df39)
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin count value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bincountoptions.html#cfn-quicksight-analysis-bincountoptions-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BinCountOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.BinWidthOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"bin_count_limit": "binCountLimit", "value": "value"},
    )
    class BinWidthOptionsProperty:
        def __init__(
            self,
            *,
            bin_count_limit: typing.Optional[jsii.Number] = None,
            value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The options that determine the bin width of a histogram.

            :param bin_count_limit: The options that determine the bin count limit.
            :param value: The options that determine the bin width value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-binwidthoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                bin_width_options_property = quicksight.CfnAnalysis.BinWidthOptionsProperty(
                    bin_count_limit=123,
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5bf9a31675e53c4ed03f804fe10a9e945f4cb2d3265ed6fcb315ab9a91b63087)
                check_type(argname="argument bin_count_limit", value=bin_count_limit, expected_type=type_hints["bin_count_limit"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_count_limit is not None:
                self._values["bin_count_limit"] = bin_count_limit
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def bin_count_limit(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin count limit.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-binwidthoptions.html#cfn-quicksight-analysis-binwidthoptions-bincountlimit
            '''
            result = self._values.get("bin_count_limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin width value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-binwidthoptions.html#cfn-quicksight-analysis-binwidthoptions-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BinWidthOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.BodySectionConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "content": "content",
            "section_id": "sectionId",
            "page_break_configuration": "pageBreakConfiguration",
            "style": "style",
        },
    )
    class BodySectionConfigurationProperty:
        def __init__(
            self,
            *,
            content: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.BodySectionContentProperty", typing.Dict[builtins.str, typing.Any]]],
            section_id: builtins.str,
            page_break_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SectionPageBreakConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SectionStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a body section.

            :param content: The configuration of content in a body section.
            :param section_id: The unique identifier of a body section.
            :param page_break_configuration: The configuration of a page break for a section.
            :param style: The style options of a body section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                body_section_configuration_property = quicksight.CfnAnalysis.BodySectionConfigurationProperty(
                    content=quicksight.CfnAnalysis.BodySectionContentProperty(
                        layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        )
                    ),
                    section_id="sectionId",
                
                    # the properties below are optional
                    page_break_configuration=quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                        after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                            status="status"
                        )
                    ),
                    style=quicksight.CfnAnalysis.SectionStyleProperty(
                        height="height",
                        padding=quicksight.CfnAnalysis.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2470326817442ac7529c78646a6f521d33b36a0b4ce5470a868a1d02e2c13a38)
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
                check_type(argname="argument section_id", value=section_id, expected_type=type_hints["section_id"])
                check_type(argname="argument page_break_configuration", value=page_break_configuration, expected_type=type_hints["page_break_configuration"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "content": content,
                "section_id": section_id,
            }
            if page_break_configuration is not None:
                self._values["page_break_configuration"] = page_break_configuration
            if style is not None:
                self._values["style"] = style

        @builtins.property
        def content(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BodySectionContentProperty"]:
            '''The configuration of content in a body section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html#cfn-quicksight-analysis-bodysectionconfiguration-content
            '''
            result = self._values.get("content")
            assert result is not None, "Required property 'content' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BodySectionContentProperty"], result)

        @builtins.property
        def section_id(self) -> builtins.str:
            '''The unique identifier of a body section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html#cfn-quicksight-analysis-bodysectionconfiguration-sectionid
            '''
            result = self._values.get("section_id")
            assert result is not None, "Required property 'section_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def page_break_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SectionPageBreakConfigurationProperty"]]:
            '''The configuration of a page break for a section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html#cfn-quicksight-analysis-bodysectionconfiguration-pagebreakconfiguration
            '''
            result = self._values.get("page_break_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SectionPageBreakConfigurationProperty"]], result)

        @builtins.property
        def style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SectionStyleProperty"]]:
            '''The style options of a body section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html#cfn-quicksight-analysis-bodysectionconfiguration-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SectionStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BodySectionConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.BodySectionContentProperty",
        jsii_struct_bases=[],
        name_mapping={"layout": "layout"},
    )
    class BodySectionContentProperty:
        def __init__(
            self,
            *,
            layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of content in a body section.

            :param layout: The layout configuration of a body section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectioncontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                body_section_content_property = quicksight.CfnAnalysis.BodySectionContentProperty(
                    layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                            elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__52862e0cf0f944ba3a4d77a6336d986d75842281f1d4a4497c0ea8035c3aa5d7)
                check_type(argname="argument layout", value=layout, expected_type=type_hints["layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if layout is not None:
                self._values["layout"] = layout

        @builtins.property
        def layout(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SectionLayoutConfigurationProperty"]]:
            '''The layout configuration of a body section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectioncontent.html#cfn-quicksight-analysis-bodysectioncontent-layout
            '''
            result = self._values.get("layout")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SectionLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BodySectionContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "values": "values"},
    )
    class BoxPlotAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well for a box plot.

            :param group_by: The group by field well of a box plot chart. Values are grouped based on group by fields.
            :param values: The value field well of a box plot chart. Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                box_plot_aggregated_field_wells_property = quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fe1567634ff247e915bad385ea901faa429b429895c09a83d0322d4c7cd8bdff)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The group by field well of a box plot chart.

            Values are grouped based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotaggregatedfieldwells.html#cfn-quicksight-analysis-boxplotaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The value field well of a box plot chart.

            Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotaggregatedfieldwells.html#cfn-quicksight-analysis-boxplotaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.BoxPlotChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "box_plot_options": "boxPlotOptions",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
        },
    )
    class BoxPlotChartConfigurationProperty:
        def __init__(
            self,
            *,
            box_plot_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.BoxPlotOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.BoxPlotFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.BoxPlotSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``BoxPlotVisual`` .

            :param box_plot_options: The box plot chart options for a box plot visual.
            :param category_axis: The label display options (grid line, range, scale, axis step) of a box plot category.
            :param category_label_options: The label options (label text, label visibility and sort Icon visibility) of a box plot category.
            :param field_wells: The field wells of the visual.
            :param legend: 
            :param primary_y_axis_display_options: The label display options (grid line, range, scale, axis step) of a box plot category.
            :param primary_y_axis_label_options: The label options (label text, label visibility and sort icon visibility) of a box plot value.
            :param reference_lines: The reference line setup of the visual.
            :param sort_configuration: The sort configuration of a ``BoxPlotVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__df46651962cedb1ef6652ed395524dbc2b63cba61bdd0276f355d4aea35da887)
                check_type(argname="argument box_plot_options", value=box_plot_options, expected_type=type_hints["box_plot_options"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if box_plot_options is not None:
                self._values["box_plot_options"] = box_plot_options
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def box_plot_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BoxPlotOptionsProperty"]]:
            '''The box plot chart options for a box plot visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-boxplotoptions
            '''
            result = self._values.get("box_plot_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BoxPlotOptionsProperty"]], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) of a box plot category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort Icon visibility) of a box plot category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BoxPlotFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BoxPlotFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) of a box plot category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) of a box plot value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineProperty"]]]]:
            '''The reference line setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineProperty"]]]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BoxPlotSortConfigurationProperty"]]:
            '''The sort configuration of a ``BoxPlotVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BoxPlotSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.BoxPlotFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "box_plot_aggregated_field_wells": "boxPlotAggregatedFieldWells",
        },
    )
    class BoxPlotFieldWellsProperty:
        def __init__(
            self,
            *,
            box_plot_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.BoxPlotAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``BoxPlotVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param box_plot_aggregated_field_wells: The aggregated field wells of a box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                box_plot_field_wells_property = quicksight.CfnAnalysis.BoxPlotFieldWellsProperty(
                    box_plot_aggregated_field_wells=quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ac1a8fba8f6c2f661b078e185c31574bc3d302ed5e28f085da15f15ce024416f)
                check_type(argname="argument box_plot_aggregated_field_wells", value=box_plot_aggregated_field_wells, expected_type=type_hints["box_plot_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if box_plot_aggregated_field_wells is not None:
                self._values["box_plot_aggregated_field_wells"] = box_plot_aggregated_field_wells

        @builtins.property
        def box_plot_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BoxPlotAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotfieldwells.html#cfn-quicksight-analysis-boxplotfieldwells-boxplotaggregatedfieldwells
            '''
            result = self._values.get("box_plot_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BoxPlotAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.BoxPlotOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "all_data_points_visibility": "allDataPointsVisibility",
            "outlier_visibility": "outlierVisibility",
            "style_options": "styleOptions",
        },
    )
    class BoxPlotOptionsProperty:
        def __init__(
            self,
            *,
            all_data_points_visibility: typing.Optional[builtins.str] = None,
            outlier_visibility: typing.Optional[builtins.str] = None,
            style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.BoxPlotStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options of a box plot visual.

            :param all_data_points_visibility: Determines the visibility of all data points of the box plot.
            :param outlier_visibility: Determines the visibility of the outlier in a box plot.
            :param style_options: The style options of the box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                box_plot_options_property = quicksight.CfnAnalysis.BoxPlotOptionsProperty(
                    all_data_points_visibility="allDataPointsVisibility",
                    outlier_visibility="outlierVisibility",
                    style_options=quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty(
                        fill_style="fillStyle"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f609ac1c7e2111a40dac58ec2bf94644d7ec89bb7e811f05ac3791b0bd840ca1)
                check_type(argname="argument all_data_points_visibility", value=all_data_points_visibility, expected_type=type_hints["all_data_points_visibility"])
                check_type(argname="argument outlier_visibility", value=outlier_visibility, expected_type=type_hints["outlier_visibility"])
                check_type(argname="argument style_options", value=style_options, expected_type=type_hints["style_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if all_data_points_visibility is not None:
                self._values["all_data_points_visibility"] = all_data_points_visibility
            if outlier_visibility is not None:
                self._values["outlier_visibility"] = outlier_visibility
            if style_options is not None:
                self._values["style_options"] = style_options

        @builtins.property
        def all_data_points_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of all data points of the box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotoptions.html#cfn-quicksight-analysis-boxplotoptions-alldatapointsvisibility
            '''
            result = self._values.get("all_data_points_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def outlier_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the outlier in a box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotoptions.html#cfn-quicksight-analysis-boxplotoptions-outliervisibility
            '''
            result = self._values.get("outlier_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BoxPlotStyleOptionsProperty"]]:
            '''The style options of the box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotoptions.html#cfn-quicksight-analysis-boxplotoptions-styleoptions
            '''
            result = self._values.get("style_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BoxPlotStyleOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.BoxPlotSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_sort": "categorySort",
            "pagination_configuration": "paginationConfiguration",
        },
    )
    class BoxPlotSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            pagination_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PaginationConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The sort configuration of a ``BoxPlotVisual`` .

            :param category_sort: The sort configuration of a group by fields.
            :param pagination_configuration: The pagination configuration of a table visual or box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                box_plot_sort_configuration_property = quicksight.CfnAnalysis.BoxPlotSortConfigurationProperty(
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                        page_number=123,
                        page_size=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4c1d82075e81046c13020ab880f86084f3bffe25cd8098d935779d515db720da)
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument pagination_configuration", value=pagination_configuration, expected_type=type_hints["pagination_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if pagination_configuration is not None:
                self._values["pagination_configuration"] = pagination_configuration

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of a group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotsortconfiguration.html#cfn-quicksight-analysis-boxplotsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def pagination_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PaginationConfigurationProperty"]]:
            '''The pagination configuration of a table visual or box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotsortconfiguration.html#cfn-quicksight-analysis-boxplotsortconfiguration-paginationconfiguration
            '''
            result = self._values.get("pagination_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PaginationConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"fill_style": "fillStyle"},
    )
    class BoxPlotStyleOptionsProperty:
        def __init__(self, *, fill_style: typing.Optional[builtins.str] = None) -> None:
            '''The style options of the box plot.

            :param fill_style: The fill styles (solid, transparent) of the box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                box_plot_style_options_property = quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty(
                    fill_style="fillStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__89d49edf39c70224f925125d76ee7b0de600605a2b15e684aa0b7ee96041320c)
                check_type(argname="argument fill_style", value=fill_style, expected_type=type_hints["fill_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if fill_style is not None:
                self._values["fill_style"] = fill_style

        @builtins.property
        def fill_style(self) -> typing.Optional[builtins.str]:
            '''The fill styles (solid, transparent) of the box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotstyleoptions.html#cfn-quicksight-analysis-boxplotstyleoptions-fillstyle
            '''
            result = self._values.get("fill_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.BoxPlotVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class BoxPlotVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.BoxPlotChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A box plot.

            For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5b3b42e671b910ca19129eb109ab58af3c253cd6b5c6f5c94a4b737e1287fcd6)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BoxPlotChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BoxPlotChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CalculatedFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "expression": "expression",
            "name": "name",
        },
    )
    class CalculatedFieldProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            expression: builtins.str,
            name: builtins.str,
        ) -> None:
            '''The calculated field of an analysis.

            :param data_set_identifier: The data set that is used in this calculated field.
            :param expression: The expression of the calculated field.
            :param name: The name of the calculated field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                calculated_field_property = quicksight.CfnAnalysis.CalculatedFieldProperty(
                    data_set_identifier="dataSetIdentifier",
                    expression="expression",
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2b3e5b275e2f35fcdf8efe7f2989ea0bda663184c63636414e26198b88057139)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "expression": expression,
                "name": name,
            }

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that is used in this calculated field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedfield.html#cfn-quicksight-analysis-calculatedfield-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the calculated field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedfield.html#cfn-quicksight-analysis-calculatedfield-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the calculated field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedfield.html#cfn-quicksight-analysis-calculatedfield-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CalculatedFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CalculatedMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "field_id": "fieldId"},
    )
    class CalculatedMeasureFieldProperty:
        def __init__(self, *, expression: builtins.str, field_id: builtins.str) -> None:
            '''The table calculation measure field for pivot tables.

            :param expression: The expression in the table calculation.
            :param field_id: The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                calculated_measure_field_property = quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                    expression="expression",
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0374ef2482b9185adce203520bc3bf342ce2682847ee02c9c7de9eb4b573df1b)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
                "field_id": field_id,
            }

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression in the table calculation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedmeasurefield.html#cfn-quicksight-analysis-calculatedmeasurefield-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedmeasurefield.html#cfn-quicksight-analysis-calculatedmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CalculatedMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CascadingControlConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"source_controls": "sourceControls"},
    )
    class CascadingControlConfigurationProperty:
        def __init__(
            self,
            *,
            source_controls: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CascadingControlSourceProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :param source_controls: A list of source controls that determine the values that are used in the current control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                cascading_control_configuration_property = quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                    source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                        column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        source_sheet_control_id="sourceSheetControlId"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e73299bcd6703fa1955807823fedc8668167418e46d6a1f346fdf0f2a291c90c)
                check_type(argname="argument source_controls", value=source_controls, expected_type=type_hints["source_controls"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if source_controls is not None:
                self._values["source_controls"] = source_controls

        @builtins.property
        def source_controls(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CascadingControlSourceProperty"]]]]:
            '''A list of source controls that determine the values that are used in the current control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolconfiguration.html#cfn-quicksight-analysis-cascadingcontrolconfiguration-sourcecontrols
            '''
            result = self._values.get("source_controls")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CascadingControlSourceProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CascadingControlConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CascadingControlSourceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_to_match": "columnToMatch",
            "source_sheet_control_id": "sourceSheetControlId",
        },
    )
    class CascadingControlSourceProperty:
        def __init__(
            self,
            *,
            column_to_match: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            source_sheet_control_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The source controls that are used in a ``CascadingControlConfiguration`` .

            :param column_to_match: The column identifier that determines which column to look up for the source sheet control.
            :param source_sheet_control_id: The source sheet control ID of a ``CascadingControlSource`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolsource.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                cascading_control_source_property = quicksight.CfnAnalysis.CascadingControlSourceProperty(
                    column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    source_sheet_control_id="sourceSheetControlId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7d12dfeb0e547c026b1df8c2f6d543f7aa0dc0842e96b7484d1e6da2e024e49d)
                check_type(argname="argument column_to_match", value=column_to_match, expected_type=type_hints["column_to_match"])
                check_type(argname="argument source_sheet_control_id", value=source_sheet_control_id, expected_type=type_hints["source_sheet_control_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_to_match is not None:
                self._values["column_to_match"] = column_to_match
            if source_sheet_control_id is not None:
                self._values["source_sheet_control_id"] = source_sheet_control_id

        @builtins.property
        def column_to_match(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]]:
            '''The column identifier that determines which column to look up for the source sheet control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolsource.html#cfn-quicksight-analysis-cascadingcontrolsource-columntomatch
            '''
            result = self._values.get("column_to_match")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]], result)

        @builtins.property
        def source_sheet_control_id(self) -> typing.Optional[builtins.str]:
            '''The source sheet control ID of a ``CascadingControlSource`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolsource.html#cfn-quicksight-analysis-cascadingcontrolsource-sourcesheetcontrolid
            '''
            result = self._values.get("source_sheet_control_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CascadingControlSourceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CategoricalDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class CategoricalDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with categorical type columns..

            :param column: The column that is used in the ``CategoricalDimensionField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                categorical_dimension_field_property = quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6f1f38bb0addf439daae4206b32dfabc93aced0cbdd4dc11840c7bc899eea7e3)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that is used in the ``CategoricalDimensionField`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html#cfn-quicksight-analysis-categoricaldimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html#cfn-quicksight-analysis-categoricaldimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.StringFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html#cfn-quicksight-analysis-categoricaldimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.StringFormatConfigurationProperty"]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html#cfn-quicksight-analysis-categoricaldimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoricalDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CategoricalMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class CategoricalMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            aggregation_function: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure type field with categorical type columns.

            :param column: The column that is used in the ``CategoricalMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                categorical_measure_field_property = quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function="aggregationFunction",
                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a9fcef98715e02f90cb5e1a80001e6046d16394dec171ccd1c964880913fe68c)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that is used in the ``CategoricalMeasureField`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html#cfn-quicksight-analysis-categoricalmeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html#cfn-quicksight-analysis-categoricalmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(self) -> typing.Optional[builtins.str]:
            '''The aggregation function of the measure field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html#cfn-quicksight-analysis-categoricalmeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.StringFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html#cfn-quicksight-analysis-categoricalmeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.StringFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoricalMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CategoryDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={"category_values": "categoryValues", "column": "column"},
    )
    class CategoryDrillDownFilterProperty:
        def __init__(
            self,
            *,
            category_values: typing.Sequence[builtins.str],
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The numeric equality type drill down filter.

            :param category_values: A list of the string inputs that are the values of the category drill down filter.
            :param column: The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categorydrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                category_drill_down_filter_property = quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                    category_values=["categoryValues"],
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__723c70aef9408e55ed338e2c0930c0382941de2c4ef2a7418407d520c5de26b3)
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category_values": category_values,
                "column": column,
            }

        @builtins.property
        def category_values(self) -> typing.List[builtins.str]:
            '''A list of the string inputs that are the values of the category drill down filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categorydrilldownfilter.html#cfn-quicksight-analysis-categorydrilldownfilter-categoryvalues
            '''
            result = self._values.get("category_values")
            assert result is not None, "Required property 'category_values' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categorydrilldownfilter.html#cfn-quicksight-analysis-categorydrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CategoryFilterConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_filter_configuration": "customFilterConfiguration",
            "custom_filter_list_configuration": "customFilterListConfiguration",
            "filter_list_configuration": "filterListConfiguration",
        },
    )
    class CategoryFilterConfigurationProperty:
        def __init__(
            self,
            *,
            custom_filter_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CustomFilterConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_filter_list_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CustomFilterListConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            filter_list_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilterListConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``CategoryFilter`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_filter_configuration: A custom filter that filters based on a single value. This filter can be partially matched.
            :param custom_filter_list_configuration: A list of custom filter values. In the Amazon QuickSight console, this filter type is called a custom filter list.
            :param filter_list_configuration: A list of filter configurations. In the Amazon QuickSight console, this filter type is called a filter list.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilterconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                category_filter_configuration_property = quicksight.CfnAnalysis.CategoryFilterConfigurationProperty(
                    custom_filter_configuration=quicksight.CfnAnalysis.CustomFilterConfigurationProperty(
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        category_value="categoryValue",
                        parameter_name="parameterName",
                        select_all_options="selectAllOptions"
                    ),
                    custom_filter_list_configuration=quicksight.CfnAnalysis.CustomFilterListConfigurationProperty(
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        category_values=["categoryValues"],
                        select_all_options="selectAllOptions"
                    ),
                    filter_list_configuration=quicksight.CfnAnalysis.FilterListConfigurationProperty(
                        match_operator="matchOperator",
                
                        # the properties below are optional
                        category_values=["categoryValues"],
                        null_option="nullOption",
                        select_all_options="selectAllOptions"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a6e5a83eb58b86ba1db93dde36f36bc38753955033efcd6df85274323c052315)
                check_type(argname="argument custom_filter_configuration", value=custom_filter_configuration, expected_type=type_hints["custom_filter_configuration"])
                check_type(argname="argument custom_filter_list_configuration", value=custom_filter_list_configuration, expected_type=type_hints["custom_filter_list_configuration"])
                check_type(argname="argument filter_list_configuration", value=filter_list_configuration, expected_type=type_hints["filter_list_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_filter_configuration is not None:
                self._values["custom_filter_configuration"] = custom_filter_configuration
            if custom_filter_list_configuration is not None:
                self._values["custom_filter_list_configuration"] = custom_filter_list_configuration
            if filter_list_configuration is not None:
                self._values["filter_list_configuration"] = filter_list_configuration

        @builtins.property
        def custom_filter_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomFilterConfigurationProperty"]]:
            '''A custom filter that filters based on a single value.

            This filter can be partially matched.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilterconfiguration.html#cfn-quicksight-analysis-categoryfilterconfiguration-customfilterconfiguration
            '''
            result = self._values.get("custom_filter_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomFilterConfigurationProperty"]], result)

        @builtins.property
        def custom_filter_list_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomFilterListConfigurationProperty"]]:
            '''A list of custom filter values.

            In the Amazon QuickSight console, this filter type is called a custom filter list.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilterconfiguration.html#cfn-quicksight-analysis-categoryfilterconfiguration-customfilterlistconfiguration
            '''
            result = self._values.get("custom_filter_list_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomFilterListConfigurationProperty"]], result)

        @builtins.property
        def filter_list_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterListConfigurationProperty"]]:
            '''A list of filter configurations.

            In the Amazon QuickSight console, this filter type is called a filter list.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilterconfiguration.html#cfn-quicksight-analysis-categoryfilterconfiguration-filterlistconfiguration
            '''
            result = self._values.get("filter_list_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterListConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryFilterConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CategoryFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "configuration": "configuration",
            "filter_id": "filterId",
        },
    )
    class CategoryFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CategoryFilterConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
        ) -> None:
            '''A ``CategoryFilter`` filters text values.

            For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .

            :param column: The column that the filter is applied to.
            :param configuration: The configuration for a ``CategoryFilter`` .
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                category_filter_property = quicksight.CfnAnalysis.CategoryFilterProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    configuration=quicksight.CfnAnalysis.CategoryFilterConfigurationProperty(
                        custom_filter_configuration=quicksight.CfnAnalysis.CustomFilterConfigurationProperty(
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            category_value="categoryValue",
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions"
                        ),
                        custom_filter_list_configuration=quicksight.CfnAnalysis.CustomFilterListConfigurationProperty(
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            category_values=["categoryValues"],
                            select_all_options="selectAllOptions"
                        ),
                        filter_list_configuration=quicksight.CfnAnalysis.FilterListConfigurationProperty(
                            match_operator="matchOperator",
                
                            # the properties below are optional
                            category_values=["categoryValues"],
                            null_option="nullOption",
                            select_all_options="selectAllOptions"
                        )
                    ),
                    filter_id="filterId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cd5df25b1a6ff9a1098d6d573aaa7220ac13f7af43bbeca0f4bc97a2cef5b96f)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "configuration": configuration,
                "filter_id": filter_id,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilter.html#cfn-quicksight-analysis-categoryfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CategoryFilterConfigurationProperty"]:
            '''The configuration for a ``CategoryFilter`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilter.html#cfn-quicksight-analysis-categoryfilter-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CategoryFilterConfigurationProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilter.html#cfn-quicksight-analysis-categoryfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_label_options": "axisLabelOptions",
            "sort_icon_visibility": "sortIconVisibility",
            "visibility": "visibility",
        },
    )
    class ChartAxisLabelOptionsProperty:
        def __init__(
            self,
            *,
            axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sort_icon_visibility: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label options for an axis on a chart.

            :param axis_label_options: The label options for a chart axis.
            :param sort_icon_visibility: The visibility configuration of the sort icon on a chart's axis label.
            :param visibility: The visibility of an axis label on a chart. Choose one of the following options:. - ``VISIBLE`` : Shows the axis. - ``HIDDEN`` : Hides the axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-chartaxislabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                chart_axis_label_options_property = quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId"
                        ),
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        )
                    )],
                    sort_icon_visibility="sortIconVisibility",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cdb4eeafd511c20ae740891fafdc3d7f3d7cfde84fc43817149bce640d505ce6)
                check_type(argname="argument axis_label_options", value=axis_label_options, expected_type=type_hints["axis_label_options"])
                check_type(argname="argument sort_icon_visibility", value=sort_icon_visibility, expected_type=type_hints["sort_icon_visibility"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_label_options is not None:
                self._values["axis_label_options"] = axis_label_options
            if sort_icon_visibility is not None:
                self._values["sort_icon_visibility"] = sort_icon_visibility
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisLabelOptionsProperty"]]]]:
            '''The label options for a chart axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-chartaxislabeloptions.html#cfn-quicksight-analysis-chartaxislabeloptions-axislabeloptions
            '''
            result = self._values.get("axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisLabelOptionsProperty"]]]], result)

        @builtins.property
        def sort_icon_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the sort icon on a chart's axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-chartaxislabeloptions.html#cfn-quicksight-analysis-chartaxislabeloptions-sorticonvisibility
            '''
            result = self._values.get("sort_icon_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of an axis label on a chart. Choose one of the following options:.

            - ``VISIBLE`` : Shows the axis.
            - ``HIDDEN`` : Hides the axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-chartaxislabeloptions.html#cfn-quicksight-analysis-chartaxislabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ChartAxisLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"cluster_marker": "clusterMarker"},
    )
    class ClusterMarkerConfigurationProperty:
        def __init__(
            self,
            *,
            cluster_marker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ClusterMarkerProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cluster marker configuration of the geospatial map selected point style.

            :param cluster_marker: The cluster marker that is a part of the cluster marker configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-clustermarkerconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                cluster_marker_configuration_property = quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty(
                    cluster_marker=quicksight.CfnAnalysis.ClusterMarkerProperty(
                        simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__98f37cdd4ca6a15f7da6a38e0b8de29bb69f8019e6eed91dd94d65ca0e9ecd7f)
                check_type(argname="argument cluster_marker", value=cluster_marker, expected_type=type_hints["cluster_marker"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cluster_marker is not None:
                self._values["cluster_marker"] = cluster_marker

        @builtins.property
        def cluster_marker(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ClusterMarkerProperty"]]:
            '''The cluster marker that is a part of the cluster marker configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-clustermarkerconfiguration.html#cfn-quicksight-analysis-clustermarkerconfiguration-clustermarker
            '''
            result = self._values.get("cluster_marker")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ClusterMarkerProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ClusterMarkerConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ClusterMarkerProperty",
        jsii_struct_bases=[],
        name_mapping={"simple_cluster_marker": "simpleClusterMarker"},
    )
    class ClusterMarkerProperty:
        def __init__(
            self,
            *,
            simple_cluster_marker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SimpleClusterMarkerProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cluster marker that is a part of the cluster marker configuration.

            :param simple_cluster_marker: The simple cluster marker of the cluster marker.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-clustermarker.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                cluster_marker_property = quicksight.CfnAnalysis.ClusterMarkerProperty(
                    simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                        color="color"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4a2783133d20e8b551d6ea144cbd6b328f577eb8803ad9ccc941a6626951f69f)
                check_type(argname="argument simple_cluster_marker", value=simple_cluster_marker, expected_type=type_hints["simple_cluster_marker"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if simple_cluster_marker is not None:
                self._values["simple_cluster_marker"] = simple_cluster_marker

        @builtins.property
        def simple_cluster_marker(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SimpleClusterMarkerProperty"]]:
            '''The simple cluster marker of the cluster marker.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-clustermarker.html#cfn-quicksight-analysis-clustermarker-simpleclustermarker
            '''
            result = self._values.get("simple_cluster_marker")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SimpleClusterMarkerProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ClusterMarkerProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ColorScaleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_fill_type": "colorFillType",
            "colors": "colors",
            "null_value_color": "nullValueColor",
        },
    )
    class ColorScaleProperty:
        def __init__(
            self,
            *,
            color_fill_type: builtins.str,
            colors: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataColorProperty", typing.Dict[builtins.str, typing.Any]]]]],
            null_value_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Determines the color scale that is applied to the visual.

            :param color_fill_type: Determines the color fill type.
            :param colors: Determines the list of colors that are applied to the visual.
            :param null_value_color: Determines the color that is applied to null values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                color_scale_property = quicksight.CfnAnalysis.ColorScaleProperty(
                    color_fill_type="colorFillType",
                    colors=[quicksight.CfnAnalysis.DataColorProperty(
                        color="color",
                        data_value=123
                    )],
                
                    # the properties below are optional
                    null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                        color="color",
                        data_value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f689b41b461f9d73e613d32fb06c81644f5d7da73bc45bce6809d7b5b2e1602c)
                check_type(argname="argument color_fill_type", value=color_fill_type, expected_type=type_hints["color_fill_type"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument null_value_color", value=null_value_color, expected_type=type_hints["null_value_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color_fill_type": color_fill_type,
                "colors": colors,
            }
            if null_value_color is not None:
                self._values["null_value_color"] = null_value_color

        @builtins.property
        def color_fill_type(self) -> builtins.str:
            '''Determines the color fill type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorscale.html#cfn-quicksight-analysis-colorscale-colorfilltype
            '''
            result = self._values.get("color_fill_type")
            assert result is not None, "Required property 'color_fill_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataColorProperty"]]]:
            '''Determines the list of colors that are applied to the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorscale.html#cfn-quicksight-analysis-colorscale-colors
            '''
            result = self._values.get("colors")
            assert result is not None, "Required property 'colors' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataColorProperty"]]], result)

        @builtins.property
        def null_value_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataColorProperty"]]:
            '''Determines the color that is applied to null values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorscale.html#cfn-quicksight-analysis-colorscale-nullvaluecolor
            '''
            result = self._values.get("null_value_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColorScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ColorsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_colors": "customColors"},
    )
    class ColorsConfigurationProperty:
        def __init__(
            self,
            *,
            custom_colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CustomColorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The color configurations for a column.

            :param custom_colors: A list of up to 50 custom colors.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                colors_configuration_property = quicksight.CfnAnalysis.ColorsConfigurationProperty(
                    custom_colors=[quicksight.CfnAnalysis.CustomColorProperty(
                        color="color",
                
                        # the properties below are optional
                        field_value="fieldValue",
                        special_value="specialValue"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7f072c6c4e3112557f99bd411406e084171378a001e7229e58365a958f5a28e8)
                check_type(argname="argument custom_colors", value=custom_colors, expected_type=type_hints["custom_colors"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_colors is not None:
                self._values["custom_colors"] = custom_colors

        @builtins.property
        def custom_colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomColorProperty"]]]]:
            '''A list of up to 50 custom colors.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorsconfiguration.html#cfn-quicksight-analysis-colorsconfiguration-customcolors
            '''
            result = self._values.get("custom_colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomColorProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColorsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ColumnConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "colors_configuration": "colorsConfiguration",
            "format_configuration": "formatConfiguration",
            "role": "role",
        },
    )
    class ColumnConfigurationProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            colors_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColorsConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            role: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The general configuration of a column.

            :param column: The column.
            :param colors_configuration: The color configurations of the column.
            :param format_configuration: The format configuration of a column.
            :param role: The role of the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_configuration_property = quicksight.CfnAnalysis.ColumnConfigurationProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    colors_configuration=quicksight.CfnAnalysis.ColorsConfigurationProperty(
                        custom_colors=[quicksight.CfnAnalysis.CustomColorProperty(
                            color="color",
                
                            # the properties below are optional
                            field_value="fieldValue",
                            special_value="specialValue"
                        )]
                    ),
                    format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    role="role"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0caa6540ab9ae618258469c56ddb4a7ac1db36480f095b1823437269d94846d9)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument colors_configuration", value=colors_configuration, expected_type=type_hints["colors_configuration"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument role", value=role, expected_type=type_hints["role"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
            }
            if colors_configuration is not None:
                self._values["colors_configuration"] = colors_configuration
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if role is not None:
                self._values["role"] = role

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html#cfn-quicksight-analysis-columnconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def colors_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColorsConfigurationProperty"]]:
            '''The color configurations of the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html#cfn-quicksight-analysis-columnconfiguration-colorsconfiguration
            '''
            result = self._values.get("colors_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColorsConfigurationProperty"]], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FormatConfigurationProperty"]]:
            '''The format configuration of a column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html#cfn-quicksight-analysis-columnconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FormatConfigurationProperty"]], result)

        @builtins.property
        def role(self) -> typing.Optional[builtins.str]:
            '''The role of the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html#cfn-quicksight-analysis-columnconfiguration-role
            '''
            result = self._values.get("role")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ColumnHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_hierarchy": "dateTimeHierarchy",
            "explicit_hierarchy": "explicitHierarchy",
            "predefined_hierarchy": "predefinedHierarchy",
        },
    )
    class ColumnHierarchyProperty:
        def __init__(
            self,
            *,
            date_time_hierarchy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DateTimeHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            explicit_hierarchy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ExplicitHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            predefined_hierarchy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PredefinedHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields for a visual element.

            :param date_time_hierarchy: The option that determines the hierarchy of any ``DateTime`` fields.
            :param explicit_hierarchy: The option that determines the hierarchy of the fields that are built within a visual's field wells. These fields can't be duplicated to other visuals.
            :param predefined_hierarchy: The option that determines the hierarchy of the fields that are defined during data preparation. These fields are available to use in any analysis that uses the data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnhierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_hierarchy_property = quicksight.CfnAnalysis.ColumnHierarchyProperty(
                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    ),
                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    ),
                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9af0953c9dd6d093bb97c949a7eafa66197bdadb0d2a6546efbbea740696b37e)
                check_type(argname="argument date_time_hierarchy", value=date_time_hierarchy, expected_type=type_hints["date_time_hierarchy"])
                check_type(argname="argument explicit_hierarchy", value=explicit_hierarchy, expected_type=type_hints["explicit_hierarchy"])
                check_type(argname="argument predefined_hierarchy", value=predefined_hierarchy, expected_type=type_hints["predefined_hierarchy"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_hierarchy is not None:
                self._values["date_time_hierarchy"] = date_time_hierarchy
            if explicit_hierarchy is not None:
                self._values["explicit_hierarchy"] = explicit_hierarchy
            if predefined_hierarchy is not None:
                self._values["predefined_hierarchy"] = predefined_hierarchy

        @builtins.property
        def date_time_hierarchy(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateTimeHierarchyProperty"]]:
            '''The option that determines the hierarchy of any ``DateTime`` fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnhierarchy.html#cfn-quicksight-analysis-columnhierarchy-datetimehierarchy
            '''
            result = self._values.get("date_time_hierarchy")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateTimeHierarchyProperty"]], result)

        @builtins.property
        def explicit_hierarchy(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ExplicitHierarchyProperty"]]:
            '''The option that determines the hierarchy of the fields that are built within a visual's field wells.

            These fields can't be duplicated to other visuals.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnhierarchy.html#cfn-quicksight-analysis-columnhierarchy-explicithierarchy
            '''
            result = self._values.get("explicit_hierarchy")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ExplicitHierarchyProperty"]], result)

        @builtins.property
        def predefined_hierarchy(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PredefinedHierarchyProperty"]]:
            '''The option that determines the hierarchy of the fields that are defined during data preparation.

            These fields are available to use in any analysis that uses the data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnhierarchy.html#cfn-quicksight-analysis-columnhierarchy-predefinedhierarchy
            '''
            result = self._values.get("predefined_hierarchy")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PredefinedHierarchyProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ColumnIdentifierProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_name": "columnName",
            "data_set_identifier": "dataSetIdentifier",
        },
    )
    class ColumnIdentifierProperty:
        def __init__(
            self,
            *,
            column_name: builtins.str,
            data_set_identifier: builtins.str,
        ) -> None:
            '''A column of a data set.

            :param column_name: The name of the column.
            :param data_set_identifier: The data set that the column belongs to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnidentifier.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_identifier_property = quicksight.CfnAnalysis.ColumnIdentifierProperty(
                    column_name="columnName",
                    data_set_identifier="dataSetIdentifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__46742d202db724573544c68fcaf77bebd24074a6cfe5236855684fee3384e8ad)
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_name": column_name,
                "data_set_identifier": data_set_identifier,
            }

        @builtins.property
        def column_name(self) -> builtins.str:
            '''The name of the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnidentifier.html#cfn-quicksight-analysis-columnidentifier-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that the column belongs to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnidentifier.html#cfn-quicksight-analysis-columnidentifier-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnIdentifierProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ColumnSortProperty",
        jsii_struct_bases=[],
        name_mapping={
            "direction": "direction",
            "sort_by": "sortBy",
            "aggregation_function": "aggregationFunction",
        },
    )
    class ColumnSortProperty:
        def __init__(
            self,
            *,
            direction: builtins.str,
            sort_by: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The sort configuration for a column that is not used in a field well.

            :param direction: The sort direction.
            :param sort_by: 
            :param aggregation_function: The aggregation function that is defined in the column sort.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_sort_property = quicksight.CfnAnalysis.ColumnSortProperty(
                    direction="direction",
                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                        attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                            simple_attribute_aggregation="simpleAttributeAggregation",
                            value_for_multiple_values="valueForMultipleValues"
                        ),
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f5996308d06dca8fcdc4fccbb3e75d61da28c753855f270dcfe532b6588e65d4)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument sort_by", value=sort_by, expected_type=type_hints["sort_by"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "sort_by": sort_by,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function

        @builtins.property
        def direction(self) -> builtins.str:
            '''The sort direction.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnsort.html#cfn-quicksight-analysis-columnsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_by(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnsort.html#cfn-quicksight-analysis-columnsort-sortby
            '''
            result = self._values.get("sort_by")
            assert result is not None, "Required property 'sort_by' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AggregationFunctionProperty"]]:
            '''The aggregation function that is defined in the column sort.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnsort.html#cfn-quicksight-analysis-columnsort-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AggregationFunctionProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ColumnTooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "aggregation": "aggregation",
            "label": "label",
            "visibility": "visibility",
        },
    )
    class ColumnTooltipItemProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            aggregation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The tooltip item for the columns that are not part of a field well.

            :param column: The target column of the tooltip item.
            :param aggregation: The aggregation function of the column tooltip item.
            :param label: The label of the tooltip item.
            :param visibility: The visibility of the tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_tooltip_item_property = quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                        attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                            simple_attribute_aggregation="simpleAttributeAggregation",
                            value_for_multiple_values="valueForMultipleValues"
                        ),
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    label="label",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__12db1f9cc37d2edf229e12062c9eab5719bcac0eab45d7cef4de82861fd08916)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
            }
            if aggregation is not None:
                self._values["aggregation"] = aggregation
            if label is not None:
                self._values["label"] = label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The target column of the tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html#cfn-quicksight-analysis-columntooltipitem-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def aggregation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AggregationFunctionProperty"]]:
            '''The aggregation function of the column tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html#cfn-quicksight-analysis-columntooltipitem-aggregation
            '''
            result = self._values.get("aggregation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AggregationFunctionProperty"]], result)

        @builtins.property
        def label(self) -> typing.Optional[builtins.str]:
            '''The label of the tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html#cfn-quicksight-analysis-columntooltipitem-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html#cfn-quicksight-analysis-columntooltipitem-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnTooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ComboChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_values": "barValues",
            "category": "category",
            "colors": "colors",
            "line_values": "lineValues",
        },
    )
    class ComboChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            bar_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            line_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a combo chart.

            :param bar_values: The aggregated ``BarValues`` field well of a combo chart.
            :param category: The aggregated category field wells of a combo chart.
            :param colors: The aggregated colors field well of a combo chart.
            :param line_values: The aggregated ``LineValues`` field well of a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__591a9749b2006f091f1b536872c6d1c0855cefdd0be4aee2b30d49d9fbfa0233)
                check_type(argname="argument bar_values", value=bar_values, expected_type=type_hints["bar_values"])
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument line_values", value=line_values, expected_type=type_hints["line_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_values is not None:
                self._values["bar_values"] = bar_values
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if line_values is not None:
                self._values["line_values"] = line_values

        @builtins.property
        def bar_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The aggregated ``BarValues`` field well of a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html#cfn-quicksight-analysis-combochartaggregatedfieldwells-barvalues
            '''
            result = self._values.get("bar_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The aggregated category field wells of a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html#cfn-quicksight-analysis-combochartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The aggregated colors field well of a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html#cfn-quicksight-analysis-combochartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def line_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The aggregated ``LineValues`` field well of a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html#cfn-quicksight-analysis-combochartaggregatedfieldwells-linevalues
            '''
            result = self._values.get("line_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ComboChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_data_labels": "barDataLabels",
            "bars_arrangement": "barsArrangement",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_label_options": "colorLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "line_data_labels": "lineDataLabels",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "secondary_y_axis_display_options": "secondaryYAxisDisplayOptions",
            "secondary_y_axis_label_options": "secondaryYAxisLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
        },
    )
    class ComboChartConfigurationProperty:
        def __init__(
            self,
            *,
            bar_data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            bars_arrangement: typing.Optional[builtins.str] = None,
            category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ComboChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            line_data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            secondary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ComboChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``ComboChartVisual`` .

            :param bar_data_labels: The options that determine if visual data labels are displayed. The data label options for a bar in a combo chart.
            :param bars_arrangement: Determines the bar arrangement in a combo chart. The following are valid values in this structure:. - ``CLUSTERED`` : For clustered bar combo charts. - ``STACKED`` : For stacked bar combo charts. - ``STACKED_PERCENT`` : Do not use. If you use this value, the operation returns a validation error.
            :param category_axis: The category axis of a combo chart.
            :param category_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.
            :param color_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param line_data_labels: The options that determine if visual data labels are displayed. The data label options for a line in a combo chart.
            :param primary_y_axis_display_options: The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.
            :param primary_y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.
            :param reference_lines: The reference line setup of the visual.
            :param secondary_y_axis_display_options: The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.
            :param secondary_y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.
            :param sort_configuration: The sort configuration of a ``ComboChartVisual`` .
            :param tooltip: The legend display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a515c71821e7f00825720a4573683ad269b842d55f7b80847bdc1398d91a83f9)
                check_type(argname="argument bar_data_labels", value=bar_data_labels, expected_type=type_hints["bar_data_labels"])
                check_type(argname="argument bars_arrangement", value=bars_arrangement, expected_type=type_hints["bars_arrangement"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument line_data_labels", value=line_data_labels, expected_type=type_hints["line_data_labels"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument secondary_y_axis_display_options", value=secondary_y_axis_display_options, expected_type=type_hints["secondary_y_axis_display_options"])
                check_type(argname="argument secondary_y_axis_label_options", value=secondary_y_axis_label_options, expected_type=type_hints["secondary_y_axis_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_data_labels is not None:
                self._values["bar_data_labels"] = bar_data_labels
            if bars_arrangement is not None:
                self._values["bars_arrangement"] = bars_arrangement
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if line_data_labels is not None:
                self._values["line_data_labels"] = line_data_labels
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if secondary_y_axis_display_options is not None:
                self._values["secondary_y_axis_display_options"] = secondary_y_axis_display_options
            if secondary_y_axis_label_options is not None:
                self._values["secondary_y_axis_label_options"] = secondary_y_axis_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def bar_data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            The data label options for a bar in a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-bardatalabels
            '''
            result = self._values.get("bar_data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def bars_arrangement(self) -> typing.Optional[builtins.str]:
            '''Determines the bar arrangement in a combo chart. The following are valid values in this structure:.

            - ``CLUSTERED`` : For clustered bar combo charts.
            - ``STACKED`` : For stacked bar combo charts.
            - ``STACKED_PERCENT`` : Do not use. If you use this value, the operation returns a validation error.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-barsarrangement
            '''
            result = self._values.get("bars_arrangement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The category axis of a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ComboChartFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ComboChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def line_data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            The data label options for a line in a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-linedatalabels
            '''
            result = self._values.get("line_data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineProperty"]]]]:
            '''The reference line setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineProperty"]]]], result)

        @builtins.property
        def secondary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-secondaryyaxisdisplayoptions
            '''
            result = self._values.get("secondary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def secondary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-secondaryyaxislabeloptions
            '''
            result = self._values.get("secondary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ComboChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``ComboChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ComboChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ComboChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "combo_chart_aggregated_field_wells": "comboChartAggregatedFieldWells",
        },
    )
    class ComboChartFieldWellsProperty:
        def __init__(
            self,
            *,
            combo_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ComboChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of the visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param combo_chart_aggregated_field_wells: The aggregated field wells of a combo chart. Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3147af60ae2143d1a034a36f8c9a82e70085ccb8ab9084867cf2765ed2324af3)
                check_type(argname="argument combo_chart_aggregated_field_wells", value=combo_chart_aggregated_field_wells, expected_type=type_hints["combo_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if combo_chart_aggregated_field_wells is not None:
                self._values["combo_chart_aggregated_field_wells"] = combo_chart_aggregated_field_wells

        @builtins.property
        def combo_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ComboChartAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a combo chart.

            Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartfieldwells.html#cfn-quicksight-analysis-combochartfieldwells-combochartaggregatedfieldwells
            '''
            result = self._values.get("combo_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ComboChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ComboChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
        },
    )
    class ComboChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``ComboChartVisual`` .

            :param category_items_limit: The item limit configuration for the category field well of a combo chart.
            :param category_sort: The sort configuration of the category field well in a combo chart.
            :param color_items_limit: The item limit configuration of the color field well in a combo chart.
            :param color_sort: The sort configuration of the color field well in a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                combo_chart_sort_configuration_property = quicksight.CfnAnalysis.ComboChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__faaa8b2a496188587008b5c7df0d9610c9d579850447a07f3ed4c0e5d23a2ad5)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The item limit configuration for the category field well of a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html#cfn-quicksight-analysis-combochartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category field well in a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html#cfn-quicksight-analysis-combochartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The item limit configuration of the color field well in a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html#cfn-quicksight-analysis-combochartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the color field well in a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html#cfn-quicksight-analysis-combochartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ComboChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class ComboChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ComboChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A combo chart.

            The ``ComboChartVisual`` includes stacked bar combo charts and clustered bar combo charts

            For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b14c3bbad40e0afa7fd81b42e30c7725d3f3d5f2db8054112cc12f490640ad4c)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ComboChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ComboChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ComparisonConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "comparison_format": "comparisonFormat",
            "comparison_method": "comparisonMethod",
        },
    )
    class ComparisonConfigurationProperty:
        def __init__(
            self,
            *,
            comparison_format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ComparisonFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            comparison_method: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The comparison display configuration of a KPI or gauge chart.

            :param comparison_format: The format of the comparison.
            :param comparison_method: The method of the comparison. Choose from the following options:. - ``DIFFERENCE`` - ``PERCENT_DIFFERENCE`` - ``PERCENT``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                comparison_configuration_property = quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                    comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    ),
                    comparison_method="comparisonMethod"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__efcddd73fc9f096352e7d41e36263d6ac82160f33a961daa63e25016155bb1d7)
                check_type(argname="argument comparison_format", value=comparison_format, expected_type=type_hints["comparison_format"])
                check_type(argname="argument comparison_method", value=comparison_method, expected_type=type_hints["comparison_method"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if comparison_format is not None:
                self._values["comparison_format"] = comparison_format
            if comparison_method is not None:
                self._values["comparison_method"] = comparison_method

        @builtins.property
        def comparison_format(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ComparisonFormatConfigurationProperty"]]:
            '''The format of the comparison.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonconfiguration.html#cfn-quicksight-analysis-comparisonconfiguration-comparisonformat
            '''
            result = self._values.get("comparison_format")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ComparisonFormatConfigurationProperty"]], result)

        @builtins.property
        def comparison_method(self) -> typing.Optional[builtins.str]:
            '''The method of the comparison. Choose from the following options:.

            - ``DIFFERENCE``
            - ``PERCENT_DIFFERENCE``
            - ``PERCENT``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonconfiguration.html#cfn-quicksight-analysis-comparisonconfiguration-comparisonmethod
            '''
            result = self._values.get("comparison_method")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComparisonConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "number_display_format_configuration": "numberDisplayFormatConfiguration",
            "percentage_display_format_configuration": "percentageDisplayFormatConfiguration",
        },
    )
    class ComparisonFormatConfigurationProperty:
        def __init__(
            self,
            *,
            number_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumberDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            percentage_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PercentageDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The format of the comparison.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param number_display_format_configuration: The number display format.
            :param percentage_display_format_configuration: The percentage display format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                comparison_format_configuration_property = quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    ),
                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        prefix="prefix",
                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aa91709855f99095961061d282729fba9d83b47411ddcd5cc76b3c7ee88b4975)
                check_type(argname="argument number_display_format_configuration", value=number_display_format_configuration, expected_type=type_hints["number_display_format_configuration"])
                check_type(argname="argument percentage_display_format_configuration", value=percentage_display_format_configuration, expected_type=type_hints["percentage_display_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if number_display_format_configuration is not None:
                self._values["number_display_format_configuration"] = number_display_format_configuration
            if percentage_display_format_configuration is not None:
                self._values["percentage_display_format_configuration"] = percentage_display_format_configuration

        @builtins.property
        def number_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumberDisplayFormatConfigurationProperty"]]:
            '''The number display format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonformatconfiguration.html#cfn-quicksight-analysis-comparisonformatconfiguration-numberdisplayformatconfiguration
            '''
            result = self._values.get("number_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumberDisplayFormatConfigurationProperty"]], result)

        @builtins.property
        def percentage_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PercentageDisplayFormatConfigurationProperty"]]:
            '''The percentage display format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonformatconfiguration.html#cfn-quicksight-analysis-comparisonformatconfiguration-percentagedisplayformatconfiguration
            '''
            result = self._values.get("percentage_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PercentageDisplayFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComparisonFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "forecast": "forecast",
            "growth_rate": "growthRate",
            "maximum_minimum": "maximumMinimum",
            "metric_comparison": "metricComparison",
            "period_over_period": "periodOverPeriod",
            "period_to_date": "periodToDate",
            "top_bottom_movers": "topBottomMovers",
            "top_bottom_ranked": "topBottomRanked",
            "total_aggregation": "totalAggregation",
            "unique_values": "uniqueValues",
        },
    )
    class ComputationProperty:
        def __init__(
            self,
            *,
            forecast: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ForecastComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            growth_rate: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GrowthRateComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            maximum_minimum: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MaximumMinimumComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            metric_comparison: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MetricComparisonComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            period_over_period: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PeriodOverPeriodComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            period_to_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PeriodToDateComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top_bottom_movers: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TopBottomMoversComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top_bottom_ranked: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TopBottomRankedComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            total_aggregation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TotalAggregationComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            unique_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.UniqueValuesComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The computation union that is used in an insight visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param forecast: The forecast computation configuration.
            :param growth_rate: The growth rate computation configuration.
            :param maximum_minimum: The maximum and minimum computation configuration.
            :param metric_comparison: The metric comparison computation configuration.
            :param period_over_period: The period over period computation configuration.
            :param period_to_date: The period to ``DataSetIdentifier`` computation configuration.
            :param top_bottom_movers: The top movers and bottom movers computation configuration.
            :param top_bottom_ranked: The top ranked and bottom ranked computation configuration.
            :param total_aggregation: The total aggregation computation configuration.
            :param unique_values: The unique values computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__10d34f637e011375fff8ef66740a653ac3902a71882f8c6c5f45e4c23f09f53d)
                check_type(argname="argument forecast", value=forecast, expected_type=type_hints["forecast"])
                check_type(argname="argument growth_rate", value=growth_rate, expected_type=type_hints["growth_rate"])
                check_type(argname="argument maximum_minimum", value=maximum_minimum, expected_type=type_hints["maximum_minimum"])
                check_type(argname="argument metric_comparison", value=metric_comparison, expected_type=type_hints["metric_comparison"])
                check_type(argname="argument period_over_period", value=period_over_period, expected_type=type_hints["period_over_period"])
                check_type(argname="argument period_to_date", value=period_to_date, expected_type=type_hints["period_to_date"])
                check_type(argname="argument top_bottom_movers", value=top_bottom_movers, expected_type=type_hints["top_bottom_movers"])
                check_type(argname="argument top_bottom_ranked", value=top_bottom_ranked, expected_type=type_hints["top_bottom_ranked"])
                check_type(argname="argument total_aggregation", value=total_aggregation, expected_type=type_hints["total_aggregation"])
                check_type(argname="argument unique_values", value=unique_values, expected_type=type_hints["unique_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if forecast is not None:
                self._values["forecast"] = forecast
            if growth_rate is not None:
                self._values["growth_rate"] = growth_rate
            if maximum_minimum is not None:
                self._values["maximum_minimum"] = maximum_minimum
            if metric_comparison is not None:
                self._values["metric_comparison"] = metric_comparison
            if period_over_period is not None:
                self._values["period_over_period"] = period_over_period
            if period_to_date is not None:
                self._values["period_to_date"] = period_to_date
            if top_bottom_movers is not None:
                self._values["top_bottom_movers"] = top_bottom_movers
            if top_bottom_ranked is not None:
                self._values["top_bottom_ranked"] = top_bottom_ranked
            if total_aggregation is not None:
                self._values["total_aggregation"] = total_aggregation
            if unique_values is not None:
                self._values["unique_values"] = unique_values

        @builtins.property
        def forecast(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ForecastComputationProperty"]]:
            '''The forecast computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-forecast
            '''
            result = self._values.get("forecast")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ForecastComputationProperty"]], result)

        @builtins.property
        def growth_rate(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GrowthRateComputationProperty"]]:
            '''The growth rate computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-growthrate
            '''
            result = self._values.get("growth_rate")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GrowthRateComputationProperty"]], result)

        @builtins.property
        def maximum_minimum(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MaximumMinimumComputationProperty"]]:
            '''The maximum and minimum computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-maximumminimum
            '''
            result = self._values.get("maximum_minimum")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MaximumMinimumComputationProperty"]], result)

        @builtins.property
        def metric_comparison(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MetricComparisonComputationProperty"]]:
            '''The metric comparison computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-metriccomparison
            '''
            result = self._values.get("metric_comparison")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MetricComparisonComputationProperty"]], result)

        @builtins.property
        def period_over_period(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PeriodOverPeriodComputationProperty"]]:
            '''The period over period computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-periodoverperiod
            '''
            result = self._values.get("period_over_period")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PeriodOverPeriodComputationProperty"]], result)

        @builtins.property
        def period_to_date(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PeriodToDateComputationProperty"]]:
            '''The period to ``DataSetIdentifier`` computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-periodtodate
            '''
            result = self._values.get("period_to_date")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PeriodToDateComputationProperty"]], result)

        @builtins.property
        def top_bottom_movers(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TopBottomMoversComputationProperty"]]:
            '''The top movers and bottom movers computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-topbottommovers
            '''
            result = self._values.get("top_bottom_movers")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TopBottomMoversComputationProperty"]], result)

        @builtins.property
        def top_bottom_ranked(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TopBottomRankedComputationProperty"]]:
            '''The top ranked and bottom ranked computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-topbottomranked
            '''
            result = self._values.get("top_bottom_ranked")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TopBottomRankedComputationProperty"]], result)

        @builtins.property
        def total_aggregation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TotalAggregationComputationProperty"]]:
            '''The total aggregation computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-totalaggregation
            '''
            result = self._values.get("total_aggregation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TotalAggregationComputationProperty"]], result)

        @builtins.property
        def unique_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.UniqueValuesComputationProperty"]]:
            '''The unique values computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-uniquevalues
            '''
            result = self._values.get("unique_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.UniqueValuesComputationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ConditionalFormattingColorProperty",
        jsii_struct_bases=[],
        name_mapping={"gradient": "gradient", "solid": "solid"},
    )
    class ConditionalFormattingColorProperty:
        def __init__(
            self,
            *,
            gradient: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingGradientColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            solid: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingSolidColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The formatting configuration for the color.

            :param gradient: Formatting configuration for gradient color.
            :param solid: Formatting configuration for solid color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_color_property = quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                        color=quicksight.CfnAnalysis.GradientColorProperty(
                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                gradient_offset=123,
                
                                # the properties below are optional
                                color="color",
                                data_value=123
                            )]
                        ),
                        expression="expression"
                    ),
                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                        expression="expression",
                
                        # the properties below are optional
                        color="color"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d52148b7056c2d0312222fff65e42ec0e5fd53022ae05a99fa0d30f027edb590)
                check_type(argname="argument gradient", value=gradient, expected_type=type_hints["gradient"])
                check_type(argname="argument solid", value=solid, expected_type=type_hints["solid"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if gradient is not None:
                self._values["gradient"] = gradient
            if solid is not None:
                self._values["solid"] = solid

        @builtins.property
        def gradient(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingGradientColorProperty"]]:
            '''Formatting configuration for gradient color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcolor.html#cfn-quicksight-analysis-conditionalformattingcolor-gradient
            '''
            result = self._values.get("gradient")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingGradientColorProperty"]], result)

        @builtins.property
        def solid(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingSolidColorProperty"]]:
            '''Formatting configuration for solid color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcolor.html#cfn-quicksight-analysis-conditionalformattingcolor-solid
            '''
            result = self._values.get("solid")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingSolidColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "expression": "expression",
            "icon_options": "iconOptions",
            "color": "color",
            "display_configuration": "displayConfiguration",
        },
    )
    class ConditionalFormattingCustomIconConditionProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            icon_options: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
            color: typing.Optional[builtins.str] = None,
            display_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Determines the custom condition for an icon set.

            :param expression: The expression that determines the condition of the icon set.
            :param icon_options: Custom icon options for an icon set.
            :param color: Determines the color of the icon.
            :param display_configuration: Determines the icon display configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_custom_icon_condition_property = quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                    expression="expression",
                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                        icon="icon",
                        unicode_icon="unicodeIcon"
                    ),
                
                    # the properties below are optional
                    color="color",
                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                        icon_display_option="iconDisplayOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c82e4ee5649da3ac08b6284e8b4daf22e5eaab886e5a4f96686f8adaf7eed9d5)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument icon_options", value=icon_options, expected_type=type_hints["icon_options"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument display_configuration", value=display_configuration, expected_type=type_hints["display_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
                "icon_options": icon_options,
            }
            if color is not None:
                self._values["color"] = color
            if display_configuration is not None:
                self._values["display_configuration"] = display_configuration

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the condition of the icon set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html#cfn-quicksight-analysis-conditionalformattingcustomiconcondition-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def icon_options(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty"]:
            '''Custom icon options for an icon set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html#cfn-quicksight-analysis-conditionalformattingcustomiconcondition-iconoptions
            '''
            result = self._values.get("icon_options")
            assert result is not None, "Required property 'icon_options' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty"], result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html#cfn-quicksight-analysis-conditionalformattingcustomiconcondition-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty"]]:
            '''Determines the icon display configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html#cfn-quicksight-analysis-conditionalformattingcustomiconcondition-displayconfiguration
            '''
            result = self._values.get("display_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingCustomIconConditionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "unicode_icon": "unicodeIcon"},
    )
    class ConditionalFormattingCustomIconOptionsProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[builtins.str] = None,
            unicode_icon: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Custom icon options for an icon set.

            :param icon: Determines the type of icon.
            :param unicode_icon: Determines the Unicode icon type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_custom_icon_options_property = quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                    icon="icon",
                    unicode_icon="unicodeIcon"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e2dadbe74f021f3e0e69b962cc389b96db48ba2bbdcd5e500656ada1005067aa)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument unicode_icon", value=unicode_icon, expected_type=type_hints["unicode_icon"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if unicode_icon is not None:
                self._values["unicode_icon"] = unicode_icon

        @builtins.property
        def icon(self) -> typing.Optional[builtins.str]:
            '''Determines the type of icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconoptions.html#cfn-quicksight-analysis-conditionalformattingcustomiconoptions-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def unicode_icon(self) -> typing.Optional[builtins.str]:
            '''Determines the Unicode icon type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconoptions.html#cfn-quicksight-analysis-conditionalformattingcustomiconoptions-unicodeicon
            '''
            result = self._values.get("unicode_icon")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingCustomIconOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "expression": "expression"},
    )
    class ConditionalFormattingGradientColorProperty:
        def __init__(
            self,
            *,
            color: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GradientColorProperty", typing.Dict[builtins.str, typing.Any]]],
            expression: builtins.str,
        ) -> None:
            '''Formatting configuration for gradient color.

            :param color: Determines the color.
            :param expression: The expression that determines the formatting configuration for gradient color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattinggradientcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_gradient_color_property = quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                    color=quicksight.CfnAnalysis.GradientColorProperty(
                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                            gradient_offset=123,
                
                            # the properties below are optional
                            color="color",
                            data_value=123
                        )]
                    ),
                    expression="expression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e74308d9e744f21b3a92b03e46e01454a2c192b8b8db9cc813ec014cd56851ab)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
                "expression": expression,
            }

        @builtins.property
        def color(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GradientColorProperty"]:
            '''Determines the color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattinggradientcolor.html#cfn-quicksight-analysis-conditionalformattinggradientcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GradientColorProperty"], result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for gradient color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattinggradientcolor.html#cfn-quicksight-analysis-conditionalformattinggradientcolor-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingGradientColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"icon_display_option": "iconDisplayOption"},
    )
    class ConditionalFormattingIconDisplayConfigurationProperty:
        def __init__(
            self,
            *,
            icon_display_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the icon display configuration.

            :param icon_display_option: Determines the icon display configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicondisplayconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_icon_display_configuration_property = quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                    icon_display_option="iconDisplayOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b8801e4508f2a867536d4c59d5f83793796e56c2f395e012b11fbfed0fc32915)
                check_type(argname="argument icon_display_option", value=icon_display_option, expected_type=type_hints["icon_display_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon_display_option is not None:
                self._values["icon_display_option"] = icon_display_option

        @builtins.property
        def icon_display_option(self) -> typing.Optional[builtins.str]:
            '''Determines the icon display configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicondisplayconfiguration.html#cfn-quicksight-analysis-conditionalformattingicondisplayconfiguration-icondisplayoption
            '''
            result = self._values.get("icon_display_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconDisplayConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ConditionalFormattingIconProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_condition": "customCondition", "icon_set": "iconSet"},
    )
    class ConditionalFormattingIconProperty:
        def __init__(
            self,
            *,
            custom_condition: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingCustomIconConditionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            icon_set: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingIconSetProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The formatting configuration for the icon.

            :param custom_condition: Determines the custom condition for an icon set.
            :param icon_set: Formatting configuration for icon set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicon.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_icon_property = quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                    custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                        expression="expression",
                        icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                            icon="icon",
                            unicode_icon="unicodeIcon"
                        ),
                
                        # the properties below are optional
                        color="color",
                        display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                            icon_display_option="iconDisplayOption"
                        )
                    ),
                    icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                        expression="expression",
                
                        # the properties below are optional
                        icon_set_type="iconSetType"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6df240f326c7bda2dad75563204ea5754a7501cc88f6bd969e922137c95d803a)
                check_type(argname="argument custom_condition", value=custom_condition, expected_type=type_hints["custom_condition"])
                check_type(argname="argument icon_set", value=icon_set, expected_type=type_hints["icon_set"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_condition is not None:
                self._values["custom_condition"] = custom_condition
            if icon_set is not None:
                self._values["icon_set"] = icon_set

        @builtins.property
        def custom_condition(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingCustomIconConditionProperty"]]:
            '''Determines the custom condition for an icon set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicon.html#cfn-quicksight-analysis-conditionalformattingicon-customcondition
            '''
            result = self._values.get("custom_condition")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingCustomIconConditionProperty"]], result)

        @builtins.property
        def icon_set(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingIconSetProperty"]]:
            '''Formatting configuration for icon set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicon.html#cfn-quicksight-analysis-conditionalformattingicon-iconset
            '''
            result = self._values.get("icon_set")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingIconSetProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "icon_set_type": "iconSetType"},
    )
    class ConditionalFormattingIconSetProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            icon_set_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Formatting configuration for icon set.

            :param expression: The expression that determines the formatting configuration for the icon set.
            :param icon_set_type: Determines the icon set type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingiconset.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_icon_set_property = quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                    expression="expression",
                
                    # the properties below are optional
                    icon_set_type="iconSetType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__37c00764af02fc0e5c936772d2729c7a412350549bea9dd4f115809c91ec66b6)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument icon_set_type", value=icon_set_type, expected_type=type_hints["icon_set_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if icon_set_type is not None:
                self._values["icon_set_type"] = icon_set_type

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for the icon set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingiconset.html#cfn-quicksight-analysis-conditionalformattingiconset-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def icon_set_type(self) -> typing.Optional[builtins.str]:
            '''Determines the icon set type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingiconset.html#cfn-quicksight-analysis-conditionalformattingiconset-iconsettype
            '''
            result = self._values.get("icon_set_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconSetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "color": "color"},
    )
    class ConditionalFormattingSolidColorProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            color: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Formatting configuration for solid color.

            :param expression: The expression that determines the formatting configuration for solid color.
            :param color: Determines the color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingsolidcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_solid_color_property = quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                    expression="expression",
                
                    # the properties below are optional
                    color="color"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__79725fa3ccee01583125c515396717e5a6314accd5df430e08b159d27267cc2d)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if color is not None:
                self._values["color"] = color

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for solid color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingsolidcolor.html#cfn-quicksight-analysis-conditionalformattingsolidcolor-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingsolidcolor.html#cfn-quicksight-analysis-conditionalformattingsolidcolor-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingSolidColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty",
        jsii_struct_bases=[],
        name_mapping={
            "contributor_dimensions": "contributorDimensions",
            "measure_field_id": "measureFieldId",
        },
    )
    class ContributionAnalysisDefaultProperty:
        def __init__(
            self,
            *,
            contributor_dimensions: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]]],
            measure_field_id: builtins.str,
        ) -> None:
            '''The contribution analysis visual display for a line, pie, or bar chart.

            :param contributor_dimensions: The dimensions columns that are used in the contribution analysis, usually a list of ``ColumnIdentifiers`` .
            :param measure_field_id: The measure field that is used in the contribution analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-contributionanalysisdefault.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                contribution_analysis_default_property = quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                    contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    measure_field_id="measureFieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__14c868a949edd50a1aefe3b168b7430cd7748a22966fb04165749b9a8c09dc8e)
                check_type(argname="argument contributor_dimensions", value=contributor_dimensions, expected_type=type_hints["contributor_dimensions"])
                check_type(argname="argument measure_field_id", value=measure_field_id, expected_type=type_hints["measure_field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "contributor_dimensions": contributor_dimensions,
                "measure_field_id": measure_field_id,
            }

        @builtins.property
        def contributor_dimensions(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]]]:
            '''The dimensions columns that are used in the contribution analysis, usually a list of ``ColumnIdentifiers`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-contributionanalysisdefault.html#cfn-quicksight-analysis-contributionanalysisdefault-contributordimensions
            '''
            result = self._values.get("contributor_dimensions")
            assert result is not None, "Required property 'contributor_dimensions' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]]], result)

        @builtins.property
        def measure_field_id(self) -> builtins.str:
            '''The measure field that is used in the contribution analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-contributionanalysisdefault.html#cfn-quicksight-analysis-contributionanalysisdefault-measurefieldid
            '''
            result = self._values.get("measure_field_id")
            assert result is not None, "Required property 'measure_field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ContributionAnalysisDefaultProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "number_scale": "numberScale",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
            "symbol": "symbol",
        },
    )
    class CurrencyDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            negative_value_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_scale: typing.Optional[builtins.str] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            suffix: typing.Optional[builtins.str] = None,
            symbol: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the currency display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param number_scale: Determines the number scale value for the currency format.
            :param prefix: Determines the prefix value of the currency format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the currency format.
            :param symbol: Determines the symbol for the currency format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                currency_display_format_configuration_property = quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    number_scale="numberScale",
                    prefix="prefix",
                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix",
                    symbol="symbol"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2d5fef0036b605708ff2c6f83939aef36f764848a1ea8b749ac6a7cb9f7bfac8)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument number_scale", value=number_scale, expected_type=type_hints["number_scale"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
                check_type(argname="argument symbol", value=symbol, expected_type=type_hints["symbol"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if number_scale is not None:
                self._values["number_scale"] = number_scale
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix
            if symbol is not None:
                self._values["symbol"] = symbol

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DecimalPlacesConfigurationProperty"]]:
            '''The option that determines the decimal places configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DecimalPlacesConfigurationProperty"]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NegativeValueConfigurationProperty"]]:
            '''The options that determine the negative value configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NegativeValueConfigurationProperty"]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def number_scale(self) -> typing.Optional[builtins.str]:
            '''Determines the number scale value for the currency format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-numberscale
            '''
            result = self._values.get("number_scale")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the currency format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericSeparatorConfigurationProperty"]]:
            '''The options that determine the numeric separator configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericSeparatorConfigurationProperty"]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the currency format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def symbol(self) -> typing.Optional[builtins.str]:
            '''Determines the symbol for the currency format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-symbol
            '''
            result = self._values.get("symbol")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CurrencyDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CustomActionFilterOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "selected_fields_configuration": "selectedFieldsConfiguration",
            "target_visuals_configuration": "targetVisualsConfiguration",
        },
    )
    class CustomActionFilterOperationProperty:
        def __init__(
            self,
            *,
            selected_fields_configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            target_visuals_configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The filter operation that filters data included in a visual or in an entire sheet.

            :param selected_fields_configuration: The configuration that chooses the fields to be filtered.
            :param target_visuals_configuration: The configuration that chooses the target visuals to be filtered.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionfilteroperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_action_filter_operation_property = quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                        selected_columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        selected_field_options="selectedFieldOptions",
                        selected_fields=["selectedFields"]
                    ),
                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                            target_visual_options="targetVisualOptions",
                            target_visuals=["targetVisuals"]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a383546d3eec1bdd3b061adab9ba14818917abd43a51c8f586e6db1ffaa56092)
                check_type(argname="argument selected_fields_configuration", value=selected_fields_configuration, expected_type=type_hints["selected_fields_configuration"])
                check_type(argname="argument target_visuals_configuration", value=target_visuals_configuration, expected_type=type_hints["target_visuals_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "selected_fields_configuration": selected_fields_configuration,
                "target_visuals_configuration": target_visuals_configuration,
            }

        @builtins.property
        def selected_fields_configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty"]:
            '''The configuration that chooses the fields to be filtered.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionfilteroperation.html#cfn-quicksight-analysis-customactionfilteroperation-selectedfieldsconfiguration
            '''
            result = self._values.get("selected_fields_configuration")
            assert result is not None, "Required property 'selected_fields_configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty"], result)

        @builtins.property
        def target_visuals_configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty"]:
            '''The configuration that chooses the target visuals to be filtered.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionfilteroperation.html#cfn-quicksight-analysis-customactionfilteroperation-targetvisualsconfiguration
            '''
            result = self._values.get("target_visuals_configuration")
            assert result is not None, "Required property 'target_visuals_configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionFilterOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CustomActionNavigationOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "local_navigation_configuration": "localNavigationConfiguration",
        },
    )
    class CustomActionNavigationOperationProperty:
        def __init__(
            self,
            *,
            local_navigation_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LocalNavigationConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The navigation operation that navigates between different sheets in the same analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param local_navigation_configuration: The configuration that chooses the navigation target.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionnavigationoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_action_navigation_operation_property = quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                        target_sheet_id="targetSheetId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c0d2a1c805344be2956837393f966072a0c76504117dbac06fb620e8d3950734)
                check_type(argname="argument local_navigation_configuration", value=local_navigation_configuration, expected_type=type_hints["local_navigation_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if local_navigation_configuration is not None:
                self._values["local_navigation_configuration"] = local_navigation_configuration

        @builtins.property
        def local_navigation_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LocalNavigationConfigurationProperty"]]:
            '''The configuration that chooses the navigation target.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionnavigationoperation.html#cfn-quicksight-analysis-customactionnavigationoperation-localnavigationconfiguration
            '''
            result = self._values.get("local_navigation_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LocalNavigationConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionNavigationOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_value_configurations": "parameterValueConfigurations",
        },
    )
    class CustomActionSetParametersOperationProperty:
        def __init__(
            self,
            *,
            parameter_value_configurations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SetParameterValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The set parameter operation that sets parameters in custom action.

            :param parameter_value_configurations: The parameter that determines the value configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionsetparametersoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_action_set_parameters_operation_property = quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                        destination_parameter_name="destinationParameterName",
                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                    date_time_values=["dateTimeValues"],
                                    decimal_values=[123],
                                    integer_values=[123],
                                    string_values=["stringValues"]
                                ),
                
                                # the properties below are optional
                                include_null_value=False
                            ),
                            select_all_value_options="selectAllValueOptions",
                            source_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_field="sourceField",
                            source_parameter_name="sourceParameterName"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9651a29ef076c161348b549e839408de6de0962e62f9664a79a5f1a6b6d899fa)
                check_type(argname="argument parameter_value_configurations", value=parameter_value_configurations, expected_type=type_hints["parameter_value_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_value_configurations": parameter_value_configurations,
            }

        @builtins.property
        def parameter_value_configurations(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SetParameterValueConfigurationProperty"]]]:
            '''The parameter that determines the value configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionsetparametersoperation.html#cfn-quicksight-analysis-customactionsetparametersoperation-parametervalueconfigurations
            '''
            result = self._values.get("parameter_value_configurations")
            assert result is not None, "Required property 'parameter_value_configurations' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SetParameterValueConfigurationProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionSetParametersOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CustomActionURLOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"url_target": "urlTarget", "url_template": "urlTemplate"},
    )
    class CustomActionURLOperationProperty:
        def __init__(
            self,
            *,
            url_target: builtins.str,
            url_template: builtins.str,
        ) -> None:
            '''The URL operation that opens a link to another webpage.

            :param url_target: The target of the ``CustomActionURLOperation`` . Valid values are defined as follows: - ``NEW_TAB`` : Opens the target URL in a new browser tab. - ``NEW_WINDOW`` : Opens the target URL in a new browser window. - ``SAME_TAB`` : Opens the target URL in the same browser tab.
            :param url_template: THe URL link of the ``CustomActionURLOperation`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionurloperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_action_uRLOperation_property = quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                    url_target="urlTarget",
                    url_template="urlTemplate"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4f737bd1c08cfbb480b0afd6dfcd8872739d8bf63785cf22f4d210654a386c28)
                check_type(argname="argument url_target", value=url_target, expected_type=type_hints["url_target"])
                check_type(argname="argument url_template", value=url_template, expected_type=type_hints["url_template"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "url_target": url_target,
                "url_template": url_template,
            }

        @builtins.property
        def url_target(self) -> builtins.str:
            '''The target of the ``CustomActionURLOperation`` .

            Valid values are defined as follows:

            - ``NEW_TAB`` : Opens the target URL in a new browser tab.
            - ``NEW_WINDOW`` : Opens the target URL in a new browser window.
            - ``SAME_TAB`` : Opens the target URL in the same browser tab.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionurloperation.html#cfn-quicksight-analysis-customactionurloperation-urltarget
            '''
            result = self._values.get("url_target")
            assert result is not None, "Required property 'url_target' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def url_template(self) -> builtins.str:
            '''THe URL link of the ``CustomActionURLOperation`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionurloperation.html#cfn-quicksight-analysis-customactionurloperation-urltemplate
            '''
            result = self._values.get("url_template")
            assert result is not None, "Required property 'url_template' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionURLOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CustomColorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color": "color",
            "field_value": "fieldValue",
            "special_value": "specialValue",
        },
    )
    class CustomColorProperty:
        def __init__(
            self,
            *,
            color: builtins.str,
            field_value: typing.Optional[builtins.str] = None,
            special_value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the color that's applied to a particular data value in a column.

            :param color: The color that is applied to the data value.
            :param field_value: The data value that the color is applied to.
            :param special_value: The value of a special data value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_color_property = quicksight.CfnAnalysis.CustomColorProperty(
                    color="color",
                
                    # the properties below are optional
                    field_value="fieldValue",
                    special_value="specialValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d872ac03245931eb5686c4a3f554633a94a804f7c635ee5d321186b3f751c581)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument special_value", value=special_value, expected_type=type_hints["special_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
            }
            if field_value is not None:
                self._values["field_value"] = field_value
            if special_value is not None:
                self._values["special_value"] = special_value

        @builtins.property
        def color(self) -> builtins.str:
            '''The color that is applied to the data value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcolor.html#cfn-quicksight-analysis-customcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The data value that the color is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcolor.html#cfn-quicksight-analysis-customcolor-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def special_value(self) -> typing.Optional[builtins.str]:
            '''The value of a special data value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcolor.html#cfn-quicksight-analysis-customcolor-specialvalue
            '''
            result = self._values.get("special_value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CustomContentConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "content_type": "contentType",
            "content_url": "contentUrl",
            "image_scaling": "imageScaling",
        },
    )
    class CustomContentConfigurationProperty:
        def __init__(
            self,
            *,
            content_type: typing.Optional[builtins.str] = None,
            content_url: typing.Optional[builtins.str] = None,
            image_scaling: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of a ``CustomContentVisual`` .

            :param content_type: The content type of the custom content visual. You can use this to have the visual render as an image.
            :param content_url: The input URL that links to the custom content that you want in the custom visual.
            :param image_scaling: The sizing options for the size of the custom content visual. This structure is required when the ``ContentType`` of the visual is ``'IMAGE'`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_content_configuration_property = quicksight.CfnAnalysis.CustomContentConfigurationProperty(
                    content_type="contentType",
                    content_url="contentUrl",
                    image_scaling="imageScaling"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6e3335fa4f454c6e8b71e44a4416f2d735b6a775ae146fc15d67b0c53b4cbc11)
                check_type(argname="argument content_type", value=content_type, expected_type=type_hints["content_type"])
                check_type(argname="argument content_url", value=content_url, expected_type=type_hints["content_url"])
                check_type(argname="argument image_scaling", value=image_scaling, expected_type=type_hints["image_scaling"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if content_type is not None:
                self._values["content_type"] = content_type
            if content_url is not None:
                self._values["content_url"] = content_url
            if image_scaling is not None:
                self._values["image_scaling"] = image_scaling

        @builtins.property
        def content_type(self) -> typing.Optional[builtins.str]:
            '''The content type of the custom content visual.

            You can use this to have the visual render as an image.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentconfiguration.html#cfn-quicksight-analysis-customcontentconfiguration-contenttype
            '''
            result = self._values.get("content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def content_url(self) -> typing.Optional[builtins.str]:
            '''The input URL that links to the custom content that you want in the custom visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentconfiguration.html#cfn-quicksight-analysis-customcontentconfiguration-contenturl
            '''
            result = self._values.get("content_url")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def image_scaling(self) -> typing.Optional[builtins.str]:
            '''The sizing options for the size of the custom content visual.

            This structure is required when the ``ContentType`` of the visual is ``'IMAGE'`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentconfiguration.html#cfn-quicksight-analysis-customcontentconfiguration-imagescaling
            '''
            result = self._values.get("image_scaling")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomContentConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CustomContentVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class CustomContentVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CustomContentConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A visual that contains custom content.

            For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :param data_set_identifier: The dataset that is used to create the custom content visual. You can't create a visual without a dataset.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``CustomContentVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_content_visual_property = quicksight.CfnAnalysis.CustomContentVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.CustomContentConfigurationProperty(
                        content_type="contentType",
                        content_url="contentUrl",
                        image_scaling="imageScaling"
                    ),
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ebca1ef6a5d4a7a0ace89b9095ff8fdd543b79c30f056718329c56a45dcdef68)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The dataset that is used to create the custom content visual.

            You can't create a visual without a dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomContentConfigurationProperty"]]:
            '''The configuration of a ``CustomContentVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomContentConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomContentVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CustomFilterConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "category_value": "categoryValue",
            "parameter_name": "parameterName",
            "select_all_options": "selectAllOptions",
        },
    )
    class CustomFilterConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            null_option: builtins.str,
            category_value: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A custom filter that filters based on a single value.

            This filter can be partially matched.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param category_value: The category value for the filter. This field is mutually exclusive to ``ParameterName`` .
            :param parameter_name: The parameter whose value should be used for the filter value. This field is mutually exclusive to ``CategoryValue`` .
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_filter_configuration_property = quicksight.CfnAnalysis.CustomFilterConfigurationProperty(
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    category_value="categoryValue",
                    parameter_name="parameterName",
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a271d758f3b9ebb8bd046ed3ce2bc4ce6c245d44ed2a96989f3803c36c1d12ee)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument category_value", value=category_value, expected_type=type_hints["category_value"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if category_value is not None:
                self._values["category_value"] = category_value
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_value(self) -> typing.Optional[builtins.str]:
            '''The category value for the filter.

            This field is mutually exclusive to ``ParameterName`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-categoryvalue
            '''
            result = self._values.get("category_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            This field is mutually exclusive to ``CategoryValue`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomFilterConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CustomFilterListConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "category_values": "categoryValues",
            "select_all_options": "selectAllOptions",
        },
    )
    class CustomFilterListConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            null_option: builtins.str,
            category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A list of custom filter values.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param category_values: The list of category values for the filter.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_filter_list_configuration_property = quicksight.CfnAnalysis.CustomFilterListConfigurationProperty(
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    category_values=["categoryValues"],
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e5f1b84b0a9078e6b57b9051d15522aac25e644f5e28e8a62515c76a3e69cba6)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if category_values is not None:
                self._values["category_values"] = category_values
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html#cfn-quicksight-analysis-customfilterlistconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html#cfn-quicksight-analysis-customfilterlistconfiguration-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of category values for the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html#cfn-quicksight-analysis-customfilterlistconfiguration-categoryvalues
            '''
            result = self._values.get("category_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html#cfn-quicksight-analysis-customfilterlistconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomFilterListConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CustomNarrativeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"narrative": "narrative"},
    )
    class CustomNarrativeOptionsProperty:
        def __init__(self, *, narrative: builtins.str) -> None:
            '''The custom narrative options.

            :param narrative: The string input of custom narrative.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customnarrativeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_narrative_options_property = quicksight.CfnAnalysis.CustomNarrativeOptionsProperty(
                    narrative="narrative"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e3661c9796a9728382d87c363f3bef8f8cf6723d1074574a85bd456d01ec1927)
                check_type(argname="argument narrative", value=narrative, expected_type=type_hints["narrative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "narrative": narrative,
            }

        @builtins.property
        def narrative(self) -> builtins.str:
            '''The string input of custom narrative.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customnarrativeoptions.html#cfn-quicksight-analysis-customnarrativeoptions-narrative
            '''
            result = self._values.get("narrative")
            assert result is not None, "Required property 'narrative' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomNarrativeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CustomParameterValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_values": "dateTimeValues",
            "decimal_values": "decimalValues",
            "integer_values": "integerValues",
            "string_values": "stringValues",
        },
    )
    class CustomParameterValuesProperty:
        def __init__(
            self,
            *,
            date_time_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            decimal_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
            integer_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
            string_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The customized parameter values.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_values: A list of datetime-type parameter values.
            :param decimal_values: A list of decimal-type parameter values.
            :param integer_values: A list of integer-type parameter values.
            :param string_values: A list of string-type parameter values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_parameter_values_property = quicksight.CfnAnalysis.CustomParameterValuesProperty(
                    date_time_values=["dateTimeValues"],
                    decimal_values=[123],
                    integer_values=[123],
                    string_values=["stringValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a5be83345843551e0be466c923ea971b83e6b63668370180560da67f794fb896)
                check_type(argname="argument date_time_values", value=date_time_values, expected_type=type_hints["date_time_values"])
                check_type(argname="argument decimal_values", value=decimal_values, expected_type=type_hints["decimal_values"])
                check_type(argname="argument integer_values", value=integer_values, expected_type=type_hints["integer_values"])
                check_type(argname="argument string_values", value=string_values, expected_type=type_hints["string_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_values is not None:
                self._values["date_time_values"] = date_time_values
            if decimal_values is not None:
                self._values["decimal_values"] = decimal_values
            if integer_values is not None:
                self._values["integer_values"] = integer_values
            if string_values is not None:
                self._values["string_values"] = string_values

        @builtins.property
        def date_time_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of datetime-type parameter values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html#cfn-quicksight-analysis-customparametervalues-datetimevalues
            '''
            result = self._values.get("date_time_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def decimal_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]]:
            '''A list of decimal-type parameter values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html#cfn-quicksight-analysis-customparametervalues-decimalvalues
            '''
            result = self._values.get("decimal_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]], result)

        @builtins.property
        def integer_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]]:
            '''A list of integer-type parameter values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html#cfn-quicksight-analysis-customparametervalues-integervalues
            '''
            result = self._values.get("integer_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]], result)

        @builtins.property
        def string_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of string-type parameter values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html#cfn-quicksight-analysis-customparametervalues-stringvalues
            '''
            result = self._values.get("string_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomParameterValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.CustomValuesConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_values": "customValues",
            "include_null_value": "includeNullValue",
        },
    )
    class CustomValuesConfigurationProperty:
        def __init__(
            self,
            *,
            custom_values: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CustomParameterValuesProperty", typing.Dict[builtins.str, typing.Any]]],
            include_null_value: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
        ) -> None:
            '''The configuration of custom values for the destination parameter in ``DestinationParameterValueConfiguration`` .

            :param custom_values: 
            :param include_null_value: Includes the null value in custom action parameter values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customvaluesconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_values_configuration_property = quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                        date_time_values=["dateTimeValues"],
                        decimal_values=[123],
                        integer_values=[123],
                        string_values=["stringValues"]
                    ),
                
                    # the properties below are optional
                    include_null_value=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a6197934fa1bd9bfeab069abdfd02d7eaac44db71933bdecd67af20812e128e7)
                check_type(argname="argument custom_values", value=custom_values, expected_type=type_hints["custom_values"])
                check_type(argname="argument include_null_value", value=include_null_value, expected_type=type_hints["include_null_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "custom_values": custom_values,
            }
            if include_null_value is not None:
                self._values["include_null_value"] = include_null_value

        @builtins.property
        def custom_values(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomParameterValuesProperty"]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customvaluesconfiguration.html#cfn-quicksight-analysis-customvaluesconfiguration-customvalues
            '''
            result = self._values.get("custom_values")
            assert result is not None, "Required property 'custom_values' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomParameterValuesProperty"], result)

        @builtins.property
        def include_null_value(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''Includes the null value in custom action parameter values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customvaluesconfiguration.html#cfn-quicksight-analysis-customvaluesconfiguration-includenullvalue
            '''
            result = self._values.get("include_null_value")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomValuesConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DataBarsOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "negative_color": "negativeColor",
            "positive_color": "positiveColor",
        },
    )
    class DataBarsOptionsProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            negative_color: typing.Optional[builtins.str] = None,
            positive_color: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for data bars.

            :param field_id: The field ID for the data bars options.
            :param negative_color: The color of the negative data bar.
            :param positive_color: The color of the positive data bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-databarsoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_bars_options_property = quicksight.CfnAnalysis.DataBarsOptionsProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    negative_color="negativeColor",
                    positive_color="positiveColor"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0b7c93e7f58e34129aee78309943f4c7156f17e5a06ed7a43c38285a625d878a)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument negative_color", value=negative_color, expected_type=type_hints["negative_color"])
                check_type(argname="argument positive_color", value=positive_color, expected_type=type_hints["positive_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if negative_color is not None:
                self._values["negative_color"] = negative_color
            if positive_color is not None:
                self._values["positive_color"] = positive_color

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for the data bars options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-databarsoptions.html#cfn-quicksight-analysis-databarsoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def negative_color(self) -> typing.Optional[builtins.str]:
            '''The color of the negative data bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-databarsoptions.html#cfn-quicksight-analysis-databarsoptions-negativecolor
            '''
            result = self._values.get("negative_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def positive_color(self) -> typing.Optional[builtins.str]:
            '''The color of the positive data bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-databarsoptions.html#cfn-quicksight-analysis-databarsoptions-positivecolor
            '''
            result = self._values.get("positive_color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataBarsOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DataColorProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "data_value": "dataValue"},
    )
    class DataColorProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            data_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''Determines the color that is applied to a particular data value.

            :param color: The color that is applied to the data value.
            :param data_value: The data value that the color is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datacolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_color_property = quicksight.CfnAnalysis.DataColorProperty(
                    color="color",
                    data_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0336c5685cce8463a8784817939facd63e5d4858cbaf0a240808f76f9c35cfee)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument data_value", value=data_value, expected_type=type_hints["data_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if data_value is not None:
                self._values["data_value"] = data_value

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color that is applied to the data value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datacolor.html#cfn-quicksight-analysis-datacolor-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_value(self) -> typing.Optional[jsii.Number]:
            '''The data value that the color is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datacolor.html#cfn-quicksight-analysis-datacolor-datavalue
            '''
            result = self._values.get("data_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DataFieldSeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "field_id": "fieldId",
            "field_value": "fieldValue",
            "settings": "settings",
        },
    )
    class DataFieldSeriesItemProperty:
        def __init__(
            self,
            *,
            axis_binding: builtins.str,
            field_id: builtins.str,
            field_value: typing.Optional[builtins.str] = None,
            settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LineChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The data field series item configuration of a line chart.

            :param axis_binding: The axis that you are binding the field to.
            :param field_id: The field ID of the field that you are setting the axis binding to.
            :param field_value: The field value of the field that you are setting the axis binding to.
            :param settings: The options that determine the presentation of line series associated to the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_field_series_item_property = quicksight.CfnAnalysis.DataFieldSeriesItemProperty(
                    axis_binding="axisBinding",
                    field_id="fieldId",
                
                    # the properties below are optional
                    field_value="fieldValue",
                    settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                        line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e357f1d2093881569025e1138e344ed72afcb5baf371c67a4f89182cc5ecd479)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument settings", value=settings, expected_type=type_hints["settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "axis_binding": axis_binding,
                "field_id": field_id,
            }
            if field_value is not None:
                self._values["field_value"] = field_value
            if settings is not None:
                self._values["settings"] = settings

        @builtins.property
        def axis_binding(self) -> builtins.str:
            '''The axis that you are binding the field to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html#cfn-quicksight-analysis-datafieldseriesitem-axisbinding
            '''
            result = self._values.get("axis_binding")
            assert result is not None, "Required property 'axis_binding' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field that you are setting the axis binding to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html#cfn-quicksight-analysis-datafieldseriesitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The field value of the field that you are setting the axis binding to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html#cfn-quicksight-analysis-datafieldseriesitem-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartSeriesSettingsProperty"]]:
            '''The options that determine the presentation of line series associated to the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html#cfn-quicksight-analysis-datafieldseriesitem-settings
            '''
            result = self._values.get("settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartSeriesSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataFieldSeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DataLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_visibility": "categoryLabelVisibility",
            "data_label_types": "dataLabelTypes",
            "label_color": "labelColor",
            "label_content": "labelContent",
            "label_font_configuration": "labelFontConfiguration",
            "measure_label_visibility": "measureLabelVisibility",
            "overlap": "overlap",
            "position": "position",
            "totals_visibility": "totalsVisibility",
            "visibility": "visibility",
        },
    )
    class DataLabelOptionsProperty:
        def __init__(
            self,
            *,
            category_label_visibility: typing.Optional[builtins.str] = None,
            data_label_types: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            label_color: typing.Optional[builtins.str] = None,
            label_content: typing.Optional[builtins.str] = None,
            label_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            measure_label_visibility: typing.Optional[builtins.str] = None,
            overlap: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of the data labels.

            :param category_label_visibility: Determines the visibility of the category field labels.
            :param data_label_types: The option that determines the data label type.
            :param label_color: Determines the color of the data labels.
            :param label_content: Determines the content of the data labels.
            :param label_font_configuration: Determines the font configuration of the data labels.
            :param measure_label_visibility: Determines the visibility of the measure field labels.
            :param overlap: Determines whether overlap is enabled or disabled for the data labels.
            :param position: Determines the position of the data labels.
            :param totals_visibility: Determines the visibility of the total.
            :param visibility: Determines the visibility of the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_label_options_property = quicksight.CfnAnalysis.DataLabelOptionsProperty(
                    category_label_visibility="categoryLabelVisibility",
                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                            field_id="fieldId",
                            field_value="fieldValue",
                            visibility="visibility"
                        ),
                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                            field_id="fieldId",
                            visibility="visibility"
                        ),
                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                            visibility="visibility"
                        ),
                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                            visibility="visibility"
                        ),
                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                            visibility="visibility"
                        )
                    )],
                    label_color="labelColor",
                    label_content="labelContent",
                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    measure_label_visibility="measureLabelVisibility",
                    overlap="overlap",
                    position="position",
                    totals_visibility="totalsVisibility",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d723fb6e0272cbb7a4b92a44aa3f1bc37eac283d3c2cd28d0a97f180b84be5a1)
                check_type(argname="argument category_label_visibility", value=category_label_visibility, expected_type=type_hints["category_label_visibility"])
                check_type(argname="argument data_label_types", value=data_label_types, expected_type=type_hints["data_label_types"])
                check_type(argname="argument label_color", value=label_color, expected_type=type_hints["label_color"])
                check_type(argname="argument label_content", value=label_content, expected_type=type_hints["label_content"])
                check_type(argname="argument label_font_configuration", value=label_font_configuration, expected_type=type_hints["label_font_configuration"])
                check_type(argname="argument measure_label_visibility", value=measure_label_visibility, expected_type=type_hints["measure_label_visibility"])
                check_type(argname="argument overlap", value=overlap, expected_type=type_hints["overlap"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_visibility is not None:
                self._values["category_label_visibility"] = category_label_visibility
            if data_label_types is not None:
                self._values["data_label_types"] = data_label_types
            if label_color is not None:
                self._values["label_color"] = label_color
            if label_content is not None:
                self._values["label_content"] = label_content
            if label_font_configuration is not None:
                self._values["label_font_configuration"] = label_font_configuration
            if measure_label_visibility is not None:
                self._values["measure_label_visibility"] = measure_label_visibility
            if overlap is not None:
                self._values["overlap"] = overlap
            if position is not None:
                self._values["position"] = position
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def category_label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the category field labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-categorylabelvisibility
            '''
            result = self._values.get("category_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_label_types(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelTypeProperty"]]]]:
            '''The option that determines the data label type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-datalabeltypes
            '''
            result = self._values.get("data_label_types")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelTypeProperty"]]]], result)

        @builtins.property
        def label_color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-labelcolor
            '''
            result = self._values.get("label_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_content(self) -> typing.Optional[builtins.str]:
            '''Determines the content of the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-labelcontent
            '''
            result = self._values.get("label_content")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"]]:
            '''Determines the font configuration of the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-labelfontconfiguration
            '''
            result = self._values.get("label_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"]], result)

        @builtins.property
        def measure_label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the measure field labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-measurelabelvisibility
            '''
            result = self._values.get("measure_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def overlap(self) -> typing.Optional[builtins.str]:
            '''Determines whether overlap is enabled or disabled for the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-overlap
            '''
            result = self._values.get("overlap")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''Determines the position of the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the total.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DataLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_path_label_type": "dataPathLabelType",
            "field_label_type": "fieldLabelType",
            "maximum_label_type": "maximumLabelType",
            "minimum_label_type": "minimumLabelType",
            "range_ends_label_type": "rangeEndsLabelType",
        },
    )
    class DataLabelTypeProperty:
        def __init__(
            self,
            *,
            data_path_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataPathLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            maximum_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MaximumLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            minimum_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MinimumLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            range_ends_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.RangeEndsLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The option that determines the data label type.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_path_label_type: The option that specifies individual data values for labels.
            :param field_label_type: Determines the label configuration for the entire field.
            :param maximum_label_type: Determines the label configuration for the maximum value in a visual.
            :param minimum_label_type: Determines the label configuration for the minimum value in a visual.
            :param range_ends_label_type: Determines the label configuration for range end value in a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_label_type_property = quicksight.CfnAnalysis.DataLabelTypeProperty(
                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                        field_id="fieldId",
                        field_value="fieldValue",
                        visibility="visibility"
                    ),
                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                        field_id="fieldId",
                        visibility="visibility"
                    ),
                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                        visibility="visibility"
                    ),
                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                        visibility="visibility"
                    ),
                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__baf45f94503ae9ca876cab034e08e9d0ffd39650ca278a4a24826388a6dee6c7)
                check_type(argname="argument data_path_label_type", value=data_path_label_type, expected_type=type_hints["data_path_label_type"])
                check_type(argname="argument field_label_type", value=field_label_type, expected_type=type_hints["field_label_type"])
                check_type(argname="argument maximum_label_type", value=maximum_label_type, expected_type=type_hints["maximum_label_type"])
                check_type(argname="argument minimum_label_type", value=minimum_label_type, expected_type=type_hints["minimum_label_type"])
                check_type(argname="argument range_ends_label_type", value=range_ends_label_type, expected_type=type_hints["range_ends_label_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_path_label_type is not None:
                self._values["data_path_label_type"] = data_path_label_type
            if field_label_type is not None:
                self._values["field_label_type"] = field_label_type
            if maximum_label_type is not None:
                self._values["maximum_label_type"] = maximum_label_type
            if minimum_label_type is not None:
                self._values["minimum_label_type"] = minimum_label_type
            if range_ends_label_type is not None:
                self._values["range_ends_label_type"] = range_ends_label_type

        @builtins.property
        def data_path_label_type(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataPathLabelTypeProperty"]]:
            '''The option that specifies individual data values for labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-datapathlabeltype
            '''
            result = self._values.get("data_path_label_type")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataPathLabelTypeProperty"]], result)

        @builtins.property
        def field_label_type(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldLabelTypeProperty"]]:
            '''Determines the label configuration for the entire field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-fieldlabeltype
            '''
            result = self._values.get("field_label_type")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldLabelTypeProperty"]], result)

        @builtins.property
        def maximum_label_type(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MaximumLabelTypeProperty"]]:
            '''Determines the label configuration for the maximum value in a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-maximumlabeltype
            '''
            result = self._values.get("maximum_label_type")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MaximumLabelTypeProperty"]], result)

        @builtins.property
        def minimum_label_type(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MinimumLabelTypeProperty"]]:
            '''Determines the label configuration for the minimum value in a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-minimumlabeltype
            '''
            result = self._values.get("minimum_label_type")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MinimumLabelTypeProperty"]], result)

        @builtins.property
        def range_ends_label_type(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RangeEndsLabelTypeProperty"]]:
            '''Determines the label configuration for range end value in a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-rangeendslabeltype
            '''
            result = self._values.get("range_ends_label_type")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RangeEndsLabelTypeProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DataPathColorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color": "color",
            "element": "element",
            "time_granularity": "timeGranularity",
        },
    )
    class DataPathColorProperty:
        def __init__(
            self,
            *,
            color: builtins.str,
            element: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]]],
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The color map that determines the color options for a particular element.

            :param color: The color that needs to be applied to the element.
            :param element: The element that the color needs to be applied to.
            :param time_granularity: The time granularity of the field that the color needs to be applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_path_color_property = quicksight.CfnAnalysis.DataPathColorProperty(
                    color="color",
                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                        data_path_type=quicksight.CfnAnalysis.DataPathTypeProperty(
                            pivot_table_data_path_type="pivotTableDataPathType"
                        ),
                        field_id="fieldId",
                        field_value="fieldValue"
                    ),
                
                    # the properties below are optional
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__22d7ab72c9e58d8a805483a123dd94538f8a59bd4b43e25b3c94b8fbb4093b3b)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument element", value=element, expected_type=type_hints["element"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
                "element": element,
            }
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def color(self) -> builtins.str:
            '''The color that needs to be applied to the element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathcolor.html#cfn-quicksight-analysis-datapathcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataPathValueProperty"]:
            '''The element that the color needs to be applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathcolor.html#cfn-quicksight-analysis-datapathcolor-element
            '''
            result = self._values.get("element")
            assert result is not None, "Required property 'element' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataPathValueProperty"], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The time granularity of the field that the color needs to be applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathcolor.html#cfn-quicksight-analysis-datapathcolor-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DataPathLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "field_value": "fieldValue",
            "visibility": "visibility",
        },
    )
    class DataPathLabelTypeProperty:
        def __init__(
            self,
            *,
            field_id: typing.Optional[builtins.str] = None,
            field_value: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The option that specifies individual data values for labels.

            :param field_id: The field ID of the field that the data label needs to be applied to.
            :param field_value: The actual value of the field that is labeled.
            :param visibility: The visibility of the data label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_path_label_type_property = quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                    field_id="fieldId",
                    field_value="fieldValue",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__92299d1328c6ec5763c4a2529888ce5ef3900ed776a8b1970a55b3c37c3b0dfb)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id
            if field_value is not None:
                self._values["field_value"] = field_value
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the field that the data label needs to be applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathlabeltype.html#cfn-quicksight-analysis-datapathlabeltype-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The actual value of the field that is labeled.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathlabeltype.html#cfn-quicksight-analysis-datapathlabeltype-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the data label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathlabeltype.html#cfn-quicksight-analysis-datapathlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DataPathSortProperty",
        jsii_struct_bases=[],
        name_mapping={"direction": "direction", "sort_paths": "sortPaths"},
    )
    class DataPathSortProperty:
        def __init__(
            self,
            *,
            direction: builtins.str,
            sort_paths: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''Allows data paths to be sorted by a specific data value.

            :param direction: Determines the sort direction.
            :param sort_paths: The list of data paths that need to be sorted.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_path_sort_property = quicksight.CfnAnalysis.DataPathSortProperty(
                    direction="direction",
                    sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                        data_path_type=quicksight.CfnAnalysis.DataPathTypeProperty(
                            pivot_table_data_path_type="pivotTableDataPathType"
                        ),
                        field_id="fieldId",
                        field_value="fieldValue"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__86d4fba3d65e1f121b841e1ea3ae51b09bf6d5742f286dbf05292fa7726c0166)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument sort_paths", value=sort_paths, expected_type=type_hints["sort_paths"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "sort_paths": sort_paths,
            }

        @builtins.property
        def direction(self) -> builtins.str:
            '''Determines the sort direction.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathsort.html#cfn-quicksight-analysis-datapathsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_paths(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataPathValueProperty"]]]:
            '''The list of data paths that need to be sorted.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathsort.html#cfn-quicksight-analysis-datapathsort-sortpaths
            '''
            result = self._values.get("sort_paths")
            assert result is not None, "Required property 'sort_paths' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataPathValueProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DataPathTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"pivot_table_data_path_type": "pivotTableDataPathType"},
    )
    class DataPathTypeProperty:
        def __init__(
            self,
            *,
            pivot_table_data_path_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The type of the data path value.

            :param pivot_table_data_path_type: The type of data path value utilized in a pivot table. Choose one of the following options:. - ``HIERARCHY_ROWS_LAYOUT_COLUMN`` - The type of data path for the rows layout column, when ``RowsLayout`` is set to ``HIERARCHY`` . - ``MULTIPLE_ROW_METRICS_COLUMN`` - The type of data path for the metric column when the row is set to Metric Placement. - ``EMPTY_COLUMN_HEADER`` - The type of data path for the column with empty column header, when there is no field in ``ColumnsFieldWell`` and the row is set to Metric Placement. - ``COUNT_METRIC_COLUMN`` - The type of data path for the column with ``COUNT`` as the metric, when there is no field in the ``ValuesFieldWell`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathtype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_path_type_property = quicksight.CfnAnalysis.DataPathTypeProperty(
                    pivot_table_data_path_type="pivotTableDataPathType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9124deacbcb1f63197a3bd5a840753ac0339784eda57ade6bb68b6fcacb08d23)
                check_type(argname="argument pivot_table_data_path_type", value=pivot_table_data_path_type, expected_type=type_hints["pivot_table_data_path_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pivot_table_data_path_type is not None:
                self._values["pivot_table_data_path_type"] = pivot_table_data_path_type

        @builtins.property
        def pivot_table_data_path_type(self) -> typing.Optional[builtins.str]:
            '''The type of data path value utilized in a pivot table. Choose one of the following options:.

            - ``HIERARCHY_ROWS_LAYOUT_COLUMN`` - The type of data path for the rows layout column, when ``RowsLayout`` is set to ``HIERARCHY`` .
            - ``MULTIPLE_ROW_METRICS_COLUMN`` - The type of data path for the metric column when the row is set to Metric Placement.
            - ``EMPTY_COLUMN_HEADER`` - The type of data path for the column with empty column header, when there is no field in ``ColumnsFieldWell`` and the row is set to Metric Placement.
            - ``COUNT_METRIC_COLUMN`` - The type of data path for the column with ``COUNT`` as the metric, when there is no field in the ``ValuesFieldWell`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathtype.html#cfn-quicksight-analysis-datapathtype-pivottabledatapathtype
            '''
            result = self._values.get("pivot_table_data_path_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DataPathValueProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_path_type": "dataPathType",
            "field_id": "fieldId",
            "field_value": "fieldValue",
        },
    )
    class DataPathValueProperty:
        def __init__(
            self,
            *,
            data_path_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataPathTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_id: typing.Optional[builtins.str] = None,
            field_value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The data path that needs to be sorted.

            :param data_path_type: The type configuration of the field.
            :param field_id: The field ID of the field that needs to be sorted.
            :param field_value: The actual value of the field that needs to be sorted.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathvalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_path_value_property = quicksight.CfnAnalysis.DataPathValueProperty(
                    data_path_type=quicksight.CfnAnalysis.DataPathTypeProperty(
                        pivot_table_data_path_type="pivotTableDataPathType"
                    ),
                    field_id="fieldId",
                    field_value="fieldValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ba849ca69e22a9c090b73d793791dc533d8bf31d54e27c2ca76b1b941a6ce8d2)
                check_type(argname="argument data_path_type", value=data_path_type, expected_type=type_hints["data_path_type"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_path_type is not None:
                self._values["data_path_type"] = data_path_type
            if field_id is not None:
                self._values["field_id"] = field_id
            if field_value is not None:
                self._values["field_value"] = field_value

        @builtins.property
        def data_path_type(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataPathTypeProperty"]]:
            '''The type configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathvalue.html#cfn-quicksight-analysis-datapathvalue-datapathtype
            '''
            result = self._values.get("data_path_type")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataPathTypeProperty"]], result)

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the field that needs to be sorted.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathvalue.html#cfn-quicksight-analysis-datapathvalue-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The actual value of the field that needs to be sorted.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathvalue.html#cfn-quicksight-analysis-datapathvalue-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DataSetIdentifierDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={"data_set_arn": "dataSetArn", "identifier": "identifier"},
    )
    class DataSetIdentifierDeclarationProperty:
        def __init__(
            self,
            *,
            data_set_arn: builtins.str,
            identifier: builtins.str,
        ) -> None:
            '''A data set.

            :param data_set_arn: The Amazon Resource Name (ARN) of the data set.
            :param identifier: The identifier of the data set, typically the data set's name.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetidentifierdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_set_identifier_declaration_property = quicksight.CfnAnalysis.DataSetIdentifierDeclarationProperty(
                    data_set_arn="dataSetArn",
                    identifier="identifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f3de1e151dbe34974f8b59029404441fba53ab091ea12315947279f3102413d3)
                check_type(argname="argument data_set_arn", value=data_set_arn, expected_type=type_hints["data_set_arn"])
                check_type(argname="argument identifier", value=identifier, expected_type=type_hints["identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_arn": data_set_arn,
                "identifier": identifier,
            }

        @builtins.property
        def data_set_arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the data set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetidentifierdeclaration.html#cfn-quicksight-analysis-datasetidentifierdeclaration-datasetarn
            '''
            result = self._values.get("data_set_arn")
            assert result is not None, "Required property 'data_set_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def identifier(self) -> builtins.str:
            '''The identifier of the data set, typically the data set's name.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetidentifierdeclaration.html#cfn-quicksight-analysis-datasetidentifierdeclaration-identifier
            '''
            result = self._values.get("identifier")
            assert result is not None, "Required property 'identifier' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetIdentifierDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DataSetReferenceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_arn": "dataSetArn",
            "data_set_placeholder": "dataSetPlaceholder",
        },
    )
    class DataSetReferenceProperty:
        def __init__(
            self,
            *,
            data_set_arn: builtins.str,
            data_set_placeholder: builtins.str,
        ) -> None:
            '''Dataset reference.

            :param data_set_arn: Dataset Amazon Resource Name (ARN).
            :param data_set_placeholder: Dataset placeholder.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetreference.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_set_reference_property = quicksight.CfnAnalysis.DataSetReferenceProperty(
                    data_set_arn="dataSetArn",
                    data_set_placeholder="dataSetPlaceholder"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e9a568b8d078664e0579c655148b615087e4791d2d616b8bec0caf8c3bff67c8)
                check_type(argname="argument data_set_arn", value=data_set_arn, expected_type=type_hints["data_set_arn"])
                check_type(argname="argument data_set_placeholder", value=data_set_placeholder, expected_type=type_hints["data_set_placeholder"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_arn": data_set_arn,
                "data_set_placeholder": data_set_placeholder,
            }

        @builtins.property
        def data_set_arn(self) -> builtins.str:
            '''Dataset Amazon Resource Name (ARN).

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetreference.html#cfn-quicksight-analysis-datasetreference-datasetarn
            '''
            result = self._values.get("data_set_arn")
            assert result is not None, "Required property 'data_set_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_placeholder(self) -> builtins.str:
            '''Dataset placeholder.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetreference.html#cfn-quicksight-analysis-datasetreference-datasetplaceholder
            '''
            result = self._values.get("data_set_placeholder")
            assert result is not None, "Required property 'data_set_placeholder' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetReferenceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DateAxisOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"missing_date_visibility": "missingDateVisibility"},
    )
    class DateAxisOptionsProperty:
        def __init__(
            self,
            *,
            missing_date_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine how a date axis is displayed.

            :param missing_date_visibility: Determines whether or not missing dates are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dateaxisoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_axis_options_property = quicksight.CfnAnalysis.DateAxisOptionsProperty(
                    missing_date_visibility="missingDateVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9200345b8443d7700b28884e93da7759942bd2a60eb6f37859aa8714fe8a4ea8)
                check_type(argname="argument missing_date_visibility", value=missing_date_visibility, expected_type=type_hints["missing_date_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if missing_date_visibility is not None:
                self._values["missing_date_visibility"] = missing_date_visibility

        @builtins.property
        def missing_date_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not missing dates are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dateaxisoptions.html#cfn-quicksight-analysis-dateaxisoptions-missingdatevisibility
            '''
            result = self._values.get("missing_date_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateAxisOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DateDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "date_granularity": "dateGranularity",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class DateDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            date_granularity: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with date type columns.

            :param column: The column that is used in the ``DateDimensionField`` .
            :param field_id: The custom field ID.
            :param date_granularity: The date granularity of the ``DateDimensionField`` . Choose one of the following options:. - ``YEAR`` - ``QUARTER`` - ``MONTH`` - ``WEEK`` - ``DAY`` - ``HOUR`` - ``MINUTE`` - ``SECOND`` - ``MILLISECOND``
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_dimension_field_property = quicksight.CfnAnalysis.DateDimensionFieldProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    date_granularity="dateGranularity",
                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fd0d8474bb61fc8fe81036b6842e1cc601b74662e1cb56e92f82e04ed92343ba)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument date_granularity", value=date_granularity, expected_type=type_hints["date_granularity"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if date_granularity is not None:
                self._values["date_granularity"] = date_granularity
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that is used in the ``DateDimensionField`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def date_granularity(self) -> typing.Optional[builtins.str]:
            '''The date granularity of the ``DateDimensionField`` . Choose one of the following options:.

            - ``YEAR``
            - ``QUARTER``
            - ``MONTH``
            - ``WEEK``
            - ``DAY``
            - ``HOUR``
            - ``MINUTE``
            - ``SECOND``
            - ``MILLISECOND``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-dategranularity
            '''
            result = self._values.get("date_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateTimeFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateTimeFormatConfigurationProperty"]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DateMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class DateMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            aggregation_function: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure type field with date type columns.

            :param column: The column that is used in the ``DateMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_measure_field_property = quicksight.CfnAnalysis.DateMeasureFieldProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function="aggregationFunction",
                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8ec1ded69f32897bf459edf237407416761a83ddfcc44202f6659bbe97b15b2b)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that is used in the ``DateMeasureField`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html#cfn-quicksight-analysis-datemeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html#cfn-quicksight-analysis-datemeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(self) -> typing.Optional[builtins.str]:
            '''The aggregation function of the measure field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html#cfn-quicksight-analysis-datemeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateTimeFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html#cfn-quicksight-analysis-datemeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateTimeFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DateTimeDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "rolling_date": "rollingDate",
            "static_values": "staticValues",
        },
    )
    class DateTimeDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rolling_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.RollingDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The default values of the ``DateTimeParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``DataTimeDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param rolling_date: The rolling date of the ``DataTimeDefaultValues`` . The date is determined from the dataset based on input expression.
            :param static_values: The static values of the ``DataTimeDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimedefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_default_values_property = quicksight.CfnAnalysis.DateTimeDefaultValuesProperty(
                    dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                        expression="expression",
                
                        # the properties below are optional
                        data_set_identifier="dataSetIdentifier"
                    ),
                    static_values=["staticValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1da8f843d15a3d85a3e70a9ec36f8e4d6bc5d873c5af842246e2e9fa1285e22c)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument rolling_date", value=rolling_date, expected_type=type_hints["rolling_date"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if rolling_date is not None:
                self._values["rolling_date"] = rolling_date
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``DataTimeDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimedefaultvalues.html#cfn-quicksight-analysis-datetimedefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def rolling_date(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RollingDateConfigurationProperty"]]:
            '''The rolling date of the ``DataTimeDefaultValues`` .

            The date is determined from the dataset based on input expression.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimedefaultvalues.html#cfn-quicksight-analysis-datetimedefaultvalues-rollingdate
            '''
            result = self._values.get("rolling_date")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RollingDateConfigurationProperty"]], result)

        @builtins.property
        def static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The static values of the ``DataTimeDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimedefaultvalues.html#cfn-quicksight-analysis-datetimedefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "numeric_format_configuration": "numericFormatConfiguration",
        },
    )
    class DateTimeFormatConfigurationProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Formatting configuration for ``DateTime`` fields.

            :param date_time_format: Determines the ``DateTime`` format.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param numeric_format_configuration: The formatting configuration for numeric ``DateTime`` fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_format_configuration_property = quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                    date_time_format="dateTimeFormat",
                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0a52a1effef6a37135b62fc99fba7a1801c65a2611508716eb6e2fc95a2a1d70)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument numeric_format_configuration", value=numeric_format_configuration, expected_type=type_hints["numeric_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if numeric_format_configuration is not None:
                self._values["numeric_format_configuration"] = numeric_format_configuration

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Determines the ``DateTime`` format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeformatconfiguration.html#cfn-quicksight-analysis-datetimeformatconfiguration-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeformatconfiguration.html#cfn-quicksight-analysis-datetimeformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def numeric_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericFormatConfigurationProperty"]]:
            '''The formatting configuration for numeric ``DateTime`` fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeformatconfiguration.html#cfn-quicksight-analysis-datetimeformatconfiguration-numericformatconfiguration
            '''
            result = self._values.get("numeric_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DateTimeHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class DateTimeHierarchyProperty:
        def __init__(
            self,
            *,
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of any ``DateTime`` fields.

            :param hierarchy_id: The hierarchy ID of the ``DateTime`` hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the ``DateTime`` hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimehierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_hierarchy_property = quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__10eb1a9ed2c4e66745e808132025ab28e7933d9384f2ad68e2a825f3210ff210)
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the ``DateTime`` hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimehierarchy.html#cfn-quicksight-analysis-datetimehierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DrillDownFilterProperty"]]]]:
            '''The option that determines the drill down filters for the ``DateTime`` hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimehierarchy.html#cfn-quicksight-analysis-datetimehierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DrillDownFilterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DateTimeParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "time_granularity": "timeGranularity",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class DateTimeParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DateTimeDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
            value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``DateTime`` data type.

            :param name: The name of the parameter that is being declared.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: 
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param value_when_unset: The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_parameter_declaration_property = quicksight.CfnAnalysis.DateTimeParameterDeclarationProperty(
                    name="name",
                
                    # the properties below are optional
                    default_values=quicksight.CfnAnalysis.DateTimeDefaultValuesProperty(
                        dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_values=["staticValues"]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    time_granularity="timeGranularity",
                    value_when_unset=quicksight.CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty(
                        custom_value="customValue",
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7a68ab56c16f4db8843b372cb5d3ee1a3e4be61d10c8ef69ba820c5da2b8a931)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateTimeDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateTimeDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MappedDataSetParameterProperty"]]]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty"]]:
            '''The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DateTimeParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class DateTimeParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Sequence[builtins.str],
        ) -> None:
            '''A date-time parameter.

            :param name: A display name for the date-time parameter.
            :param values: The values for the date-time parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_parameter_property = quicksight.CfnAnalysis.DateTimeParameterProperty(
                    name="name",
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c4df0ff05d2f7f0ede02161ea59214e17a3da562d2ba522d066c007b3508815e)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for the date-time parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameter.html#cfn-quicksight-analysis-datetimeparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(self) -> typing.List[builtins.str]:
            '''The values for the date-time parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameter.html#cfn-quicksight-analysis-datetimeparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.List[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "info_icon_label_options": "infoIconLabelOptions",
            "title_options": "titleOptions",
        },
    )
    class DateTimePickerControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SheetControlInfoIconLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param date_time_format: Customize how dates are formatted in controls.
            :param info_icon_label_options: The configuration of info icon label options.
            :param title_options: The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimepickercontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_picker_control_display_options_property = quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                    date_time_format="dateTimeFormat",
                    info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                        info_icon_text="infoIconText",
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__16031b544a2c676bbfee7ed1c93e204aa5a7f2dab58622a274141ef9710b48c8)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument info_icon_label_options", value=info_icon_label_options, expected_type=type_hints["info_icon_label_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if info_icon_label_options is not None:
                self._values["info_icon_label_options"] = info_icon_label_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Customize how dates are formatted in controls.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimepickercontroldisplayoptions.html#cfn-quicksight-analysis-datetimepickercontroldisplayoptions-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def info_icon_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetControlInfoIconLabelOptionsProperty"]]:
            '''The configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimepickercontroldisplayoptions.html#cfn-quicksight-analysis-datetimepickercontroldisplayoptions-infoiconlabeloptions
            '''
            result = self._values.get("info_icon_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetControlInfoIconLabelOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimepickercontroldisplayoptions.html#cfn-quicksight-analysis-datetimepickercontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimePickerControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class DateTimeValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[builtins.str] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimevaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_value_when_unset_configuration_property = quicksight.CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty(
                    custom_value="customValue",
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__496e42293484deb5a0ef4cc356b965767bd664aee533cf7d9bcb6320cc824c66)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[builtins.str]:
            '''A custom value that's used when the value of a parameter isn't set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-analysis-datetimevaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-analysis-datetimevaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DecimalDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class DecimalDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
        ) -> None:
            '''The default values of the ``DecimalParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``DecimalDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``DecimalDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimaldefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                decimal_default_values_property = quicksight.CfnAnalysis.DecimalDefaultValuesProperty(
                    dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6041f968355c092078a2031614955bc07a4930897e0c000ded27c288989fb7ee)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``DecimalDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimaldefaultvalues.html#cfn-quicksight-analysis-decimaldefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def static_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]]:
            '''The static values of the ``DecimalDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimaldefaultvalues.html#cfn-quicksight-analysis-decimaldefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DecimalParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class DecimalParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DecimalDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``Decimal`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: 
            :param value_when_unset: The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                decimal_parameter_declaration_property = quicksight.CfnAnalysis.DecimalParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnAnalysis.DecimalDefaultValuesProperty(
                        dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=[123]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty(
                        custom_value=123,
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e7a7efdffb85dad0fe095929a9da76445b466b9316260d44790824714f09c274)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DecimalDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DecimalDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MappedDataSetParameterProperty"]]]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty"]]:
            '''The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DecimalParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class DecimalParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]],
        ) -> None:
            '''A decimal parameter.

            :param name: A display name for the decimal parameter.
            :param values: The values for the decimal parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                decimal_parameter_property = quicksight.CfnAnalysis.DecimalParameterProperty(
                    name="name",
                    values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1c30fcfd3a96dfa875b3537e48e84a223b349d53190700099dc7830feb1f0b64)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for the decimal parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameter.html#cfn-quicksight-analysis-decimalparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]:
            '''The values for the decimal parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameter.html#cfn-quicksight-analysis-decimalparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"decimal_places": "decimalPlaces"},
    )
    class DecimalPlacesConfigurationProperty:
        def __init__(self, *, decimal_places: jsii.Number) -> None:
            '''The option that determines the decimal places configuration.

            :param decimal_places: The values of the decimal places.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalplacesconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                decimal_places_configuration_property = quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                    decimal_places=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fdba937bce62805797d8bd38df0006794f78ccf7a86bb2a96afd1ccc3c7d830d)
                check_type(argname="argument decimal_places", value=decimal_places, expected_type=type_hints["decimal_places"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "decimal_places": decimal_places,
            }

        @builtins.property
        def decimal_places(self) -> jsii.Number:
            '''The values of the decimal places.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalplacesconfiguration.html#cfn-quicksight-analysis-decimalplacesconfiguration-decimalplaces
            '''
            result = self._values.get("decimal_places")
            assert result is not None, "Required property 'decimal_places' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalPlacesConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class DecimalValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[jsii.Number] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalvaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                decimal_value_when_unset_configuration_property = quicksight.CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty(
                    custom_value=123,
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b5b58e947afff94824ee0192ed7fb58383917df19648d81c4312996d2c9149d1)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[jsii.Number]:
            '''A custom value that's used when the value of a parameter isn't set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-analysis-decimalvaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-analysis-decimalvaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultFreeFormLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The options that determine the default settings of a free-form layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultfreeformlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                default_free_form_layout_configuration_property = quicksight.CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2576800bc2c6797c492467497289cafee3725d83b8b2a0c3e9ada116b562fb6d)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty"]:
            '''Determines the screen canvas size options for a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultfreeformlayoutconfiguration.html#cfn-quicksight-analysis-defaultfreeformlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultFreeFormLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DefaultGridLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultGridLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GridLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The options that determine the default settings for a grid layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a grid layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultgridlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                default_grid_layout_configuration_property = quicksight.CfnAnalysis.DefaultGridLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                            resize_option="resizeOption",
                
                            # the properties below are optional
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8086a8fa2fdaace4e00baac5605b96e46ed5fb1925470181b7056cabae70c506)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GridLayoutCanvasSizeOptionsProperty"]:
            '''Determines the screen canvas size options for a grid layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultgridlayoutconfiguration.html#cfn-quicksight-analysis-defaultgridlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GridLayoutCanvasSizeOptionsProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultGridLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"free_form": "freeForm", "grid": "grid"},
    )
    class DefaultInteractiveLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            grid: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DefaultGridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the default settings for interactive layout configuration.

            :param free_form: The options that determine the default settings of a free-form layout configuration.
            :param grid: The options that determine the default settings for a grid layout configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultinteractivelayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                default_interactive_layout_configuration_property = quicksight.CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty(
                    free_form=quicksight.CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    grid=quicksight.CfnAnalysis.DefaultGridLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d04354276f7247945ccd165e93cd180a01a97b610a00894675eb0c9f03759f12)
                check_type(argname="argument free_form", value=free_form, expected_type=type_hints["free_form"])
                check_type(argname="argument grid", value=grid, expected_type=type_hints["grid"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if free_form is not None:
                self._values["free_form"] = free_form
            if grid is not None:
                self._values["grid"] = grid

        @builtins.property
        def free_form(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty"]]:
            '''The options that determine the default settings of a free-form layout configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultinteractivelayoutconfiguration.html#cfn-quicksight-analysis-defaultinteractivelayoutconfiguration-freeform
            '''
            result = self._values.get("free_form")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty"]], result)

        @builtins.property
        def grid(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DefaultGridLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for a grid layout configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultinteractivelayoutconfiguration.html#cfn-quicksight-analysis-defaultinteractivelayoutconfiguration-grid
            '''
            result = self._values.get("grid")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DefaultGridLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultInteractiveLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DefaultNewSheetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "interactive_layout_configuration": "interactiveLayoutConfiguration",
            "paginated_layout_configuration": "paginatedLayoutConfiguration",
            "sheet_content_type": "sheetContentType",
        },
    )
    class DefaultNewSheetConfigurationProperty:
        def __init__(
            self,
            *,
            interactive_layout_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paginated_layout_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sheet_content_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration for default new sheet settings.

            :param interactive_layout_configuration: The options that determine the default settings for interactive layout configuration.
            :param paginated_layout_configuration: The options that determine the default settings for a paginated layout configuration.
            :param sheet_content_type: The option that determines the sheet content type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultnewsheetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                default_new_sheet_configuration_property = quicksight.CfnAnalysis.DefaultNewSheetConfigurationProperty(
                    interactive_layout_configuration=quicksight.CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty(
                        free_form=quicksight.CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        grid=quicksight.CfnAnalysis.DefaultGridLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        )
                    ),
                    paginated_layout_configuration=quicksight.CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty(
                        section_based=quicksight.CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                    paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    ),
                                    paper_orientation="paperOrientation",
                                    paper_size="paperSize"
                                )
                            )
                        )
                    ),
                    sheet_content_type="sheetContentType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e7279c174707162e2869656b88d69fa16e6e97a88e1e9041bec55319aab36d19)
                check_type(argname="argument interactive_layout_configuration", value=interactive_layout_configuration, expected_type=type_hints["interactive_layout_configuration"])
                check_type(argname="argument paginated_layout_configuration", value=paginated_layout_configuration, expected_type=type_hints["paginated_layout_configuration"])
                check_type(argname="argument sheet_content_type", value=sheet_content_type, expected_type=type_hints["sheet_content_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if interactive_layout_configuration is not None:
                self._values["interactive_layout_configuration"] = interactive_layout_configuration
            if paginated_layout_configuration is not None:
                self._values["paginated_layout_configuration"] = paginated_layout_configuration
            if sheet_content_type is not None:
                self._values["sheet_content_type"] = sheet_content_type

        @builtins.property
        def interactive_layout_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for interactive layout configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultnewsheetconfiguration.html#cfn-quicksight-analysis-defaultnewsheetconfiguration-interactivelayoutconfiguration
            '''
            result = self._values.get("interactive_layout_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty"]], result)

        @builtins.property
        def paginated_layout_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for a paginated layout configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultnewsheetconfiguration.html#cfn-quicksight-analysis-defaultnewsheetconfiguration-paginatedlayoutconfiguration
            '''
            result = self._values.get("paginated_layout_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty"]], result)

        @builtins.property
        def sheet_content_type(self) -> typing.Optional[builtins.str]:
            '''The option that determines the sheet content type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultnewsheetconfiguration.html#cfn-quicksight-analysis-defaultnewsheetconfiguration-sheetcontenttype
            '''
            result = self._values.get("sheet_content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultNewSheetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"section_based": "sectionBased"},
    )
    class DefaultPaginatedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            section_based: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the default settings for a paginated layout configuration.

            :param section_based: The options that determine the default settings for a section-based layout configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultpaginatedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                default_paginated_layout_configuration_property = quicksight.CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty(
                    section_based=quicksight.CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                            paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                ),
                                paper_orientation="paperOrientation",
                                paper_size="paperSize"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5bd1fdbfb41878c1a01bf4ec5b04bee7584ad858147b67db1a2d05dda1702891)
                check_type(argname="argument section_based", value=section_based, expected_type=type_hints["section_based"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if section_based is not None:
                self._values["section_based"] = section_based

        @builtins.property
        def section_based(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for a section-based layout configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultpaginatedlayoutconfiguration.html#cfn-quicksight-analysis-defaultpaginatedlayoutconfiguration-sectionbased
            '''
            result = self._values.get("section_based")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultPaginatedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultSectionBasedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The options that determine the default settings for a section-based layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a section-based layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultsectionbasedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                default_section_based_layout_configuration_property = quicksight.CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                        paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                            paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            ),
                            paper_orientation="paperOrientation",
                            paper_size="paperSize"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__844118c582547d0457e97e77b0e34513191da4989820067b337b49d1e239a90b)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty"]:
            '''Determines the screen canvas size options for a section-based layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultsectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-defaultsectionbasedlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultSectionBasedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_values_configuration": "customValuesConfiguration",
            "select_all_value_options": "selectAllValueOptions",
            "source_column": "sourceColumn",
            "source_field": "sourceField",
            "source_parameter_name": "sourceParameterName",
        },
    )
    class DestinationParameterValueConfigurationProperty:
        def __init__(
            self,
            *,
            custom_values_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CustomValuesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            select_all_value_options: typing.Optional[builtins.str] = None,
            source_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            source_field: typing.Optional[builtins.str] = None,
            source_parameter_name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of destination parameter values.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_values_configuration: The configuration of custom values for destination parameter in ``DestinationParameterValueConfiguration`` .
            :param select_all_value_options: The configuration that selects all options.
            :param source_column: 
            :param source_field: The source field ID of the destination parameter.
            :param source_parameter_name: The source parameter name of the destination parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                destination_parameter_value_configuration_property = quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                            date_time_values=["dateTimeValues"],
                            decimal_values=[123],
                            integer_values=[123],
                            string_values=["stringValues"]
                        ),
                
                        # the properties below are optional
                        include_null_value=False
                    ),
                    select_all_value_options="selectAllValueOptions",
                    source_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    source_field="sourceField",
                    source_parameter_name="sourceParameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b568ad7c5608ef334c1467a57d1b9916a10bda6f9c7696669cedd4a8a2c78a8c)
                check_type(argname="argument custom_values_configuration", value=custom_values_configuration, expected_type=type_hints["custom_values_configuration"])
                check_type(argname="argument select_all_value_options", value=select_all_value_options, expected_type=type_hints["select_all_value_options"])
                check_type(argname="argument source_column", value=source_column, expected_type=type_hints["source_column"])
                check_type(argname="argument source_field", value=source_field, expected_type=type_hints["source_field"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_values_configuration is not None:
                self._values["custom_values_configuration"] = custom_values_configuration
            if select_all_value_options is not None:
                self._values["select_all_value_options"] = select_all_value_options
            if source_column is not None:
                self._values["source_column"] = source_column
            if source_field is not None:
                self._values["source_field"] = source_field
            if source_parameter_name is not None:
                self._values["source_parameter_name"] = source_parameter_name

        @builtins.property
        def custom_values_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomValuesConfigurationProperty"]]:
            '''The configuration of custom values for destination parameter in ``DestinationParameterValueConfiguration`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-customvaluesconfiguration
            '''
            result = self._values.get("custom_values_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomValuesConfigurationProperty"]], result)

        @builtins.property
        def select_all_value_options(self) -> typing.Optional[builtins.str]:
            '''The configuration that selects all options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-selectallvalueoptions
            '''
            result = self._values.get("select_all_value_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def source_column(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-sourcecolumn
            '''
            result = self._values.get("source_column")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]], result)

        @builtins.property
        def source_field(self) -> typing.Optional[builtins.str]:
            '''The source field ID of the destination parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-sourcefield
            '''
            result = self._values.get("source_field")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def source_parameter_name(self) -> typing.Optional[builtins.str]:
            '''The source parameter name of the destination parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DestinationParameterValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "categorical_dimension_field": "categoricalDimensionField",
            "date_dimension_field": "dateDimensionField",
            "numerical_dimension_field": "numericalDimensionField",
        },
    )
    class DimensionFieldProperty:
        def __init__(
            self,
            *,
            categorical_dimension_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CategoricalDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            date_dimension_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DateDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numerical_dimension_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumericalDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The dimension type field.

            :param categorical_dimension_field: The dimension type field with categorical type columns.
            :param date_dimension_field: The dimension type field with date type columns.
            :param numerical_dimension_field: The dimension type field with numerical type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                dimension_field_property = quicksight.CfnAnalysis.DimensionFieldProperty(
                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    ),
                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        date_granularity="dateGranularity",
                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    ),
                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__47d2749256cc1777ad9f47e7272592b9ce95c8a7bb0694c352c23fabf36f8bed)
                check_type(argname="argument categorical_dimension_field", value=categorical_dimension_field, expected_type=type_hints["categorical_dimension_field"])
                check_type(argname="argument date_dimension_field", value=date_dimension_field, expected_type=type_hints["date_dimension_field"])
                check_type(argname="argument numerical_dimension_field", value=numerical_dimension_field, expected_type=type_hints["numerical_dimension_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if categorical_dimension_field is not None:
                self._values["categorical_dimension_field"] = categorical_dimension_field
            if date_dimension_field is not None:
                self._values["date_dimension_field"] = date_dimension_field
            if numerical_dimension_field is not None:
                self._values["numerical_dimension_field"] = numerical_dimension_field

        @builtins.property
        def categorical_dimension_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CategoricalDimensionFieldProperty"]]:
            '''The dimension type field with categorical type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dimensionfield.html#cfn-quicksight-analysis-dimensionfield-categoricaldimensionfield
            '''
            result = self._values.get("categorical_dimension_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CategoricalDimensionFieldProperty"]], result)

        @builtins.property
        def date_dimension_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateDimensionFieldProperty"]]:
            '''The dimension type field with date type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dimensionfield.html#cfn-quicksight-analysis-dimensionfield-datedimensionfield
            '''
            result = self._values.get("date_dimension_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateDimensionFieldProperty"]], result)

        @builtins.property
        def numerical_dimension_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericalDimensionFieldProperty"]]:
            '''The dimension type field with numerical type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dimensionfield.html#cfn-quicksight-analysis-dimensionfield-numericaldimensionfield
            '''
            result = self._values.get("numerical_dimension_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericalDimensionFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DonutCenterOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"label_visibility": "labelVisibility"},
    )
    class DonutCenterOptionsProperty:
        def __init__(
            self,
            *,
            label_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label options of the label that is displayed in the center of a donut chart.

            This option isn't available for pie charts.

            :param label_visibility: Determines the visibility of the label in a donut chart. In the Amazon QuickSight console, this option is called ``'Show total'`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutcenteroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                donut_center_options_property = quicksight.CfnAnalysis.DonutCenterOptionsProperty(
                    label_visibility="labelVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__be1f945d08f91a6a6f7b2701dbe881f346d1dca9634f685da7b97951943fd5b7)
                check_type(argname="argument label_visibility", value=label_visibility, expected_type=type_hints["label_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if label_visibility is not None:
                self._values["label_visibility"] = label_visibility

        @builtins.property
        def label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the label in a donut chart.

            In the Amazon QuickSight console, this option is called ``'Show total'`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutcenteroptions.html#cfn-quicksight-analysis-donutcenteroptions-labelvisibility
            '''
            result = self._values.get("label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DonutCenterOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DonutOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arc_options": "arcOptions",
            "donut_center_options": "donutCenterOptions",
        },
    )
    class DonutOptionsProperty:
        def __init__(
            self,
            *,
            arc_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ArcOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            donut_center_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DonutCenterOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options for configuring a donut chart or pie chart.

            :param arc_options: The option for define the arc of the chart shape. Valid values are as follows:. - ``WHOLE`` - A pie chart - ``SMALL`` - A small-sized donut chart - ``MEDIUM`` - A medium-sized donut chart - ``LARGE`` - A large-sized donut chart
            :param donut_center_options: The label options of the label that is displayed in the center of a donut chart. This option isn't available for pie charts.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                donut_options_property = quicksight.CfnAnalysis.DonutOptionsProperty(
                    arc_options=quicksight.CfnAnalysis.ArcOptionsProperty(
                        arc_thickness="arcThickness"
                    ),
                    donut_center_options=quicksight.CfnAnalysis.DonutCenterOptionsProperty(
                        label_visibility="labelVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__36f3881197859f312008e2497b1f7133aeec48b33690834c8a3249cf7fed0f48)
                check_type(argname="argument arc_options", value=arc_options, expected_type=type_hints["arc_options"])
                check_type(argname="argument donut_center_options", value=donut_center_options, expected_type=type_hints["donut_center_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_options is not None:
                self._values["arc_options"] = arc_options
            if donut_center_options is not None:
                self._values["donut_center_options"] = donut_center_options

        @builtins.property
        def arc_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ArcOptionsProperty"]]:
            '''The option for define the arc of the chart shape. Valid values are as follows:.

            - ``WHOLE`` - A pie chart
            - ``SMALL`` - A small-sized donut chart
            - ``MEDIUM`` - A medium-sized donut chart
            - ``LARGE`` - A large-sized donut chart

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutoptions.html#cfn-quicksight-analysis-donutoptions-arcoptions
            '''
            result = self._values.get("arc_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ArcOptionsProperty"]], result)

        @builtins.property
        def donut_center_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DonutCenterOptionsProperty"]]:
            '''The label options of the label that is displayed in the center of a donut chart.

            This option isn't available for pie charts.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutoptions.html#cfn-quicksight-analysis-donutoptions-donutcenteroptions
            '''
            result = self._values.get("donut_center_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DonutCenterOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DonutOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_filter": "categoryFilter",
            "numeric_equality_filter": "numericEqualityFilter",
            "time_range_filter": "timeRangeFilter",
        },
    )
    class DrillDownFilterProperty:
        def __init__(
            self,
            *,
            category_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CategoryDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_equality_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumericEqualityDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TimeRangeDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The drill down filter for the column hierarchies.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param category_filter: The category type drill down filter. This filter is used for string type columns.
            :param numeric_equality_filter: The numeric equality type drill down filter. This filter is used for number type columns.
            :param time_range_filter: The time range drill down filter. This filter is used for date time columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-drilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                drill_down_filter_property = quicksight.CfnAnalysis.DrillDownFilterProperty(
                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                        category_values=["categoryValues"],
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        value=123
                    ),
                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        range_maximum="rangeMaximum",
                        range_minimum="rangeMinimum",
                        time_granularity="timeGranularity"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__63714a0f5ddd94a6add28ab64356e46ddad604ffd9e4c7c5990527129eb07ae9)
                check_type(argname="argument category_filter", value=category_filter, expected_type=type_hints["category_filter"])
                check_type(argname="argument numeric_equality_filter", value=numeric_equality_filter, expected_type=type_hints["numeric_equality_filter"])
                check_type(argname="argument time_range_filter", value=time_range_filter, expected_type=type_hints["time_range_filter"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_filter is not None:
                self._values["category_filter"] = category_filter
            if numeric_equality_filter is not None:
                self._values["numeric_equality_filter"] = numeric_equality_filter
            if time_range_filter is not None:
                self._values["time_range_filter"] = time_range_filter

        @builtins.property
        def category_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CategoryDrillDownFilterProperty"]]:
            '''The category type drill down filter.

            This filter is used for string type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-drilldownfilter.html#cfn-quicksight-analysis-drilldownfilter-categoryfilter
            '''
            result = self._values.get("category_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CategoryDrillDownFilterProperty"]], result)

        @builtins.property
        def numeric_equality_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericEqualityDrillDownFilterProperty"]]:
            '''The numeric equality type drill down filter.

            This filter is used for number type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-drilldownfilter.html#cfn-quicksight-analysis-drilldownfilter-numericequalityfilter
            '''
            result = self._values.get("numeric_equality_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericEqualityDrillDownFilterProperty"]], result)

        @builtins.property
        def time_range_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TimeRangeDrillDownFilterProperty"]]:
            '''The time range drill down filter.

            This filter is used for date time columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-drilldownfilter.html#cfn-quicksight-analysis-drilldownfilter-timerangefilter
            '''
            result = self._values.get("time_range_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TimeRangeDrillDownFilterProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "info_icon_label_options": "infoIconLabelOptions",
            "select_all_options": "selectAllOptions",
            "title_options": "titleOptions",
        },
    )
    class DropDownControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SheetControlInfoIconLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            select_all_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ListControlSelectAllOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param info_icon_label_options: The configuration of info icon label options.
            :param select_all_options: The configuration of the ``Select all`` options in a dropdown control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dropdowncontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                drop_down_control_display_options_property = quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                    info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                        info_icon_text="infoIconText",
                        visibility="visibility"
                    ),
                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__30f399901a109252449886599a579773134377fc9cf49eb2e30dfb58a7bafb35)
                check_type(argname="argument info_icon_label_options", value=info_icon_label_options, expected_type=type_hints["info_icon_label_options"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if info_icon_label_options is not None:
                self._values["info_icon_label_options"] = info_icon_label_options
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def info_icon_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetControlInfoIconLabelOptionsProperty"]]:
            '''The configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dropdowncontroldisplayoptions.html#cfn-quicksight-analysis-dropdowncontroldisplayoptions-infoiconlabeloptions
            '''
            result = self._values.get("info_icon_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetControlInfoIconLabelOptionsProperty"]], result)

        @builtins.property
        def select_all_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ListControlSelectAllOptionsProperty"]]:
            '''The configuration of the ``Select all`` options in a dropdown control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dropdowncontroldisplayoptions.html#cfn-quicksight-analysis-dropdowncontroldisplayoptions-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ListControlSelectAllOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dropdowncontroldisplayoptions.html#cfn-quicksight-analysis-dropdowncontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DropDownControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.DynamicDefaultValueProperty",
        jsii_struct_bases=[],
        name_mapping={
            "default_value_column": "defaultValueColumn",
            "group_name_column": "groupNameColumn",
            "user_name_column": "userNameColumn",
        },
    )
    class DynamicDefaultValueProperty:
        def __init__(
            self,
            *,
            default_value_column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            group_name_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            user_name_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Defines different defaults to the users or groups based on mapping.

            :param default_value_column: The column that contains the default value of each user or group.
            :param group_name_column: The column that contains the group name.
            :param user_name_column: The column that contains the username.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dynamicdefaultvalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                dynamic_default_value_property = quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                    default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c3d4b0670d07ee16280a547fe53b00b90cdb9a12ba231eb0dbdb9ea9ca830dc1)
                check_type(argname="argument default_value_column", value=default_value_column, expected_type=type_hints["default_value_column"])
                check_type(argname="argument group_name_column", value=group_name_column, expected_type=type_hints["group_name_column"])
                check_type(argname="argument user_name_column", value=user_name_column, expected_type=type_hints["user_name_column"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "default_value_column": default_value_column,
            }
            if group_name_column is not None:
                self._values["group_name_column"] = group_name_column
            if user_name_column is not None:
                self._values["user_name_column"] = user_name_column

        @builtins.property
        def default_value_column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that contains the default value of each user or group.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dynamicdefaultvalue.html#cfn-quicksight-analysis-dynamicdefaultvalue-defaultvaluecolumn
            '''
            result = self._values.get("default_value_column")
            assert result is not None, "Required property 'default_value_column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def group_name_column(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]]:
            '''The column that contains the group name.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dynamicdefaultvalue.html#cfn-quicksight-analysis-dynamicdefaultvalue-groupnamecolumn
            '''
            result = self._values.get("group_name_column")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]], result)

        @builtins.property
        def user_name_column(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]]:
            '''The column that contains the username.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dynamicdefaultvalue.html#cfn-quicksight-analysis-dynamicdefaultvalue-usernamecolumn
            '''
            result = self._values.get("user_name_column")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DynamicDefaultValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.EmptyVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
        },
    )
    class EmptyVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''An empty visual.

            Empty visuals are used in layouts but have not been configured to show any data. A new visual created in the Amazon QuickSight console is considered an ``EmptyVisual`` until a visual type is selected.

            :param data_set_identifier: The data set that is used in the empty visual. Every visual requires a dataset to render.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-emptyvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                empty_visual_property = quicksight.CfnAnalysis.EmptyVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__91c2446b2b894ede2d4797bf64f87f839affcb97fb0a4b0978a0dd8d78bd25db)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that is used in the empty visual.

            Every visual requires a dataset to render.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-emptyvisual.html#cfn-quicksight-analysis-emptyvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-emptyvisual.html#cfn-quicksight-analysis-emptyvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-emptyvisual.html#cfn-quicksight-analysis-emptyvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "EmptyVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.EntityProperty",
        jsii_struct_bases=[],
        name_mapping={"path": "path"},
    )
    class EntityProperty:
        def __init__(self, *, path: typing.Optional[builtins.str] = None) -> None:
            '''An object, structure, or sub-structure of an analysis, template, or dashboard.

            :param path: The hierarchical path of the entity within the analysis, template, or dashboard definition tree.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-entity.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                entity_property = quicksight.CfnAnalysis.EntityProperty(
                    path="path"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__800b433b7f82672440f865224ede9130f33730dda19b42651dd93929249b7291)
                check_type(argname="argument path", value=path, expected_type=type_hints["path"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if path is not None:
                self._values["path"] = path

        @builtins.property
        def path(self) -> typing.Optional[builtins.str]:
            '''The hierarchical path of the entity within the analysis, template, or dashboard definition tree.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-entity.html#cfn-quicksight-analysis-entity-path
            '''
            result = self._values.get("path")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "EntityProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "amount": "amount",
            "granularity": "granularity",
            "status": "status",
        },
    )
    class ExcludePeriodConfigurationProperty:
        def __init__(
            self,
            *,
            amount: jsii.Number,
            granularity: builtins.str,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The exclude period of ``TimeRangeFilter`` or ``RelativeDatesFilter`` .

            :param amount: The amount or number of the exclude period.
            :param granularity: The granularity or unit (day, month, year) of the exclude period.
            :param status: The status of the exclude period. Choose from the following options:. - ``ENABLED`` - ``DISABLED``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-excludeperiodconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                exclude_period_configuration_property = quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                    amount=123,
                    granularity="granularity",
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e13c0d1f2b524d378faf5d092530d94a87b58c2d430cad270aa2a67f655f967d)
                check_type(argname="argument amount", value=amount, expected_type=type_hints["amount"])
                check_type(argname="argument granularity", value=granularity, expected_type=type_hints["granularity"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "amount": amount,
                "granularity": granularity,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def amount(self) -> jsii.Number:
            '''The amount or number of the exclude period.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-excludeperiodconfiguration.html#cfn-quicksight-analysis-excludeperiodconfiguration-amount
            '''
            result = self._values.get("amount")
            assert result is not None, "Required property 'amount' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def granularity(self) -> builtins.str:
            '''The granularity or unit (day, month, year) of the exclude period.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-excludeperiodconfiguration.html#cfn-quicksight-analysis-excludeperiodconfiguration-granularity
            '''
            result = self._values.get("granularity")
            assert result is not None, "Required property 'granularity' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the exclude period. Choose from the following options:.

            - ``ENABLED``
            - ``DISABLED``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-excludeperiodconfiguration.html#cfn-quicksight-analysis-excludeperiodconfiguration-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExcludePeriodConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ExplicitHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class ExplicitHierarchyProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]]],
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields that are built within a visual's field wells.

            These fields can't be duplicated to other visuals.

            :param columns: The list of columns that define the explicit hierarchy.
            :param hierarchy_id: The hierarchy ID of the explicit hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the explicit hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-explicithierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                explicit_hierarchy_property = quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__34dd11fb8a2f2d1be7b77d4774d2571ec51eed42de5ef8b76001040fb1074364)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]]]:
            '''The list of columns that define the explicit hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-explicithierarchy.html#cfn-quicksight-analysis-explicithierarchy-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]]], result)

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the explicit hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-explicithierarchy.html#cfn-quicksight-analysis-explicithierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DrillDownFilterProperty"]]]]:
            '''The option that determines the drill down filters for the explicit hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-explicithierarchy.html#cfn-quicksight-analysis-explicithierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DrillDownFilterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExplicitHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FieldBasedTooltipProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_visibility": "aggregationVisibility",
            "tooltip_fields": "tooltipFields",
            "tooltip_title_type": "tooltipTitleType",
        },
    )
    class FieldBasedTooltipProperty:
        def __init__(
            self,
            *,
            aggregation_visibility: typing.Optional[builtins.str] = None,
            tooltip_fields: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TooltipItemProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            tooltip_title_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The setup for the detailed tooltip.

            :param aggregation_visibility: The visibility of ``Show aggregations`` .
            :param tooltip_fields: The fields configuration in the tooltip.
            :param tooltip_title_type: The type for the >tooltip title. Choose one of the following options:. - ``NONE`` : Doesn't use the primary value as the title. - ``PRIMARY_VALUE`` : Uses primary value as the title.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldbasedtooltip.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                field_based_tooltip_property = quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                    aggregation_visibility="aggregationVisibility",
                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            label="label",
                            visibility="visibility"
                        ),
                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            label="label",
                            visibility="visibility"
                        )
                    )],
                    tooltip_title_type="tooltipTitleType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__680d70d46ef4446a4baff79d816c51e2ac5f516ac8d178640e6eee60b890b0fb)
                check_type(argname="argument aggregation_visibility", value=aggregation_visibility, expected_type=type_hints["aggregation_visibility"])
                check_type(argname="argument tooltip_fields", value=tooltip_fields, expected_type=type_hints["tooltip_fields"])
                check_type(argname="argument tooltip_title_type", value=tooltip_title_type, expected_type=type_hints["tooltip_title_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if aggregation_visibility is not None:
                self._values["aggregation_visibility"] = aggregation_visibility
            if tooltip_fields is not None:
                self._values["tooltip_fields"] = tooltip_fields
            if tooltip_title_type is not None:
                self._values["tooltip_title_type"] = tooltip_title_type

        @builtins.property
        def aggregation_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of ``Show aggregations`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldbasedtooltip.html#cfn-quicksight-analysis-fieldbasedtooltip-aggregationvisibility
            '''
            result = self._values.get("aggregation_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tooltip_fields(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipItemProperty"]]]]:
            '''The fields configuration in the tooltip.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldbasedtooltip.html#cfn-quicksight-analysis-fieldbasedtooltip-tooltipfields
            '''
            result = self._values.get("tooltip_fields")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipItemProperty"]]]], result)

        @builtins.property
        def tooltip_title_type(self) -> typing.Optional[builtins.str]:
            '''The type for the >tooltip title. Choose one of the following options:.

            - ``NONE`` : Doesn't use the primary value as the title.
            - ``PRIMARY_VALUE`` : Uses primary value as the title.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldbasedtooltip.html#cfn-quicksight-analysis-fieldbasedtooltip-tooltiptitletype
            '''
            result = self._values.get("tooltip_title_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldBasedTooltipProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FieldLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "visibility": "visibility"},
    )
    class FieldLabelTypeProperty:
        def __init__(
            self,
            *,
            field_id: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The field label type.

            :param field_id: Indicates the field that is targeted by the field label.
            :param visibility: The visibility of the field label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                field_label_type_property = quicksight.CfnAnalysis.FieldLabelTypeProperty(
                    field_id="fieldId",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7d8a084997e56f1f44aa4cbb8b67219df15c79c7067a582119e46d015ed3c5fe)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''Indicates the field that is targeted by the field label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldlabeltype.html#cfn-quicksight-analysis-fieldlabeltype-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the field label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldlabeltype.html#cfn-quicksight-analysis-fieldlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FieldSeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "field_id": "fieldId",
            "settings": "settings",
        },
    )
    class FieldSeriesItemProperty:
        def __init__(
            self,
            *,
            axis_binding: builtins.str,
            field_id: builtins.str,
            settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LineChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field series item configuration of a line chart.

            :param axis_binding: The axis that you are binding the field to.
            :param field_id: The field ID of the field for which you are setting the axis binding.
            :param settings: The options that determine the presentation of line series associated to the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldseriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                field_series_item_property = quicksight.CfnAnalysis.FieldSeriesItemProperty(
                    axis_binding="axisBinding",
                    field_id="fieldId",
                
                    # the properties below are optional
                    settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                        line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e5024c98bfe0ffc4d25e2f6e024e903df5afee411cc1f0341e9d3554eeb83305)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument settings", value=settings, expected_type=type_hints["settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "axis_binding": axis_binding,
                "field_id": field_id,
            }
            if settings is not None:
                self._values["settings"] = settings

        @builtins.property
        def axis_binding(self) -> builtins.str:
            '''The axis that you are binding the field to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldseriesitem.html#cfn-quicksight-analysis-fieldseriesitem-axisbinding
            '''
            result = self._values.get("axis_binding")
            assert result is not None, "Required property 'axis_binding' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field for which you are setting the axis binding.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldseriesitem.html#cfn-quicksight-analysis-fieldseriesitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartSeriesSettingsProperty"]]:
            '''The options that determine the presentation of line series associated to the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldseriesitem.html#cfn-quicksight-analysis-fieldseriesitem-settings
            '''
            result = self._values.get("settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartSeriesSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FieldSortOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"column_sort": "columnSort", "field_sort": "fieldSort"},
    )
    class FieldSortOptionsProperty:
        def __init__(
            self,
            *,
            column_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field sort options in a chart configuration.

            :param column_sort: The sort configuration for a column that is not used in a field well.
            :param field_sort: The sort configuration for a field in a field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsortoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                field_sort_options_property = quicksight.CfnAnalysis.FieldSortOptionsProperty(
                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                        direction="direction",
                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                            attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                simple_attribute_aggregation="simpleAttributeAggregation",
                                value_for_multiple_values="valueForMultipleValues"
                            ),
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                        direction="direction",
                        field_id="fieldId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__09b2a478bb48b8a35e68145d82a1103f14e17d408a63bee51b6cc6e656260892)
                check_type(argname="argument column_sort", value=column_sort, expected_type=type_hints["column_sort"])
                check_type(argname="argument field_sort", value=field_sort, expected_type=type_hints["field_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_sort is not None:
                self._values["column_sort"] = column_sort
            if field_sort is not None:
                self._values["field_sort"] = field_sort

        @builtins.property
        def column_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnSortProperty"]]:
            '''The sort configuration for a column that is not used in a field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsortoptions.html#cfn-quicksight-analysis-fieldsortoptions-columnsort
            '''
            result = self._values.get("column_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnSortProperty"]], result)

        @builtins.property
        def field_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortProperty"]]:
            '''The sort configuration for a field in a field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsortoptions.html#cfn-quicksight-analysis-fieldsortoptions-fieldsort
            '''
            result = self._values.get("field_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSortOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FieldSortProperty",
        jsii_struct_bases=[],
        name_mapping={"direction": "direction", "field_id": "fieldId"},
    )
    class FieldSortProperty:
        def __init__(self, *, direction: builtins.str, field_id: builtins.str) -> None:
            '''The sort configuration for a field in a field well.

            :param direction: The sort direction. Choose one of the following options:. - ``ASC`` : Ascending - ``DESC`` : Descending
            :param field_id: The sort configuration target field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                field_sort_property = quicksight.CfnAnalysis.FieldSortProperty(
                    direction="direction",
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c342abcfaa5edb52d461f8d86d4843f430763e848397a672078e3cbc14582dc6)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "field_id": field_id,
            }

        @builtins.property
        def direction(self) -> builtins.str:
            '''The sort direction. Choose one of the following options:.

            - ``ASC`` : Ascending
            - ``DESC`` : Descending

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsort.html#cfn-quicksight-analysis-fieldsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The sort configuration target field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsort.html#cfn-quicksight-analysis-fieldsort-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FieldTooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "label": "label",
            "visibility": "visibility",
        },
    )
    class FieldTooltipItemProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The tooltip item for the fields.

            :param field_id: The unique ID of the field that is targeted by the tooltip.
            :param label: The label of the tooltip item.
            :param visibility: The visibility of the tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldtooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                field_tooltip_item_property = quicksight.CfnAnalysis.FieldTooltipItemProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    label="label",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5c4bc4ebe959aca45b152955d00be66568532d3a9a70918e0b907c898d2525c0)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if label is not None:
                self._values["label"] = label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The unique ID of the field that is targeted by the tooltip.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldtooltipitem.html#cfn-quicksight-analysis-fieldtooltipitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def label(self) -> typing.Optional[builtins.str]:
            '''The label of the tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldtooltipitem.html#cfn-quicksight-analysis-fieldtooltipitem-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldtooltipitem.html#cfn-quicksight-analysis-fieldtooltipitem-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldTooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"geospatial": "geospatial", "values": "values"},
    )
    class FilledMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            geospatial: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well of the filled map.

            :param geospatial: The aggregated location field well of the filled map. Values are grouped by location fields.
            :param values: The aggregated color field well of a filled map. Values are aggregated based on location fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filled_map_aggregated_field_wells_property = quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty(
                    geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e21654768a09627518420e739c98d80ccb9c26d519750bf53628439fb7fe9b0c)
                check_type(argname="argument geospatial", value=geospatial, expected_type=type_hints["geospatial"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if geospatial is not None:
                self._values["geospatial"] = geospatial
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def geospatial(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The aggregated location field well of the filled map.

            Values are grouped by location fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapaggregatedfieldwells.html#cfn-quicksight-analysis-filledmapaggregatedfieldwells-geospatial
            '''
            result = self._values.get("geospatial")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The aggregated color field well of a filled map.

            Values are aggregated based on location fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapaggregatedfieldwells.html#cfn-quicksight-analysis-filledmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilledMapConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"shape": "shape"},
    )
    class FilledMapConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            shape: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilledMapShapeConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''Conditional formatting options of a ``FilledMapVisual`` .

            :param shape: The conditional formatting that determines the shape of the filled map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filled_map_conditional_formatting_option_property = quicksight.CfnAnalysis.FilledMapConditionalFormattingOptionProperty(
                    shape=quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        format=quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9772e47745d01f72dd9f2030f7be07be11dbade90b3280b435db961d0413ad0a)
                check_type(argname="argument shape", value=shape, expected_type=type_hints["shape"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "shape": shape,
            }

        @builtins.property
        def shape(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilledMapShapeConditionalFormattingProperty"]:
            '''The conditional formatting that determines the shape of the filled map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconditionalformattingoption.html#cfn-quicksight-analysis-filledmapconditionalformattingoption-shape
            '''
            result = self._values.get("shape")
            assert result is not None, "Required property 'shape' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilledMapShapeConditionalFormattingProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilledMapConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class FilledMapConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilledMapConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The conditional formatting of a ``FilledMapVisual`` .

            :param conditional_formatting_options: Conditional formatting options of a ``FilledMapVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filled_map_conditional_formatting_property = quicksight.CfnAnalysis.FilledMapConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnAnalysis.FilledMapConditionalFormattingOptionProperty(
                        shape=quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            format=quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e70b0cf46f1a44c9193e30c0aa909063226e6d64d1e563b8e66bfbabe12ec3da)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "conditional_formatting_options": conditional_formatting_options,
            }

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilledMapConditionalFormattingOptionProperty"]]]:
            '''Conditional formatting options of a ``FilledMapVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconditionalformatting.html#cfn-quicksight-analysis-filledmapconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            assert result is not None, "Required property 'conditional_formatting_options' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilledMapConditionalFormattingOptionProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilledMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "legend": "legend",
            "map_style_options": "mapStyleOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "window_options": "windowOptions",
        },
    )
    class FilledMapConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilledMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            map_style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GeospatialMapStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilledMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            window_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GeospatialWindowOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``FilledMapVisual`` .

            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param map_style_options: The map style options of the filled map visual.
            :param sort_configuration: The sort configuration of a ``FilledMapVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param window_options: The window options of the filled map visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__99afb2f4f36a4b3edd690faca9ffebf4ddfd77fccfd84731038c44e072b19685)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument map_style_options", value=map_style_options, expected_type=type_hints["map_style_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument window_options", value=window_options, expected_type=type_hints["window_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if map_style_options is not None:
                self._values["map_style_options"] = map_style_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if window_options is not None:
                self._values["window_options"] = window_options

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilledMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilledMapFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def map_style_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialMapStyleOptionsProperty"]]:
            '''The map style options of the filled map visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-mapstyleoptions
            '''
            result = self._values.get("map_style_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialMapStyleOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilledMapSortConfigurationProperty"]]:
            '''The sort configuration of a ``FilledMapVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilledMapSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def window_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialWindowOptionsProperty"]]:
            '''The window options of the filled map visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-windowoptions
            '''
            result = self._values.get("window_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialWindowOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilledMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filled_map_aggregated_field_wells": "filledMapAggregatedFieldWells",
        },
    )
    class FilledMapFieldWellsProperty:
        def __init__(
            self,
            *,
            filled_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilledMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``FilledMapVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param filled_map_aggregated_field_wells: The aggregated field well of the filled map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filled_map_field_wells_property = quicksight.CfnAnalysis.FilledMapFieldWellsProperty(
                    filled_map_aggregated_field_wells=quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty(
                        geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__092c4eda73a3a123e4407f658010f07c9bfba724b3bcfacb1d91adf1c32bf0b1)
                check_type(argname="argument filled_map_aggregated_field_wells", value=filled_map_aggregated_field_wells, expected_type=type_hints["filled_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if filled_map_aggregated_field_wells is not None:
                self._values["filled_map_aggregated_field_wells"] = filled_map_aggregated_field_wells

        @builtins.property
        def filled_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilledMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field well of the filled map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapfieldwells.html#cfn-quicksight-analysis-filledmapfieldwells-filledmapaggregatedfieldwells
            '''
            result = self._values.get("filled_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilledMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "format": "format"},
    )
    class FilledMapShapeConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ShapeConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting that determines the shape of the filled map.

            :param field_id: The field ID of the filled map shape.
            :param format: The conditional formatting that determines the background color of a filled map's shape.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapshapeconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filled_map_shape_conditional_formatting_property = quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    format=quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ad5ace1e82268bfe9179bd98c493efc272bf172bbdc01e1ffa8d5cfb25bf4d26)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format", value=format, expected_type=type_hints["format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if format is not None:
                self._values["format"] = format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the filled map shape.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapshapeconditionalformatting.html#cfn-quicksight-analysis-filledmapshapeconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ShapeConditionalFormatProperty"]]:
            '''The conditional formatting that determines the background color of a filled map's shape.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapshapeconditionalformatting.html#cfn-quicksight-analysis-filledmapshapeconditionalformatting-format
            '''
            result = self._values.get("format")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ShapeConditionalFormatProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapShapeConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilledMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"category_sort": "categorySort"},
    )
    class FilledMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``FilledMapVisual`` .

            :param category_sort: The sort configuration of the location fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filled_map_sort_configuration_property = quicksight.CfnAnalysis.FilledMapSortConfigurationProperty(
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d6d3cba79f5d7156e9ef59b1a4b9999956bae25a6d6c5a18934537336c58c774)
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the location fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapsortconfiguration.html#cfn-quicksight-analysis-filledmapsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilledMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class FilledMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilledMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilledMapConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A filled map.

            For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param conditional_formatting: The conditional formatting of a ``FilledMapVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9c13faf467dc514b92b7ca29db46641e794b86d94dc41af1c6dc842560a64e5c)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilledMapConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilledMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilledMapConditionalFormattingProperty"]]:
            '''The conditional formatting of a ``FilledMapVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilledMapConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilterControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_picker": "dateTimePicker",
            "dropdown": "dropdown",
            "list": "list",
            "relative_date_time": "relativeDateTime",
            "slider": "slider",
            "text_area": "textArea",
            "text_field": "textField",
        },
    )
    class FilterControlProperty:
        def __init__(
            self,
            *,
            date_time_picker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilterDateTimePickerControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            dropdown: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilterDropDownControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            list: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilterListControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relative_date_time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilterRelativeDateTimeControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            slider: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilterSliderControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_area: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilterTextAreaControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilterTextFieldControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The control of a filter that is used to interact with a dashboard or an analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_picker: A control from a date filter that is used to specify date and time.
            :param dropdown: A control to display a dropdown list with buttons that are used to select a single value.
            :param list: A control to display a list of buttons or boxes. This is used to select either a single value or multiple values.
            :param relative_date_time: A control from a date filter that is used to specify the relative date.
            :param slider: A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
            :param text_area: A control to display a text box that is used to enter multiple entries.
            :param text_field: A control to display a text box that is used to enter a single entry.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_control_property = quicksight.CfnAnalysis.FilterControlProperty(
                    date_time_picker=quicksight.CfnAnalysis.FilterDateTimePickerControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        type="type"
                    ),
                    dropdown=quicksight.CfnAnalysis.FilterDropDownControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                            values=["values"]
                        ),
                        type="type"
                    ),
                    list=quicksight.CfnAnalysis.FilterListControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                            values=["values"]
                        ),
                        type="type"
                    ),
                    relative_date_time=quicksight.CfnAnalysis.FilterRelativeDateTimeControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    slider=quicksight.CfnAnalysis.FilterSliderControlProperty(
                        filter_control_id="filterControlId",
                        maximum_value=123,
                        minimum_value=123,
                        source_filter_id="sourceFilterId",
                        step_size=123,
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        type="type"
                    ),
                    text_area=quicksight.CfnAnalysis.FilterTextAreaControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        delimiter="delimiter",
                        display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_field=quicksight.CfnAnalysis.FilterTextFieldControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7f891ce6730f89d762147e5a41ef8552838308665394afca7cba59c6261421a4)
                check_type(argname="argument date_time_picker", value=date_time_picker, expected_type=type_hints["date_time_picker"])
                check_type(argname="argument dropdown", value=dropdown, expected_type=type_hints["dropdown"])
                check_type(argname="argument list", value=list, expected_type=type_hints["list"])
                check_type(argname="argument relative_date_time", value=relative_date_time, expected_type=type_hints["relative_date_time"])
                check_type(argname="argument slider", value=slider, expected_type=type_hints["slider"])
                check_type(argname="argument text_area", value=text_area, expected_type=type_hints["text_area"])
                check_type(argname="argument text_field", value=text_field, expected_type=type_hints["text_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_picker is not None:
                self._values["date_time_picker"] = date_time_picker
            if dropdown is not None:
                self._values["dropdown"] = dropdown
            if list is not None:
                self._values["list"] = list
            if relative_date_time is not None:
                self._values["relative_date_time"] = relative_date_time
            if slider is not None:
                self._values["slider"] = slider
            if text_area is not None:
                self._values["text_area"] = text_area
            if text_field is not None:
                self._values["text_field"] = text_field

        @builtins.property
        def date_time_picker(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterDateTimePickerControlProperty"]]:
            '''A control from a date filter that is used to specify date and time.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-datetimepicker
            '''
            result = self._values.get("date_time_picker")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterDateTimePickerControlProperty"]], result)

        @builtins.property
        def dropdown(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterDropDownControlProperty"]]:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-dropdown
            '''
            result = self._values.get("dropdown")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterDropDownControlProperty"]], result)

        @builtins.property
        def list(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterListControlProperty"]]:
            '''A control to display a list of buttons or boxes.

            This is used to select either a single value or multiple values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-list
            '''
            result = self._values.get("list")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterListControlProperty"]], result)

        @builtins.property
        def relative_date_time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterRelativeDateTimeControlProperty"]]:
            '''A control from a date filter that is used to specify the relative date.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-relativedatetime
            '''
            result = self._values.get("relative_date_time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterRelativeDateTimeControlProperty"]], result)

        @builtins.property
        def slider(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterSliderControlProperty"]]:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-slider
            '''
            result = self._values.get("slider")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterSliderControlProperty"]], result)

        @builtins.property
        def text_area(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterTextAreaControlProperty"]]:
            '''A control to display a text box that is used to enter multiple entries.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-textarea
            '''
            result = self._values.get("text_area")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterTextAreaControlProperty"]], result)

        @builtins.property
        def text_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterTextFieldControlProperty"]]:
            '''A control to display a text box that is used to enter a single entry.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-textfield
            '''
            result = self._values.get("text_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterTextFieldControlProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilterDateTimePickerControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
            "type": "type",
        },
    )
    class FilterDateTimePickerControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DateTimePickerControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control from a date filter that is used to specify date and time.

            :param filter_control_id: The ID of the ``FilterDateTimePickerControl`` .
            :param source_filter_id: The source filter ID of the ``FilterDateTimePickerControl`` .
            :param title: The title of the ``FilterDateTimePickerControl`` .
            :param display_options: The display options of a control.
            :param type: The date time picker type of a ``FilterDateTimePickerControl`` . Choose one of the following options:. - ``SINGLE_VALUED`` : The filter condition is a fixed date. - ``DATE_RANGE`` : The filter condition is a date time range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_date_time_picker_control_property = quicksight.CfnAnalysis.FilterDateTimePickerControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a31e001b763f1cb36b8ef2f855857a0d498a62019ecaccf6d4a379426fe217e7)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterDateTimePickerControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterDateTimePickerControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterDateTimePickerControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateTimePickerControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateTimePickerControlDisplayOptionsProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The date time picker type of a ``FilterDateTimePickerControl`` . Choose one of the following options:.

            - ``SINGLE_VALUED`` : The filter condition is a fixed date.
            - ``DATE_RANGE`` : The filter condition is a date time range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterDateTimePickerControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilterDropDownControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class FilterDropDownControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DropDownControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :param filter_control_id: The ID of the ``FilterDropDownControl`` .
            :param source_filter_id: The source filter ID of the ``FilterDropDownControl`` .
            :param title: The title of the ``FilterDropDownControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of the ``FilterDropDownControl`` .
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of the ``FilterDropDownControl`` . Choose one of the following options:. - ``MULTI_SELECT`` : The user can select multiple entries from a dropdown menu. - ``SINGLE_SELECT`` : The user can select a single entry from a dropdown menu.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_drop_down_control_property = quicksight.CfnAnalysis.FilterDropDownControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5ebb604ee1289b475cb6bd411e972c68a17390bd59a08f2bf0171ed1e7691759)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DropDownControlDisplayOptionsProperty"]]:
            '''The display options of the ``FilterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DropDownControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of the ``FilterDropDownControl`` . Choose one of the following options:.

            - ``MULTI_SELECT`` : The user can select multiple entries from a dropdown menu.
            - ``SINGLE_SELECT`` : The user can select a single entry from a dropdown menu.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterDropDownControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilterGroupProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cross_dataset": "crossDataset",
            "filter_group_id": "filterGroupId",
            "filters": "filters",
            "scope_configuration": "scopeConfiguration",
            "status": "status",
        },
    )
    class FilterGroupProperty:
        def __init__(
            self,
            *,
            cross_dataset: builtins.str,
            filter_group_id: builtins.str,
            filters: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilterProperty", typing.Dict[builtins.str, typing.Any]]]]],
            scope_configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilterScopeConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A grouping of individual filters. Filter groups are applied to the same group of visuals.

            For more information, see `Adding filter conditions (group filters) with AND and OR operators <https://docs.aws.amazon.com/quicksight/latest/user/add-a-compound-filter.html>`_ in the *Amazon QuickSight User Guide* .

            :param cross_dataset: The filter new feature which can apply filter group to all data sets. Choose one of the following options:. - ``ALL_DATASETS`` - ``SINGLE_DATASET``
            :param filter_group_id: The value that uniquely identifies a ``FilterGroup`` within a dashboard, template, or analysis.
            :param filters: The list of filters that are present in a ``FilterGroup`` .
            :param scope_configuration: The configuration that specifies what scope to apply to a ``FilterGroup`` . This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
            :param status: The status of the ``FilterGroup`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # all_sheets: Any
                
                filter_group_property = quicksight.CfnAnalysis.FilterGroupProperty(
                    cross_dataset="crossDataset",
                    filter_group_id="filterGroupId",
                    filters=[quicksight.CfnAnalysis.FilterProperty(
                        category_filter=quicksight.CfnAnalysis.CategoryFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            configuration=quicksight.CfnAnalysis.CategoryFilterConfigurationProperty(
                                custom_filter_configuration=quicksight.CfnAnalysis.CustomFilterConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
                
                                    # the properties below are optional
                                    category_value="categoryValue",
                                    parameter_name="parameterName",
                                    select_all_options="selectAllOptions"
                                ),
                                custom_filter_list_configuration=quicksight.CfnAnalysis.CustomFilterListConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
                
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                ),
                                filter_list_configuration=quicksight.CfnAnalysis.FilterListConfigurationProperty(
                                    match_operator="matchOperator",
                
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    null_option="nullOption",
                                    select_all_options="selectAllOptions"
                                )
                            ),
                            filter_id="filterId"
                        ),
                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions",
                            value=123
                        ),
                        numeric_range_filter=quicksight.CfnAnalysis.NumericRangeFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            range_minimum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            select_all_options="selectAllOptions"
                        ),
                        relative_dates_filter=quicksight.CfnAnalysis.RelativeDatesFilterProperty(
                            anchor_date_configuration=quicksight.CfnAnalysis.AnchorDateConfigurationProperty(
                                anchor_option="anchorOption",
                                parameter_name="parameterName"
                            ),
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                            relative_date_type="relativeDateType",
                            time_granularity="timeGranularity",
                
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
                
                                # the properties below are optional
                                status="status"
                            ),
                            minimum_granularity="minimumGranularity",
                            parameter_name="parameterName",
                            relative_date_value=123
                        ),
                        time_equality_filter=quicksight.CfnAnalysis.TimeEqualityFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                
                            # the properties below are optional
                            parameter_name="parameterName",
                            rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            time_granularity="timeGranularity",
                            value="value"
                        ),
                        time_range_filter=quicksight.CfnAnalysis.TimeRangeFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
                
                                # the properties below are optional
                                status="status"
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            range_minimum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            time_granularity="timeGranularity"
                        ),
                        top_bottom_filter=quicksight.CfnAnalysis.TopBottomFilterProperty(
                            aggregation_sort_configurations=[quicksight.CfnAnalysis.AggregationSortConfigurationProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                sort_direction="sortDirection",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                        simple_attribute_aggregation="simpleAttributeAggregation",
                                        value_for_multiple_values="valueForMultipleValues"
                                    ),
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            )],
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                
                            # the properties below are optional
                            limit=123,
                            parameter_name="parameterName",
                            time_granularity="timeGranularity"
                        )
                    )],
                    scope_configuration=quicksight.CfnAnalysis.FilterScopeConfigurationProperty(
                        all_sheets=all_sheets,
                        selected_sheets=quicksight.CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty(
                            sheet_visual_scoping_configurations=[quicksight.CfnAnalysis.SheetVisualScopingConfigurationProperty(
                                scope="scope",
                                sheet_id="sheetId",
                
                                # the properties below are optional
                                visual_ids=["visualIds"]
                            )]
                        )
                    ),
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e48fb275d6dda270ccf1167e8321070aacd0e881203a1c0c74a395a7efebde35)
                check_type(argname="argument cross_dataset", value=cross_dataset, expected_type=type_hints["cross_dataset"])
                check_type(argname="argument filter_group_id", value=filter_group_id, expected_type=type_hints["filter_group_id"])
                check_type(argname="argument filters", value=filters, expected_type=type_hints["filters"])
                check_type(argname="argument scope_configuration", value=scope_configuration, expected_type=type_hints["scope_configuration"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "cross_dataset": cross_dataset,
                "filter_group_id": filter_group_id,
                "filters": filters,
                "scope_configuration": scope_configuration,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def cross_dataset(self) -> builtins.str:
            '''The filter new feature which can apply filter group to all data sets. Choose one of the following options:.

            - ``ALL_DATASETS``
            - ``SINGLE_DATASET``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-crossdataset
            '''
            result = self._values.get("cross_dataset")
            assert result is not None, "Required property 'cross_dataset' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def filter_group_id(self) -> builtins.str:
            '''The value that uniquely identifies a ``FilterGroup`` within a dashboard, template, or analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-filtergroupid
            '''
            result = self._values.get("filter_group_id")
            assert result is not None, "Required property 'filter_group_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def filters(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterProperty"]]]:
            '''The list of filters that are present in a ``FilterGroup`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-filters
            '''
            result = self._values.get("filters")
            assert result is not None, "Required property 'filters' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterProperty"]]], result)

        @builtins.property
        def scope_configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterScopeConfigurationProperty"]:
            '''The configuration that specifies what scope to apply to a ``FilterGroup`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-scopeconfiguration
            '''
            result = self._values.get("scope_configuration")
            assert result is not None, "Required property 'scope_configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterScopeConfigurationProperty"], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the ``FilterGroup`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterGroupProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilterListConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "category_values": "categoryValues",
            "null_option": "nullOption",
            "select_all_options": "selectAllOptions",
        },
    )
    class FilterListConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            null_option: typing.Optional[builtins.str] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A list of filter configurations.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param category_values: The list of category values for the filter.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_list_configuration_property = quicksight.CfnAnalysis.FilterListConfigurationProperty(
                    match_operator="matchOperator",
                
                    # the properties below are optional
                    category_values=["categoryValues"],
                    null_option="nullOption",
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b974c135517a956a54d1798d6a1cded03296e13b5d2939faad4af76a1cb0055c)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
            }
            if category_values is not None:
                self._values["category_values"] = category_values
            if null_option is not None:
                self._values["null_option"] = null_option
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html#cfn-quicksight-analysis-filterlistconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of category values for the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html#cfn-quicksight-analysis-filterlistconfiguration-categoryvalues
            '''
            result = self._values.get("category_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def null_option(self) -> typing.Optional[builtins.str]:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html#cfn-quicksight-analysis-filterlistconfiguration-nulloption
            '''
            result = self._values.get("null_option")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html#cfn-quicksight-analysis-filterlistconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterListConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilterListControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class FilterListControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ListControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a list of buttons or boxes.

            This is used to select either a single value or multiple values.

            :param filter_control_id: The ID of the ``FilterListControl`` .
            :param source_filter_id: The source filter ID of the ``FilterListControl`` .
            :param title: The title of the ``FilterListControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of ``FilterListControl`` . Choose one of the following options:. - ``MULTI_SELECT`` : The user can select multiple entries from the list. - ``SINGLE_SELECT`` : The user can select a single entry from the list.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_list_control_property = quicksight.CfnAnalysis.FilterListControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f8abf6a7704eac8483c2a9b81169ef7027a912c5d234ab272d9daa0a3d838381)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ListControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ListControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``FilterListControl`` . Choose one of the following options:.

            - ``MULTI_SELECT`` : The user can select multiple entries from the list.
            - ``SINGLE_SELECT`` : The user can select a single entry from the list.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterListControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "selected_columns": "selectedColumns",
            "selected_field_options": "selectedFieldOptions",
            "selected_fields": "selectedFields",
        },
    )
    class FilterOperationSelectedFieldsConfigurationProperty:
        def __init__(
            self,
            *,
            selected_columns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            selected_field_options: typing.Optional[builtins.str] = None,
            selected_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The configuration of selected fields in the ``CustomActionFilterOperation`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param selected_columns: The selected columns of a dataset.
            :param selected_field_options: A structure that contains the options that choose which fields are filtered in the ``CustomActionFilterOperation`` . Valid values are defined as follows: - ``ALL_FIELDS`` : Applies the filter operation to all fields.
            :param selected_fields: Chooses the fields that are filtered in ``CustomActionFilterOperation`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationselectedfieldsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_operation_selected_fields_configuration_property = quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                    selected_columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    selected_field_options="selectedFieldOptions",
                    selected_fields=["selectedFields"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9288615b24c4f7a9a7f074e121e6e811e2e524049b19243814784b2b81345286)
                check_type(argname="argument selected_columns", value=selected_columns, expected_type=type_hints["selected_columns"])
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
                check_type(argname="argument selected_fields", value=selected_fields, expected_type=type_hints["selected_fields"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if selected_columns is not None:
                self._values["selected_columns"] = selected_columns
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options
            if selected_fields is not None:
                self._values["selected_fields"] = selected_fields

        @builtins.property
        def selected_columns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]]]]:
            '''The selected columns of a dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-analysis-filteroperationselectedfieldsconfiguration-selectedcolumns
            '''
            result = self._values.get("selected_columns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]]]], result)

        @builtins.property
        def selected_field_options(self) -> typing.Optional[builtins.str]:
            '''A structure that contains the options that choose which fields are filtered in the ``CustomActionFilterOperation`` .

            Valid values are defined as follows:

            - ``ALL_FIELDS`` : Applies the filter operation to all fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-analysis-filteroperationselectedfieldsconfiguration-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def selected_fields(self) -> typing.Optional[typing.List[builtins.str]]:
            '''Chooses the fields that are filtered in ``CustomActionFilterOperation`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-analysis-filteroperationselectedfieldsconfiguration-selectedfields
            '''
            result = self._values.get("selected_fields")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterOperationSelectedFieldsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "same_sheet_target_visual_configuration": "sameSheetTargetVisualConfiguration",
        },
    )
    class FilterOperationTargetVisualsConfigurationProperty:
        def __init__(
            self,
            *,
            same_sheet_target_visual_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SameSheetTargetVisualConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of target visuals that you want to be filtered.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param same_sheet_target_visual_configuration: The configuration of the same-sheet target visuals that you want to be filtered.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationtargetvisualsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_operation_target_visuals_configuration_property = quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                        target_visual_options="targetVisualOptions",
                        target_visuals=["targetVisuals"]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f5490b40d7c62237df50c87f1ae3088084d263413035ee935290c574541f86a1)
                check_type(argname="argument same_sheet_target_visual_configuration", value=same_sheet_target_visual_configuration, expected_type=type_hints["same_sheet_target_visual_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if same_sheet_target_visual_configuration is not None:
                self._values["same_sheet_target_visual_configuration"] = same_sheet_target_visual_configuration

        @builtins.property
        def same_sheet_target_visual_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SameSheetTargetVisualConfigurationProperty"]]:
            '''The configuration of the same-sheet target visuals that you want to be filtered.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationtargetvisualsconfiguration.html#cfn-quicksight-analysis-filteroperationtargetvisualsconfiguration-samesheettargetvisualconfiguration
            '''
            result = self._values.get("same_sheet_target_visual_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SameSheetTargetVisualConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterOperationTargetVisualsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_filter": "categoryFilter",
            "numeric_equality_filter": "numericEqualityFilter",
            "numeric_range_filter": "numericRangeFilter",
            "relative_dates_filter": "relativeDatesFilter",
            "time_equality_filter": "timeEqualityFilter",
            "time_range_filter": "timeRangeFilter",
            "top_bottom_filter": "topBottomFilter",
        },
    )
    class FilterProperty:
        def __init__(
            self,
            *,
            category_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CategoryFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_equality_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumericEqualityFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumericRangeFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relative_dates_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.RelativeDatesFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_equality_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TimeEqualityFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TimeRangeFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top_bottom_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TopBottomFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''With a ``Filter`` , you can remove portions of data from a particular visual or view.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param category_filter: A ``CategoryFilter`` filters text values. For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .
            :param numeric_equality_filter: A ``NumericEqualityFilter`` filters numeric values that equal or do not equal a given numeric value.
            :param numeric_range_filter: A ``NumericRangeFilter`` filters numeric values that are either inside or outside a given numeric range.
            :param relative_dates_filter: A ``RelativeDatesFilter`` filters date values that are relative to a given date.
            :param time_equality_filter: A ``TimeEqualityFilter`` filters date-time values that equal or do not equal a given date/time value.
            :param time_range_filter: A ``TimeRangeFilter`` filters date-time values that are either inside or outside a given date/time range.
            :param top_bottom_filter: A ``TopBottomFilter`` filters data to the top or bottom values for a given column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_property = quicksight.CfnAnalysis.FilterProperty(
                    category_filter=quicksight.CfnAnalysis.CategoryFilterProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        configuration=quicksight.CfnAnalysis.CategoryFilterConfigurationProperty(
                            custom_filter_configuration=quicksight.CfnAnalysis.CustomFilterConfigurationProperty(
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                category_value="categoryValue",
                                parameter_name="parameterName",
                                select_all_options="selectAllOptions"
                            ),
                            custom_filter_list_configuration=quicksight.CfnAnalysis.CustomFilterListConfigurationProperty(
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                category_values=["categoryValues"],
                                select_all_options="selectAllOptions"
                            ),
                            filter_list_configuration=quicksight.CfnAnalysis.FilterListConfigurationProperty(
                                match_operator="matchOperator",
                
                                # the properties below are optional
                                category_values=["categoryValues"],
                                null_option="nullOption",
                                select_all_options="selectAllOptions"
                            )
                        ),
                        filter_id="filterId"
                    ),
                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityFilterProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                            attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                simple_attribute_aggregation="simpleAttributeAggregation",
                                value_for_multiple_values="valueForMultipleValues"
                            ),
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        parameter_name="parameterName",
                        select_all_options="selectAllOptions",
                        value=123
                    ),
                    numeric_range_filter=quicksight.CfnAnalysis.NumericRangeFilterProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                            attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                simple_attribute_aggregation="simpleAttributeAggregation",
                                value_for_multiple_values="valueForMultipleValues"
                            ),
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        include_maximum=False,
                        include_minimum=False,
                        range_maximum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                            parameter="parameter",
                            static_value=123
                        ),
                        range_minimum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                            parameter="parameter",
                            static_value=123
                        ),
                        select_all_options="selectAllOptions"
                    ),
                    relative_dates_filter=quicksight.CfnAnalysis.RelativeDatesFilterProperty(
                        anchor_date_configuration=quicksight.CfnAnalysis.AnchorDateConfigurationProperty(
                            anchor_option="anchorOption",
                            parameter_name="parameterName"
                        ),
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                        relative_date_type="relativeDateType",
                        time_granularity="timeGranularity",
                
                        # the properties below are optional
                        exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                            amount=123,
                            granularity="granularity",
                
                            # the properties below are optional
                            status="status"
                        ),
                        minimum_granularity="minimumGranularity",
                        parameter_name="parameterName",
                        relative_date_value=123
                    ),
                    time_equality_filter=quicksight.CfnAnalysis.TimeEqualityFilterProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                
                        # the properties below are optional
                        parameter_name="parameterName",
                        rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        time_granularity="timeGranularity",
                        value="value"
                    ),
                    time_range_filter=quicksight.CfnAnalysis.TimeRangeFilterProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                
                        # the properties below are optional
                        exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                            amount=123,
                            granularity="granularity",
                
                            # the properties below are optional
                            status="status"
                        ),
                        include_maximum=False,
                        include_minimum=False,
                        range_maximum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                            parameter="parameter",
                            rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_value="staticValue"
                        ),
                        range_minimum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                            parameter="parameter",
                            rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_value="staticValue"
                        ),
                        time_granularity="timeGranularity"
                    ),
                    top_bottom_filter=quicksight.CfnAnalysis.TopBottomFilterProperty(
                        aggregation_sort_configurations=[quicksight.CfnAnalysis.AggregationSortConfigurationProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            sort_direction="sortDirection",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        )],
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                
                        # the properties below are optional
                        limit=123,
                        parameter_name="parameterName",
                        time_granularity="timeGranularity"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e5ec3a86d99768a1b2bd1ed74da1da68c4fcdc98b71db0a76af4dd3d698e1d03)
                check_type(argname="argument category_filter", value=category_filter, expected_type=type_hints["category_filter"])
                check_type(argname="argument numeric_equality_filter", value=numeric_equality_filter, expected_type=type_hints["numeric_equality_filter"])
                check_type(argname="argument numeric_range_filter", value=numeric_range_filter, expected_type=type_hints["numeric_range_filter"])
                check_type(argname="argument relative_dates_filter", value=relative_dates_filter, expected_type=type_hints["relative_dates_filter"])
                check_type(argname="argument time_equality_filter", value=time_equality_filter, expected_type=type_hints["time_equality_filter"])
                check_type(argname="argument time_range_filter", value=time_range_filter, expected_type=type_hints["time_range_filter"])
                check_type(argname="argument top_bottom_filter", value=top_bottom_filter, expected_type=type_hints["top_bottom_filter"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_filter is not None:
                self._values["category_filter"] = category_filter
            if numeric_equality_filter is not None:
                self._values["numeric_equality_filter"] = numeric_equality_filter
            if numeric_range_filter is not None:
                self._values["numeric_range_filter"] = numeric_range_filter
            if relative_dates_filter is not None:
                self._values["relative_dates_filter"] = relative_dates_filter
            if time_equality_filter is not None:
                self._values["time_equality_filter"] = time_equality_filter
            if time_range_filter is not None:
                self._values["time_range_filter"] = time_range_filter
            if top_bottom_filter is not None:
                self._values["top_bottom_filter"] = top_bottom_filter

        @builtins.property
        def category_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CategoryFilterProperty"]]:
            '''A ``CategoryFilter`` filters text values.

            For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-categoryfilter
            '''
            result = self._values.get("category_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CategoryFilterProperty"]], result)

        @builtins.property
        def numeric_equality_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericEqualityFilterProperty"]]:
            '''A ``NumericEqualityFilter`` filters numeric values that equal or do not equal a given numeric value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-numericequalityfilter
            '''
            result = self._values.get("numeric_equality_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericEqualityFilterProperty"]], result)

        @builtins.property
        def numeric_range_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericRangeFilterProperty"]]:
            '''A ``NumericRangeFilter`` filters numeric values that are either inside or outside a given numeric range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-numericrangefilter
            '''
            result = self._values.get("numeric_range_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericRangeFilterProperty"]], result)

        @builtins.property
        def relative_dates_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RelativeDatesFilterProperty"]]:
            '''A ``RelativeDatesFilter`` filters date values that are relative to a given date.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-relativedatesfilter
            '''
            result = self._values.get("relative_dates_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RelativeDatesFilterProperty"]], result)

        @builtins.property
        def time_equality_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TimeEqualityFilterProperty"]]:
            '''A ``TimeEqualityFilter`` filters date-time values that equal or do not equal a given date/time value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-timeequalityfilter
            '''
            result = self._values.get("time_equality_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TimeEqualityFilterProperty"]], result)

        @builtins.property
        def time_range_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TimeRangeFilterProperty"]]:
            '''A ``TimeRangeFilter`` filters date-time values that are either inside or outside a given date/time range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-timerangefilter
            '''
            result = self._values.get("time_range_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TimeRangeFilterProperty"]], result)

        @builtins.property
        def top_bottom_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TopBottomFilterProperty"]]:
            '''A ``TopBottomFilter`` filters data to the top or bottom values for a given column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-topbottomfilter
            '''
            result = self._values.get("top_bottom_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TopBottomFilterProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilterRelativeDateTimeControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class FilterRelativeDateTimeControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control from a date filter that is used to specify the relative date.

            :param filter_control_id: The ID of the ``FilterTextAreaControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextAreaControl`` .
            :param title: The title of the ``FilterTextAreaControl`` .
            :param display_options: The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_relative_date_time_control_property = quicksight.CfnAnalysis.FilterRelativeDateTimeControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c5c9b044726cee5e7d0481c3871cd665c27926007e2b26bdcbe80a4ba9f8545b)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html#cfn-quicksight-analysis-filterrelativedatetimecontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html#cfn-quicksight-analysis-filterrelativedatetimecontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html#cfn-quicksight-analysis-filterrelativedatetimecontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html#cfn-quicksight-analysis-filterrelativedatetimecontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterRelativeDateTimeControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilterScopeConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"all_sheets": "allSheets", "selected_sheets": "selectedSheets"},
    )
    class FilterScopeConfigurationProperty:
        def __init__(
            self,
            *,
            all_sheets: typing.Any = None,
            selected_sheets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The scope configuration for a ``FilterGroup`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param all_sheets: The configuration for applying a filter to all sheets.
            :param selected_sheets: The configuration for applying a filter to specific sheets.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterscopeconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # all_sheets: Any
                
                filter_scope_configuration_property = quicksight.CfnAnalysis.FilterScopeConfigurationProperty(
                    all_sheets=all_sheets,
                    selected_sheets=quicksight.CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty(
                        sheet_visual_scoping_configurations=[quicksight.CfnAnalysis.SheetVisualScopingConfigurationProperty(
                            scope="scope",
                            sheet_id="sheetId",
                
                            # the properties below are optional
                            visual_ids=["visualIds"]
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__70a5f07709c49e9ea802a870316716ecedbe97516939a55dceba445d77cf6457)
                check_type(argname="argument all_sheets", value=all_sheets, expected_type=type_hints["all_sheets"])
                check_type(argname="argument selected_sheets", value=selected_sheets, expected_type=type_hints["selected_sheets"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if all_sheets is not None:
                self._values["all_sheets"] = all_sheets
            if selected_sheets is not None:
                self._values["selected_sheets"] = selected_sheets

        @builtins.property
        def all_sheets(self) -> typing.Any:
            '''The configuration for applying a filter to all sheets.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterscopeconfiguration.html#cfn-quicksight-analysis-filterscopeconfiguration-allsheets
            '''
            result = self._values.get("all_sheets")
            return typing.cast(typing.Any, result)

        @builtins.property
        def selected_sheets(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty"]]:
            '''The configuration for applying a filter to specific sheets.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterscopeconfiguration.html#cfn-quicksight-analysis-filterscopeconfiguration-selectedsheets
            '''
            result = self._values.get("selected_sheets")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterScopeConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilterSelectableValuesProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class FilterSelectableValuesProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A list of selectable values that are used in a control.

            :param values: The values that are used in the ``FilterSelectableValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterselectablevalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_selectable_values_property = quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cbcfc10d90502877786dae85b75d32aecd1aa2d996944b9890a28ab13bbe1369)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The values that are used in the ``FilterSelectableValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterselectablevalues.html#cfn-quicksight-analysis-filterselectablevalues-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterSelectableValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilterSliderControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "maximum_value": "maximumValue",
            "minimum_value": "minimumValue",
            "source_filter_id": "sourceFilterId",
            "step_size": "stepSize",
            "title": "title",
            "display_options": "displayOptions",
            "type": "type",
        },
    )
    class FilterSliderControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            maximum_value: jsii.Number,
            minimum_value: jsii.Number,
            source_filter_id: builtins.str,
            step_size: jsii.Number,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SliderControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :param filter_control_id: The ID of the ``FilterSliderControl`` .
            :param maximum_value: The smaller value that is displayed at the left of the slider. Default: - 0
            :param minimum_value: The larger value that is displayed at the right of the slider. Default: - 0
            :param source_filter_id: The source filter ID of the ``FilterSliderControl`` .
            :param step_size: The number of increments that the slider bar is divided into. Default: - 0
            :param title: The title of the ``FilterSliderControl`` .
            :param display_options: The display options of a control.
            :param type: The type of ``FilterSliderControl`` . Choose one of the following options:. - ``SINGLE_POINT`` : Filter against(equals) a single data point. - ``RANGE`` : Filter data that is in a specified range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_slider_control_property = quicksight.CfnAnalysis.FilterSliderControlProperty(
                    filter_control_id="filterControlId",
                    maximum_value=123,
                    minimum_value=123,
                    source_filter_id="sourceFilterId",
                    step_size=123,
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__300315640c398eebc98d281ad0b8d598424a042f059c9a2e327e6eec203dbcef)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument maximum_value", value=maximum_value, expected_type=type_hints["maximum_value"])
                check_type(argname="argument minimum_value", value=minimum_value, expected_type=type_hints["minimum_value"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "maximum_value": maximum_value,
                "minimum_value": minimum_value,
                "source_filter_id": source_filter_id,
                "step_size": step_size,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterSliderControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def maximum_value(self) -> jsii.Number:
            '''The smaller value that is displayed at the left of the slider.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-maximumvalue
            '''
            result = self._values.get("maximum_value")
            assert result is not None, "Required property 'maximum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def minimum_value(self) -> jsii.Number:
            '''The larger value that is displayed at the right of the slider.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-minimumvalue
            '''
            result = self._values.get("minimum_value")
            assert result is not None, "Required property 'minimum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterSliderControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def step_size(self) -> jsii.Number:
            '''The number of increments that the slider bar is divided into.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-stepsize
            '''
            result = self._values.get("step_size")
            assert result is not None, "Required property 'step_size' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterSliderControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SliderControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SliderControlDisplayOptionsProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``FilterSliderControl`` . Choose one of the following options:.

            - ``SINGLE_POINT`` : Filter against(equals) a single data point.
            - ``RANGE`` : Filter data that is in a specified range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterSliderControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilterTextAreaControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "delimiter": "delimiter",
            "display_options": "displayOptions",
        },
    )
    class FilterTextAreaControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            delimiter: typing.Optional[builtins.str] = None,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TextAreaControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter multiple entries.

            :param filter_control_id: The ID of the ``FilterTextAreaControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextAreaControl`` .
            :param title: The title of the ``FilterTextAreaControl`` .
            :param delimiter: The delimiter that is used to separate the lines in text.
            :param display_options: The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_text_area_control_property = quicksight.CfnAnalysis.FilterTextAreaControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    delimiter="delimiter",
                    display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cc536764886ec354b00eee87422c46819ed4f288594d069028faa6beff0c8492)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument delimiter", value=delimiter, expected_type=type_hints["delimiter"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if delimiter is not None:
                self._values["delimiter"] = delimiter
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def delimiter(self) -> typing.Optional[builtins.str]:
            '''The delimiter that is used to separate the lines in text.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-delimiter
            '''
            result = self._values.get("delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TextAreaControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TextAreaControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterTextAreaControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FilterTextFieldControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class FilterTextFieldControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TextFieldControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter a single entry.

            :param filter_control_id: The ID of the ``FilterTextFieldControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextFieldControl`` .
            :param title: The title of the ``FilterTextFieldControl`` .
            :param display_options: The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_text_field_control_property = quicksight.CfnAnalysis.FilterTextFieldControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__160a2b14f69f63383b7675afc255198b7e38397f8278883db718b1c37320ae13)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextFieldControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html#cfn-quicksight-analysis-filtertextfieldcontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextFieldControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html#cfn-quicksight-analysis-filtertextfieldcontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextFieldControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html#cfn-quicksight-analysis-filtertextfieldcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TextFieldControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html#cfn-quicksight-analysis-filtertextfieldcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TextFieldControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterTextFieldControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FontConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "font_color": "fontColor",
            "font_decoration": "fontDecoration",
            "font_size": "fontSize",
            "font_style": "fontStyle",
            "font_weight": "fontWeight",
        },
    )
    class FontConfigurationProperty:
        def __init__(
            self,
            *,
            font_color: typing.Optional[builtins.str] = None,
            font_decoration: typing.Optional[builtins.str] = None,
            font_size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FontSizeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            font_style: typing.Optional[builtins.str] = None,
            font_weight: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FontWeightProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Configures the display properties of the given text.

            :param font_color: Determines the color of the text.
            :param font_decoration: Determines the appearance of decorative lines on the text.
            :param font_size: The option that determines the text display size.
            :param font_style: Determines the text display face that is inherited by the given font family.
            :param font_weight: The option that determines the text display weight, or boldness.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                font_configuration_property = quicksight.CfnAnalysis.FontConfigurationProperty(
                    font_color="fontColor",
                    font_decoration="fontDecoration",
                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                        relative="relative"
                    ),
                    font_style="fontStyle",
                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                        name="name"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e7d690fad0a2f6f831868512422f604b26b5221365d6878f0654a4e9a6686871)
                check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
                check_type(argname="argument font_decoration", value=font_decoration, expected_type=type_hints["font_decoration"])
                check_type(argname="argument font_size", value=font_size, expected_type=type_hints["font_size"])
                check_type(argname="argument font_style", value=font_style, expected_type=type_hints["font_style"])
                check_type(argname="argument font_weight", value=font_weight, expected_type=type_hints["font_weight"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_color is not None:
                self._values["font_color"] = font_color
            if font_decoration is not None:
                self._values["font_decoration"] = font_decoration
            if font_size is not None:
                self._values["font_size"] = font_size
            if font_style is not None:
                self._values["font_style"] = font_style
            if font_weight is not None:
                self._values["font_weight"] = font_weight

        @builtins.property
        def font_color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the text.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontcolor
            '''
            result = self._values.get("font_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_decoration(self) -> typing.Optional[builtins.str]:
            '''Determines the appearance of decorative lines on the text.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontdecoration
            '''
            result = self._values.get("font_decoration")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_size(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontSizeProperty"]]:
            '''The option that determines the text display size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontsize
            '''
            result = self._values.get("font_size")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontSizeProperty"]], result)

        @builtins.property
        def font_style(self) -> typing.Optional[builtins.str]:
            '''Determines the text display face that is inherited by the given font family.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontstyle
            '''
            result = self._values.get("font_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_weight(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontWeightProperty"]]:
            '''The option that determines the text display weight, or boldness.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontweight
            '''
            result = self._values.get("font_weight")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontWeightProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FontSizeProperty",
        jsii_struct_bases=[],
        name_mapping={"relative": "relative"},
    )
    class FontSizeProperty:
        def __init__(self, *, relative: typing.Optional[builtins.str] = None) -> None:
            '''The option that determines the text display size.

            :param relative: The lexical name for the text size, proportional to its surrounding context.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontsize.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                font_size_property = quicksight.CfnAnalysis.FontSizeProperty(
                    relative="relative"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__780f10dfaa345c38c017c0745f17b71d06e7ff3ba11207f70c1a1f7a2c9a3bf4)
                check_type(argname="argument relative", value=relative, expected_type=type_hints["relative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if relative is not None:
                self._values["relative"] = relative

        @builtins.property
        def relative(self) -> typing.Optional[builtins.str]:
            '''The lexical name for the text size, proportional to its surrounding context.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontsize.html#cfn-quicksight-analysis-fontsize-relative
            '''
            result = self._values.get("relative")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontSizeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FontWeightProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name"},
    )
    class FontWeightProperty:
        def __init__(self, *, name: typing.Optional[builtins.str] = None) -> None:
            '''The option that determines the text display weight, or boldness.

            :param name: The lexical name for the level of boldness of the text display.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontweight.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                font_weight_property = quicksight.CfnAnalysis.FontWeightProperty(
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__46f74702553dccb4bfa142dc6d7a31cf148bc7c14f3675489d8970c4657eda17)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The lexical name for the level of boldness of the text display.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontweight.html#cfn-quicksight-analysis-fontweight-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontWeightProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ForecastComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "custom_seasonality_value": "customSeasonalityValue",
            "lower_boundary": "lowerBoundary",
            "name": "name",
            "periods_backward": "periodsBackward",
            "periods_forward": "periodsForward",
            "prediction_interval": "predictionInterval",
            "seasonality": "seasonality",
            "time": "time",
            "upper_boundary": "upperBoundary",
            "value": "value",
        },
    )
    class ForecastComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            custom_seasonality_value: typing.Optional[jsii.Number] = None,
            lower_boundary: typing.Optional[jsii.Number] = None,
            name: typing.Optional[builtins.str] = None,
            periods_backward: typing.Optional[jsii.Number] = None,
            periods_forward: typing.Optional[jsii.Number] = None,
            prediction_interval: typing.Optional[jsii.Number] = None,
            seasonality: typing.Optional[builtins.str] = None,
            time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            upper_boundary: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The forecast computation configuration.

            :param computation_id: The ID for a computation.
            :param custom_seasonality_value: The custom seasonality value setup of a forecast computation.
            :param lower_boundary: The lower boundary setup of a forecast computation.
            :param name: The name of a computation.
            :param periods_backward: The periods backward setup of a forecast computation.
            :param periods_forward: The periods forward setup of a forecast computation.
            :param prediction_interval: The prediction interval setup of a forecast computation.
            :param seasonality: The seasonality setup of a forecast computation. Choose one of the following options:. - ``AUTOMATIC`` - ``CUSTOM`` : Checks the custom seasonality value.
            :param time: The time field that is used in a computation.
            :param upper_boundary: The upper boundary setup of a forecast computation.
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c92d9e711d8ae9f042a8e0269c5d1cb5d882fc89523e5544ee0ef11f92029973)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument custom_seasonality_value", value=custom_seasonality_value, expected_type=type_hints["custom_seasonality_value"])
                check_type(argname="argument lower_boundary", value=lower_boundary, expected_type=type_hints["lower_boundary"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument periods_backward", value=periods_backward, expected_type=type_hints["periods_backward"])
                check_type(argname="argument periods_forward", value=periods_forward, expected_type=type_hints["periods_forward"])
                check_type(argname="argument prediction_interval", value=prediction_interval, expected_type=type_hints["prediction_interval"])
                check_type(argname="argument seasonality", value=seasonality, expected_type=type_hints["seasonality"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument upper_boundary", value=upper_boundary, expected_type=type_hints["upper_boundary"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
            }
            if custom_seasonality_value is not None:
                self._values["custom_seasonality_value"] = custom_seasonality_value
            if lower_boundary is not None:
                self._values["lower_boundary"] = lower_boundary
            if name is not None:
                self._values["name"] = name
            if periods_backward is not None:
                self._values["periods_backward"] = periods_backward
            if periods_forward is not None:
                self._values["periods_forward"] = periods_forward
            if prediction_interval is not None:
                self._values["prediction_interval"] = prediction_interval
            if seasonality is not None:
                self._values["seasonality"] = seasonality
            if time is not None:
                self._values["time"] = time
            if upper_boundary is not None:
                self._values["upper_boundary"] = upper_boundary
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def custom_seasonality_value(self) -> typing.Optional[jsii.Number]:
            '''The custom seasonality value setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-customseasonalityvalue
            '''
            result = self._values.get("custom_seasonality_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def lower_boundary(self) -> typing.Optional[jsii.Number]:
            '''The lower boundary setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-lowerboundary
            '''
            result = self._values.get("lower_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def periods_backward(self) -> typing.Optional[jsii.Number]:
            '''The periods backward setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-periodsbackward
            '''
            result = self._values.get("periods_backward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_forward(self) -> typing.Optional[jsii.Number]:
            '''The periods forward setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-periodsforward
            '''
            result = self._values.get("periods_forward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def prediction_interval(self) -> typing.Optional[jsii.Number]:
            '''The prediction interval setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-predictioninterval
            '''
            result = self._values.get("prediction_interval")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def seasonality(self) -> typing.Optional[builtins.str]:
            '''The seasonality setup of a forecast computation. Choose one of the following options:.

            - ``AUTOMATIC``
            - ``CUSTOM`` : Checks the custom seasonality value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-seasonality
            '''
            result = self._values.get("seasonality")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]:
            '''The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-time
            '''
            result = self._values.get("time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]], result)

        @builtins.property
        def upper_boundary(self) -> typing.Optional[jsii.Number]:
            '''The upper boundary setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-upperboundary
            '''
            result = self._values.get("upper_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ForecastConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "forecast_properties": "forecastProperties",
            "scenario": "scenario",
        },
    )
    class ForecastConfigurationProperty:
        def __init__(
            self,
            *,
            forecast_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TimeBasedForecastPropertiesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scenario: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ForecastScenarioProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The forecast configuration that is used in a line chart's display properties.

            :param forecast_properties: The forecast properties setup of a forecast in the line chart.
            :param scenario: The forecast scenario of a forecast in the line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                forecast_configuration_property = quicksight.CfnAnalysis.ForecastConfigurationProperty(
                    forecast_properties=quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty(
                        lower_boundary=123,
                        periods_backward=123,
                        periods_forward=123,
                        prediction_interval=123,
                        seasonality=123,
                        upper_boundary=123
                    ),
                    scenario=quicksight.CfnAnalysis.ForecastScenarioProperty(
                        what_if_point_scenario=quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                            date="date",
                            value=123
                        ),
                        what_if_range_scenario=quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                            end_date="endDate",
                            start_date="startDate",
                            value=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__55ee3f9c9949ac200dfb995903d71b28366ba3897b07124ed698fce60bc6bfc1)
                check_type(argname="argument forecast_properties", value=forecast_properties, expected_type=type_hints["forecast_properties"])
                check_type(argname="argument scenario", value=scenario, expected_type=type_hints["scenario"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if forecast_properties is not None:
                self._values["forecast_properties"] = forecast_properties
            if scenario is not None:
                self._values["scenario"] = scenario

        @builtins.property
        def forecast_properties(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TimeBasedForecastPropertiesProperty"]]:
            '''The forecast properties setup of a forecast in the line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastconfiguration.html#cfn-quicksight-analysis-forecastconfiguration-forecastproperties
            '''
            result = self._values.get("forecast_properties")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TimeBasedForecastPropertiesProperty"]], result)

        @builtins.property
        def scenario(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ForecastScenarioProperty"]]:
            '''The forecast scenario of a forecast in the line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastconfiguration.html#cfn-quicksight-analysis-forecastconfiguration-scenario
            '''
            result = self._values.get("scenario")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ForecastScenarioProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ForecastScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={
            "what_if_point_scenario": "whatIfPointScenario",
            "what_if_range_scenario": "whatIfRangeScenario",
        },
    )
    class ForecastScenarioProperty:
        def __init__(
            self,
            *,
            what_if_point_scenario: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.WhatIfPointScenarioProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            what_if_range_scenario: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.WhatIfRangeScenarioProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The forecast scenario of a forecast in the line chart.

            :param what_if_point_scenario: The what-if analysis forecast setup with the target date.
            :param what_if_range_scenario: The what-if analysis forecast setup with the date range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastscenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                forecast_scenario_property = quicksight.CfnAnalysis.ForecastScenarioProperty(
                    what_if_point_scenario=quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                        date="date",
                        value=123
                    ),
                    what_if_range_scenario=quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                        end_date="endDate",
                        start_date="startDate",
                        value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__18aee80c4c0b357676edee24744630662f9e337c087eadc389f409a3e5152fb0)
                check_type(argname="argument what_if_point_scenario", value=what_if_point_scenario, expected_type=type_hints["what_if_point_scenario"])
                check_type(argname="argument what_if_range_scenario", value=what_if_range_scenario, expected_type=type_hints["what_if_range_scenario"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if what_if_point_scenario is not None:
                self._values["what_if_point_scenario"] = what_if_point_scenario
            if what_if_range_scenario is not None:
                self._values["what_if_range_scenario"] = what_if_range_scenario

        @builtins.property
        def what_if_point_scenario(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WhatIfPointScenarioProperty"]]:
            '''The what-if analysis forecast setup with the target date.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastscenario.html#cfn-quicksight-analysis-forecastscenario-whatifpointscenario
            '''
            result = self._values.get("what_if_point_scenario")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WhatIfPointScenarioProperty"]], result)

        @builtins.property
        def what_if_range_scenario(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WhatIfRangeScenarioProperty"]]:
            '''The what-if analysis forecast setup with the date range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastscenario.html#cfn-quicksight-analysis-forecastscenario-whatifrangescenario
            '''
            result = self._values.get("what_if_range_scenario")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WhatIfRangeScenarioProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format_configuration": "dateTimeFormatConfiguration",
            "number_format_configuration": "numberFormatConfiguration",
            "string_format_configuration": "stringFormatConfiguration",
        },
    )
    class FormatConfigurationProperty:
        def __init__(
            self,
            *,
            date_time_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            string_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The formatting configuration for all types of field.

            :param date_time_format_configuration: Formatting configuration for ``DateTime`` fields.
            :param number_format_configuration: Formatting configuration for number fields.
            :param string_format_configuration: Formatting configuration for string fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-formatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                format_configuration_property = quicksight.CfnAnalysis.FormatConfigurationProperty(
                    date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__efcf1f5e9363b1373e5358c9586872769fcb3284c0ecffaec880cc8d92f7950b)
                check_type(argname="argument date_time_format_configuration", value=date_time_format_configuration, expected_type=type_hints["date_time_format_configuration"])
                check_type(argname="argument number_format_configuration", value=number_format_configuration, expected_type=type_hints["number_format_configuration"])
                check_type(argname="argument string_format_configuration", value=string_format_configuration, expected_type=type_hints["string_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format_configuration is not None:
                self._values["date_time_format_configuration"] = date_time_format_configuration
            if number_format_configuration is not None:
                self._values["number_format_configuration"] = number_format_configuration
            if string_format_configuration is not None:
                self._values["string_format_configuration"] = string_format_configuration

        @builtins.property
        def date_time_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateTimeFormatConfigurationProperty"]]:
            '''Formatting configuration for ``DateTime`` fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-formatconfiguration.html#cfn-quicksight-analysis-formatconfiguration-datetimeformatconfiguration
            '''
            result = self._values.get("date_time_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateTimeFormatConfigurationProperty"]], result)

        @builtins.property
        def number_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumberFormatConfigurationProperty"]]:
            '''Formatting configuration for number fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-formatconfiguration.html#cfn-quicksight-analysis-formatconfiguration-numberformatconfiguration
            '''
            result = self._values.get("number_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumberFormatConfigurationProperty"]], result)

        @builtins.property
        def string_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.StringFormatConfigurationProperty"]]:
            '''Formatting configuration for string fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-formatconfiguration.html#cfn-quicksight-analysis-formatconfiguration-stringformatconfiguration
            '''
            result = self._values.get("string_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.StringFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"screen_canvas_size_options": "screenCanvasSizeOptions"},
    )
    class FreeFormLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            screen_canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Configuration options for the canvas of a free-form layout.

            :param screen_canvas_size_options: The options that determine the sizing of the canvas used in a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                free_form_layout_canvas_size_options_property = quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                    screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                        optimized_view_port_width="optimizedViewPortWidth"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__698e8fd81e4aa68b07ce6cea19d4035e8a2f382c7e037a2a999ac4a10c1fad9f)
                check_type(argname="argument screen_canvas_size_options", value=screen_canvas_size_options, expected_type=type_hints["screen_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if screen_canvas_size_options is not None:
                self._values["screen_canvas_size_options"] = screen_canvas_size_options

        @builtins.property
        def screen_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty"]]:
            '''The options that determine the sizing of the canvas used in a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutcanvassizeoptions.html#cfn-quicksight-analysis-freeformlayoutcanvassizeoptions-screencanvassizeoptions
            '''
            result = self._values.get("screen_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FreeFormLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "elements": "elements",
            "canvas_size_options": "canvasSizeOptions",
        },
    )
    class FreeFormLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FreeFormLayoutElementProperty", typing.Dict[builtins.str, typing.Any]]]]],
            canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a free-form layout.

            :param elements: The elements that are included in a free-form layout.
            :param canvas_size_options: 

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                free_form_layout_configuration_property = quicksight.CfnAnalysis.FreeFormLayoutConfigurationProperty(
                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                        element_id="elementId",
                        element_type="elementType",
                        height="height",
                        width="width",
                        x_axis_location="xAxisLocation",
                        y_axis_location="yAxisLocation",
                
                        # the properties below are optional
                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                            visibility="visibility"
                        ),
                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                visibility="visibility"
                            ),
                            expression="expression"
                        )],
                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        visibility="visibility"
                    )],
                
                    # the properties below are optional
                    canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aaf6efb92d4cf93969fd221e0391d2751c34b3d74c2193f388a42438452b4c29)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }
            if canvas_size_options is not None:
                self._values["canvas_size_options"] = canvas_size_options

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FreeFormLayoutElementProperty"]]]:
            '''The elements that are included in a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutconfiguration.html#cfn-quicksight-analysis-freeformlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FreeFormLayoutElementProperty"]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutconfiguration.html#cfn-quicksight-analysis-freeformlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "visibility": "visibility"},
    )
    class FreeFormLayoutElementBackgroundStyleProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The background style configuration of a free-form layout element.

            :param color: The background color of a free-form layout element.
            :param visibility: The background visibility of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementbackgroundstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                free_form_layout_element_background_style_property = quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                    color="color",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__adac39e36e75be1d2f7eaa4ca69f7f4e2b827196e4d531b052c4446fbcfafb87)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The background color of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-analysis-freeformlayoutelementbackgroundstyle-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The background visibility of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-analysis-freeformlayoutelementbackgroundstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementBackgroundStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "visibility": "visibility"},
    )
    class FreeFormLayoutElementBorderStyleProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The background style configuration of a free-form layout element.

            :param color: The border color of a free-form layout element.
            :param visibility: The border visibility of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementborderstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                free_form_layout_element_border_style_property = quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                    color="color",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2267aeb863dc17444666c4d4c14c0d55a80504486991f6363d67db9ec700174a)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The border color of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementborderstyle.html#cfn-quicksight-analysis-freeformlayoutelementborderstyle-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The border visibility of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementborderstyle.html#cfn-quicksight-analysis-freeformlayoutelementborderstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementBorderStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FreeFormLayoutElementProperty",
        jsii_struct_bases=[],
        name_mapping={
            "element_id": "elementId",
            "element_type": "elementType",
            "height": "height",
            "width": "width",
            "x_axis_location": "xAxisLocation",
            "y_axis_location": "yAxisLocation",
            "background_style": "backgroundStyle",
            "border_style": "borderStyle",
            "loading_animation": "loadingAnimation",
            "rendering_rules": "renderingRules",
            "selected_border_style": "selectedBorderStyle",
            "visibility": "visibility",
        },
    )
    class FreeFormLayoutElementProperty:
        def __init__(
            self,
            *,
            element_id: builtins.str,
            element_type: builtins.str,
            height: builtins.str,
            width: builtins.str,
            x_axis_location: builtins.str,
            y_axis_location: builtins.str,
            background_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            border_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FreeFormLayoutElementBorderStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            loading_animation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LoadingAnimationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rendering_rules: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SheetElementRenderingRuleProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            selected_border_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FreeFormLayoutElementBorderStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''An element within a free-form layout.

            :param element_id: A unique identifier for an element within a free-form layout.
            :param element_type: The type of element.
            :param height: The height of an element within a free-form layout.
            :param width: The width of an element within a free-form layout.
            :param x_axis_location: The x-axis coordinate of the element.
            :param y_axis_location: The y-axis coordinate of the element.
            :param background_style: The background style configuration of a free-form layout element.
            :param border_style: The border style configuration of a free-form layout element.
            :param loading_animation: The loading animation configuration of a free-form layout element.
            :param rendering_rules: The rendering rules that determine when an element should be displayed within a free-form layout.
            :param selected_border_style: The border style configuration of a free-form layout element. This border style is used when the element is selected.
            :param visibility: The visibility of an element within a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                free_form_layout_element_property = quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                    element_id="elementId",
                    element_type="elementType",
                    height="height",
                    width="width",
                    x_axis_location="xAxisLocation",
                    y_axis_location="yAxisLocation",
                
                    # the properties below are optional
                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                        visibility="visibility"
                    ),
                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                            visibility="visibility"
                        ),
                        expression="expression"
                    )],
                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c154d668b63e927f0bd2b9f311a9e0b02b2a2db340096b0ad42a676a7282798a)
                check_type(argname="argument element_id", value=element_id, expected_type=type_hints["element_id"])
                check_type(argname="argument element_type", value=element_type, expected_type=type_hints["element_type"])
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
                check_type(argname="argument x_axis_location", value=x_axis_location, expected_type=type_hints["x_axis_location"])
                check_type(argname="argument y_axis_location", value=y_axis_location, expected_type=type_hints["y_axis_location"])
                check_type(argname="argument background_style", value=background_style, expected_type=type_hints["background_style"])
                check_type(argname="argument border_style", value=border_style, expected_type=type_hints["border_style"])
                check_type(argname="argument loading_animation", value=loading_animation, expected_type=type_hints["loading_animation"])
                check_type(argname="argument rendering_rules", value=rendering_rules, expected_type=type_hints["rendering_rules"])
                check_type(argname="argument selected_border_style", value=selected_border_style, expected_type=type_hints["selected_border_style"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "element_id": element_id,
                "element_type": element_type,
                "height": height,
                "width": width,
                "x_axis_location": x_axis_location,
                "y_axis_location": y_axis_location,
            }
            if background_style is not None:
                self._values["background_style"] = background_style
            if border_style is not None:
                self._values["border_style"] = border_style
            if loading_animation is not None:
                self._values["loading_animation"] = loading_animation
            if rendering_rules is not None:
                self._values["rendering_rules"] = rendering_rules
            if selected_border_style is not None:
                self._values["selected_border_style"] = selected_border_style
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def element_id(self) -> builtins.str:
            '''A unique identifier for an element within a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-elementid
            '''
            result = self._values.get("element_id")
            assert result is not None, "Required property 'element_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element_type(self) -> builtins.str:
            '''The type of element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-elementtype
            '''
            result = self._values.get("element_type")
            assert result is not None, "Required property 'element_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def height(self) -> builtins.str:
            '''The height of an element within a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-height
            '''
            result = self._values.get("height")
            assert result is not None, "Required property 'height' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def width(self) -> builtins.str:
            '''The width of an element within a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-width
            '''
            result = self._values.get("width")
            assert result is not None, "Required property 'width' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def x_axis_location(self) -> builtins.str:
            '''The x-axis coordinate of the element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-xaxislocation
            '''
            result = self._values.get("x_axis_location")
            assert result is not None, "Required property 'x_axis_location' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def y_axis_location(self) -> builtins.str:
            '''The y-axis coordinate of the element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-yaxislocation
            '''
            result = self._values.get("y_axis_location")
            assert result is not None, "Required property 'y_axis_location' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def background_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty"]]:
            '''The background style configuration of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-backgroundstyle
            '''
            result = self._values.get("background_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty"]], result)

        @builtins.property
        def border_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FreeFormLayoutElementBorderStyleProperty"]]:
            '''The border style configuration of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-borderstyle
            '''
            result = self._values.get("border_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FreeFormLayoutElementBorderStyleProperty"]], result)

        @builtins.property
        def loading_animation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LoadingAnimationProperty"]]:
            '''The loading animation configuration of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-loadinganimation
            '''
            result = self._values.get("loading_animation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LoadingAnimationProperty"]], result)

        @builtins.property
        def rendering_rules(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetElementRenderingRuleProperty"]]]]:
            '''The rendering rules that determine when an element should be displayed within a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-renderingrules
            '''
            result = self._values.get("rendering_rules")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetElementRenderingRuleProperty"]]]], result)

        @builtins.property
        def selected_border_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FreeFormLayoutElementBorderStyleProperty"]]:
            '''The border style configuration of a free-form layout element.

            This border style is used when the element is selected.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-selectedborderstyle
            '''
            result = self._values.get("selected_border_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FreeFormLayoutElementBorderStyleProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of an element within a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"optimized_view_port_width": "optimizedViewPortWidth"},
    )
    class FreeFormLayoutScreenCanvasSizeOptionsProperty:
        def __init__(self, *, optimized_view_port_width: builtins.str) -> None:
            '''The options that determine the sizing of the canvas used in a free-form layout.

            :param optimized_view_port_width: The width that the view port will be optimized for when the layout renders.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutscreencanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                free_form_layout_screen_canvas_size_options_property = quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                    optimized_view_port_width="optimizedViewPortWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9079092af38ceb7cdba1387b07783295f04fd5dc900a86ba153374da8a1e1222)
                check_type(argname="argument optimized_view_port_width", value=optimized_view_port_width, expected_type=type_hints["optimized_view_port_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "optimized_view_port_width": optimized_view_port_width,
            }

        @builtins.property
        def optimized_view_port_width(self) -> builtins.str:
            '''The width that the view port will be optimized for when the layout renders.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutscreencanvassizeoptions.html#cfn-quicksight-analysis-freeformlayoutscreencanvassizeoptions-optimizedviewportwidth
            '''
            result = self._values.get("optimized_view_port_width")
            assert result is not None, "Required property 'optimized_view_port_width' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutScreenCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"elements": "elements"},
    )
    class FreeFormSectionLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FreeFormLayoutElementProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The free-form layout configuration of a section.

            :param elements: The elements that are included in the free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformsectionlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                free_form_section_layout_configuration_property = quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                        element_id="elementId",
                        element_type="elementType",
                        height="height",
                        width="width",
                        x_axis_location="xAxisLocation",
                        y_axis_location="yAxisLocation",
                
                        # the properties below are optional
                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                            visibility="visibility"
                        ),
                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                visibility="visibility"
                            ),
                            expression="expression"
                        )],
                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        visibility="visibility"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e9e5c14817e88c14408adc420a17eb5c46f1c8a179df4ee1d49b5e998c0c37e2)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FreeFormLayoutElementProperty"]]]:
            '''The elements that are included in the free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformsectionlayoutconfiguration.html#cfn-quicksight-analysis-freeformsectionlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FreeFormLayoutElementProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormSectionLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"category": "category", "values": "values"},
    )
    class FunnelChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :param category: The category field wells of a funnel chart. Values are grouped by category fields.
            :param values: The value field wells of a funnel chart. Values are aggregated based on categories.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                funnel_chart_aggregated_field_wells_property = quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6af0bdb93ec1eaebe9fa6a0d12f67574de2b864cbe005104709a984c6c99fc51)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The category field wells of a funnel chart.

            Values are grouped by category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartaggregatedfieldwells.html#cfn-quicksight-analysis-funnelchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The value field wells of a funnel chart.

            Values are aggregated based on categories.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartaggregatedfieldwells.html#cfn-quicksight-analysis-funnelchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FunnelChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "data_label_options": "dataLabelOptions",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class FunnelChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FunnelChartDataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FunnelChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FunnelChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``FunnelChartVisual`` .

            :param category_label_options: The label options of the categories that are displayed in a ``FunnelChartVisual`` .
            :param data_label_options: The options that determine the presentation of the data labels.
            :param field_wells: The field well configuration of a ``FunnelChartVisual`` .
            :param sort_configuration: The sort configuration of a ``FunnelChartVisual`` .
            :param tooltip: The tooltip configuration of a ``FunnelChartVisual`` .
            :param value_label_options: The label options for the values that are displayed in a ``FunnelChartVisual`` .
            :param visual_palette: The visual palette configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f0ceb2f79431fef514821fc3b0a6b319b6a89b57cd69ecb43f4df332dad8681c)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument data_label_options", value=data_label_options, expected_type=type_hints["data_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if data_label_options is not None:
                self._values["data_label_options"] = data_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the categories that are displayed in a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def data_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FunnelChartDataLabelOptionsProperty"]]:
            '''The options that determine the presentation of the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-datalabeloptions
            '''
            result = self._values.get("data_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FunnelChartDataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FunnelChartFieldWellsProperty"]]:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FunnelChartFieldWellsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FunnelChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FunnelChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options for the values that are displayed in a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The visual palette configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FunnelChartDataLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_visibility": "categoryLabelVisibility",
            "label_color": "labelColor",
            "label_font_configuration": "labelFontConfiguration",
            "measure_data_label_style": "measureDataLabelStyle",
            "measure_label_visibility": "measureLabelVisibility",
            "position": "position",
            "visibility": "visibility",
        },
    )
    class FunnelChartDataLabelOptionsProperty:
        def __init__(
            self,
            *,
            category_label_visibility: typing.Optional[builtins.str] = None,
            label_color: typing.Optional[builtins.str] = None,
            label_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            measure_data_label_style: typing.Optional[builtins.str] = None,
            measure_label_visibility: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of the data labels.

            :param category_label_visibility: The visibility of the category labels within the data labels.
            :param label_color: The color of the data label text.
            :param label_font_configuration: The font configuration for the data labels. Only the ``FontSize`` attribute of the font configuration is used for data labels.
            :param measure_data_label_style: Determines the style of the metric labels.
            :param measure_label_visibility: The visibility of the measure labels within the data labels.
            :param position: Determines the positioning of the data label relative to a section of the funnel.
            :param visibility: The visibility option that determines if data labels are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                funnel_chart_data_label_options_property = quicksight.CfnAnalysis.FunnelChartDataLabelOptionsProperty(
                    category_label_visibility="categoryLabelVisibility",
                    label_color="labelColor",
                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    measure_data_label_style="measureDataLabelStyle",
                    measure_label_visibility="measureLabelVisibility",
                    position="position",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__119735cd37500e682e128a306ae03b3fdcdac6ee732414d9a409f8107cafaa02)
                check_type(argname="argument category_label_visibility", value=category_label_visibility, expected_type=type_hints["category_label_visibility"])
                check_type(argname="argument label_color", value=label_color, expected_type=type_hints["label_color"])
                check_type(argname="argument label_font_configuration", value=label_font_configuration, expected_type=type_hints["label_font_configuration"])
                check_type(argname="argument measure_data_label_style", value=measure_data_label_style, expected_type=type_hints["measure_data_label_style"])
                check_type(argname="argument measure_label_visibility", value=measure_label_visibility, expected_type=type_hints["measure_label_visibility"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_visibility is not None:
                self._values["category_label_visibility"] = category_label_visibility
            if label_color is not None:
                self._values["label_color"] = label_color
            if label_font_configuration is not None:
                self._values["label_font_configuration"] = label_font_configuration
            if measure_data_label_style is not None:
                self._values["measure_data_label_style"] = measure_data_label_style
            if measure_label_visibility is not None:
                self._values["measure_label_visibility"] = measure_label_visibility
            if position is not None:
                self._values["position"] = position
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def category_label_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the category labels within the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-categorylabelvisibility
            '''
            result = self._values.get("category_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_color(self) -> typing.Optional[builtins.str]:
            '''The color of the data label text.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-labelcolor
            '''
            result = self._values.get("label_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"]]:
            '''The font configuration for the data labels.

            Only the ``FontSize`` attribute of the font configuration is used for data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-labelfontconfiguration
            '''
            result = self._values.get("label_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"]], result)

        @builtins.property
        def measure_data_label_style(self) -> typing.Optional[builtins.str]:
            '''Determines the style of the metric labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-measuredatalabelstyle
            '''
            result = self._values.get("measure_data_label_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def measure_label_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the measure labels within the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-measurelabelvisibility
            '''
            result = self._values.get("measure_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''Determines the positioning of the data label relative to a section of the funnel.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility option that determines if data labels are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartDataLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FunnelChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "funnel_chart_aggregated_field_wells": "funnelChartAggregatedFieldWells",
        },
    )
    class FunnelChartFieldWellsProperty:
        def __init__(
            self,
            *,
            funnel_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FunnelChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a ``FunnelChartVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param funnel_chart_aggregated_field_wells: The field well configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                funnel_chart_field_wells_property = quicksight.CfnAnalysis.FunnelChartFieldWellsProperty(
                    funnel_chart_aggregated_field_wells=quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__12f1cfc87ca359e9f1f5bb1f72eb016743da084dcc2437c8e9537da5b96d2fc4)
                check_type(argname="argument funnel_chart_aggregated_field_wells", value=funnel_chart_aggregated_field_wells, expected_type=type_hints["funnel_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if funnel_chart_aggregated_field_wells is not None:
                self._values["funnel_chart_aggregated_field_wells"] = funnel_chart_aggregated_field_wells

        @builtins.property
        def funnel_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FunnelChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartfieldwells.html#cfn-quicksight-analysis-funnelchartfieldwells-funnelchartaggregatedfieldwells
            '''
            result = self._values.get("funnel_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FunnelChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FunnelChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class FunnelChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``FunnelChartVisual`` .

            :param category_items_limit: The limit on the number of categories displayed.
            :param category_sort: The sort configuration of the category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                funnel_chart_sort_configuration_property = quicksight.CfnAnalysis.FunnelChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fd70df6fe2a086ff578149465483bb7a8c5202ed3429bf283bf9905bc646ae5b)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartsortconfiguration.html#cfn-quicksight-analysis-funnelchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartsortconfiguration.html#cfn-quicksight-analysis-funnelchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.FunnelChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class FunnelChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FunnelChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A funnel chart.

            For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``FunnelChartVisual`` .
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__392520e04bb1b961d06bd10c924febe7d1e2b11a6d663bc25872e2edf5b1a760)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FunnelChartConfigurationProperty"]]:
            '''The configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FunnelChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"foreground_color": "foregroundColor"},
    )
    class GaugeChartArcConditionalFormattingProperty:
        def __init__(
            self,
            *,
            foreground_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of the arc of a ``GaugeChartVisual`` .

            :param foreground_color: The conditional formatting of the arc foreground color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartarcconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gauge_chart_arc_conditional_formatting_property = quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty(
                    foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b374ec018743390b4521dfc3aa342f26565b8eb4ee0f053fd9791ff204e8f615)
                check_type(argname="argument foreground_color", value=foreground_color, expected_type=type_hints["foreground_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if foreground_color is not None:
                self._values["foreground_color"] = foreground_color

        @builtins.property
        def foreground_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the arc foreground color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartarcconditionalformatting.html#cfn-quicksight-analysis-gaugechartarcconditionalformatting-foregroundcolor
            '''
            result = self._values.get("foreground_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartArcConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GaugeChartConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"arc": "arc", "primary_value": "primaryValue"},
    )
    class GaugeChartConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            arc: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GaugeChartArcConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Conditional formatting options of a ``GaugeChartVisual`` .

            :param arc: The options that determine the presentation of the arc of a ``GaugeChartVisual`` .
            :param primary_value: The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gauge_chart_conditional_formatting_option_property = quicksight.CfnAnalysis.GaugeChartConditionalFormattingOptionProperty(
                    arc=quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty(
                        foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    primary_value=quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty(
                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f538edfa4fedce6e8dac39d02e58b25883f9d3571afe2e707d1157916af517d3)
                check_type(argname="argument arc", value=arc, expected_type=type_hints["arc"])
                check_type(argname="argument primary_value", value=primary_value, expected_type=type_hints["primary_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc is not None:
                self._values["arc"] = arc
            if primary_value is not None:
                self._values["primary_value"] = primary_value

        @builtins.property
        def arc(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GaugeChartArcConditionalFormattingProperty"]]:
            '''The options that determine the presentation of the arc of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformattingoption.html#cfn-quicksight-analysis-gaugechartconditionalformattingoption-arc
            '''
            result = self._values.get("arc")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GaugeChartArcConditionalFormattingProperty"]], result)

        @builtins.property
        def primary_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty"]]:
            '''The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformattingoption.html#cfn-quicksight-analysis-gaugechartconditionalformattingoption-primaryvalue
            '''
            result = self._values.get("primary_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GaugeChartConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class GaugeChartConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GaugeChartConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting of a ``GaugeChartVisual`` .

            :param conditional_formatting_options: Conditional formatting options of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gauge_chart_conditional_formatting_property = quicksight.CfnAnalysis.GaugeChartConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnAnalysis.GaugeChartConditionalFormattingOptionProperty(
                        arc=quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty(
                            foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        primary_value=quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty(
                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6c6c904e3df29b8eac2d58a81cf044e707544a88d9ef2ac4642c3cd7406bc14c)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GaugeChartConditionalFormattingOptionProperty"]]]]:
            '''Conditional formatting options of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformatting.html#cfn-quicksight-analysis-gaugechartconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GaugeChartConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GaugeChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "gauge_chart_options": "gaugeChartOptions",
            "tooltip_options": "tooltipOptions",
            "visual_palette": "visualPalette",
        },
    )
    class GaugeChartConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GaugeChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            gauge_chart_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GaugeChartOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``GaugeChartVisual`` .

            :param data_labels: The data label configuration of a ``GaugeChartVisual`` .
            :param field_wells: The field well configuration of a ``GaugeChartVisual`` .
            :param gauge_chart_options: The options that determine the presentation of the ``GaugeChartVisual`` .
            :param tooltip_options: The tooltip configuration of a ``GaugeChartVisual`` .
            :param visual_palette: The visual palette configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__04e8e0e332bbcfd4f449ede609b0b25344f8501403e42ae88f789e995f285e83)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument gauge_chart_options", value=gauge_chart_options, expected_type=type_hints["gauge_chart_options"])
                check_type(argname="argument tooltip_options", value=tooltip_options, expected_type=type_hints["tooltip_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if gauge_chart_options is not None:
                self._values["gauge_chart_options"] = gauge_chart_options
            if tooltip_options is not None:
                self._values["tooltip_options"] = tooltip_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The data label configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GaugeChartFieldWellsProperty"]]:
            '''The field well configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GaugeChartFieldWellsProperty"]], result)

        @builtins.property
        def gauge_chart_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GaugeChartOptionsProperty"]]:
            '''The options that determine the presentation of the ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-gaugechartoptions
            '''
            result = self._values.get("gauge_chart_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GaugeChartOptionsProperty"]], result)

        @builtins.property
        def tooltip_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-tooltipoptions
            '''
            result = self._values.get("tooltip_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The visual palette configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GaugeChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"target_values": "targetValues", "values": "values"},
    )
    class GaugeChartFieldWellsProperty:
        def __init__(
            self,
            *,
            target_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a ``GaugeChartVisual`` .

            :param target_values: The target value field wells of a ``GaugeChartVisual`` .
            :param values: The value field wells of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ac68757308c1ebd9814780dd8455cdfc4ee57167d6a012b4df3fc5ec4856eba6)
                check_type(argname="argument target_values", value=target_values, expected_type=type_hints["target_values"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_values is not None:
                self._values["target_values"] = target_values
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def target_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The target value field wells of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartfieldwells.html#cfn-quicksight-analysis-gaugechartfieldwells-targetvalues
            '''
            result = self._values.get("target_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The value field wells of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartfieldwells.html#cfn-quicksight-analysis-gaugechartfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GaugeChartOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arc": "arc",
            "arc_axis": "arcAxis",
            "comparison": "comparison",
            "primary_value_display_type": "primaryValueDisplayType",
            "primary_value_font_configuration": "primaryValueFontConfiguration",
        },
    )
    class GaugeChartOptionsProperty:
        def __init__(
            self,
            *,
            arc: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ArcConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            arc_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ArcAxisConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            comparison: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ComparisonConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_value_display_type: typing.Optional[builtins.str] = None,
            primary_value_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of the ``GaugeChartVisual`` .

            :param arc: The arc configuration of a ``GaugeChartVisual`` .
            :param arc_axis: The arc axis configuration of a ``GaugeChartVisual`` .
            :param comparison: The comparison configuration of a ``GaugeChartVisual`` .
            :param primary_value_display_type: The options that determine the primary value display type.
            :param primary_value_font_configuration: The options that determine the primary value font configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gauge_chart_options_property = quicksight.CfnAnalysis.GaugeChartOptionsProperty(
                    arc=quicksight.CfnAnalysis.ArcConfigurationProperty(
                        arc_angle=123,
                        arc_thickness="arcThickness"
                    ),
                    arc_axis=quicksight.CfnAnalysis.ArcAxisConfigurationProperty(
                        range=quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                            max=123,
                            min=123
                        ),
                        reserve_range=123
                    ),
                    comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                        comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        comparison_method="comparisonMethod"
                    ),
                    primary_value_display_type="primaryValueDisplayType",
                    primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__526df1b911d4c47fec9f8cdcddd4a9d5050693feb76dd54539df1a51bd45c305)
                check_type(argname="argument arc", value=arc, expected_type=type_hints["arc"])
                check_type(argname="argument arc_axis", value=arc_axis, expected_type=type_hints["arc_axis"])
                check_type(argname="argument comparison", value=comparison, expected_type=type_hints["comparison"])
                check_type(argname="argument primary_value_display_type", value=primary_value_display_type, expected_type=type_hints["primary_value_display_type"])
                check_type(argname="argument primary_value_font_configuration", value=primary_value_font_configuration, expected_type=type_hints["primary_value_font_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc is not None:
                self._values["arc"] = arc
            if arc_axis is not None:
                self._values["arc_axis"] = arc_axis
            if comparison is not None:
                self._values["comparison"] = comparison
            if primary_value_display_type is not None:
                self._values["primary_value_display_type"] = primary_value_display_type
            if primary_value_font_configuration is not None:
                self._values["primary_value_font_configuration"] = primary_value_font_configuration

        @builtins.property
        def arc(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ArcConfigurationProperty"]]:
            '''The arc configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-arc
            '''
            result = self._values.get("arc")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ArcConfigurationProperty"]], result)

        @builtins.property
        def arc_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ArcAxisConfigurationProperty"]]:
            '''The arc axis configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-arcaxis
            '''
            result = self._values.get("arc_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ArcAxisConfigurationProperty"]], result)

        @builtins.property
        def comparison(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ComparisonConfigurationProperty"]]:
            '''The comparison configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-comparison
            '''
            result = self._values.get("comparison")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ComparisonConfigurationProperty"]], result)

        @builtins.property
        def primary_value_display_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the primary value display type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-primaryvaluedisplaytype
            '''
            result = self._values.get("primary_value_display_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"]]:
            '''The options that determine the primary value font configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-primaryvaluefontconfiguration
            '''
            result = self._values.get("primary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class GaugeChartPrimaryValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :param icon: The conditional formatting of the primary value icon.
            :param text_color: The conditional formatting of the primary value text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartprimaryvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gauge_chart_primary_value_conditional_formatting_property = quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty(
                    icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__05cd51f4c2623976de54394f832cb186600ac7643d5d9e3215c098afd9a1fb61)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting of the primary value icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-analysis-gaugechartprimaryvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the primary value text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-analysis-gaugechartprimaryvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartPrimaryValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GaugeChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class GaugeChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GaugeChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GaugeChartConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A gauge chart.

            For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``GaugeChartVisual`` .
            :param conditional_formatting: The conditional formatting of a ``GaugeChartVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__db10659b7b6c7e891848e0cc3d42c70167896823fb2317ad92c10f5c8078ef60)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GaugeChartConfigurationProperty"]]:
            '''The configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GaugeChartConfigurationProperty"]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GaugeChartConditionalFormattingProperty"]]:
            '''The conditional formatting of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GaugeChartConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "east": "east",
            "north": "north",
            "south": "south",
            "west": "west",
        },
    )
    class GeospatialCoordinateBoundsProperty:
        def __init__(
            self,
            *,
            east: jsii.Number,
            north: jsii.Number,
            south: jsii.Number,
            west: jsii.Number,
        ) -> None:
            '''The bound options (north, south, west, east) of the geospatial window options.

            :param east: The longitude of the east bound of the geospatial coordinate bounds.
            :param north: The latitude of the north bound of the geospatial coordinate bounds.
            :param south: The latitude of the south bound of the geospatial coordinate bounds.
            :param west: The longitude of the west bound of the geospatial coordinate bounds.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geospatial_coordinate_bounds_property = quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                    east=123,
                    north=123,
                    south=123,
                    west=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c69fee4597d6a6e52289c965dc69615cc99078bd4e55eafd2e189d0506ce8a3d)
                check_type(argname="argument east", value=east, expected_type=type_hints["east"])
                check_type(argname="argument north", value=north, expected_type=type_hints["north"])
                check_type(argname="argument south", value=south, expected_type=type_hints["south"])
                check_type(argname="argument west", value=west, expected_type=type_hints["west"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "east": east,
                "north": north,
                "south": south,
                "west": west,
            }

        @builtins.property
        def east(self) -> jsii.Number:
            '''The longitude of the east bound of the geospatial coordinate bounds.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html#cfn-quicksight-analysis-geospatialcoordinatebounds-east
            '''
            result = self._values.get("east")
            assert result is not None, "Required property 'east' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def north(self) -> jsii.Number:
            '''The latitude of the north bound of the geospatial coordinate bounds.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html#cfn-quicksight-analysis-geospatialcoordinatebounds-north
            '''
            result = self._values.get("north")
            assert result is not None, "Required property 'north' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def south(self) -> jsii.Number:
            '''The latitude of the south bound of the geospatial coordinate bounds.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html#cfn-quicksight-analysis-geospatialcoordinatebounds-south
            '''
            result = self._values.get("south")
            assert result is not None, "Required property 'south' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def west(self) -> jsii.Number:
            '''The longitude of the west bound of the geospatial coordinate bounds.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html#cfn-quicksight-analysis-geospatialcoordinatebounds-west
            '''
            result = self._values.get("west")
            assert result is not None, "Required property 'west' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialCoordinateBoundsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GeospatialHeatmapColorScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"colors": "colors"},
    )
    class GeospatialHeatmapColorScaleProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GeospatialHeatmapDataColorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The color scale specification for the heatmap point style.

            :param colors: The list of colors to be used in heatmap point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialheatmapcolorscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geospatial_heatmap_color_scale_property = quicksight.CfnAnalysis.GeospatialHeatmapColorScaleProperty(
                    colors=[quicksight.CfnAnalysis.GeospatialHeatmapDataColorProperty(
                        color="color"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9b2e1935b3f92bf7953fd6c5c1510e0db5fcfa10bdca91dc31934d137781b2ef)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialHeatmapDataColorProperty"]]]]:
            '''The list of colors to be used in heatmap point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialheatmapcolorscale.html#cfn-quicksight-analysis-geospatialheatmapcolorscale-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialHeatmapDataColorProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialHeatmapColorScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GeospatialHeatmapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"heatmap_color": "heatmapColor"},
    )
    class GeospatialHeatmapConfigurationProperty:
        def __init__(
            self,
            *,
            heatmap_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GeospatialHeatmapColorScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The heatmap configuration of the geospatial point style.

            :param heatmap_color: The color scale specification for the heatmap point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialheatmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geospatial_heatmap_configuration_property = quicksight.CfnAnalysis.GeospatialHeatmapConfigurationProperty(
                    heatmap_color=quicksight.CfnAnalysis.GeospatialHeatmapColorScaleProperty(
                        colors=[quicksight.CfnAnalysis.GeospatialHeatmapDataColorProperty(
                            color="color"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ec20340d5e164e926e09594b2dff74ff05b41cc216237f87e6b7673968fb66e5)
                check_type(argname="argument heatmap_color", value=heatmap_color, expected_type=type_hints["heatmap_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if heatmap_color is not None:
                self._values["heatmap_color"] = heatmap_color

        @builtins.property
        def heatmap_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialHeatmapColorScaleProperty"]]:
            '''The color scale specification for the heatmap point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialheatmapconfiguration.html#cfn-quicksight-analysis-geospatialheatmapconfiguration-heatmapcolor
            '''
            result = self._values.get("heatmap_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialHeatmapColorScaleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialHeatmapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GeospatialHeatmapDataColorProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color"},
    )
    class GeospatialHeatmapDataColorProperty:
        def __init__(self, *, color: builtins.str) -> None:
            '''The color to be used in the heatmap point style.

            :param color: The hex color to be used in the heatmap point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialheatmapdatacolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geospatial_heatmap_data_color_property = quicksight.CfnAnalysis.GeospatialHeatmapDataColorProperty(
                    color="color"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7ff0131f0ddc655a12db2314b1d42e47bee9e4b5ec3fe9c3c2d30f381303e986)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
            }

        @builtins.property
        def color(self) -> builtins.str:
            '''The hex color to be used in the heatmap point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialheatmapdatacolor.html#cfn-quicksight-analysis-geospatialheatmapdatacolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialHeatmapDataColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "colors": "colors",
            "geospatial": "geospatial",
            "values": "values",
        },
    )
    class GeospatialMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            geospatial: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells for a geospatial map.

            :param colors: The color field wells of a geospatial map.
            :param geospatial: The geospatial field wells of a geospatial map. Values are grouped by geospatial fields.
            :param values: The size field wells of a geospatial map. Values are aggregated based on geospatial fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__39dbfd9468a705a82826afd15f6f727c87ee9cdbf2a0c017e2c18c162a04f47e)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument geospatial", value=geospatial, expected_type=type_hints["geospatial"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors
            if geospatial is not None:
                self._values["geospatial"] = geospatial
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The color field wells of a geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapaggregatedfieldwells.html#cfn-quicksight-analysis-geospatialmapaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def geospatial(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The geospatial field wells of a geospatial map.

            Values are grouped by geospatial fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapaggregatedfieldwells.html#cfn-quicksight-analysis-geospatialmapaggregatedfieldwells-geospatial
            '''
            result = self._values.get("geospatial")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The size field wells of a geospatial map.

            Values are aggregated based on geospatial fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapaggregatedfieldwells.html#cfn-quicksight-analysis-geospatialmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GeospatialMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "legend": "legend",
            "map_style_options": "mapStyleOptions",
            "point_style_options": "pointStyleOptions",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "window_options": "windowOptions",
        },
    )
    class GeospatialMapConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GeospatialMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            map_style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GeospatialMapStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            point_style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GeospatialPointStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            window_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GeospatialWindowOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``GeospatialMapVisual`` .

            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param map_style_options: The map style options of the geospatial map.
            :param point_style_options: The point style options of the geospatial map.
            :param tooltip: The tooltip display setup of the visual.
            :param visual_palette: 
            :param window_options: The window options of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__60d57edb34f563d63db66a41f0e9e2f72571d6fee2bc11156b17cabc0db57153)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument map_style_options", value=map_style_options, expected_type=type_hints["map_style_options"])
                check_type(argname="argument point_style_options", value=point_style_options, expected_type=type_hints["point_style_options"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument window_options", value=window_options, expected_type=type_hints["window_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if map_style_options is not None:
                self._values["map_style_options"] = map_style_options
            if point_style_options is not None:
                self._values["point_style_options"] = point_style_options
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if window_options is not None:
                self._values["window_options"] = window_options

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialMapFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def map_style_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialMapStyleOptionsProperty"]]:
            '''The map style options of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-mapstyleoptions
            '''
            result = self._values.get("map_style_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialMapStyleOptionsProperty"]], result)

        @builtins.property
        def point_style_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialPointStyleOptionsProperty"]]:
            '''The point style options of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-pointstyleoptions
            '''
            result = self._values.get("point_style_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialPointStyleOptionsProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]], result)

        @builtins.property
        def window_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialWindowOptionsProperty"]]:
            '''The window options of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-windowoptions
            '''
            result = self._values.get("window_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialWindowOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GeospatialMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "geospatial_map_aggregated_field_wells": "geospatialMapAggregatedFieldWells",
        },
    )
    class GeospatialMapFieldWellsProperty:
        def __init__(
            self,
            *,
            geospatial_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``GeospatialMapVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param geospatial_map_aggregated_field_wells: The aggregated field well for a geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0b35fb60d54f698e768871c04d9bc83b2ffdfeaf90be9c7d7a7ff855c373b6b0)
                check_type(argname="argument geospatial_map_aggregated_field_wells", value=geospatial_map_aggregated_field_wells, expected_type=type_hints["geospatial_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if geospatial_map_aggregated_field_wells is not None:
                self._values["geospatial_map_aggregated_field_wells"] = geospatial_map_aggregated_field_wells

        @builtins.property
        def geospatial_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field well for a geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapfieldwells.html#cfn-quicksight-analysis-geospatialmapfieldwells-geospatialmapaggregatedfieldwells
            '''
            result = self._values.get("geospatial_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"base_map_style": "baseMapStyle"},
    )
    class GeospatialMapStyleOptionsProperty:
        def __init__(
            self,
            *,
            base_map_style: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The map style options of the geospatial map.

            :param base_map_style: The base map style of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geospatial_map_style_options_property = quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                    base_map_style="baseMapStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__da4c763b91dac10c5731141417c32a202a7ab85b5a46f08058fcc455d7c50aa0)
                check_type(argname="argument base_map_style", value=base_map_style, expected_type=type_hints["base_map_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if base_map_style is not None:
                self._values["base_map_style"] = base_map_style

        @builtins.property
        def base_map_style(self) -> typing.Optional[builtins.str]:
            '''The base map style of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapstyleoptions.html#cfn-quicksight-analysis-geospatialmapstyleoptions-basemapstyle
            '''
            result = self._values.get("base_map_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GeospatialMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class GeospatialMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GeospatialMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A geospatial map or a points on map visual.

            For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f7285c62652ed38c015ec301e5d9f8177678997b524fd20a0d43c688fea50f1c)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialMapConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GeospatialPointStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cluster_marker_configuration": "clusterMarkerConfiguration",
            "heatmap_configuration": "heatmapConfiguration",
            "selected_point_style": "selectedPointStyle",
        },
    )
    class GeospatialPointStyleOptionsProperty:
        def __init__(
            self,
            *,
            cluster_marker_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ClusterMarkerConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            heatmap_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GeospatialHeatmapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selected_point_style: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The point style of the geospatial map.

            :param cluster_marker_configuration: The cluster marker configuration of the geospatial point style.
            :param heatmap_configuration: The heatmap configuration of the geospatial point style.
            :param selected_point_style: The selected point styles (point, cluster) of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialpointstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geospatial_point_style_options_property = quicksight.CfnAnalysis.GeospatialPointStyleOptionsProperty(
                    cluster_marker_configuration=quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty(
                        cluster_marker=quicksight.CfnAnalysis.ClusterMarkerProperty(
                            simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                                color="color"
                            )
                        )
                    ),
                    heatmap_configuration=quicksight.CfnAnalysis.GeospatialHeatmapConfigurationProperty(
                        heatmap_color=quicksight.CfnAnalysis.GeospatialHeatmapColorScaleProperty(
                            colors=[quicksight.CfnAnalysis.GeospatialHeatmapDataColorProperty(
                                color="color"
                            )]
                        )
                    ),
                    selected_point_style="selectedPointStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9b8e51d51b46915c6e8131ab17aae68901c47973d9a47f99d3df8bf878210a2b)
                check_type(argname="argument cluster_marker_configuration", value=cluster_marker_configuration, expected_type=type_hints["cluster_marker_configuration"])
                check_type(argname="argument heatmap_configuration", value=heatmap_configuration, expected_type=type_hints["heatmap_configuration"])
                check_type(argname="argument selected_point_style", value=selected_point_style, expected_type=type_hints["selected_point_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cluster_marker_configuration is not None:
                self._values["cluster_marker_configuration"] = cluster_marker_configuration
            if heatmap_configuration is not None:
                self._values["heatmap_configuration"] = heatmap_configuration
            if selected_point_style is not None:
                self._values["selected_point_style"] = selected_point_style

        @builtins.property
        def cluster_marker_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ClusterMarkerConfigurationProperty"]]:
            '''The cluster marker configuration of the geospatial point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialpointstyleoptions.html#cfn-quicksight-analysis-geospatialpointstyleoptions-clustermarkerconfiguration
            '''
            result = self._values.get("cluster_marker_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ClusterMarkerConfigurationProperty"]], result)

        @builtins.property
        def heatmap_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialHeatmapConfigurationProperty"]]:
            '''The heatmap configuration of the geospatial point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialpointstyleoptions.html#cfn-quicksight-analysis-geospatialpointstyleoptions-heatmapconfiguration
            '''
            result = self._values.get("heatmap_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialHeatmapConfigurationProperty"]], result)

        @builtins.property
        def selected_point_style(self) -> typing.Optional[builtins.str]:
            '''The selected point styles (point, cluster) of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialpointstyleoptions.html#cfn-quicksight-analysis-geospatialpointstyleoptions-selectedpointstyle
            '''
            result = self._values.get("selected_point_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialPointStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GeospatialWindowOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"bounds": "bounds", "map_zoom_mode": "mapZoomMode"},
    )
    class GeospatialWindowOptionsProperty:
        def __init__(
            self,
            *,
            bounds: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GeospatialCoordinateBoundsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            map_zoom_mode: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The window options of the geospatial map visual.

            :param bounds: The bounds options (north, south, west, east) of the geospatial window options.
            :param map_zoom_mode: The map zoom modes (manual, auto) of the geospatial window options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialwindowoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geospatial_window_options_property = quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                    bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                        east=123,
                        north=123,
                        south=123,
                        west=123
                    ),
                    map_zoom_mode="mapZoomMode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e3701bb8b52fddc028e19d6f383a1ebd415dfc7d7e09e7d2aad6498b94016524)
                check_type(argname="argument bounds", value=bounds, expected_type=type_hints["bounds"])
                check_type(argname="argument map_zoom_mode", value=map_zoom_mode, expected_type=type_hints["map_zoom_mode"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bounds is not None:
                self._values["bounds"] = bounds
            if map_zoom_mode is not None:
                self._values["map_zoom_mode"] = map_zoom_mode

        @builtins.property
        def bounds(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialCoordinateBoundsProperty"]]:
            '''The bounds options (north, south, west, east) of the geospatial window options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialwindowoptions.html#cfn-quicksight-analysis-geospatialwindowoptions-bounds
            '''
            result = self._values.get("bounds")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialCoordinateBoundsProperty"]], result)

        @builtins.property
        def map_zoom_mode(self) -> typing.Optional[builtins.str]:
            '''The map zoom modes (manual, auto) of the geospatial window options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialwindowoptions.html#cfn-quicksight-analysis-geospatialwindowoptions-mapzoommode
            '''
            result = self._values.get("map_zoom_mode")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialWindowOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "side_specific_border": "sideSpecificBorder",
            "uniform_border": "uniformBorder",
        },
    )
    class GlobalTableBorderOptionsProperty:
        def __init__(
            self,
            *,
            side_specific_border: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableSideBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            uniform_border: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Determines the border options for a table visual.

            :param side_specific_border: Determines the options for side specific border.
            :param uniform_border: Determines the options for uniform border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-globaltableborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                global_table_border_options_property = quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        )
                    ),
                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__efd154cde8886acf419124fd05fb50e244943d8507a453540554430d066fb50a)
                check_type(argname="argument side_specific_border", value=side_specific_border, expected_type=type_hints["side_specific_border"])
                check_type(argname="argument uniform_border", value=uniform_border, expected_type=type_hints["uniform_border"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if side_specific_border is not None:
                self._values["side_specific_border"] = side_specific_border
            if uniform_border is not None:
                self._values["uniform_border"] = uniform_border

        @builtins.property
        def side_specific_border(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableSideBorderOptionsProperty"]]:
            '''Determines the options for side specific border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-globaltableborderoptions.html#cfn-quicksight-analysis-globaltableborderoptions-sidespecificborder
            '''
            result = self._values.get("side_specific_border")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableSideBorderOptionsProperty"]], result)

        @builtins.property
        def uniform_border(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableBorderOptionsProperty"]]:
            '''Determines the options for uniform border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-globaltableborderoptions.html#cfn-quicksight-analysis-globaltableborderoptions-uniformborder
            '''
            result = self._values.get("uniform_border")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableBorderOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GlobalTableBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GradientColorProperty",
        jsii_struct_bases=[],
        name_mapping={"stops": "stops"},
    )
    class GradientColorProperty:
        def __init__(
            self,
            *,
            stops: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GradientStopProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''Determines the gradient color settings.

            :param stops: The list of gradient color stops.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gradient_color_property = quicksight.CfnAnalysis.GradientColorProperty(
                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                        gradient_offset=123,
                
                        # the properties below are optional
                        color="color",
                        data_value=123
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__764cda6c5613192b186c772a28cf3f3d3a8007ba7eabffeab1d3f89d1b4a0575)
                check_type(argname="argument stops", value=stops, expected_type=type_hints["stops"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if stops is not None:
                self._values["stops"] = stops

        @builtins.property
        def stops(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GradientStopProperty"]]]]:
            '''The list of gradient color stops.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientcolor.html#cfn-quicksight-analysis-gradientcolor-stops
            '''
            result = self._values.get("stops")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GradientStopProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GradientColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GradientStopProperty",
        jsii_struct_bases=[],
        name_mapping={
            "gradient_offset": "gradientOffset",
            "color": "color",
            "data_value": "dataValue",
        },
    )
    class GradientStopProperty:
        def __init__(
            self,
            *,
            gradient_offset: jsii.Number,
            color: typing.Optional[builtins.str] = None,
            data_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''Determines the gradient stop configuration.

            :param gradient_offset: Determines gradient offset value. Default: - 0
            :param color: Determines the color.
            :param data_value: Determines the data value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientstop.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gradient_stop_property = quicksight.CfnAnalysis.GradientStopProperty(
                    gradient_offset=123,
                
                    # the properties below are optional
                    color="color",
                    data_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6f72df1511db50e88a6e0c8cdf93031107526c7cfa28cd63ca52e30a6d5ec2d4)
                check_type(argname="argument gradient_offset", value=gradient_offset, expected_type=type_hints["gradient_offset"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument data_value", value=data_value, expected_type=type_hints["data_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "gradient_offset": gradient_offset,
            }
            if color is not None:
                self._values["color"] = color
            if data_value is not None:
                self._values["data_value"] = data_value

        @builtins.property
        def gradient_offset(self) -> jsii.Number:
            '''Determines gradient offset value.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientstop.html#cfn-quicksight-analysis-gradientstop-gradientoffset
            '''
            result = self._values.get("gradient_offset")
            assert result is not None, "Required property 'gradient_offset' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientstop.html#cfn-quicksight-analysis-gradientstop-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_value(self) -> typing.Optional[jsii.Number]:
            '''Determines the data value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientstop.html#cfn-quicksight-analysis-gradientstop-datavalue
            '''
            result = self._values.get("data_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GradientStopProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"screen_canvas_size_options": "screenCanvasSizeOptions"},
    )
    class GridLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            screen_canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Configuration options for the canvas of a grid layout.

            :param screen_canvas_size_options: The options that determine the sizing of the canvas used in a grid layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                grid_layout_canvas_size_options_property = quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                    screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                        resize_option="resizeOption",
                
                        # the properties below are optional
                        optimized_view_port_width="optimizedViewPortWidth"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9032999c1d5c23a20c178ae6a0ea418c966b47c69e7e38db22e981a9eec9dfb9)
                check_type(argname="argument screen_canvas_size_options", value=screen_canvas_size_options, expected_type=type_hints["screen_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if screen_canvas_size_options is not None:
                self._values["screen_canvas_size_options"] = screen_canvas_size_options

        @builtins.property
        def screen_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty"]]:
            '''The options that determine the sizing of the canvas used in a grid layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutcanvassizeoptions.html#cfn-quicksight-analysis-gridlayoutcanvassizeoptions-screencanvassizeoptions
            '''
            result = self._values.get("screen_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GridLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "elements": "elements",
            "canvas_size_options": "canvasSizeOptions",
        },
    )
    class GridLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GridLayoutElementProperty", typing.Dict[builtins.str, typing.Any]]]]],
            canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GridLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a grid layout. Also called a tiled layout.

            Visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size.

            :param elements: The elements that are included in a grid layout.
            :param canvas_size_options: 

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                grid_layout_configuration_property = quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                    elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                        column_span=123,
                        element_id="elementId",
                        element_type="elementType",
                        row_span=123,
                
                        # the properties below are optional
                        column_index=123,
                        row_index=123
                    )],
                
                    # the properties below are optional
                    canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                            resize_option="resizeOption",
                
                            # the properties below are optional
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fde6163e0ef9c8dd6175bd498780f77956152c35734dc1dc27dcbefdd08a7ec4)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }
            if canvas_size_options is not None:
                self._values["canvas_size_options"] = canvas_size_options

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GridLayoutElementProperty"]]]:
            '''The elements that are included in a grid layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutconfiguration.html#cfn-quicksight-analysis-gridlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GridLayoutElementProperty"]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GridLayoutCanvasSizeOptionsProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutconfiguration.html#cfn-quicksight-analysis-gridlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GridLayoutCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GridLayoutElementProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_span": "columnSpan",
            "element_id": "elementId",
            "element_type": "elementType",
            "row_span": "rowSpan",
            "column_index": "columnIndex",
            "row_index": "rowIndex",
        },
    )
    class GridLayoutElementProperty:
        def __init__(
            self,
            *,
            column_span: jsii.Number,
            element_id: builtins.str,
            element_type: builtins.str,
            row_span: jsii.Number,
            column_index: typing.Optional[jsii.Number] = None,
            row_index: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''An element within a grid layout.

            :param column_span: The width of a grid element expressed as a number of grid columns.
            :param element_id: A unique identifier for an element within a grid layout.
            :param element_type: The type of element.
            :param row_span: The height of a grid element expressed as a number of grid rows.
            :param column_index: The column index for the upper left corner of an element.
            :param row_index: The row index for the upper left corner of an element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                grid_layout_element_property = quicksight.CfnAnalysis.GridLayoutElementProperty(
                    column_span=123,
                    element_id="elementId",
                    element_type="elementType",
                    row_span=123,
                
                    # the properties below are optional
                    column_index=123,
                    row_index=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__307481ce8409315cf6663d7274d00b4e65eb0d0f6bc8595d43345f711f024373)
                check_type(argname="argument column_span", value=column_span, expected_type=type_hints["column_span"])
                check_type(argname="argument element_id", value=element_id, expected_type=type_hints["element_id"])
                check_type(argname="argument element_type", value=element_type, expected_type=type_hints["element_type"])
                check_type(argname="argument row_span", value=row_span, expected_type=type_hints["row_span"])
                check_type(argname="argument column_index", value=column_index, expected_type=type_hints["column_index"])
                check_type(argname="argument row_index", value=row_index, expected_type=type_hints["row_index"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_span": column_span,
                "element_id": element_id,
                "element_type": element_type,
                "row_span": row_span,
            }
            if column_index is not None:
                self._values["column_index"] = column_index
            if row_index is not None:
                self._values["row_index"] = row_index

        @builtins.property
        def column_span(self) -> jsii.Number:
            '''The width of a grid element expressed as a number of grid columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-columnspan
            '''
            result = self._values.get("column_span")
            assert result is not None, "Required property 'column_span' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def element_id(self) -> builtins.str:
            '''A unique identifier for an element within a grid layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-elementid
            '''
            result = self._values.get("element_id")
            assert result is not None, "Required property 'element_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element_type(self) -> builtins.str:
            '''The type of element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-elementtype
            '''
            result = self._values.get("element_type")
            assert result is not None, "Required property 'element_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def row_span(self) -> jsii.Number:
            '''The height of a grid element expressed as a number of grid rows.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-rowspan
            '''
            result = self._values.get("row_span")
            assert result is not None, "Required property 'row_span' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def column_index(self) -> typing.Optional[jsii.Number]:
            '''The column index for the upper left corner of an element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-columnindex
            '''
            result = self._values.get("column_index")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def row_index(self) -> typing.Optional[jsii.Number]:
            '''The row index for the upper left corner of an element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-rowindex
            '''
            result = self._values.get("row_index")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutElementProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "resize_option": "resizeOption",
            "optimized_view_port_width": "optimizedViewPortWidth",
        },
    )
    class GridLayoutScreenCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            resize_option: builtins.str,
            optimized_view_port_width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the sizing of the canvas used in a grid layout.

            :param resize_option: This value determines the layout behavior when the viewport is resized. - ``FIXED`` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called ``Classic`` . - ``RESPONSIVE`` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called ``Tiled`` .
            :param optimized_view_port_width: The width that the view port will be optimized for when the layout renders.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutscreencanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                grid_layout_screen_canvas_size_options_property = quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                    resize_option="resizeOption",
                
                    # the properties below are optional
                    optimized_view_port_width="optimizedViewPortWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__221750db38bb8676e3648a48a1c5cc108d0d3b29458039df5cfe92100370ce38)
                check_type(argname="argument resize_option", value=resize_option, expected_type=type_hints["resize_option"])
                check_type(argname="argument optimized_view_port_width", value=optimized_view_port_width, expected_type=type_hints["optimized_view_port_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "resize_option": resize_option,
            }
            if optimized_view_port_width is not None:
                self._values["optimized_view_port_width"] = optimized_view_port_width

        @builtins.property
        def resize_option(self) -> builtins.str:
            '''This value determines the layout behavior when the viewport is resized.

            - ``FIXED`` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called ``Classic`` .
            - ``RESPONSIVE`` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called ``Tiled`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-analysis-gridlayoutscreencanvassizeoptions-resizeoption
            '''
            result = self._values.get("resize_option")
            assert result is not None, "Required property 'resize_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def optimized_view_port_width(self) -> typing.Optional[builtins.str]:
            '''The width that the view port will be optimized for when the layout renders.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-analysis-gridlayoutscreencanvassizeoptions-optimizedviewportwidth
            '''
            result = self._values.get("optimized_view_port_width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutScreenCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.GrowthRateComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "name": "name",
            "period_size": "periodSize",
            "time": "time",
            "value": "value",
        },
    )
    class GrowthRateComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            name: typing.Optional[builtins.str] = None,
            period_size: typing.Optional[jsii.Number] = None,
            time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The growth rate computation configuration.

            :param computation_id: The ID for a computation.
            :param name: The name of a computation.
            :param period_size: The period size setup of a growth rate computation. Default: - 0
            :param time: The time field that is used in a computation.
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                growth_rate_computation_property = quicksight.CfnAnalysis.GrowthRateComputationProperty(
                    computation_id="computationId",
                
                    # the properties below are optional
                    name="name",
                    period_size=123,
                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ba3a1d3fae573c9d9556225f15a510102810b06ed491a8765e3fad28f9ed47bd)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument period_size", value=period_size, expected_type=type_hints["period_size"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
            }
            if name is not None:
                self._values["name"] = name
            if period_size is not None:
                self._values["period_size"] = period_size
            if time is not None:
                self._values["time"] = time
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def period_size(self) -> typing.Optional[jsii.Number]:
            '''The period size setup of a growth rate computation.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-periodsize
            '''
            result = self._values.get("period_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]:
            '''The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-time
            '''
            result = self._values.get("time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GrowthRateComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"layout": "layout", "section_id": "sectionId", "style": "style"},
    )
    class HeaderFooterSectionConfigurationProperty:
        def __init__(
            self,
            *,
            layout: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            section_id: builtins.str,
            style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SectionStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a header or footer section.

            :param layout: The layout configuration of the header or footer section.
            :param section_id: The unique identifier of the header or footer section.
            :param style: The style options of a header or footer section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-headerfootersectionconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                header_footer_section_configuration_property = quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                    layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                            elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )]
                        )
                    ),
                    section_id="sectionId",
                
                    # the properties below are optional
                    style=quicksight.CfnAnalysis.SectionStyleProperty(
                        height="height",
                        padding=quicksight.CfnAnalysis.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__35fc4e97fb490a88b80fcd818812b0805d66bda99cf40754fae7d8891edf0465)
                check_type(argname="argument layout", value=layout, expected_type=type_hints["layout"])
                check_type(argname="argument section_id", value=section_id, expected_type=type_hints["section_id"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "layout": layout,
                "section_id": section_id,
            }
            if style is not None:
                self._values["style"] = style

        @builtins.property
        def layout(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SectionLayoutConfigurationProperty"]:
            '''The layout configuration of the header or footer section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-headerfootersectionconfiguration.html#cfn-quicksight-analysis-headerfootersectionconfiguration-layout
            '''
            result = self._values.get("layout")
            assert result is not None, "Required property 'layout' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SectionLayoutConfigurationProperty"], result)

        @builtins.property
        def section_id(self) -> builtins.str:
            '''The unique identifier of the header or footer section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-headerfootersectionconfiguration.html#cfn-quicksight-analysis-headerfootersectionconfiguration-sectionid
            '''
            result = self._values.get("section_id")
            assert result is not None, "Required property 'section_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SectionStyleProperty"]]:
            '''The style options of a header or footer section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-headerfootersectionconfiguration.html#cfn-quicksight-analysis-headerfootersectionconfiguration-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SectionStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeaderFooterSectionConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.HeatMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns", "rows": "rows", "values": "values"},
    )
    class HeatMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            columns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            rows: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a heat map.

            :param columns: The columns field well of a heat map.
            :param rows: The rows field well of a heat map.
            :param values: The values field well of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aeb3ce7bbd15d1a2dfa8706acb5ac470849c443e00789d502870a865bfbcb347)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument rows", value=rows, expected_type=type_hints["rows"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if columns is not None:
                self._values["columns"] = columns
            if rows is not None:
                self._values["rows"] = rows
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def columns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The columns field well of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapaggregatedfieldwells.html#cfn-quicksight-analysis-heatmapaggregatedfieldwells-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def rows(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The rows field well of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapaggregatedfieldwells.html#cfn-quicksight-analysis-heatmapaggregatedfieldwells-rows
            '''
            result = self._values.get("rows")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The values field well of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapaggregatedfieldwells.html#cfn-quicksight-analysis-heatmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.HeatMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_scale": "colorScale",
            "column_label_options": "columnLabelOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "row_label_options": "rowLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
        },
    )
    class HeatMapConfigurationProperty:
        def __init__(
            self,
            *,
            color_scale: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColorScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.HeatMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.HeatMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a heat map.

            :param color_scale: The color options (gradient color, point of divergence) in a heat map.
            :param column_label_options: The label options of the column that is displayed in a heat map.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param row_label_options: The label options of the row that is displayed in a ``heat map`` .
            :param sort_configuration: The sort configuration of a heat map.
            :param tooltip: The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__949b7ee985e07924144c5df8e37b24bba5628cbf367269af4925c9846e69b555)
                check_type(argname="argument color_scale", value=color_scale, expected_type=type_hints["color_scale"])
                check_type(argname="argument column_label_options", value=column_label_options, expected_type=type_hints["column_label_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument row_label_options", value=row_label_options, expected_type=type_hints["row_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color_scale is not None:
                self._values["color_scale"] = color_scale
            if column_label_options is not None:
                self._values["column_label_options"] = column_label_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if row_label_options is not None:
                self._values["row_label_options"] = row_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip

        @builtins.property
        def color_scale(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColorScaleProperty"]]:
            '''The color options (gradient color, point of divergence) in a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-colorscale
            '''
            result = self._values.get("color_scale")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColorScaleProperty"]], result)

        @builtins.property
        def column_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the column that is displayed in a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-columnlabeloptions
            '''
            result = self._values.get("column_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HeatMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HeatMapFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def row_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the row that is displayed in a ``heat map`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-rowlabeloptions
            '''
            result = self._values.get("row_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HeatMapSortConfigurationProperty"]]:
            '''The sort configuration of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HeatMapSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.HeatMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "heat_map_aggregated_field_wells": "heatMapAggregatedFieldWells",
        },
    )
    class HeatMapFieldWellsProperty:
        def __init__(
            self,
            *,
            heat_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.HeatMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a heat map.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param heat_map_aggregated_field_wells: The aggregated field wells of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3300b757c8e6e50e090686798cce09a8cc9ebb6a6bd46f7e6d686ff74f942442)
                check_type(argname="argument heat_map_aggregated_field_wells", value=heat_map_aggregated_field_wells, expected_type=type_hints["heat_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if heat_map_aggregated_field_wells is not None:
                self._values["heat_map_aggregated_field_wells"] = heat_map_aggregated_field_wells

        @builtins.property
        def heat_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HeatMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapfieldwells.html#cfn-quicksight-analysis-heatmapfieldwells-heatmapaggregatedfieldwells
            '''
            result = self._values.get("heat_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HeatMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.HeatMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "heat_map_column_items_limit_configuration": "heatMapColumnItemsLimitConfiguration",
            "heat_map_column_sort": "heatMapColumnSort",
            "heat_map_row_items_limit_configuration": "heatMapRowItemsLimitConfiguration",
            "heat_map_row_sort": "heatMapRowSort",
        },
    )
    class HeatMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            heat_map_column_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            heat_map_column_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            heat_map_row_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            heat_map_row_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a heat map.

            :param heat_map_column_items_limit_configuration: The limit on the number of columns that are displayed in a heat map.
            :param heat_map_column_sort: The column sort configuration for heat map for columns that aren't a part of a field well.
            :param heat_map_row_items_limit_configuration: The limit on the number of rows that are displayed in a heat map.
            :param heat_map_row_sort: The field sort configuration of the rows fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                heat_map_sort_configuration_property = quicksight.CfnAnalysis.HeatMapSortConfigurationProperty(
                    heat_map_column_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    heat_map_column_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    heat_map_row_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    heat_map_row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4944be76fc7bcb2cc426caeae1cac5134fe30802b90c87dcdd9ebb9bf00a246e)
                check_type(argname="argument heat_map_column_items_limit_configuration", value=heat_map_column_items_limit_configuration, expected_type=type_hints["heat_map_column_items_limit_configuration"])
                check_type(argname="argument heat_map_column_sort", value=heat_map_column_sort, expected_type=type_hints["heat_map_column_sort"])
                check_type(argname="argument heat_map_row_items_limit_configuration", value=heat_map_row_items_limit_configuration, expected_type=type_hints["heat_map_row_items_limit_configuration"])
                check_type(argname="argument heat_map_row_sort", value=heat_map_row_sort, expected_type=type_hints["heat_map_row_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if heat_map_column_items_limit_configuration is not None:
                self._values["heat_map_column_items_limit_configuration"] = heat_map_column_items_limit_configuration
            if heat_map_column_sort is not None:
                self._values["heat_map_column_sort"] = heat_map_column_sort
            if heat_map_row_items_limit_configuration is not None:
                self._values["heat_map_row_items_limit_configuration"] = heat_map_row_items_limit_configuration
            if heat_map_row_sort is not None:
                self._values["heat_map_row_sort"] = heat_map_row_sort

        @builtins.property
        def heat_map_column_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of columns that are displayed in a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html#cfn-quicksight-analysis-heatmapsortconfiguration-heatmapcolumnitemslimitconfiguration
            '''
            result = self._values.get("heat_map_column_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def heat_map_column_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The column sort configuration for heat map for columns that aren't a part of a field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html#cfn-quicksight-analysis-heatmapsortconfiguration-heatmapcolumnsort
            '''
            result = self._values.get("heat_map_column_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def heat_map_row_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of rows that are displayed in a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html#cfn-quicksight-analysis-heatmapsortconfiguration-heatmaprowitemslimitconfiguration
            '''
            result = self._values.get("heat_map_row_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def heat_map_row_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The field sort configuration of the rows fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html#cfn-quicksight-analysis-heatmapsortconfiguration-heatmaprowsort
            '''
            result = self._values.get("heat_map_row_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.HeatMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class HeatMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.HeatMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A heat map.

            For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a heat map.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e923cce50a7350257179452cc78b6089af9611cfbaff594980761a3911f45b86)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HeatMapConfigurationProperty"]]:
            '''The configuration of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HeatMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class HistogramAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a histogram.

            :param values: The value field wells of a histogram. Values are aggregated by ``COUNT`` or ``DISTINCT_COUNT`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                histogram_aggregated_field_wells_property = quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty(
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__74130651daf0ff3d0f9179df3cfa23ca1d80c9f7f98dba04a6eb3dd0234169bc)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The value field wells of a histogram.

            Values are aggregated by ``COUNT`` or ``DISTINCT_COUNT`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramaggregatedfieldwells.html#cfn-quicksight-analysis-histogramaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.HistogramBinOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bin_count": "binCount",
            "bin_width": "binWidth",
            "selected_bin_type": "selectedBinType",
            "start_value": "startValue",
        },
    )
    class HistogramBinOptionsProperty:
        def __init__(
            self,
            *,
            bin_count: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.BinCountOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            bin_width: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.BinWidthOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selected_bin_type: typing.Optional[builtins.str] = None,
            start_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The options that determine the presentation of histogram bins.

            :param bin_count: The options that determine the bin count of a histogram.
            :param bin_width: The options that determine the bin width of a histogram.
            :param selected_bin_type: The options that determine the selected bin type.
            :param start_value: The options that determine the bin start value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                histogram_bin_options_property = quicksight.CfnAnalysis.HistogramBinOptionsProperty(
                    bin_count=quicksight.CfnAnalysis.BinCountOptionsProperty(
                        value=123
                    ),
                    bin_width=quicksight.CfnAnalysis.BinWidthOptionsProperty(
                        bin_count_limit=123,
                        value=123
                    ),
                    selected_bin_type="selectedBinType",
                    start_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c4ae0c269410b7cca139ecef4fbf1458d675742c259682c6b6f9c33460bab271)
                check_type(argname="argument bin_count", value=bin_count, expected_type=type_hints["bin_count"])
                check_type(argname="argument bin_width", value=bin_width, expected_type=type_hints["bin_width"])
                check_type(argname="argument selected_bin_type", value=selected_bin_type, expected_type=type_hints["selected_bin_type"])
                check_type(argname="argument start_value", value=start_value, expected_type=type_hints["start_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_count is not None:
                self._values["bin_count"] = bin_count
            if bin_width is not None:
                self._values["bin_width"] = bin_width
            if selected_bin_type is not None:
                self._values["selected_bin_type"] = selected_bin_type
            if start_value is not None:
                self._values["start_value"] = start_value

        @builtins.property
        def bin_count(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BinCountOptionsProperty"]]:
            '''The options that determine the bin count of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html#cfn-quicksight-analysis-histogrambinoptions-bincount
            '''
            result = self._values.get("bin_count")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BinCountOptionsProperty"]], result)

        @builtins.property
        def bin_width(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BinWidthOptionsProperty"]]:
            '''The options that determine the bin width of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html#cfn-quicksight-analysis-histogrambinoptions-binwidth
            '''
            result = self._values.get("bin_width")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BinWidthOptionsProperty"]], result)

        @builtins.property
        def selected_bin_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the selected bin type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html#cfn-quicksight-analysis-histogrambinoptions-selectedbintype
            '''
            result = self._values.get("selected_bin_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def start_value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin start value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html#cfn-quicksight-analysis-histogrambinoptions-startvalue
            '''
            result = self._values.get("start_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramBinOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.HistogramConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bin_options": "binOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
            "y_axis_display_options": "yAxisDisplayOptions",
        },
    )
    class HistogramConfigurationProperty:
        def __init__(
            self,
            *,
            bin_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.HistogramBinOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.HistogramFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``HistogramVisual`` .

            :param bin_options: The options that determine the presentation of histogram bins.
            :param data_labels: The data label configuration of a histogram.
            :param field_wells: The field well configuration of a histogram.
            :param tooltip: The tooltip configuration of a histogram.
            :param visual_palette: The visual palette configuration of a histogram.
            :param x_axis_display_options: The options that determine the presentation of the x-axis.
            :param x_axis_label_options: The options that determine the presentation of the x-axis label.
            :param y_axis_display_options: The options that determine the presentation of the y-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6dd1f42f6ea90a578204ceb138560811902ee27d218128f302a027eb5136062d)
                check_type(argname="argument bin_options", value=bin_options, expected_type=type_hints["bin_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
                check_type(argname="argument y_axis_display_options", value=y_axis_display_options, expected_type=type_hints["y_axis_display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_options is not None:
                self._values["bin_options"] = bin_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options
            if y_axis_display_options is not None:
                self._values["y_axis_display_options"] = y_axis_display_options

        @builtins.property
        def bin_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HistogramBinOptionsProperty"]]:
            '''The options that determine the presentation of histogram bins.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-binoptions
            '''
            result = self._values.get("bin_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HistogramBinOptionsProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The data label configuration of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HistogramFieldWellsProperty"]]:
            '''The field well configuration of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HistogramFieldWellsProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The visual palette configuration of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-yaxisdisplayoptions
            '''
            result = self._values.get("y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.HistogramFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "histogram_aggregated_field_wells": "histogramAggregatedFieldWells",
        },
    )
    class HistogramFieldWellsProperty:
        def __init__(
            self,
            *,
            histogram_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.HistogramAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a histogram.

            :param histogram_aggregated_field_wells: The field well configuration of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                histogram_field_wells_property = quicksight.CfnAnalysis.HistogramFieldWellsProperty(
                    histogram_aggregated_field_wells=quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty(
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__93a58fe1aec089289e51347f4e2f15663a5ef0b83ddd44b4a1716fbb42c19c2f)
                check_type(argname="argument histogram_aggregated_field_wells", value=histogram_aggregated_field_wells, expected_type=type_hints["histogram_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if histogram_aggregated_field_wells is not None:
                self._values["histogram_aggregated_field_wells"] = histogram_aggregated_field_wells

        @builtins.property
        def histogram_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HistogramAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramfieldwells.html#cfn-quicksight-analysis-histogramfieldwells-histogramaggregatedfieldwells
            '''
            result = self._values.get("histogram_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HistogramAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.HistogramVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class HistogramVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.HistogramConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A histogram.

            For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration for a ``HistogramVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9b9d5c9507d3323958409c1c9d4a9fb9fddaca4d0d02309f8baf8d0df465dbd8)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HistogramConfigurationProperty"]]:
            '''The configuration for a ``HistogramVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HistogramConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.InsightConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computations": "computations",
            "custom_narrative": "customNarrative",
        },
    )
    class InsightConfigurationProperty:
        def __init__(
            self,
            *,
            computations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ComputationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            custom_narrative: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CustomNarrativeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of an insight visual.

            :param computations: The computations configurations of the insight visual.
            :param custom_narrative: The custom narrative of the insight visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3b1f4686e9a6b17ff8f88eae015d754bae635d12717476852207d861895839dc)
                check_type(argname="argument computations", value=computations, expected_type=type_hints["computations"])
                check_type(argname="argument custom_narrative", value=custom_narrative, expected_type=type_hints["custom_narrative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if computations is not None:
                self._values["computations"] = computations
            if custom_narrative is not None:
                self._values["custom_narrative"] = custom_narrative

        @builtins.property
        def computations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ComputationProperty"]]]]:
            '''The computations configurations of the insight visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightconfiguration.html#cfn-quicksight-analysis-insightconfiguration-computations
            '''
            result = self._values.get("computations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ComputationProperty"]]]], result)

        @builtins.property
        def custom_narrative(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomNarrativeOptionsProperty"]]:
            '''The custom narrative of the insight visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightconfiguration.html#cfn-quicksight-analysis-insightconfiguration-customnarrative
            '''
            result = self._values.get("custom_narrative")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomNarrativeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "InsightConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.InsightVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
            "insight_configuration": "insightConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class InsightVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            insight_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.InsightConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''An insight visual.

            For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .

            :param data_set_identifier: The dataset that is used in the insight visual.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param insight_configuration: The configuration of an insight visual.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__254ef8f13eadc2eb0c8c2650c71c7477803594d57b8261e9bd8939491d1edeef)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument insight_configuration", value=insight_configuration, expected_type=type_hints["insight_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if insight_configuration is not None:
                self._values["insight_configuration"] = insight_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The dataset that is used in the insight visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def insight_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.InsightConfigurationProperty"]]:
            '''The configuration of an insight visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-insightconfiguration
            '''
            result = self._values.get("insight_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.InsightConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "InsightVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.IntegerDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class IntegerDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
        ) -> None:
            '''The default values of the ``IntegerParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``IntegerDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``IntegerDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                integer_default_values_property = quicksight.CfnAnalysis.IntegerDefaultValuesProperty(
                    dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__df75ce26bb2c4132a288b64c361aa58aee8d1bd0275f7f70da125f2c1384667e)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``IntegerDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerdefaultvalues.html#cfn-quicksight-analysis-integerdefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def static_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]]:
            '''The static values of the ``IntegerDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerdefaultvalues.html#cfn-quicksight-analysis-integerdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.IntegerParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class IntegerParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.IntegerDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``Integer`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: 
            :param value_when_unset: A parameter declaration for the ``Integer`` data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                integer_parameter_declaration_property = quicksight.CfnAnalysis.IntegerParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnAnalysis.IntegerDefaultValuesProperty(
                        dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=[123]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty(
                        custom_value=123,
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c4e46f79877c1d5ea7200cce72e4cbb3bda41b536d11cb23aee669ec7505903d)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.IntegerDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.IntegerDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MappedDataSetParameterProperty"]]]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty"]]:
            '''A parameter declaration for the ``Integer`` data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.IntegerParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class IntegerParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]],
        ) -> None:
            '''An integer parameter.

            :param name: The name of the integer parameter.
            :param values: The values for the integer parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                integer_parameter_property = quicksight.CfnAnalysis.IntegerParameterProperty(
                    name="name",
                    values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a95b208567e290650bcc53e94792f3f667e4fc822766c0c7c77ba80c05129063)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the integer parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameter.html#cfn-quicksight-analysis-integerparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]:
            '''The values for the integer parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameter.html#cfn-quicksight-analysis-integerparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class IntegerValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[jsii.Number] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A parameter declaration for the ``Integer`` data type.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integervaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                integer_value_when_unset_configuration_property = quicksight.CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty(
                    custom_value=123,
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__13e33c685845db910a2cdb302f29c7dda9e37dd6927464bb7e458d04fc597d70)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[jsii.Number]:
            '''A custom value that's used when the value of a parameter isn't set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integervaluewhenunsetconfiguration.html#cfn-quicksight-analysis-integervaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integervaluewhenunsetconfiguration.html#cfn-quicksight-analysis-integervaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ItemsLimitConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "items_limit": "itemsLimit",
            "other_categories": "otherCategories",
        },
    )
    class ItemsLimitConfigurationProperty:
        def __init__(
            self,
            *,
            items_limit: typing.Optional[jsii.Number] = None,
            other_categories: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The limit configuration of the visual display for an axis.

            :param items_limit: The limit on how many items of a field are showed in the chart. For example, the number of slices that are displayed in a pie chart.
            :param other_categories: The ``Show other`` of an axis in the chart. Choose one of the following options:. - ``INCLUDE`` - ``EXCLUDE``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-itemslimitconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                items_limit_configuration_property = quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                    items_limit=123,
                    other_categories="otherCategories"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c7837f741338797d7b367bd8f818d5d6f2f733c9366fac33fba11eea113da7c4)
                check_type(argname="argument items_limit", value=items_limit, expected_type=type_hints["items_limit"])
                check_type(argname="argument other_categories", value=other_categories, expected_type=type_hints["other_categories"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if items_limit is not None:
                self._values["items_limit"] = items_limit
            if other_categories is not None:
                self._values["other_categories"] = other_categories

        @builtins.property
        def items_limit(self) -> typing.Optional[jsii.Number]:
            '''The limit on how many items of a field are showed in the chart.

            For example, the number of slices that are displayed in a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-itemslimitconfiguration.html#cfn-quicksight-analysis-itemslimitconfiguration-itemslimit
            '''
            result = self._values.get("items_limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def other_categories(self) -> typing.Optional[builtins.str]:
            '''The ``Show other`` of an axis in the chart. Choose one of the following options:.

            - ``INCLUDE``
            - ``EXCLUDE``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-itemslimitconfiguration.html#cfn-quicksight-analysis-itemslimitconfiguration-othercategories
            '''
            result = self._values.get("other_categories")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ItemsLimitConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.KPIActualValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class KPIActualValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the actual value of a KPI visual.

            :param icon: The conditional formatting of the actual value's icon.
            :param text_color: The conditional formatting of the actual value's text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiactualvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIActual_value_conditional_formatting_property = quicksight.CfnAnalysis.KPIActualValueConditionalFormattingProperty(
                    icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__62fd79d6d6b83de52fd9c66519b63f99afe25d2524c06723daaf72c4fcb8b997)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting of the actual value's icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiactualvalueconditionalformatting.html#cfn-quicksight-analysis-kpiactualvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the actual value's text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiactualvalueconditionalformatting.html#cfn-quicksight-analysis-kpiactualvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIActualValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.KPIComparisonValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class KPIComparisonValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the comparison value of a KPI visual.

            :param icon: The conditional formatting of the comparison value's icon.
            :param text_color: The conditional formatting of the comparison value's text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpicomparisonvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIComparison_value_conditional_formatting_property = quicksight.CfnAnalysis.KPIComparisonValueConditionalFormattingProperty(
                    icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fbd6a01397645828bcae2c115e1d8f217c81792121ff843ce7c7a98717d66bbd)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting of the comparison value's icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpicomparisonvalueconditionalformatting.html#cfn-quicksight-analysis-kpicomparisonvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the comparison value's text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpicomparisonvalueconditionalformatting.html#cfn-quicksight-analysis-kpicomparisonvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIComparisonValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.KPIConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "actual_value": "actualValue",
            "comparison_value": "comparisonValue",
            "primary_value": "primaryValue",
            "progress_bar": "progressBar",
        },
    )
    class KPIConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            actual_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.KPIActualValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            comparison_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.KPIComparisonValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            progress_bar: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.KPIProgressBarConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting options of a KPI visual.

            :param actual_value: The conditional formatting for the actual value of a KPI visual.
            :param comparison_value: The conditional formatting for the comparison value of a KPI visual.
            :param primary_value: The conditional formatting for the primary value of a KPI visual.
            :param progress_bar: The conditional formatting for the progress bar of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIConditional_formatting_option_property = quicksight.CfnAnalysis.KPIConditionalFormattingOptionProperty(
                    actual_value=quicksight.CfnAnalysis.KPIActualValueConditionalFormattingProperty(
                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    comparison_value=quicksight.CfnAnalysis.KPIComparisonValueConditionalFormattingProperty(
                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    primary_value=quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty(
                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    progress_bar=quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty(
                        foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c47a8a963b224d51f9eebe235dee2686c303a35b7bb953424d4470373ae23c31)
                check_type(argname="argument actual_value", value=actual_value, expected_type=type_hints["actual_value"])
                check_type(argname="argument comparison_value", value=comparison_value, expected_type=type_hints["comparison_value"])
                check_type(argname="argument primary_value", value=primary_value, expected_type=type_hints["primary_value"])
                check_type(argname="argument progress_bar", value=progress_bar, expected_type=type_hints["progress_bar"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if actual_value is not None:
                self._values["actual_value"] = actual_value
            if comparison_value is not None:
                self._values["comparison_value"] = comparison_value
            if primary_value is not None:
                self._values["primary_value"] = primary_value
            if progress_bar is not None:
                self._values["progress_bar"] = progress_bar

        @builtins.property
        def actual_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIActualValueConditionalFormattingProperty"]]:
            '''The conditional formatting for the actual value of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformattingoption.html#cfn-quicksight-analysis-kpiconditionalformattingoption-actualvalue
            '''
            result = self._values.get("actual_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIActualValueConditionalFormattingProperty"]], result)

        @builtins.property
        def comparison_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIComparisonValueConditionalFormattingProperty"]]:
            '''The conditional formatting for the comparison value of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformattingoption.html#cfn-quicksight-analysis-kpiconditionalformattingoption-comparisonvalue
            '''
            result = self._values.get("comparison_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIComparisonValueConditionalFormattingProperty"]], result)

        @builtins.property
        def primary_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty"]]:
            '''The conditional formatting for the primary value of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformattingoption.html#cfn-quicksight-analysis-kpiconditionalformattingoption-primaryvalue
            '''
            result = self._values.get("primary_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty"]], result)

        @builtins.property
        def progress_bar(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIProgressBarConditionalFormattingProperty"]]:
            '''The conditional formatting for the progress bar of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformattingoption.html#cfn-quicksight-analysis-kpiconditionalformattingoption-progressbar
            '''
            result = self._values.get("progress_bar")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIProgressBarConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.KPIConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class KPIConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.KPIConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting of a KPI visual.

            :param conditional_formatting_options: The conditional formatting options of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIConditional_formatting_property = quicksight.CfnAnalysis.KPIConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnAnalysis.KPIConditionalFormattingOptionProperty(
                        actual_value=quicksight.CfnAnalysis.KPIActualValueConditionalFormattingProperty(
                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        comparison_value=quicksight.CfnAnalysis.KPIComparisonValueConditionalFormattingProperty(
                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        primary_value=quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty(
                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        progress_bar=quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty(
                            foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__093405de0b0ece6949aa37731977a76c567dde63c113f2b4cf6d1fde67890b15)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIConditionalFormattingOptionProperty"]]]]:
            '''The conditional formatting options of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformatting.html#cfn-quicksight-analysis-kpiconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.KPIConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "kpi_options": "kpiOptions",
            "sort_configuration": "sortConfiguration",
        },
    )
    class KPIConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.KPIFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            kpi_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.KPIOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.KPISortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a KPI visual.

            :param field_wells: The field well configuration of a KPI visual.
            :param kpi_options: The options that determine the presentation of a KPI visual.
            :param sort_configuration: The sort configuration of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b7347e7f7d3e790a3415bf9ae796ab09590ea8b172cb4b5232d8a04a1224e09c)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument kpi_options", value=kpi_options, expected_type=type_hints["kpi_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if kpi_options is not None:
                self._values["kpi_options"] = kpi_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIFieldWellsProperty"]]:
            '''The field well configuration of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconfiguration.html#cfn-quicksight-analysis-kpiconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIFieldWellsProperty"]], result)

        @builtins.property
        def kpi_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIOptionsProperty"]]:
            '''The options that determine the presentation of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconfiguration.html#cfn-quicksight-analysis-kpiconfiguration-kpioptions
            '''
            result = self._values.get("kpi_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPISortConfigurationProperty"]]:
            '''The sort configuration of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconfiguration.html#cfn-quicksight-analysis-kpiconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPISortConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.KPIFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "target_values": "targetValues",
            "trend_groups": "trendGroups",
            "values": "values",
        },
    )
    class KPIFieldWellsProperty:
        def __init__(
            self,
            *,
            target_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            trend_groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a KPI visual.

            :param target_values: The target value field wells of a KPI visual.
            :param trend_groups: The trend group field wells of a KPI visual.
            :param values: The value field wells of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpifieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f2ab3d1139c92a9534efac3fb34060891ab135e5d400b370632c9f4961718d65)
                check_type(argname="argument target_values", value=target_values, expected_type=type_hints["target_values"])
                check_type(argname="argument trend_groups", value=trend_groups, expected_type=type_hints["trend_groups"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_values is not None:
                self._values["target_values"] = target_values
            if trend_groups is not None:
                self._values["trend_groups"] = trend_groups
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def target_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The target value field wells of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpifieldwells.html#cfn-quicksight-analysis-kpifieldwells-targetvalues
            '''
            result = self._values.get("target_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        @builtins.property
        def trend_groups(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The trend group field wells of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpifieldwells.html#cfn-quicksight-analysis-kpifieldwells-trendgroups
            '''
            result = self._values.get("trend_groups")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The value field wells of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpifieldwells.html#cfn-quicksight-analysis-kpifieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.KPIOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "comparison": "comparison",
            "primary_value_display_type": "primaryValueDisplayType",
            "primary_value_font_configuration": "primaryValueFontConfiguration",
            "progress_bar": "progressBar",
            "secondary_value": "secondaryValue",
            "secondary_value_font_configuration": "secondaryValueFontConfiguration",
            "sparkline": "sparkline",
            "trend_arrows": "trendArrows",
            "visual_layout_options": "visualLayoutOptions",
        },
    )
    class KPIOptionsProperty:
        def __init__(
            self,
            *,
            comparison: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ComparisonConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_value_display_type: typing.Optional[builtins.str] = None,
            primary_value_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            progress_bar: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ProgressBarOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SecondaryValueOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_value_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sparkline: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.KPISparklineOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            trend_arrows: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TrendArrowOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_layout_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.KPIVisualLayoutOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of a KPI visual.

            :param comparison: The comparison configuration of a KPI visual.
            :param primary_value_display_type: The options that determine the primary value display type.
            :param primary_value_font_configuration: The options that determine the primary value font configuration.
            :param progress_bar: The options that determine the presentation of the progress bar of a KPI visual.
            :param secondary_value: The options that determine the presentation of the secondary value of a KPI visual.
            :param secondary_value_font_configuration: The options that determine the secondary value font configuration.
            :param sparkline: The options that determine the visibility, color, type, and tooltip visibility of the sparkline of a KPI visual.
            :param trend_arrows: The options that determine the presentation of trend arrows in a KPI visual.
            :param visual_layout_options: The options that determine the layout a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIOptions_property = quicksight.CfnAnalysis.KPIOptionsProperty(
                    comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                        comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        comparison_method="comparisonMethod"
                    ),
                    primary_value_display_type="primaryValueDisplayType",
                    primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    progress_bar=quicksight.CfnAnalysis.ProgressBarOptionsProperty(
                        visibility="visibility"
                    ),
                    secondary_value=quicksight.CfnAnalysis.SecondaryValueOptionsProperty(
                        visibility="visibility"
                    ),
                    secondary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    sparkline=quicksight.CfnAnalysis.KPISparklineOptionsProperty(
                        type="type",
                
                        # the properties below are optional
                        color="color",
                        tooltip_visibility="tooltipVisibility",
                        visibility="visibility"
                    ),
                    trend_arrows=quicksight.CfnAnalysis.TrendArrowOptionsProperty(
                        visibility="visibility"
                    ),
                    visual_layout_options=quicksight.CfnAnalysis.KPIVisualLayoutOptionsProperty(
                        standard_layout=quicksight.CfnAnalysis.KPIVisualStandardLayoutProperty(
                            type="type"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__14494fc1848bd55db71c296019baf22f78b5e68a3679d356c04f82b341453996)
                check_type(argname="argument comparison", value=comparison, expected_type=type_hints["comparison"])
                check_type(argname="argument primary_value_display_type", value=primary_value_display_type, expected_type=type_hints["primary_value_display_type"])
                check_type(argname="argument primary_value_font_configuration", value=primary_value_font_configuration, expected_type=type_hints["primary_value_font_configuration"])
                check_type(argname="argument progress_bar", value=progress_bar, expected_type=type_hints["progress_bar"])
                check_type(argname="argument secondary_value", value=secondary_value, expected_type=type_hints["secondary_value"])
                check_type(argname="argument secondary_value_font_configuration", value=secondary_value_font_configuration, expected_type=type_hints["secondary_value_font_configuration"])
                check_type(argname="argument sparkline", value=sparkline, expected_type=type_hints["sparkline"])
                check_type(argname="argument trend_arrows", value=trend_arrows, expected_type=type_hints["trend_arrows"])
                check_type(argname="argument visual_layout_options", value=visual_layout_options, expected_type=type_hints["visual_layout_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if comparison is not None:
                self._values["comparison"] = comparison
            if primary_value_display_type is not None:
                self._values["primary_value_display_type"] = primary_value_display_type
            if primary_value_font_configuration is not None:
                self._values["primary_value_font_configuration"] = primary_value_font_configuration
            if progress_bar is not None:
                self._values["progress_bar"] = progress_bar
            if secondary_value is not None:
                self._values["secondary_value"] = secondary_value
            if secondary_value_font_configuration is not None:
                self._values["secondary_value_font_configuration"] = secondary_value_font_configuration
            if sparkline is not None:
                self._values["sparkline"] = sparkline
            if trend_arrows is not None:
                self._values["trend_arrows"] = trend_arrows
            if visual_layout_options is not None:
                self._values["visual_layout_options"] = visual_layout_options

        @builtins.property
        def comparison(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ComparisonConfigurationProperty"]]:
            '''The comparison configuration of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-comparison
            '''
            result = self._values.get("comparison")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ComparisonConfigurationProperty"]], result)

        @builtins.property
        def primary_value_display_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the primary value display type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-primaryvaluedisplaytype
            '''
            result = self._values.get("primary_value_display_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"]]:
            '''The options that determine the primary value font configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-primaryvaluefontconfiguration
            '''
            result = self._values.get("primary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"]], result)

        @builtins.property
        def progress_bar(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ProgressBarOptionsProperty"]]:
            '''The options that determine the presentation of the progress bar of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-progressbar
            '''
            result = self._values.get("progress_bar")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ProgressBarOptionsProperty"]], result)

        @builtins.property
        def secondary_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SecondaryValueOptionsProperty"]]:
            '''The options that determine the presentation of the secondary value of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-secondaryvalue
            '''
            result = self._values.get("secondary_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SecondaryValueOptionsProperty"]], result)

        @builtins.property
        def secondary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"]]:
            '''The options that determine the secondary value font configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-secondaryvaluefontconfiguration
            '''
            result = self._values.get("secondary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"]], result)

        @builtins.property
        def sparkline(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPISparklineOptionsProperty"]]:
            '''The options that determine the visibility, color, type, and tooltip visibility of the sparkline of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-sparkline
            '''
            result = self._values.get("sparkline")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPISparklineOptionsProperty"]], result)

        @builtins.property
        def trend_arrows(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TrendArrowOptionsProperty"]]:
            '''The options that determine the presentation of trend arrows in a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-trendarrows
            '''
            result = self._values.get("trend_arrows")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TrendArrowOptionsProperty"]], result)

        @builtins.property
        def visual_layout_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIVisualLayoutOptionsProperty"]]:
            '''The options that determine the layout a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-visuallayoutoptions
            '''
            result = self._values.get("visual_layout_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIVisualLayoutOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class KPIPrimaryValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the primary value of a KPI visual.

            :param icon: The conditional formatting of the primary value's icon.
            :param text_color: The conditional formatting of the primary value's text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprimaryvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIPrimary_value_conditional_formatting_property = quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty(
                    icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dda5b2471fce86de1f1bd82ecf7f9238e5c42052d573d16257139b9739a9e972)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting of the primary value's icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-analysis-kpiprimaryvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the primary value's text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-analysis-kpiprimaryvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIPrimaryValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"foreground_color": "foregroundColor"},
    )
    class KPIProgressBarConditionalFormattingProperty:
        def __init__(
            self,
            *,
            foreground_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the progress bar of a KPI visual.

            :param foreground_color: The conditional formatting of the progress bar's foreground color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprogressbarconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIProgress_bar_conditional_formatting_property = quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty(
                    foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0e03285437fef32f601a5efd046f8046ff96be24d19819f31f01d45934510eda)
                check_type(argname="argument foreground_color", value=foreground_color, expected_type=type_hints["foreground_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if foreground_color is not None:
                self._values["foreground_color"] = foreground_color

        @builtins.property
        def foreground_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the progress bar's foreground color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprogressbarconditionalformatting.html#cfn-quicksight-analysis-kpiprogressbarconditionalformatting-foregroundcolor
            '''
            result = self._values.get("foreground_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIProgressBarConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.KPISortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"trend_group_sort": "trendGroupSort"},
    )
    class KPISortConfigurationProperty:
        def __init__(
            self,
            *,
            trend_group_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a KPI visual.

            :param trend_group_sort: The sort configuration of the trend group fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpisortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pISort_configuration_property = quicksight.CfnAnalysis.KPISortConfigurationProperty(
                    trend_group_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e93019a993ee84e58e6d870f4d5ee82c10125c910ab2214510a26d9b3c471fed)
                check_type(argname="argument trend_group_sort", value=trend_group_sort, expected_type=type_hints["trend_group_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if trend_group_sort is not None:
                self._values["trend_group_sort"] = trend_group_sort

        @builtins.property
        def trend_group_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the trend group fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpisortconfiguration.html#cfn-quicksight-analysis-kpisortconfiguration-trendgroupsort
            '''
            result = self._values.get("trend_group_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPISortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.KPISparklineOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "type": "type",
            "color": "color",
            "tooltip_visibility": "tooltipVisibility",
            "visibility": "visibility",
        },
    )
    class KPISparklineOptionsProperty:
        def __init__(
            self,
            *,
            type: builtins.str,
            color: typing.Optional[builtins.str] = None,
            tooltip_visibility: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the visibility, color, type, and tooltip visibility of the sparkline of a KPI visual.

            :param type: The type of the sparkline.
            :param color: The color of the sparkline.
            :param tooltip_visibility: The tooltip visibility of the sparkline.
            :param visibility: The visibility of the sparkline.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpisparklineoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pISparkline_options_property = quicksight.CfnAnalysis.KPISparklineOptionsProperty(
                    type="type",
                
                    # the properties below are optional
                    color="color",
                    tooltip_visibility="tooltipVisibility",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3be4495469d6e19fe8ef384eec06f1df885d3447466904ecdffe0f7ac2355ebd)
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument tooltip_visibility", value=tooltip_visibility, expected_type=type_hints["tooltip_visibility"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "type": type,
            }
            if color is not None:
                self._values["color"] = color
            if tooltip_visibility is not None:
                self._values["tooltip_visibility"] = tooltip_visibility
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def type(self) -> builtins.str:
            '''The type of the sparkline.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpisparklineoptions.html#cfn-quicksight-analysis-kpisparklineoptions-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color of the sparkline.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpisparklineoptions.html#cfn-quicksight-analysis-kpisparklineoptions-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tooltip_visibility(self) -> typing.Optional[builtins.str]:
            '''The tooltip visibility of the sparkline.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpisparklineoptions.html#cfn-quicksight-analysis-kpisparklineoptions-tooltipvisibility
            '''
            result = self._values.get("tooltip_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the sparkline.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpisparklineoptions.html#cfn-quicksight-analysis-kpisparklineoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPISparklineOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.KPIVisualLayoutOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"standard_layout": "standardLayout"},
    )
    class KPIVisualLayoutOptionsProperty:
        def __init__(
            self,
            *,
            standard_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.KPIVisualStandardLayoutProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the layout a KPI visual.

            :param standard_layout: The standard layout of the KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisuallayoutoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIVisual_layout_options_property = quicksight.CfnAnalysis.KPIVisualLayoutOptionsProperty(
                    standard_layout=quicksight.CfnAnalysis.KPIVisualStandardLayoutProperty(
                        type="type"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__48fbce62cfa096a37c10afd1546006b403110253ae89f9ad8d55fc91cd7f6f30)
                check_type(argname="argument standard_layout", value=standard_layout, expected_type=type_hints["standard_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if standard_layout is not None:
                self._values["standard_layout"] = standard_layout

        @builtins.property
        def standard_layout(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIVisualStandardLayoutProperty"]]:
            '''The standard layout of the KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisuallayoutoptions.html#cfn-quicksight-analysis-kpivisuallayoutoptions-standardlayout
            '''
            result = self._values.get("standard_layout")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIVisualStandardLayoutProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIVisualLayoutOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.KPIVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class KPIVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.KPIConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.KPIConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A key performance indicator (KPI).

            For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a KPI visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param conditional_formatting: The conditional formatting of a KPI visual.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d5d36bea3f6023d9c8597cca3babeb32cbeb0db83e22f9d75ccda908876eee36)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIConfigurationProperty"]]:
            '''The configuration of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIConditionalFormattingProperty"]]:
            '''The conditional formatting of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.KPIVisualStandardLayoutProperty",
        jsii_struct_bases=[],
        name_mapping={"type": "type"},
    )
    class KPIVisualStandardLayoutProperty:
        def __init__(self, *, type: builtins.str) -> None:
            '''The standard layout of the KPI visual.

            :param type: The standard layout type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisualstandardlayout.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIVisual_standard_layout_property = quicksight.CfnAnalysis.KPIVisualStandardLayoutProperty(
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d68e110b12f2158f2717a768c70570e746f7d8a26d6352fb02468e589306879b)
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "type": type,
            }

        @builtins.property
        def type(self) -> builtins.str:
            '''The standard layout type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisualstandardlayout.html#cfn-quicksight-analysis-kpivisualstandardlayout-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIVisualStandardLayoutProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.LabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "font_configuration": "fontConfiguration",
            "visibility": "visibility",
        },
    )
    class LabelOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The share label options for the labels.

            :param custom_label: The text for the label.
            :param font_configuration: The font configuration of the label.
            :param visibility: Determines whether or not the label is visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-labeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                label_options_property = quicksight.CfnAnalysis.LabelOptionsProperty(
                    custom_label="customLabel",
                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__43cac7e826338cc7ef6b1274b75855f2c64aa3f565868ee802e58284861f9b22)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The text for the label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-labeloptions.html#cfn-quicksight-analysis-labeloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"]]:
            '''The font configuration of the label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-labeloptions.html#cfn-quicksight-analysis-labeloptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the label is visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-labeloptions.html#cfn-quicksight-analysis-labeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.LayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "free_form_layout": "freeFormLayout",
            "grid_layout": "gridLayout",
            "section_based_layout": "sectionBasedLayout",
        },
    )
    class LayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FreeFormLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            grid_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            section_based_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SectionBasedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration that determines what the type of layout will be used on a sheet.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param free_form_layout: A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.
            :param grid_layout: A type of layout that can be used on a sheet. In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: ``FIXED`` or ``RESPONSIVE`` .
            :param section_based_layout: A section based layout organizes visuals into multiple sections and has customized header, footer and page break.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                layout_configuration_property = quicksight.CfnAnalysis.LayoutConfigurationProperty(
                    free_form_layout=quicksight.CfnAnalysis.FreeFormLayoutConfigurationProperty(
                        elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                            element_id="elementId",
                            element_type="elementType",
                            height="height",
                            width="width",
                            x_axis_location="xAxisLocation",
                            y_axis_location="yAxisLocation",
                
                            # the properties below are optional
                            background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                visibility="visibility"
                            ),
                            rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                    visibility="visibility"
                                ),
                                expression="expression"
                            )],
                            selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            visibility="visibility"
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                        elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                            column_span=123,
                            element_id="elementId",
                            element_type="elementType",
                            row_span=123,
                
                            # the properties below are optional
                            column_index=123,
                            row_index=123
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    section_based_layout=quicksight.CfnAnalysis.SectionBasedLayoutConfigurationProperty(
                        body_sections=[quicksight.CfnAnalysis.BodySectionConfigurationProperty(
                            content=quicksight.CfnAnalysis.BodySectionContentProperty(
                                layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            page_break_configuration=quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                                after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                                    status="status"
                                )
                            ),
                            style=quicksight.CfnAnalysis.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnAnalysis.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )],
                        canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                            paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                ),
                                paper_orientation="paperOrientation",
                                paper_size="paperSize"
                            )
                        ),
                        footer_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                            layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            style=quicksight.CfnAnalysis.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnAnalysis.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )],
                        header_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                            layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            style=quicksight.CfnAnalysis.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnAnalysis.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__42b1d13e0d93684e8246d6f5cefcdf9b4d463c7b0c1a53be36ad708b74065fc2)
                check_type(argname="argument free_form_layout", value=free_form_layout, expected_type=type_hints["free_form_layout"])
                check_type(argname="argument grid_layout", value=grid_layout, expected_type=type_hints["grid_layout"])
                check_type(argname="argument section_based_layout", value=section_based_layout, expected_type=type_hints["section_based_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if free_form_layout is not None:
                self._values["free_form_layout"] = free_form_layout
            if grid_layout is not None:
                self._values["grid_layout"] = grid_layout
            if section_based_layout is not None:
                self._values["section_based_layout"] = section_based_layout

        @builtins.property
        def free_form_layout(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FreeFormLayoutConfigurationProperty"]]:
            '''A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layoutconfiguration.html#cfn-quicksight-analysis-layoutconfiguration-freeformlayout
            '''
            result = self._values.get("free_form_layout")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FreeFormLayoutConfigurationProperty"]], result)

        @builtins.property
        def grid_layout(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GridLayoutConfigurationProperty"]]:
            '''A type of layout that can be used on a sheet.

            In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: ``FIXED`` or ``RESPONSIVE`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layoutconfiguration.html#cfn-quicksight-analysis-layoutconfiguration-gridlayout
            '''
            result = self._values.get("grid_layout")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GridLayoutConfigurationProperty"]], result)

        @builtins.property
        def section_based_layout(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SectionBasedLayoutConfigurationProperty"]]:
            '''A section based layout organizes visuals into multiple sections and has customized header, footer and page break.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layoutconfiguration.html#cfn-quicksight-analysis-layoutconfiguration-sectionbasedlayout
            '''
            result = self._values.get("section_based_layout")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SectionBasedLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.LayoutProperty",
        jsii_struct_bases=[],
        name_mapping={"configuration": "configuration"},
    )
    class LayoutProperty:
        def __init__(
            self,
            *,
            configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''A ``Layout`` defines the placement of elements within a sheet.

            For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param configuration: The configuration that determines what the type of layout for a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layout.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                layout_property = quicksight.CfnAnalysis.LayoutProperty(
                    configuration=quicksight.CfnAnalysis.LayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnAnalysis.FreeFormLayoutConfigurationProperty(
                            elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                            elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                column_span=123,
                                element_id="elementId",
                                element_type="elementType",
                                row_span=123,
                
                                # the properties below are optional
                                column_index=123,
                                row_index=123
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        section_based_layout=quicksight.CfnAnalysis.SectionBasedLayoutConfigurationProperty(
                            body_sections=[quicksight.CfnAnalysis.BodySectionConfigurationProperty(
                                content=quicksight.CfnAnalysis.BodySectionContentProperty(
                                    layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
                
                                                # the properties below are optional
                                                background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                page_break_configuration=quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                                    after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                                        status="status"
                                    )
                                ),
                                style=quicksight.CfnAnalysis.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnAnalysis.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )],
                            canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                    paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    ),
                                    paper_orientation="paperOrientation",
                                    paper_size="paperSize"
                                )
                            ),
                            footer_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                style=quicksight.CfnAnalysis.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnAnalysis.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )],
                            header_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                style=quicksight.CfnAnalysis.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnAnalysis.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__24b97aabe72e04ae9d89a8fa6e9fa491403d4b8cfcbb7ff5396d3725df5e83c2)
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration": configuration,
            }

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LayoutConfigurationProperty"]:
            '''The configuration that determines what the type of layout for a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layout.html#cfn-quicksight-analysis-layout-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LayoutConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LayoutProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.LegendOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "height": "height",
            "position": "position",
            "title": "title",
            "visibility": "visibility",
            "width": "width",
        },
    )
    class LegendOptionsProperty:
        def __init__(
            self,
            *,
            height: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for the legend setup of a visual.

            :param height: The height of the legend. If this value is omitted, a default height is used when rendering.
            :param position: The positions for the legend. Choose one of the following options:. - ``AUTO`` - ``RIGHT`` - ``BOTTOM`` - ``LEFT``
            :param title: The custom title for the legend.
            :param visibility: Determines whether or not the legend is visible.
            :param width: The width of the legend. If this value is omitted, a default width is used when rendering.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                legend_options_property = quicksight.CfnAnalysis.LegendOptionsProperty(
                    height="height",
                    position="position",
                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    ),
                    visibility="visibility",
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__48c8ae8b06a6c4e8b5a9c55d8d55df5647a9884b662ab141ba34300e08b77046)
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if height is not None:
                self._values["height"] = height
            if position is not None:
                self._values["position"] = position
            if title is not None:
                self._values["title"] = title
            if visibility is not None:
                self._values["visibility"] = visibility
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def height(self) -> typing.Optional[builtins.str]:
            '''The height of the legend.

            If this value is omitted, a default height is used when rendering.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''The positions for the legend. Choose one of the following options:.

            - ``AUTO``
            - ``RIGHT``
            - ``BOTTOM``
            - ``LEFT``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LabelOptionsProperty"]]:
            '''The custom title for the legend.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LabelOptionsProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the legend is visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width of the legend.

            If this value is omitted, a default width is used when rendering.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LegendOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.LineChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "colors": "colors",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class LineChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a line chart.

            :param category: The category field wells of a line chart. Values are grouped by category fields.
            :param colors: The color field wells of a line chart. Values are grouped by category fields.
            :param small_multiples: The small multiples field well of a line chart.
            :param values: The value field wells of a line chart. Values are aggregated based on categories.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__68f9310cfaab3eacca20f4fe82f1c526cf71f490e0bf430e6f0efeb8728bcda5)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The category field wells of a line chart.

            Values are grouped by category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html#cfn-quicksight-analysis-linechartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The color field wells of a line chart.

            Values are grouped by category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html#cfn-quicksight-analysis-linechartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The small multiples field well of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html#cfn-quicksight-analysis-linechartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The value field wells of a line chart.

            Values are aggregated based on categories.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html#cfn-quicksight-analysis-linechartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.LineChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "default_series_settings": "defaultSeriesSettings",
            "field_wells": "fieldWells",
            "forecast_configurations": "forecastConfigurations",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "secondary_y_axis_display_options": "secondaryYAxisDisplayOptions",
            "secondary_y_axis_label_options": "secondaryYAxisLabelOptions",
            "series": "series",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "type": "type",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
        },
    )
    class LineChartConfigurationProperty:
        def __init__(
            self,
            *,
            contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            default_series_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LineChartDefaultSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LineChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            forecast_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ForecastConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LineSeriesAxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            secondary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LineSeriesAxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            series: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SeriesItemProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LineChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a line chart.

            :param contribution_analysis_defaults: The default configuration of a line chart's contribution analysis.
            :param data_labels: The data label configuration of a line chart.
            :param default_series_settings: The options that determine the default presentation of all line series in ``LineChartVisual`` .
            :param field_wells: The field well configuration of a line chart.
            :param forecast_configurations: The forecast configuration of a line chart.
            :param legend: The legend configuration of a line chart.
            :param primary_y_axis_display_options: The series axis configuration of a line chart.
            :param primary_y_axis_label_options: The options that determine the presentation of the y-axis label.
            :param reference_lines: The reference lines configuration of a line chart.
            :param secondary_y_axis_display_options: The series axis configuration of a line chart.
            :param secondary_y_axis_label_options: The options that determine the presentation of the secondary y-axis label.
            :param series: The series item configuration of a line chart.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a line chart.
            :param tooltip: The tooltip configuration of a line chart.
            :param type: Determines the type of the line chart.
            :param visual_palette: The visual palette configuration of a line chart.
            :param x_axis_display_options: The options that determine the presentation of the x-axis.
            :param x_axis_label_options: The options that determine the presentation of the x-axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8e4502981ca8885c526c0c955a0d5f3d3b8508216fe092b6d829c86bf6862b90)
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument default_series_settings", value=default_series_settings, expected_type=type_hints["default_series_settings"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument forecast_configurations", value=forecast_configurations, expected_type=type_hints["forecast_configurations"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument secondary_y_axis_display_options", value=secondary_y_axis_display_options, expected_type=type_hints["secondary_y_axis_display_options"])
                check_type(argname="argument secondary_y_axis_label_options", value=secondary_y_axis_label_options, expected_type=type_hints["secondary_y_axis_label_options"])
                check_type(argname="argument series", value=series, expected_type=type_hints["series"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if default_series_settings is not None:
                self._values["default_series_settings"] = default_series_settings
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if forecast_configurations is not None:
                self._values["forecast_configurations"] = forecast_configurations
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if secondary_y_axis_display_options is not None:
                self._values["secondary_y_axis_display_options"] = secondary_y_axis_display_options
            if secondary_y_axis_label_options is not None:
                self._values["secondary_y_axis_label_options"] = secondary_y_axis_label_options
            if series is not None:
                self._values["series"] = series
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if type is not None:
                self._values["type"] = type
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ContributionAnalysisDefaultProperty"]]]]:
            '''The default configuration of a line chart's contribution analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ContributionAnalysisDefaultProperty"]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The data label configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def default_series_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartDefaultSeriesSettingsProperty"]]:
            '''The options that determine the default presentation of all line series in ``LineChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-defaultseriessettings
            '''
            result = self._values.get("default_series_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartDefaultSeriesSettingsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartFieldWellsProperty"]]:
            '''The field well configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartFieldWellsProperty"]], result)

        @builtins.property
        def forecast_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ForecastConfigurationProperty"]]]]:
            '''The forecast configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-forecastconfigurations
            '''
            result = self._values.get("forecast_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ForecastConfigurationProperty"]]]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineSeriesAxisDisplayOptionsProperty"]]:
            '''The series axis configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineSeriesAxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineProperty"]]]]:
            '''The reference lines configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineProperty"]]]], result)

        @builtins.property
        def secondary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineSeriesAxisDisplayOptionsProperty"]]:
            '''The series axis configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-secondaryyaxisdisplayoptions
            '''
            result = self._values.get("secondary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineSeriesAxisDisplayOptionsProperty"]], result)

        @builtins.property
        def secondary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the secondary y-axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-secondaryyaxislabeloptions
            '''
            result = self._values.get("secondary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def series(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SeriesItemProperty"]]]]:
            '''The series item configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-series
            '''
            result = self._values.get("series")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SeriesItemProperty"]]]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SmallMultiplesOptionsProperty"]]:
            '''The small multiples setup for the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SmallMultiplesOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartSortConfigurationProperty"]]:
            '''The sort configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''Determines the type of the line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The visual palette configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.LineChartDefaultSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "line_style_settings": "lineStyleSettings",
            "marker_style_settings": "markerStyleSettings",
        },
    )
    class LineChartDefaultSeriesSettingsProperty:
        def __init__(
            self,
            *,
            axis_binding: typing.Optional[builtins.str] = None,
            line_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LineChartLineStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            marker_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LineChartMarkerStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the default presentation of all line series in ``LineChartVisual`` .

            :param axis_binding: The axis to which you are binding all line series to.
            :param line_style_settings: Line styles options for all line series in the visual.
            :param marker_style_settings: Marker styles options for all line series in the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartdefaultseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                line_chart_default_series_settings_property = quicksight.CfnAnalysis.LineChartDefaultSeriesSettingsProperty(
                    axis_binding="axisBinding",
                    line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                        line_interpolation="lineInterpolation",
                        line_style="lineStyle",
                        line_visibility="lineVisibility",
                        line_width="lineWidth"
                    ),
                    marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                        marker_color="markerColor",
                        marker_shape="markerShape",
                        marker_size="markerSize",
                        marker_visibility="markerVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5a5a7d0cd55f4d54e05c5d22c88d2a1adabfaecff26e9671f1d691b1a6545d12)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument line_style_settings", value=line_style_settings, expected_type=type_hints["line_style_settings"])
                check_type(argname="argument marker_style_settings", value=marker_style_settings, expected_type=type_hints["marker_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_binding is not None:
                self._values["axis_binding"] = axis_binding
            if line_style_settings is not None:
                self._values["line_style_settings"] = line_style_settings
            if marker_style_settings is not None:
                self._values["marker_style_settings"] = marker_style_settings

        @builtins.property
        def axis_binding(self) -> typing.Optional[builtins.str]:
            '''The axis to which you are binding all line series to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartdefaultseriessettings.html#cfn-quicksight-analysis-linechartdefaultseriessettings-axisbinding
            '''
            result = self._values.get("axis_binding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartLineStyleSettingsProperty"]]:
            '''Line styles options for all line series in the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartdefaultseriessettings.html#cfn-quicksight-analysis-linechartdefaultseriessettings-linestylesettings
            '''
            result = self._values.get("line_style_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartLineStyleSettingsProperty"]], result)

        @builtins.property
        def marker_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartMarkerStyleSettingsProperty"]]:
            '''Marker styles options for all line series in the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartdefaultseriessettings.html#cfn-quicksight-analysis-linechartdefaultseriessettings-markerstylesettings
            '''
            result = self._values.get("marker_style_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartMarkerStyleSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartDefaultSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.LineChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_chart_aggregated_field_wells": "lineChartAggregatedFieldWells",
        },
    )
    class LineChartFieldWellsProperty:
        def __init__(
            self,
            *,
            line_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LineChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a line chart.

            :param line_chart_aggregated_field_wells: The field well configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2e43be70b1c36384b647ea13ae980a10f1ecafa0ffa642d90b02785ad8c9efd4)
                check_type(argname="argument line_chart_aggregated_field_wells", value=line_chart_aggregated_field_wells, expected_type=type_hints["line_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_chart_aggregated_field_wells is not None:
                self._values["line_chart_aggregated_field_wells"] = line_chart_aggregated_field_wells

        @builtins.property
        def line_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartfieldwells.html#cfn-quicksight-analysis-linechartfieldwells-linechartaggregatedfieldwells
            '''
            result = self._values.get("line_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_interpolation": "lineInterpolation",
            "line_style": "lineStyle",
            "line_visibility": "lineVisibility",
            "line_width": "lineWidth",
        },
    )
    class LineChartLineStyleSettingsProperty:
        def __init__(
            self,
            *,
            line_interpolation: typing.Optional[builtins.str] = None,
            line_style: typing.Optional[builtins.str] = None,
            line_visibility: typing.Optional[builtins.str] = None,
            line_width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Line styles options for a line series in ``LineChartVisual`` .

            :param line_interpolation: Interpolation style for line series. - ``LINEAR`` : Show as default, linear style. - ``SMOOTH`` : Show as a smooth curve. - ``STEPPED`` : Show steps in line.
            :param line_style: Line style for line series. - ``SOLID`` : Show as a solid line. - ``DOTTED`` : Show as a dotted line. - ``DASHED`` : Show as a dashed line.
            :param line_visibility: Configuration option that determines whether to show the line for the series.
            :param line_width: Width that determines the line thickness.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                line_chart_line_style_settings_property = quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                    line_interpolation="lineInterpolation",
                    line_style="lineStyle",
                    line_visibility="lineVisibility",
                    line_width="lineWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3fc3c5f5cfe1e65e4cb7ba3389c83c14e1094b948d8f635c80339d44a8a87e5b)
                check_type(argname="argument line_interpolation", value=line_interpolation, expected_type=type_hints["line_interpolation"])
                check_type(argname="argument line_style", value=line_style, expected_type=type_hints["line_style"])
                check_type(argname="argument line_visibility", value=line_visibility, expected_type=type_hints["line_visibility"])
                check_type(argname="argument line_width", value=line_width, expected_type=type_hints["line_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_interpolation is not None:
                self._values["line_interpolation"] = line_interpolation
            if line_style is not None:
                self._values["line_style"] = line_style
            if line_visibility is not None:
                self._values["line_visibility"] = line_visibility
            if line_width is not None:
                self._values["line_width"] = line_width

        @builtins.property
        def line_interpolation(self) -> typing.Optional[builtins.str]:
            '''Interpolation style for line series.

            - ``LINEAR`` : Show as default, linear style.
            - ``SMOOTH`` : Show as a smooth curve.
            - ``STEPPED`` : Show steps in line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html#cfn-quicksight-analysis-linechartlinestylesettings-lineinterpolation
            '''
            result = self._values.get("line_interpolation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_style(self) -> typing.Optional[builtins.str]:
            '''Line style for line series.

            - ``SOLID`` : Show as a solid line.
            - ``DOTTED`` : Show as a dotted line.
            - ``DASHED`` : Show as a dashed line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html#cfn-quicksight-analysis-linechartlinestylesettings-linestyle
            '''
            result = self._values.get("line_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_visibility(self) -> typing.Optional[builtins.str]:
            '''Configuration option that determines whether to show the line for the series.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html#cfn-quicksight-analysis-linechartlinestylesettings-linevisibility
            '''
            result = self._values.get("line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_width(self) -> typing.Optional[builtins.str]:
            '''Width that determines the line thickness.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html#cfn-quicksight-analysis-linechartlinestylesettings-linewidth
            '''
            result = self._values.get("line_width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartLineStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "marker_color": "markerColor",
            "marker_shape": "markerShape",
            "marker_size": "markerSize",
            "marker_visibility": "markerVisibility",
        },
    )
    class LineChartMarkerStyleSettingsProperty:
        def __init__(
            self,
            *,
            marker_color: typing.Optional[builtins.str] = None,
            marker_shape: typing.Optional[builtins.str] = None,
            marker_size: typing.Optional[builtins.str] = None,
            marker_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Marker styles options for a line series in ``LineChartVisual`` .

            :param marker_color: Color of marker in the series.
            :param marker_shape: Shape option for markers in the series. - ``CIRCLE`` : Show marker as a circle. - ``TRIANGLE`` : Show marker as a triangle. - ``SQUARE`` : Show marker as a square. - ``DIAMOND`` : Show marker as a diamond. - ``ROUNDED_SQUARE`` : Show marker as a rounded square.
            :param marker_size: Size of marker in the series.
            :param marker_visibility: Configuration option that determines whether to show the markers in the series.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                line_chart_marker_style_settings_property = quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                    marker_color="markerColor",
                    marker_shape="markerShape",
                    marker_size="markerSize",
                    marker_visibility="markerVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7b81789298d598d65075f668b5d50e8064e42add88450e3a59131c2e9f601952)
                check_type(argname="argument marker_color", value=marker_color, expected_type=type_hints["marker_color"])
                check_type(argname="argument marker_shape", value=marker_shape, expected_type=type_hints["marker_shape"])
                check_type(argname="argument marker_size", value=marker_size, expected_type=type_hints["marker_size"])
                check_type(argname="argument marker_visibility", value=marker_visibility, expected_type=type_hints["marker_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if marker_color is not None:
                self._values["marker_color"] = marker_color
            if marker_shape is not None:
                self._values["marker_shape"] = marker_shape
            if marker_size is not None:
                self._values["marker_size"] = marker_size
            if marker_visibility is not None:
                self._values["marker_visibility"] = marker_visibility

        @builtins.property
        def marker_color(self) -> typing.Optional[builtins.str]:
            '''Color of marker in the series.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html#cfn-quicksight-analysis-linechartmarkerstylesettings-markercolor
            '''
            result = self._values.get("marker_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_shape(self) -> typing.Optional[builtins.str]:
            '''Shape option for markers in the series.

            - ``CIRCLE`` : Show marker as a circle.
            - ``TRIANGLE`` : Show marker as a triangle.
            - ``SQUARE`` : Show marker as a square.
            - ``DIAMOND`` : Show marker as a diamond.
            - ``ROUNDED_SQUARE`` : Show marker as a rounded square.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html#cfn-quicksight-analysis-linechartmarkerstylesettings-markershape
            '''
            result = self._values.get("marker_shape")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_size(self) -> typing.Optional[builtins.str]:
            '''Size of marker in the series.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html#cfn-quicksight-analysis-linechartmarkerstylesettings-markersize
            '''
            result = self._values.get("marker_size")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_visibility(self) -> typing.Optional[builtins.str]:
            '''Configuration option that determines whether to show the markers in the series.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html#cfn-quicksight-analysis-linechartmarkerstylesettings-markervisibility
            '''
            result = self._values.get("marker_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartMarkerStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.LineChartSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_style_settings": "lineStyleSettings",
            "marker_style_settings": "markerStyleSettings",
        },
    )
    class LineChartSeriesSettingsProperty:
        def __init__(
            self,
            *,
            line_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LineChartLineStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            marker_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LineChartMarkerStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of a line series in the visual.

            :param line_style_settings: Line styles options for a line series in ``LineChartVisual`` .
            :param marker_style_settings: Marker styles options for a line series in ``LineChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                line_chart_series_settings_property = quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                    line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                        line_interpolation="lineInterpolation",
                        line_style="lineStyle",
                        line_visibility="lineVisibility",
                        line_width="lineWidth"
                    ),
                    marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                        marker_color="markerColor",
                        marker_shape="markerShape",
                        marker_size="markerSize",
                        marker_visibility="markerVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__719b2ae1f716ca1978f946cb87bb19acac4b968b72ca7e4528dfa79b485ae933)
                check_type(argname="argument line_style_settings", value=line_style_settings, expected_type=type_hints["line_style_settings"])
                check_type(argname="argument marker_style_settings", value=marker_style_settings, expected_type=type_hints["marker_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_style_settings is not None:
                self._values["line_style_settings"] = line_style_settings
            if marker_style_settings is not None:
                self._values["marker_style_settings"] = marker_style_settings

        @builtins.property
        def line_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartLineStyleSettingsProperty"]]:
            '''Line styles options for a line series in ``LineChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartseriessettings.html#cfn-quicksight-analysis-linechartseriessettings-linestylesettings
            '''
            result = self._values.get("line_style_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartLineStyleSettingsProperty"]], result)

        @builtins.property
        def marker_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartMarkerStyleSettingsProperty"]]:
            '''Marker styles options for a line series in ``LineChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartseriessettings.html#cfn-quicksight-analysis-linechartseriessettings-markerstylesettings
            '''
            result = self._values.get("marker_style_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartMarkerStyleSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.LineChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit_configuration": "categoryItemsLimitConfiguration",
            "category_sort": "categorySort",
            "color_items_limit_configuration": "colorItemsLimitConfiguration",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class LineChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a line chart.

            :param category_items_limit_configuration: The limit on the number of categories that are displayed in a line chart.
            :param category_sort: The sort configuration of the category fields.
            :param color_items_limit_configuration: The limit on the number of lines that are displayed in a line chart.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                line_chart_sort_configuration_property = quicksight.CfnAnalysis.LineChartSortConfigurationProperty(
                    category_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ff6d65ce53fd5502b502b61555bb7c4fedef0ea515b369f50ff903626e398eea)
                check_type(argname="argument category_items_limit_configuration", value=category_items_limit_configuration, expected_type=type_hints["category_items_limit_configuration"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit_configuration", value=color_items_limit_configuration, expected_type=type_hints["color_items_limit_configuration"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit_configuration is not None:
                self._values["category_items_limit_configuration"] = category_items_limit_configuration
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit_configuration is not None:
                self._values["color_items_limit_configuration"] = color_items_limit_configuration
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories that are displayed in a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-categoryitemslimitconfiguration
            '''
            result = self._values.get("category_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of lines that are displayed in a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-coloritemslimitconfiguration
            '''
            result = self._values.get("color_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of small multiples panels that are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the small multiples field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.LineChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class LineChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LineChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A line chart.

            For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a line chart.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bdab8c410a0336e9ae1bb1bf86f581d932f24bb158be83ea0ff9f4927382b4fc)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartConfigurationProperty"]]:
            '''The configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_options": "axisOptions",
            "missing_data_configurations": "missingDataConfigurations",
        },
    )
    class LineSeriesAxisDisplayOptionsProperty:
        def __init__(
            self,
            *,
            axis_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            missing_data_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MissingDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The series axis configuration of a line chart.

            :param axis_options: The options that determine the presentation of the line series axis.
            :param missing_data_configurations: The configuration options that determine how missing data is treated during the rendering of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-lineseriesaxisdisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                line_series_axis_display_options_property = quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                    axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                        treatment_option="treatmentOption"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__785381c00bdcd271c76ce148cd8e40602b2901db410eb397ed365fa6f89973b4)
                check_type(argname="argument axis_options", value=axis_options, expected_type=type_hints["axis_options"])
                check_type(argname="argument missing_data_configurations", value=missing_data_configurations, expected_type=type_hints["missing_data_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_options is not None:
                self._values["axis_options"] = axis_options
            if missing_data_configurations is not None:
                self._values["missing_data_configurations"] = missing_data_configurations

        @builtins.property
        def axis_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the line series axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-lineseriesaxisdisplayoptions.html#cfn-quicksight-analysis-lineseriesaxisdisplayoptions-axisoptions
            '''
            result = self._values.get("axis_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def missing_data_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MissingDataConfigurationProperty"]]]]:
            '''The configuration options that determine how missing data is treated during the rendering of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-lineseriesaxisdisplayoptions.html#cfn-quicksight-analysis-lineseriesaxisdisplayoptions-missingdataconfigurations
            '''
            result = self._values.get("missing_data_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MissingDataConfigurationProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineSeriesAxisDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ListControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "info_icon_label_options": "infoIconLabelOptions",
            "search_options": "searchOptions",
            "select_all_options": "selectAllOptions",
            "title_options": "titleOptions",
        },
    )
    class ListControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SheetControlInfoIconLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            search_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ListControlSearchOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            select_all_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ListControlSelectAllOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param info_icon_label_options: The configuration of info icon label options.
            :param search_options: The configuration of the search options in a list control.
            :param select_all_options: The configuration of the ``Select all`` options in a list control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                list_control_display_options_property = quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                    info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                        info_icon_text="infoIconText",
                        visibility="visibility"
                    ),
                    search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                        visibility="visibility"
                    ),
                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__11d6276e4ba5436512b67cd6bf0cabbf0596e0531ba8962545576b3e67f326f4)
                check_type(argname="argument info_icon_label_options", value=info_icon_label_options, expected_type=type_hints["info_icon_label_options"])
                check_type(argname="argument search_options", value=search_options, expected_type=type_hints["search_options"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if info_icon_label_options is not None:
                self._values["info_icon_label_options"] = info_icon_label_options
            if search_options is not None:
                self._values["search_options"] = search_options
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def info_icon_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetControlInfoIconLabelOptionsProperty"]]:
            '''The configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html#cfn-quicksight-analysis-listcontroldisplayoptions-infoiconlabeloptions
            '''
            result = self._values.get("info_icon_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetControlInfoIconLabelOptionsProperty"]], result)

        @builtins.property
        def search_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ListControlSearchOptionsProperty"]]:
            '''The configuration of the search options in a list control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html#cfn-quicksight-analysis-listcontroldisplayoptions-searchoptions
            '''
            result = self._values.get("search_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ListControlSearchOptionsProperty"]], result)

        @builtins.property
        def select_all_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ListControlSelectAllOptionsProperty"]]:
            '''The configuration of the ``Select all`` options in a list control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html#cfn-quicksight-analysis-listcontroldisplayoptions-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ListControlSelectAllOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html#cfn-quicksight-analysis-listcontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ListControlSearchOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ListControlSearchOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the search options in a list control.

            :param visibility: The visibility configuration of the search options in a list control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontrolsearchoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                list_control_search_options_property = quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f576914c1297ac516dbc6dd540a06cc81aa553b79cd3e449979af00a754ce442)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the search options in a list control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontrolsearchoptions.html#cfn-quicksight-analysis-listcontrolsearchoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlSearchOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ListControlSelectAllOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the ``Select all`` options in a list control.

            :param visibility: The visibility configuration of the ``Select all`` options in a list control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontrolselectalloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                list_control_select_all_options_property = quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1fe92e2b8f7160aef769b651c7fa4273580fda6211aa73a1cf91b6634fbf3239)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the ``Select all`` options in a list control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontrolselectalloptions.html#cfn-quicksight-analysis-listcontrolselectalloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlSelectAllOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.LoadingAnimationProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class LoadingAnimationProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of loading animation in free-form layout.

            :param visibility: The visibility configuration of ``LoadingAnimation`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-loadinganimation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                loading_animation_property = quicksight.CfnAnalysis.LoadingAnimationProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__93b5b2ef7375666d961408b29bf636eee1853366f4448ef58a64b828fd415ae0)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of ``LoadingAnimation`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-loadinganimation.html#cfn-quicksight-analysis-loadinganimation-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LoadingAnimationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.LocalNavigationConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"target_sheet_id": "targetSheetId"},
    )
    class LocalNavigationConfigurationProperty:
        def __init__(self, *, target_sheet_id: builtins.str) -> None:
            '''The navigation configuration for ``CustomActionNavigationOperation`` .

            :param target_sheet_id: The sheet that is targeted for navigation in the same analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-localnavigationconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                local_navigation_configuration_property = quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                    target_sheet_id="targetSheetId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5df000507cfe706fe7cdc113ae0477d02c3ec38758dae029987c2a222a87b37b)
                check_type(argname="argument target_sheet_id", value=target_sheet_id, expected_type=type_hints["target_sheet_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "target_sheet_id": target_sheet_id,
            }

        @builtins.property
        def target_sheet_id(self) -> builtins.str:
            '''The sheet that is targeted for navigation in the same analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-localnavigationconfiguration.html#cfn-quicksight-analysis-localnavigationconfiguration-targetsheetid
            '''
            result = self._values.get("target_sheet_id")
            assert result is not None, "Required property 'target_sheet_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LocalNavigationConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.LongFormatTextProperty",
        jsii_struct_bases=[],
        name_mapping={"plain_text": "plainText", "rich_text": "richText"},
    )
    class LongFormatTextProperty:
        def __init__(
            self,
            *,
            plain_text: typing.Optional[builtins.str] = None,
            rich_text: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The text format for a subtitle.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param plain_text: Plain text format.
            :param rich_text: Rich text. Examples of rich text include bold, underline, and italics.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-longformattext.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                long_format_text_property = quicksight.CfnAnalysis.LongFormatTextProperty(
                    plain_text="plainText",
                    rich_text="richText"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__25972d14881d2916d8f2106914671470333465f27bf4d55f09f2241af6a1b1ea)
                check_type(argname="argument plain_text", value=plain_text, expected_type=type_hints["plain_text"])
                check_type(argname="argument rich_text", value=rich_text, expected_type=type_hints["rich_text"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if plain_text is not None:
                self._values["plain_text"] = plain_text
            if rich_text is not None:
                self._values["rich_text"] = rich_text

        @builtins.property
        def plain_text(self) -> typing.Optional[builtins.str]:
            '''Plain text format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-longformattext.html#cfn-quicksight-analysis-longformattext-plaintext
            '''
            result = self._values.get("plain_text")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rich_text(self) -> typing.Optional[builtins.str]:
            '''Rich text.

            Examples of rich text include bold, underline, and italics.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-longformattext.html#cfn-quicksight-analysis-longformattext-richtext
            '''
            result = self._values.get("rich_text")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LongFormatTextProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.MappedDataSetParameterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "data_set_parameter_name": "dataSetParameterName",
        },
    )
    class MappedDataSetParameterProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            data_set_parameter_name: builtins.str,
        ) -> None:
            '''A dataset parameter that is mapped to an analysis parameter.

            :param data_set_identifier: A unique name that identifies a dataset within the analysis or dashboard.
            :param data_set_parameter_name: The name of the dataset parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-mappeddatasetparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                mapped_data_set_parameter_property = quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                    data_set_identifier="dataSetIdentifier",
                    data_set_parameter_name="dataSetParameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3bb16eb58d41f3a41812e41ea150331419a4965847be9bae55002d381b03308a)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument data_set_parameter_name", value=data_set_parameter_name, expected_type=type_hints["data_set_parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "data_set_parameter_name": data_set_parameter_name,
            }

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''A unique name that identifies a dataset within the analysis or dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-mappeddatasetparameter.html#cfn-quicksight-analysis-mappeddatasetparameter-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_parameter_name(self) -> builtins.str:
            '''The name of the dataset parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-mappeddatasetparameter.html#cfn-quicksight-analysis-mappeddatasetparameter-datasetparametername
            '''
            result = self._values.get("data_set_parameter_name")
            assert result is not None, "Required property 'data_set_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MappedDataSetParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.MaximumLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class MaximumLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The maximum label of a data path label.

            :param visibility: The visibility of the maximum label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                maximum_label_type_property = quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__286c43f9a143ec482dc3f27f678e5b04b0874c082f9b3e87dcf41eebe0b99f33)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the maximum label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumlabeltype.html#cfn-quicksight-analysis-maximumlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MaximumLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.MaximumMinimumComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "type": "type",
            "name": "name",
            "time": "time",
            "value": "value",
        },
    )
    class MaximumMinimumComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            type: builtins.str,
            name: typing.Optional[builtins.str] = None,
            time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The maximum and minimum computation configuration.

            :param computation_id: The ID for a computation.
            :param type: The type of computation. Choose one of the following options:. - MAXIMUM: A maximum computation. - MINIMUM: A minimum computation.
            :param name: The name of a computation.
            :param time: The time field that is used in a computation.
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                maximum_minimum_computation_property = quicksight.CfnAnalysis.MaximumMinimumComputationProperty(
                    computation_id="computationId",
                    type="type",
                
                    # the properties below are optional
                    name="name",
                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__91509d04a0e8ae4917832fd46882ec304495325653d7e06f260ef76a23f38651)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "type": type,
            }
            if name is not None:
                self._values["name"] = name
            if time is not None:
                self._values["time"] = time
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The type of computation. Choose one of the following options:.

            - MAXIMUM: A maximum computation.
            - MINIMUM: A minimum computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]:
            '''The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-time
            '''
            result = self._values.get("time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MaximumMinimumComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.MeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "calculated_measure_field": "calculatedMeasureField",
            "categorical_measure_field": "categoricalMeasureField",
            "date_measure_field": "dateMeasureField",
            "numerical_measure_field": "numericalMeasureField",
        },
    )
    class MeasureFieldProperty:
        def __init__(
            self,
            *,
            calculated_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CalculatedMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            categorical_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CategoricalMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            date_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DateMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numerical_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumericalMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure (metric) type field.

            :param calculated_measure_field: The calculated measure field only used in pivot tables.
            :param categorical_measure_field: The measure type field with categorical type columns.
            :param date_measure_field: The measure type field with date type columns.
            :param numerical_measure_field: The measure type field with numerical type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                measure_field_property = quicksight.CfnAnalysis.MeasureFieldProperty(
                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                        expression="expression",
                        field_id="fieldId"
                    ),
                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function="aggregationFunction",
                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function="aggregationFunction",
                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        ),
                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__912ecd28ec0047466f479d848db03397eb408315496ae14d8c424d1a04107006)
                check_type(argname="argument calculated_measure_field", value=calculated_measure_field, expected_type=type_hints["calculated_measure_field"])
                check_type(argname="argument categorical_measure_field", value=categorical_measure_field, expected_type=type_hints["categorical_measure_field"])
                check_type(argname="argument date_measure_field", value=date_measure_field, expected_type=type_hints["date_measure_field"])
                check_type(argname="argument numerical_measure_field", value=numerical_measure_field, expected_type=type_hints["numerical_measure_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if calculated_measure_field is not None:
                self._values["calculated_measure_field"] = calculated_measure_field
            if categorical_measure_field is not None:
                self._values["categorical_measure_field"] = categorical_measure_field
            if date_measure_field is not None:
                self._values["date_measure_field"] = date_measure_field
            if numerical_measure_field is not None:
                self._values["numerical_measure_field"] = numerical_measure_field

        @builtins.property
        def calculated_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CalculatedMeasureFieldProperty"]]:
            '''The calculated measure field only used in pivot tables.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html#cfn-quicksight-analysis-measurefield-calculatedmeasurefield
            '''
            result = self._values.get("calculated_measure_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CalculatedMeasureFieldProperty"]], result)

        @builtins.property
        def categorical_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CategoricalMeasureFieldProperty"]]:
            '''The measure type field with categorical type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html#cfn-quicksight-analysis-measurefield-categoricalmeasurefield
            '''
            result = self._values.get("categorical_measure_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CategoricalMeasureFieldProperty"]], result)

        @builtins.property
        def date_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateMeasureFieldProperty"]]:
            '''The measure type field with date type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html#cfn-quicksight-analysis-measurefield-datemeasurefield
            '''
            result = self._values.get("date_measure_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateMeasureFieldProperty"]], result)

        @builtins.property
        def numerical_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericalMeasureFieldProperty"]]:
            '''The measure type field with numerical type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html#cfn-quicksight-analysis-measurefield-numericalmeasurefield
            '''
            result = self._values.get("numerical_measure_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericalMeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.MetricComparisonComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "from_value": "fromValue",
            "name": "name",
            "target_value": "targetValue",
            "time": "time",
        },
    )
    class MetricComparisonComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            from_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            name: typing.Optional[builtins.str] = None,
            target_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The metric comparison computation configuration.

            :param computation_id: The ID for a computation.
            :param from_value: The field that is used in a metric comparison from value setup.
            :param name: The name of a computation.
            :param target_value: The field that is used in a metric comparison to value setup.
            :param time: The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__50bb05b9db78e8a22fb074f318a4866d592109593030fb6706a040baed1f2206)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument from_value", value=from_value, expected_type=type_hints["from_value"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument target_value", value=target_value, expected_type=type_hints["target_value"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
            }
            if from_value is not None:
                self._values["from_value"] = from_value
            if name is not None:
                self._values["name"] = name
            if target_value is not None:
                self._values["target_value"] = target_value
            if time is not None:
                self._values["time"] = time

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def from_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]:
            '''The field that is used in a metric comparison from value setup.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-fromvalue
            '''
            result = self._values.get("from_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def target_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]:
            '''The field that is used in a metric comparison to value setup.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-targetvalue
            '''
            result = self._values.get("target_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]:
            '''The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-time
            '''
            result = self._values.get("time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MetricComparisonComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.MinimumLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class MinimumLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The minimum label of a data path label.

            :param visibility: The visibility of the minimum label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-minimumlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                minimum_label_type_property = quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ee324b937890d03d5a527a28a012b13e6020cd2133e1e8c889d87abce930afa5)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the minimum label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-minimumlabeltype.html#cfn-quicksight-analysis-minimumlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MinimumLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.MissingDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"treatment_option": "treatmentOption"},
    )
    class MissingDataConfigurationProperty:
        def __init__(
            self,
            *,
            treatment_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration options that determine how missing data is treated during the rendering of a line chart.

            :param treatment_option: The treatment option that determines how missing data should be rendered. Choose from the following options:. - ``INTERPOLATE`` : Interpolate missing values between the prior and the next known value. - ``SHOW_AS_ZERO`` : Show missing values as the value ``0`` . - ``SHOW_AS_BLANK`` : Display a blank space when rendering missing data.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-missingdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                missing_data_configuration_property = quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                    treatment_option="treatmentOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__75ea413e2315799674d8c1d76cbcf36d232cd3a0684dca86ab92e2b289e560fc)
                check_type(argname="argument treatment_option", value=treatment_option, expected_type=type_hints["treatment_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if treatment_option is not None:
                self._values["treatment_option"] = treatment_option

        @builtins.property
        def treatment_option(self) -> typing.Optional[builtins.str]:
            '''The treatment option that determines how missing data should be rendered. Choose from the following options:.

            - ``INTERPOLATE`` : Interpolate missing values between the prior and the next known value.
            - ``SHOW_AS_ZERO`` : Show missing values as the value ``0`` .
            - ``SHOW_AS_BLANK`` : Display a blank space when rendering missing data.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-missingdataconfiguration.html#cfn-quicksight-analysis-missingdataconfiguration-treatmentoption
            '''
            result = self._values.get("treatment_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MissingDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.NegativeValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"display_mode": "displayMode"},
    )
    class NegativeValueConfigurationProperty:
        def __init__(self, *, display_mode: builtins.str) -> None:
            '''The options that determine the negative value configuration.

            :param display_mode: Determines the display mode of the negative value configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-negativevalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                negative_value_configuration_property = quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                    display_mode="displayMode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__793176bb726227d6768a798703e6f55c058d7fd7161ce55ae77842a75b0869c3)
                check_type(argname="argument display_mode", value=display_mode, expected_type=type_hints["display_mode"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "display_mode": display_mode,
            }

        @builtins.property
        def display_mode(self) -> builtins.str:
            '''Determines the display mode of the negative value configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-negativevalueconfiguration.html#cfn-quicksight-analysis-negativevalueconfiguration-displaymode
            '''
            result = self._values.get("display_mode")
            assert result is not None, "Required property 'display_mode' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NegativeValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.NullValueFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"null_string": "nullString"},
    )
    class NullValueFormatConfigurationProperty:
        def __init__(self, *, null_string: builtins.str) -> None:
            '''The options that determine the null value format configuration.

            :param null_string: Determines the null string of null values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-nullvalueformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                null_value_format_configuration_property = quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                    null_string="nullString"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6accfef980def7683166f161eccc3f4a0a522aa91f8b2fa7091e4657cdd10079)
                check_type(argname="argument null_string", value=null_string, expected_type=type_hints["null_string"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "null_string": null_string,
            }

        @builtins.property
        def null_string(self) -> builtins.str:
            '''Determines the null string of null values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-nullvalueformatconfiguration.html#cfn-quicksight-analysis-nullvalueformatconfiguration-nullstring
            '''
            result = self._values.get("null_string")
            assert result is not None, "Required property 'null_string' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NullValueFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "number_scale": "numberScale",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
        },
    )
    class NumberDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            negative_value_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_scale: typing.Optional[builtins.str] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            suffix: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the number display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param number_scale: Determines the number scale value of the number format.
            :param prefix: Determines the prefix value of the number format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the number format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                number_display_format_configuration_property = quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    number_scale="numberScale",
                    prefix="prefix",
                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4d380b69e23daf3c044546cdc60f14115db7d64c7d369b74fcf220fd554be2a3)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument number_scale", value=number_scale, expected_type=type_hints["number_scale"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if number_scale is not None:
                self._values["number_scale"] = number_scale
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DecimalPlacesConfigurationProperty"]]:
            '''The option that determines the decimal places configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DecimalPlacesConfigurationProperty"]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NegativeValueConfigurationProperty"]]:
            '''The options that determine the negative value configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NegativeValueConfigurationProperty"]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def number_scale(self) -> typing.Optional[builtins.str]:
            '''Determines the number scale value of the number format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-numberscale
            '''
            result = self._values.get("number_scale")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the number format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericSeparatorConfigurationProperty"]]:
            '''The options that determine the numeric separator configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericSeparatorConfigurationProperty"]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the number format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumberDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.NumberFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"format_configuration": "formatConfiguration"},
    )
    class NumberFormatConfigurationProperty:
        def __init__(
            self,
            *,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Formatting configuration for number fields.

            :param format_configuration: The options that determine the numeric format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                number_format_configuration_property = quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1239e4ae15d858e0b513656d1ed9b69c68f9c3e40fce2226f8533bb5b3b8b919)
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericFormatConfigurationProperty"]]:
            '''The options that determine the numeric format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberformatconfiguration.html#cfn-quicksight-analysis-numberformatconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumberFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.NumericAxisOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"range": "range", "scale": "scale"},
    )
    class NumericAxisOptionsProperty:
        def __init__(
            self,
            *,
            range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisDisplayRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scale: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options for an axis with a numeric field.

            :param range: The range setup of a numeric axis.
            :param scale: The scale setup of a numeric axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaxisoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                numeric_axis_options_property = quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                        data_driven=data_driven,
                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                            maximum=123,
                            minimum=123
                        )
                    ),
                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                            step_count=123,
                            step_size=123
                        ),
                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                            base=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e6a23def5664c62fb5c22d6673c08d3a48e1204498d14f7530509b276a64bbda)
                check_type(argname="argument range", value=range, expected_type=type_hints["range"])
                check_type(argname="argument scale", value=scale, expected_type=type_hints["scale"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if range is not None:
                self._values["range"] = range
            if scale is not None:
                self._values["scale"] = scale

        @builtins.property
        def range(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayRangeProperty"]]:
            '''The range setup of a numeric axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaxisoptions.html#cfn-quicksight-analysis-numericaxisoptions-range
            '''
            result = self._values.get("range")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayRangeProperty"]], result)

        @builtins.property
        def scale(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisScaleProperty"]]:
            '''The scale setup of a numeric axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaxisoptions.html#cfn-quicksight-analysis-numericaxisoptions-scale
            '''
            result = self._values.get("scale")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisScaleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericAxisOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "value": "value"},
    )
    class NumericEqualityDrillDownFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            value: jsii.Number,
        ) -> None:
            '''The category drill down filter.

            :param column: The column that the filter is applied to.
            :param value: The value of the double input numeric drill down filter. Default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalitydrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numeric_equality_drill_down_filter_property = quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b5f75b38709c3141a0ae29eef4d16460261d12ff8569c81cceae3f651568cb4b)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "value": value,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalitydrilldownfilter.html#cfn-quicksight-analysis-numericequalitydrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The value of the double input numeric drill down filter.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalitydrilldownfilter.html#cfn-quicksight-analysis-numericequalitydrilldownfilter-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericEqualityDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.NumericEqualityFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "aggregation_function": "aggregationFunction",
            "parameter_name": "parameterName",
            "select_all_options": "selectAllOptions",
            "value": "value",
        },
    )
    class NumericEqualityFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            match_operator: builtins.str,
            null_option: builtins.str,
            aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            select_all_options: typing.Optional[builtins.str] = None,
            value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A ``NumericEqualityFilter`` filters values that are equal to the specified value.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param aggregation_function: The aggregation function of the filter.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``
            :param value: The input value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numeric_equality_filter_property = quicksight.CfnAnalysis.NumericEqualityFilterProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                        attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                            simple_attribute_aggregation="simpleAttributeAggregation",
                            value_for_multiple_values="valueForMultipleValues"
                        ),
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    parameter_name="parameterName",
                    select_all_options="selectAllOptions",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__28c9e7c1d69e0ffde206a0f71403aeea3130f5112ee45c6c70db7fca94d22408)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AggregationFunctionProperty"]]:
            '''The aggregation function of the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AggregationFunctionProperty"]], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The input value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericEqualityFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.NumericFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "currency_display_format_configuration": "currencyDisplayFormatConfiguration",
            "number_display_format_configuration": "numberDisplayFormatConfiguration",
            "percentage_display_format_configuration": "percentageDisplayFormatConfiguration",
        },
    )
    class NumericFormatConfigurationProperty:
        def __init__(
            self,
            *,
            currency_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CurrencyDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumberDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            percentage_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PercentageDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the numeric format configuration.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param currency_display_format_configuration: The options that determine the currency display format configuration.
            :param number_display_format_configuration: The options that determine the number display format configuration.
            :param percentage_display_format_configuration: The options that determine the percentage display format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numeric_format_configuration_property = quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix",
                        symbol="symbol"
                    ),
                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    ),
                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        prefix="prefix",
                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7e32dd597a791c590be66197299edd4ff20c24b7a392a55360ff88c62d5848e5)
                check_type(argname="argument currency_display_format_configuration", value=currency_display_format_configuration, expected_type=type_hints["currency_display_format_configuration"])
                check_type(argname="argument number_display_format_configuration", value=number_display_format_configuration, expected_type=type_hints["number_display_format_configuration"])
                check_type(argname="argument percentage_display_format_configuration", value=percentage_display_format_configuration, expected_type=type_hints["percentage_display_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if currency_display_format_configuration is not None:
                self._values["currency_display_format_configuration"] = currency_display_format_configuration
            if number_display_format_configuration is not None:
                self._values["number_display_format_configuration"] = number_display_format_configuration
            if percentage_display_format_configuration is not None:
                self._values["percentage_display_format_configuration"] = percentage_display_format_configuration

        @builtins.property
        def currency_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CurrencyDisplayFormatConfigurationProperty"]]:
            '''The options that determine the currency display format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericformatconfiguration.html#cfn-quicksight-analysis-numericformatconfiguration-currencydisplayformatconfiguration
            '''
            result = self._values.get("currency_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CurrencyDisplayFormatConfigurationProperty"]], result)

        @builtins.property
        def number_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumberDisplayFormatConfigurationProperty"]]:
            '''The options that determine the number display format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericformatconfiguration.html#cfn-quicksight-analysis-numericformatconfiguration-numberdisplayformatconfiguration
            '''
            result = self._values.get("number_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumberDisplayFormatConfigurationProperty"]], result)

        @builtins.property
        def percentage_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PercentageDisplayFormatConfigurationProperty"]]:
            '''The options that determine the percentage display format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericformatconfiguration.html#cfn-quicksight-analysis-numericformatconfiguration-percentagedisplayformatconfiguration
            '''
            result = self._values.get("percentage_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PercentageDisplayFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.NumericRangeFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "aggregation_function": "aggregationFunction",
            "include_maximum": "includeMaximum",
            "include_minimum": "includeMinimum",
            "range_maximum": "rangeMaximum",
            "range_minimum": "rangeMinimum",
            "select_all_options": "selectAllOptions",
        },
    )
    class NumericRangeFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            null_option: builtins.str,
            aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
            include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
            range_maximum: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumericRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            range_minimum: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumericRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``NumericRangeFilter`` filters values that are within the value range.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param aggregation_function: The aggregation function of the filter.
            :param include_maximum: Determines whether the maximum value in the filter value range should be included in the filtered results.
            :param include_minimum: Determines whether the minimum value in the filter value range should be included in the filtered results.
            :param range_maximum: The maximum value for the filter value range.
            :param range_minimum: The minimum value for the filter value range.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numeric_range_filter_property = quicksight.CfnAnalysis.NumericRangeFilterProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                        attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                            simple_attribute_aggregation="simpleAttributeAggregation",
                            value_for_multiple_values="valueForMultipleValues"
                        ),
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    include_maximum=False,
                    include_minimum=False,
                    range_maximum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                        parameter="parameter",
                        static_value=123
                    ),
                    range_minimum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                        parameter="parameter",
                        static_value=123
                    ),
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__22121b996d17d1f69aed09532525dd7473a2a7435181784f7a383c84827a4a8b)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument include_maximum", value=include_maximum, expected_type=type_hints["include_maximum"])
                check_type(argname="argument include_minimum", value=include_minimum, expected_type=type_hints["include_minimum"])
                check_type(argname="argument range_maximum", value=range_maximum, expected_type=type_hints["range_maximum"])
                check_type(argname="argument range_minimum", value=range_minimum, expected_type=type_hints["range_minimum"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if include_maximum is not None:
                self._values["include_maximum"] = include_maximum
            if include_minimum is not None:
                self._values["include_minimum"] = include_minimum
            if range_maximum is not None:
                self._values["range_maximum"] = range_maximum
            if range_minimum is not None:
                self._values["range_minimum"] = range_minimum
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AggregationFunctionProperty"]]:
            '''The aggregation function of the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AggregationFunctionProperty"]], result)

        @builtins.property
        def include_maximum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''Determines whether the maximum value in the filter value range should be included in the filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-includemaximum
            '''
            result = self._values.get("include_maximum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        @builtins.property
        def include_minimum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''Determines whether the minimum value in the filter value range should be included in the filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-includeminimum
            '''
            result = self._values.get("include_minimum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        @builtins.property
        def range_maximum(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericRangeFilterValueProperty"]]:
            '''The maximum value for the filter value range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-rangemaximum
            '''
            result = self._values.get("range_maximum")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericRangeFilterValueProperty"]], result)

        @builtins.property
        def range_minimum(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericRangeFilterValueProperty"]]:
            '''The minimum value for the filter value range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-rangeminimum
            '''
            result = self._values.get("range_minimum")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericRangeFilterValueProperty"]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericRangeFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.NumericRangeFilterValueProperty",
        jsii_struct_bases=[],
        name_mapping={"parameter": "parameter", "static_value": "staticValue"},
    )
    class NumericRangeFilterValueProperty:
        def __init__(
            self,
            *,
            parameter: typing.Optional[builtins.str] = None,
            static_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The value input pf the numeric range filter.

            :param parameter: The parameter that is used in the numeric range.
            :param static_value: The static value of the numeric range filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefiltervalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numeric_range_filter_value_property = quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                    parameter="parameter",
                    static_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__94b66a9875fdff413b818df8868b864ccb89e25196ca329ba757670f4eabf6bc)
                check_type(argname="argument parameter", value=parameter, expected_type=type_hints["parameter"])
                check_type(argname="argument static_value", value=static_value, expected_type=type_hints["static_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if parameter is not None:
                self._values["parameter"] = parameter
            if static_value is not None:
                self._values["static_value"] = static_value

        @builtins.property
        def parameter(self) -> typing.Optional[builtins.str]:
            '''The parameter that is used in the numeric range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefiltervalue.html#cfn-quicksight-analysis-numericrangefiltervalue-parameter
            '''
            result = self._values.get("parameter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def static_value(self) -> typing.Optional[jsii.Number]:
            '''The static value of the numeric range filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefiltervalue.html#cfn-quicksight-analysis-numericrangefiltervalue-staticvalue
            '''
            result = self._values.get("static_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericRangeFilterValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_separator": "decimalSeparator",
            "thousands_separator": "thousandsSeparator",
        },
    )
    class NumericSeparatorConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_separator: typing.Optional[builtins.str] = None,
            thousands_separator: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ThousandSeparatorOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the numeric separator configuration.

            :param decimal_separator: Determines the decimal separator.
            :param thousands_separator: The options that determine the thousands separator configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericseparatorconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numeric_separator_configuration_property = quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                    decimal_separator="decimalSeparator",
                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                        symbol="symbol",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__35127550d5767c629ae21cfca2c3501eee97480296df3162a9d4444efcfaa787)
                check_type(argname="argument decimal_separator", value=decimal_separator, expected_type=type_hints["decimal_separator"])
                check_type(argname="argument thousands_separator", value=thousands_separator, expected_type=type_hints["thousands_separator"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_separator is not None:
                self._values["decimal_separator"] = decimal_separator
            if thousands_separator is not None:
                self._values["thousands_separator"] = thousands_separator

        @builtins.property
        def decimal_separator(self) -> typing.Optional[builtins.str]:
            '''Determines the decimal separator.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericseparatorconfiguration.html#cfn-quicksight-analysis-numericseparatorconfiguration-decimalseparator
            '''
            result = self._values.get("decimal_separator")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def thousands_separator(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ThousandSeparatorOptionsProperty"]]:
            '''The options that determine the thousands separator configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericseparatorconfiguration.html#cfn-quicksight-analysis-numericseparatorconfiguration-thousandsseparator
            '''
            result = self._values.get("thousands_separator")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ThousandSeparatorOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericSeparatorConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.NumericalAggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "percentile_aggregation": "percentileAggregation",
            "simple_numerical_aggregation": "simpleNumericalAggregation",
        },
    )
    class NumericalAggregationFunctionProperty:
        def __init__(
            self,
            *,
            percentile_aggregation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PercentileAggregationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            simple_numerical_aggregation: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Aggregation for numerical values.

            :param percentile_aggregation: An aggregation based on the percentile of values in a dimension or measure.
            :param simple_numerical_aggregation: Built-in aggregation functions for numerical values. - ``SUM`` : The sum of a dimension or measure. - ``AVERAGE`` : The average of a dimension or measure. - ``MIN`` : The minimum value of a dimension or measure. - ``MAX`` : The maximum value of a dimension or measure. - ``COUNT`` : The count of a dimension or measure. - ``DISTINCT_COUNT`` : The count of distinct values in a dimension or measure. - ``VAR`` : The variance of a dimension or measure. - ``VARP`` : The partitioned variance of a dimension or measure. - ``STDEV`` : The standard deviation of a dimension or measure. - ``STDEVP`` : The partitioned standard deviation of a dimension or measure. - ``MEDIAN`` : The median value of a dimension or measure.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalaggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numerical_aggregation_function_property = quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                        percentile_value=123
                    ),
                    simple_numerical_aggregation="simpleNumericalAggregation"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f3699075a07bdf0da1b9b1cd6175755a4f1bd3ab16ec2487d515407f560ee9c4)
                check_type(argname="argument percentile_aggregation", value=percentile_aggregation, expected_type=type_hints["percentile_aggregation"])
                check_type(argname="argument simple_numerical_aggregation", value=simple_numerical_aggregation, expected_type=type_hints["simple_numerical_aggregation"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percentile_aggregation is not None:
                self._values["percentile_aggregation"] = percentile_aggregation
            if simple_numerical_aggregation is not None:
                self._values["simple_numerical_aggregation"] = simple_numerical_aggregation

        @builtins.property
        def percentile_aggregation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PercentileAggregationProperty"]]:
            '''An aggregation based on the percentile of values in a dimension or measure.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalaggregationfunction.html#cfn-quicksight-analysis-numericalaggregationfunction-percentileaggregation
            '''
            result = self._values.get("percentile_aggregation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PercentileAggregationProperty"]], result)

        @builtins.property
        def simple_numerical_aggregation(self) -> typing.Optional[builtins.str]:
            '''Built-in aggregation functions for numerical values.

            - ``SUM`` : The sum of a dimension or measure.
            - ``AVERAGE`` : The average of a dimension or measure.
            - ``MIN`` : The minimum value of a dimension or measure.
            - ``MAX`` : The maximum value of a dimension or measure.
            - ``COUNT`` : The count of a dimension or measure.
            - ``DISTINCT_COUNT`` : The count of distinct values in a dimension or measure.
            - ``VAR`` : The variance of a dimension or measure.
            - ``VARP`` : The partitioned variance of a dimension or measure.
            - ``STDEV`` : The standard deviation of a dimension or measure.
            - ``STDEVP`` : The partitioned standard deviation of a dimension or measure.
            - ``MEDIAN`` : The median value of a dimension or measure.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalaggregationfunction.html#cfn-quicksight-analysis-numericalaggregationfunction-simplenumericalaggregation
            '''
            result = self._values.get("simple_numerical_aggregation")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalAggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.NumericalDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class NumericalDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with numerical type columns.

            :param column: The column that is used in the ``NumericalDimensionField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numerical_dimension_field_property = quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c884448e58886a2cd093fa60765ed534cb3ce6ccf9f4e7726904392be8fb1a88)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that is used in the ``NumericalDimensionField`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html#cfn-quicksight-analysis-numericaldimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html#cfn-quicksight-analysis-numericaldimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumberFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html#cfn-quicksight-analysis-numericaldimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumberFormatConfigurationProperty"]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html#cfn-quicksight-analysis-numericaldimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.NumericalMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class NumericalMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure type field with numerical type columns.

            :param column: The column that is used in the ``NumericalMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numerical_measure_field_property = quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    ),
                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5f1c6489007cf21aeca1aed2e4c6a71300c68f91d9e433f5b58d4cbba2ef0f73)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that is used in the ``NumericalMeasureField`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html#cfn-quicksight-analysis-numericalmeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html#cfn-quicksight-analysis-numericalmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericalAggregationFunctionProperty"]]:
            '''The aggregation function of the measure field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html#cfn-quicksight-analysis-numericalmeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericalAggregationFunctionProperty"]], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumberFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html#cfn-quicksight-analysis-numericalmeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumberFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PaginationConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"page_number": "pageNumber", "page_size": "pageSize"},
    )
    class PaginationConfigurationProperty:
        def __init__(self, *, page_number: jsii.Number, page_size: jsii.Number) -> None:
            '''The pagination configuration for a table visual or boxplot.

            :param page_number: Indicates the page number.
            :param page_size: Indicates how many items render in one page.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paginationconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pagination_configuration_property = quicksight.CfnAnalysis.PaginationConfigurationProperty(
                    page_number=123,
                    page_size=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f399c1aaf81d1ec0b93e1de9bb2452d78823166b84f409c470082903a9007a7d)
                check_type(argname="argument page_number", value=page_number, expected_type=type_hints["page_number"])
                check_type(argname="argument page_size", value=page_size, expected_type=type_hints["page_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "page_number": page_number,
                "page_size": page_size,
            }

        @builtins.property
        def page_number(self) -> jsii.Number:
            '''Indicates the page number.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paginationconfiguration.html#cfn-quicksight-analysis-paginationconfiguration-pagenumber
            '''
            result = self._values.get("page_number")
            assert result is not None, "Required property 'page_number' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def page_size(self) -> jsii.Number:
            '''Indicates how many items render in one page.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paginationconfiguration.html#cfn-quicksight-analysis-paginationconfiguration-pagesize
            '''
            result = self._values.get("page_size")
            assert result is not None, "Required property 'page_size' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PaginationConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PanelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "background_visibility": "backgroundVisibility",
            "border_color": "borderColor",
            "border_style": "borderStyle",
            "border_thickness": "borderThickness",
            "border_visibility": "borderVisibility",
            "gutter_spacing": "gutterSpacing",
            "gutter_visibility": "gutterVisibility",
            "title": "title",
        },
    )
    class PanelConfigurationProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[builtins.str] = None,
            background_visibility: typing.Optional[builtins.str] = None,
            border_color: typing.Optional[builtins.str] = None,
            border_style: typing.Optional[builtins.str] = None,
            border_thickness: typing.Optional[builtins.str] = None,
            border_visibility: typing.Optional[builtins.str] = None,
            gutter_spacing: typing.Optional[builtins.str] = None,
            gutter_visibility: typing.Optional[builtins.str] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PanelTitleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A collection of options that configure how each panel displays in a small multiples chart.

            :param background_color: Sets the background color for each panel.
            :param background_visibility: Determines whether or not a background for each small multiples panel is rendered.
            :param border_color: Sets the line color of panel borders.
            :param border_style: Sets the line style of panel borders.
            :param border_thickness: Sets the line thickness of panel borders.
            :param border_visibility: Determines whether or not each panel displays a border.
            :param gutter_spacing: Sets the total amount of negative space to display between sibling panels.
            :param gutter_visibility: Determines whether or not negative space between sibling panels is rendered.
            :param title: Configures the title display within each small multiples panel.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                panel_configuration_property = quicksight.CfnAnalysis.PanelConfigurationProperty(
                    background_color="backgroundColor",
                    background_visibility="backgroundVisibility",
                    border_color="borderColor",
                    border_style="borderStyle",
                    border_thickness="borderThickness",
                    border_visibility="borderVisibility",
                    gutter_spacing="gutterSpacing",
                    gutter_visibility="gutterVisibility",
                    title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        horizontal_text_alignment="horizontalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__62ff6dc42b0e964ae6d9aa22bd3fa707ca34b4bf7933246833e06ab836a72bfb)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument background_visibility", value=background_visibility, expected_type=type_hints["background_visibility"])
                check_type(argname="argument border_color", value=border_color, expected_type=type_hints["border_color"])
                check_type(argname="argument border_style", value=border_style, expected_type=type_hints["border_style"])
                check_type(argname="argument border_thickness", value=border_thickness, expected_type=type_hints["border_thickness"])
                check_type(argname="argument border_visibility", value=border_visibility, expected_type=type_hints["border_visibility"])
                check_type(argname="argument gutter_spacing", value=gutter_spacing, expected_type=type_hints["gutter_spacing"])
                check_type(argname="argument gutter_visibility", value=gutter_visibility, expected_type=type_hints["gutter_visibility"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if background_visibility is not None:
                self._values["background_visibility"] = background_visibility
            if border_color is not None:
                self._values["border_color"] = border_color
            if border_style is not None:
                self._values["border_style"] = border_style
            if border_thickness is not None:
                self._values["border_thickness"] = border_thickness
            if border_visibility is not None:
                self._values["border_visibility"] = border_visibility
            if gutter_spacing is not None:
                self._values["gutter_spacing"] = gutter_spacing
            if gutter_visibility is not None:
                self._values["gutter_visibility"] = gutter_visibility
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def background_color(self) -> typing.Optional[builtins.str]:
            '''Sets the background color for each panel.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def background_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not a background for each small multiples panel is rendered.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-backgroundvisibility
            '''
            result = self._values.get("background_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_color(self) -> typing.Optional[builtins.str]:
            '''Sets the line color of panel borders.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-bordercolor
            '''
            result = self._values.get("border_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_style(self) -> typing.Optional[builtins.str]:
            '''Sets the line style of panel borders.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-borderstyle
            '''
            result = self._values.get("border_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_thickness(self) -> typing.Optional[builtins.str]:
            '''Sets the line thickness of panel borders.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-borderthickness
            '''
            result = self._values.get("border_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not each panel displays a border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-bordervisibility
            '''
            result = self._values.get("border_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def gutter_spacing(self) -> typing.Optional[builtins.str]:
            '''Sets the total amount of negative space to display between sibling panels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-gutterspacing
            '''
            result = self._values.get("gutter_spacing")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def gutter_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not negative space between sibling panels is rendered.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-guttervisibility
            '''
            result = self._values.get("gutter_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PanelTitleOptionsProperty"]]:
            '''Configures the title display within each small multiples panel.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PanelTitleOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PanelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PanelTitleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "font_configuration": "fontConfiguration",
            "horizontal_text_alignment": "horizontalTextAlignment",
            "visibility": "visibility",
        },
    )
    class PanelTitleOptionsProperty:
        def __init__(
            self,
            *,
            font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            horizontal_text_alignment: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the title styles for each small multiples panel.

            :param font_configuration: 
            :param horizontal_text_alignment: Sets the horizontal text alignment of the title within each panel.
            :param visibility: Determines whether or not panel titles are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paneltitleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                panel_title_options_property = quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    horizontal_text_alignment="horizontalTextAlignment",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__420cc8bf6553fc030a994a97a56037a8c6ae2dfd085c7e8ddfc6446751aca562)
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument horizontal_text_alignment", value=horizontal_text_alignment, expected_type=type_hints["horizontal_text_alignment"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if horizontal_text_alignment is not None:
                self._values["horizontal_text_alignment"] = horizontal_text_alignment
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paneltitleoptions.html#cfn-quicksight-analysis-paneltitleoptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"]], result)

        @builtins.property
        def horizontal_text_alignment(self) -> typing.Optional[builtins.str]:
            '''Sets the horizontal text alignment of the title within each panel.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paneltitleoptions.html#cfn-quicksight-analysis-paneltitleoptions-horizontaltextalignment
            '''
            result = self._values.get("horizontal_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not panel titles are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paneltitleoptions.html#cfn-quicksight-analysis-paneltitleoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PanelTitleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ParameterControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_picker": "dateTimePicker",
            "dropdown": "dropdown",
            "list": "list",
            "slider": "slider",
            "text_area": "textArea",
            "text_field": "textField",
        },
    )
    class ParameterControlProperty:
        def __init__(
            self,
            *,
            date_time_picker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ParameterDateTimePickerControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            dropdown: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ParameterDropDownControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            list: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ParameterListControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            slider: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ParameterSliderControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_area: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ParameterTextAreaControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ParameterTextFieldControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The control of a parameter that users can interact with in a dashboard or an analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_picker: A control from a date parameter that specifies date and time.
            :param dropdown: A control to display a dropdown list with buttons that are used to select a single value.
            :param list: A control to display a list with buttons or boxes that are used to select either a single value or multiple values.
            :param slider: A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
            :param text_area: A control to display a text box that is used to enter multiple entries.
            :param text_field: A control to display a text box that is used to enter a single entry.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_control_property = quicksight.CfnAnalysis.ParameterControlProperty(
                    date_time_picker=quicksight.CfnAnalysis.ParameterDateTimePickerControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    dropdown=quicksight.CfnAnalysis.ParameterDropDownControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                            link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            values=["values"]
                        ),
                        type="type"
                    ),
                    list=quicksight.CfnAnalysis.ParameterListControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                            link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            values=["values"]
                        ),
                        type="type"
                    ),
                    slider=quicksight.CfnAnalysis.ParameterSliderControlProperty(
                        maximum_value=123,
                        minimum_value=123,
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        step_size=123,
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_area=quicksight.CfnAnalysis.ParameterTextAreaControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        delimiter="delimiter",
                        display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_field=quicksight.CfnAnalysis.ParameterTextFieldControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__60327b150984223494769cd6a0d97c0e2e6eb3b5c17091364485d519da83f42b)
                check_type(argname="argument date_time_picker", value=date_time_picker, expected_type=type_hints["date_time_picker"])
                check_type(argname="argument dropdown", value=dropdown, expected_type=type_hints["dropdown"])
                check_type(argname="argument list", value=list, expected_type=type_hints["list"])
                check_type(argname="argument slider", value=slider, expected_type=type_hints["slider"])
                check_type(argname="argument text_area", value=text_area, expected_type=type_hints["text_area"])
                check_type(argname="argument text_field", value=text_field, expected_type=type_hints["text_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_picker is not None:
                self._values["date_time_picker"] = date_time_picker
            if dropdown is not None:
                self._values["dropdown"] = dropdown
            if list is not None:
                self._values["list"] = list
            if slider is not None:
                self._values["slider"] = slider
            if text_area is not None:
                self._values["text_area"] = text_area
            if text_field is not None:
                self._values["text_field"] = text_field

        @builtins.property
        def date_time_picker(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParameterDateTimePickerControlProperty"]]:
            '''A control from a date parameter that specifies date and time.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-datetimepicker
            '''
            result = self._values.get("date_time_picker")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParameterDateTimePickerControlProperty"]], result)

        @builtins.property
        def dropdown(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParameterDropDownControlProperty"]]:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-dropdown
            '''
            result = self._values.get("dropdown")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParameterDropDownControlProperty"]], result)

        @builtins.property
        def list(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParameterListControlProperty"]]:
            '''A control to display a list with buttons or boxes that are used to select either a single value or multiple values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-list
            '''
            result = self._values.get("list")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParameterListControlProperty"]], result)

        @builtins.property
        def slider(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParameterSliderControlProperty"]]:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-slider
            '''
            result = self._values.get("slider")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParameterSliderControlProperty"]], result)

        @builtins.property
        def text_area(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParameterTextAreaControlProperty"]]:
            '''A control to display a text box that is used to enter multiple entries.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-textarea
            '''
            result = self._values.get("text_area")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParameterTextAreaControlProperty"]], result)

        @builtins.property
        def text_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParameterTextFieldControlProperty"]]:
            '''A control to display a text box that is used to enter a single entry.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-textfield
            '''
            result = self._values.get("text_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParameterTextFieldControlProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ParameterDateTimePickerControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterDateTimePickerControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DateTimePickerControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control from a date parameter that specifies date and time.

            :param parameter_control_id: The ID of the ``ParameterDateTimePickerControl`` .
            :param source_parameter_name: The name of the ``ParameterDateTimePickerControl`` .
            :param title: The title of the ``ParameterDateTimePickerControl`` .
            :param display_options: The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_date_time_picker_control_property = quicksight.CfnAnalysis.ParameterDateTimePickerControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0b947c55505b1138b27122fbf28b6cd6397c31aea7b933155d1fdb1b62181cff)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterDateTimePickerControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html#cfn-quicksight-analysis-parameterdatetimepickercontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The name of the ``ParameterDateTimePickerControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html#cfn-quicksight-analysis-parameterdatetimepickercontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterDateTimePickerControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html#cfn-quicksight-analysis-parameterdatetimepickercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateTimePickerControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html#cfn-quicksight-analysis-parameterdatetimepickercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateTimePickerControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDateTimePickerControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_parameter_declaration": "dateTimeParameterDeclaration",
            "decimal_parameter_declaration": "decimalParameterDeclaration",
            "integer_parameter_declaration": "integerParameterDeclaration",
            "string_parameter_declaration": "stringParameterDeclaration",
        },
    )
    class ParameterDeclarationProperty:
        def __init__(
            self,
            *,
            date_time_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DateTimeParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            decimal_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DecimalParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            integer_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.IntegerParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            string_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.StringParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The declaration definition of a parameter.

            For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_parameter_declaration: A parameter declaration for the ``DateTime`` data type.
            :param decimal_parameter_declaration: A parameter declaration for the ``Decimal`` data type.
            :param integer_parameter_declaration: A parameter declaration for the ``Integer`` data type.
            :param string_parameter_declaration: A parameter declaration for the ``String`` data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_declaration_property = quicksight.CfnAnalysis.ParameterDeclarationProperty(
                    date_time_parameter_declaration=quicksight.CfnAnalysis.DateTimeParameterDeclarationProperty(
                        name="name",
                
                        # the properties below are optional
                        default_values=quicksight.CfnAnalysis.DateTimeDefaultValuesProperty(
                            dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        time_granularity="timeGranularity",
                        value_when_unset=quicksight.CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    decimal_parameter_declaration=quicksight.CfnAnalysis.DecimalParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnAnalysis.DecimalDefaultValuesProperty(
                            dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    integer_parameter_declaration=quicksight.CfnAnalysis.IntegerParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnAnalysis.IntegerDefaultValuesProperty(
                            dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    string_parameter_declaration=quicksight.CfnAnalysis.StringParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnAnalysis.StringDefaultValuesProperty(
                            dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnAnalysis.StringValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a7f9503f996228753475510f1868569a83191bf0466dca548b445ea0134b6200)
                check_type(argname="argument date_time_parameter_declaration", value=date_time_parameter_declaration, expected_type=type_hints["date_time_parameter_declaration"])
                check_type(argname="argument decimal_parameter_declaration", value=decimal_parameter_declaration, expected_type=type_hints["decimal_parameter_declaration"])
                check_type(argname="argument integer_parameter_declaration", value=integer_parameter_declaration, expected_type=type_hints["integer_parameter_declaration"])
                check_type(argname="argument string_parameter_declaration", value=string_parameter_declaration, expected_type=type_hints["string_parameter_declaration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_parameter_declaration is not None:
                self._values["date_time_parameter_declaration"] = date_time_parameter_declaration
            if decimal_parameter_declaration is not None:
                self._values["decimal_parameter_declaration"] = decimal_parameter_declaration
            if integer_parameter_declaration is not None:
                self._values["integer_parameter_declaration"] = integer_parameter_declaration
            if string_parameter_declaration is not None:
                self._values["string_parameter_declaration"] = string_parameter_declaration

        @builtins.property
        def date_time_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateTimeParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``DateTime`` data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html#cfn-quicksight-analysis-parameterdeclaration-datetimeparameterdeclaration
            '''
            result = self._values.get("date_time_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateTimeParameterDeclarationProperty"]], result)

        @builtins.property
        def decimal_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DecimalParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``Decimal`` data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html#cfn-quicksight-analysis-parameterdeclaration-decimalparameterdeclaration
            '''
            result = self._values.get("decimal_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DecimalParameterDeclarationProperty"]], result)

        @builtins.property
        def integer_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.IntegerParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``Integer`` data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html#cfn-quicksight-analysis-parameterdeclaration-integerparameterdeclaration
            '''
            result = self._values.get("integer_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.IntegerParameterDeclarationProperty"]], result)

        @builtins.property
        def string_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.StringParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``String`` data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html#cfn-quicksight-analysis-parameterdeclaration-stringparameterdeclaration
            '''
            result = self._values.get("string_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.StringParameterDeclarationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ParameterDropDownControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class ParameterDropDownControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DropDownControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ParameterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :param parameter_control_id: The ID of the ``ParameterDropDownControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterDropDownControl`` .
            :param title: The title of the ``ParameterDropDownControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type parameter name of the ``ParameterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_drop_down_control_property = quicksight.CfnAnalysis.ParameterDropDownControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                        link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1ffee6e4397e03ece63c1d82997f046791b6c95a0aed66aafa947c2c12873d70)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DropDownControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DropDownControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParameterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParameterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type parameter name of the ``ParameterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDropDownControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ParameterListControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class ParameterListControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ListControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ParameterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a list with buttons or boxes that are used to select either a single value or multiple values.

            :param parameter_control_id: The ID of the ``ParameterListControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterListControl`` .
            :param title: The title of the ``ParameterListControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of ``ParameterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_list_control_property = quicksight.CfnAnalysis.ParameterListControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                        link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__46c6c2e726ece85a94eaed4b6a42b2fd10c25b40e9a848649b6e8f7479005e28)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ListControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ListControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParameterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParameterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``ParameterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterListControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ParameterSelectableValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "link_to_data_set_column": "linkToDataSetColumn",
            "values": "values",
        },
    )
    class ParameterSelectableValuesProperty:
        def __init__(
            self,
            *,
            link_to_data_set_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A list of selectable values that are used in a control.

            :param link_to_data_set_column: The column identifier that fetches values from the data set.
            :param values: The values that are used in ``ParameterSelectableValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterselectablevalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_selectable_values_property = quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                    link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e9db77e230e585a4678dc0cb2fab8d12e011198969384173fb938948f444397f)
                check_type(argname="argument link_to_data_set_column", value=link_to_data_set_column, expected_type=type_hints["link_to_data_set_column"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if link_to_data_set_column is not None:
                self._values["link_to_data_set_column"] = link_to_data_set_column
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def link_to_data_set_column(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]]:
            '''The column identifier that fetches values from the data set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterselectablevalues.html#cfn-quicksight-analysis-parameterselectablevalues-linktodatasetcolumn
            '''
            result = self._values.get("link_to_data_set_column")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]], result)

        @builtins.property
        def values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The values that are used in ``ParameterSelectableValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterselectablevalues.html#cfn-quicksight-analysis-parameterselectablevalues-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterSelectableValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ParameterSliderControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "maximum_value": "maximumValue",
            "minimum_value": "minimumValue",
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "step_size": "stepSize",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterSliderControlProperty:
        def __init__(
            self,
            *,
            maximum_value: jsii.Number,
            minimum_value: jsii.Number,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            step_size: jsii.Number,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SliderControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :param maximum_value: The smaller value that is displayed at the left of the slider. Default: - 0
            :param minimum_value: The larger value that is displayed at the right of the slider. Default: - 0
            :param parameter_control_id: The ID of the ``ParameterSliderControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterSliderControl`` .
            :param step_size: The number of increments that the slider bar is divided into. Default: - 0
            :param title: The title of the ``ParameterSliderControl`` .
            :param display_options: The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_slider_control_property = quicksight.CfnAnalysis.ParameterSliderControlProperty(
                    maximum_value=123,
                    minimum_value=123,
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    step_size=123,
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bde7f633ffe57c8bd9fb30ef7b449ee66036bed77faa582e75a4aaa49ae2ba4e)
                check_type(argname="argument maximum_value", value=maximum_value, expected_type=type_hints["maximum_value"])
                check_type(argname="argument minimum_value", value=minimum_value, expected_type=type_hints["minimum_value"])
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "maximum_value": maximum_value,
                "minimum_value": minimum_value,
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "step_size": step_size,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def maximum_value(self) -> jsii.Number:
            '''The smaller value that is displayed at the left of the slider.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-maximumvalue
            '''
            result = self._values.get("maximum_value")
            assert result is not None, "Required property 'maximum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def minimum_value(self) -> jsii.Number:
            '''The larger value that is displayed at the right of the slider.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-minimumvalue
            '''
            result = self._values.get("minimum_value")
            assert result is not None, "Required property 'minimum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterSliderControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterSliderControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def step_size(self) -> jsii.Number:
            '''The number of increments that the slider bar is divided into.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-stepsize
            '''
            result = self._values.get("step_size")
            assert result is not None, "Required property 'step_size' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterSliderControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SliderControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SliderControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterSliderControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ParameterTextAreaControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "delimiter": "delimiter",
            "display_options": "displayOptions",
        },
    )
    class ParameterTextAreaControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            delimiter: typing.Optional[builtins.str] = None,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TextAreaControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter multiple entries.

            :param parameter_control_id: The ID of the ``ParameterTextAreaControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterTextAreaControl`` .
            :param title: The title of the ``ParameterTextAreaControl`` .
            :param delimiter: The delimiter that is used to separate the lines in text.
            :param display_options: The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_text_area_control_property = quicksight.CfnAnalysis.ParameterTextAreaControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    delimiter="delimiter",
                    display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__242e7927bb747c15898e306165b8b35c0c02c95070a0e16d9596fbeb66e6a5f0)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument delimiter", value=delimiter, expected_type=type_hints["delimiter"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if delimiter is not None:
                self._values["delimiter"] = delimiter
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def delimiter(self) -> typing.Optional[builtins.str]:
            '''The delimiter that is used to separate the lines in text.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-delimiter
            '''
            result = self._values.get("delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TextAreaControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TextAreaControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterTextAreaControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ParameterTextFieldControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterTextFieldControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TextFieldControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter a single entry.

            :param parameter_control_id: The ID of the ``ParameterTextFieldControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterTextFieldControl`` .
            :param title: The title of the ``ParameterTextFieldControl`` .
            :param display_options: The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_text_field_control_property = quicksight.CfnAnalysis.ParameterTextFieldControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0cd8bb9ad011a95ad6fa12b6fe0e13c2fe9df3921fc471bd6b9e0031cead6374)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterTextFieldControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html#cfn-quicksight-analysis-parametertextfieldcontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterTextFieldControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html#cfn-quicksight-analysis-parametertextfieldcontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterTextFieldControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html#cfn-quicksight-analysis-parametertextfieldcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TextFieldControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html#cfn-quicksight-analysis-parametertextfieldcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TextFieldControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterTextFieldControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ParametersProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_parameters": "dateTimeParameters",
            "decimal_parameters": "decimalParameters",
            "integer_parameters": "integerParameters",
            "string_parameters": "stringParameters",
        },
    )
    class ParametersProperty:
        def __init__(
            self,
            *,
            date_time_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DateTimeParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            decimal_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DecimalParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            integer_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.IntegerParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            string_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.StringParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''A list of Amazon QuickSight parameters and the list's override values.

            :param date_time_parameters: The parameters that have a data type of date-time.
            :param decimal_parameters: The parameters that have a data type of decimal.
            :param integer_parameters: The parameters that have a data type of integer.
            :param string_parameters: The parameters that have a data type of string.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameters_property = quicksight.CfnAnalysis.ParametersProperty(
                    date_time_parameters=[quicksight.CfnAnalysis.DateTimeParameterProperty(
                        name="name",
                        values=["values"]
                    )],
                    decimal_parameters=[quicksight.CfnAnalysis.DecimalParameterProperty(
                        name="name",
                        values=[123]
                    )],
                    integer_parameters=[quicksight.CfnAnalysis.IntegerParameterProperty(
                        name="name",
                        values=[123]
                    )],
                    string_parameters=[quicksight.CfnAnalysis.StringParameterProperty(
                        name="name",
                        values=["values"]
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c42f460c9d73b0fdb3e26fa1e8f471087532a0157acd6382fae430e5636b95bc)
                check_type(argname="argument date_time_parameters", value=date_time_parameters, expected_type=type_hints["date_time_parameters"])
                check_type(argname="argument decimal_parameters", value=decimal_parameters, expected_type=type_hints["decimal_parameters"])
                check_type(argname="argument integer_parameters", value=integer_parameters, expected_type=type_hints["integer_parameters"])
                check_type(argname="argument string_parameters", value=string_parameters, expected_type=type_hints["string_parameters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_parameters is not None:
                self._values["date_time_parameters"] = date_time_parameters
            if decimal_parameters is not None:
                self._values["decimal_parameters"] = decimal_parameters
            if integer_parameters is not None:
                self._values["integer_parameters"] = integer_parameters
            if string_parameters is not None:
                self._values["string_parameters"] = string_parameters

        @builtins.property
        def date_time_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateTimeParameterProperty"]]]]:
            '''The parameters that have a data type of date-time.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html#cfn-quicksight-analysis-parameters-datetimeparameters
            '''
            result = self._values.get("date_time_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DateTimeParameterProperty"]]]], result)

        @builtins.property
        def decimal_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DecimalParameterProperty"]]]]:
            '''The parameters that have a data type of decimal.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html#cfn-quicksight-analysis-parameters-decimalparameters
            '''
            result = self._values.get("decimal_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DecimalParameterProperty"]]]], result)

        @builtins.property
        def integer_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.IntegerParameterProperty"]]]]:
            '''The parameters that have a data type of integer.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html#cfn-quicksight-analysis-parameters-integerparameters
            '''
            result = self._values.get("integer_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.IntegerParameterProperty"]]]], result)

        @builtins.property
        def string_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.StringParameterProperty"]]]]:
            '''The parameters that have a data type of string.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html#cfn-quicksight-analysis-parameters-stringparameters
            '''
            result = self._values.get("string_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.StringParameterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PercentVisibleRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"from_": "from", "to": "to"},
    )
    class PercentVisibleRangeProperty:
        def __init__(
            self,
            *,
            from_: typing.Optional[jsii.Number] = None,
            to: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The percent range in the visible range.

            :param from_: The lower bound of the range.
            :param to: The top bound of the range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentvisiblerange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                percent_visible_range_property = quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                    from=123,
                    to=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6cbf715fdd3a2e720ecfa77cee9035e99c3b3b01308a907e8a1885bbf22db2f8)
                check_type(argname="argument from_", value=from_, expected_type=type_hints["from_"])
                check_type(argname="argument to", value=to, expected_type=type_hints["to"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if from_ is not None:
                self._values["from_"] = from_
            if to is not None:
                self._values["to"] = to

        @builtins.property
        def from_(self) -> typing.Optional[jsii.Number]:
            '''The lower bound of the range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentvisiblerange.html#cfn-quicksight-analysis-percentvisiblerange-from
            '''
            result = self._values.get("from_")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def to(self) -> typing.Optional[jsii.Number]:
            '''The top bound of the range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentvisiblerange.html#cfn-quicksight-analysis-percentvisiblerange-to
            '''
            result = self._values.get("to")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentVisibleRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
        },
    )
    class PercentageDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            negative_value_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            suffix: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the percentage display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param prefix: Determines the prefix value of the percentage format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the percentage format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                percentage_display_format_configuration_property = quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    prefix="prefix",
                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__57ce990bfa06d51987647cf514f9a8e16fde67d724df4f7d2cf788dccdb93125)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DecimalPlacesConfigurationProperty"]]:
            '''The option that determines the decimal places configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DecimalPlacesConfigurationProperty"]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NegativeValueConfigurationProperty"]]:
            '''The options that determine the negative value configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NegativeValueConfigurationProperty"]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the percentage format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericSeparatorConfigurationProperty"]]:
            '''The options that determine the numeric separator configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericSeparatorConfigurationProperty"]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the percentage format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentageDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PercentileAggregationProperty",
        jsii_struct_bases=[],
        name_mapping={"percentile_value": "percentileValue"},
    )
    class PercentileAggregationProperty:
        def __init__(
            self,
            *,
            percentile_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''An aggregation based on the percentile of values in a dimension or measure.

            :param percentile_value: The percentile value. This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentileaggregation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                percentile_aggregation_property = quicksight.CfnAnalysis.PercentileAggregationProperty(
                    percentile_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__049fe0843ccff40544d214fb7ec1f9bafd5175190fe04d33179dc68fa17e8a2d)
                check_type(argname="argument percentile_value", value=percentile_value, expected_type=type_hints["percentile_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percentile_value is not None:
                self._values["percentile_value"] = percentile_value

        @builtins.property
        def percentile_value(self) -> typing.Optional[jsii.Number]:
            '''The percentile value.

            This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentileaggregation.html#cfn-quicksight-analysis-percentileaggregation-percentilevalue
            '''
            result = self._values.get("percentile_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentileAggregationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "name": "name",
            "time": "time",
            "value": "value",
        },
    )
    class PeriodOverPeriodComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            name: typing.Optional[builtins.str] = None,
            time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The period over period computation configuration.

            :param computation_id: The ID for a computation.
            :param name: The name of a computation.
            :param time: The time field that is used in a computation.
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                period_over_period_computation_property = quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty(
                    computation_id="computationId",
                
                    # the properties below are optional
                    name="name",
                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__19abb806312347d369d990a7bb54b20d3a7767497ca5fc56c09168efbc1ffb70)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
            }
            if name is not None:
                self._values["name"] = name
            if time is not None:
                self._values["time"] = time
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html#cfn-quicksight-analysis-periodoverperiodcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html#cfn-quicksight-analysis-periodoverperiodcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]:
            '''The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html#cfn-quicksight-analysis-periodoverperiodcomputation-time
            '''
            result = self._values.get("time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html#cfn-quicksight-analysis-periodoverperiodcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PeriodOverPeriodComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PeriodToDateComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "name": "name",
            "period_time_granularity": "periodTimeGranularity",
            "time": "time",
            "value": "value",
        },
    )
    class PeriodToDateComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            name: typing.Optional[builtins.str] = None,
            period_time_granularity: typing.Optional[builtins.str] = None,
            time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The period to date computation configuration.

            :param computation_id: The ID for a computation.
            :param name: The name of a computation.
            :param period_time_granularity: The time granularity setup of period to date computation. Choose from the following options:. - YEAR: Year to date. - MONTH: Month to date.
            :param time: The time field that is used in a computation.
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                period_to_date_computation_property = quicksight.CfnAnalysis.PeriodToDateComputationProperty(
                    computation_id="computationId",
                
                    # the properties below are optional
                    name="name",
                    period_time_granularity="periodTimeGranularity",
                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fe85ace06e99d6c2d932a6aa27764fdf899d91a8fa36393bf94f4d593596c62f)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument period_time_granularity", value=period_time_granularity, expected_type=type_hints["period_time_granularity"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
            }
            if name is not None:
                self._values["name"] = name
            if period_time_granularity is not None:
                self._values["period_time_granularity"] = period_time_granularity
            if time is not None:
                self._values["time"] = time
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def period_time_granularity(self) -> typing.Optional[builtins.str]:
            '''The time granularity setup of period to date computation. Choose from the following options:.

            - YEAR: Year to date.
            - MONTH: Month to date.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-periodtimegranularity
            '''
            result = self._values.get("period_time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]:
            '''The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-time
            '''
            result = self._values.get("time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PeriodToDateComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PieChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class PieChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a pie chart.

            :param category: The category (group/color) field wells of a pie chart.
            :param small_multiples: The small multiples field well of a pie chart.
            :param values: The value field wells of a pie chart. Values are aggregated based on categories.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b55211ea304f1ba435ed044a6533c8f5fd12bc96eb05251261916d02bb93fd55)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The category (group/color) field wells of a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartaggregatedfieldwells.html#cfn-quicksight-analysis-piechartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The small multiples field well of a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartaggregatedfieldwells.html#cfn-quicksight-analysis-piechartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The value field wells of a pie chart.

            Values are aggregated based on categories.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartaggregatedfieldwells.html#cfn-quicksight-analysis-piechartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PieChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "donut_options": "donutOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class PieChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            donut_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DonutOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PieChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PieChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a pie chart.

            :param category_label_options: The label options of the group/color that is displayed in a pie chart.
            :param contribution_analysis_defaults: The contribution analysis (anomaly configuration) setup of the visual.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param donut_options: The options that determine the shape of the chart. This option determines whether the chart is a pie chart or a donut chart.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a pie chart.
            :param tooltip: The tooltip display setup of the visual.
            :param value_label_options: The label options for the value that is displayed in a pie chart.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__06e6889a741bd706b6aa9c48db14c01e76697b34f5e2500f53c7f3657475fca4)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument donut_options", value=donut_options, expected_type=type_hints["donut_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if donut_options is not None:
                self._values["donut_options"] = donut_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the group/color that is displayed in a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ContributionAnalysisDefaultProperty"]]]]:
            '''The contribution analysis (anomaly configuration) setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ContributionAnalysisDefaultProperty"]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def donut_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DonutOptionsProperty"]]:
            '''The options that determine the shape of the chart.

            This option determines whether the chart is a pie chart or a donut chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-donutoptions
            '''
            result = self._values.get("donut_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DonutOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PieChartFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PieChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SmallMultiplesOptionsProperty"]]:
            '''The small multiples setup for the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SmallMultiplesOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PieChartSortConfigurationProperty"]]:
            '''The sort configuration of a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PieChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options for the value that is displayed in a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PieChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pie_chart_aggregated_field_wells": "pieChartAggregatedFieldWells",
        },
    )
    class PieChartFieldWellsProperty:
        def __init__(
            self,
            *,
            pie_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PieChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a pie chart.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param pie_chart_aggregated_field_wells: The field well configuration of a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ab54105dabb13e29c9576abcfa5bbeb882c91302b0041e5ea9046cf95659429b)
                check_type(argname="argument pie_chart_aggregated_field_wells", value=pie_chart_aggregated_field_wells, expected_type=type_hints["pie_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pie_chart_aggregated_field_wells is not None:
                self._values["pie_chart_aggregated_field_wells"] = pie_chart_aggregated_field_wells

        @builtins.property
        def pie_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PieChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartfieldwells.html#cfn-quicksight-analysis-piechartfieldwells-piechartaggregatedfieldwells
            '''
            result = self._values.get("pie_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PieChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PieChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class PieChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a pie chart.

            :param category_items_limit: The limit on the number of categories that are displayed in a pie chart.
            :param category_sort: The sort configuration of the category fields.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pie_chart_sort_configuration_property = quicksight.CfnAnalysis.PieChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a198c936c49f9e68a2f73d8d57b554e2757aa506639569158c4fb5f01fc27ea5)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories that are displayed in a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html#cfn-quicksight-analysis-piechartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html#cfn-quicksight-analysis-piechartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of small multiples panels that are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html#cfn-quicksight-analysis-piechartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the small multiples field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html#cfn-quicksight-analysis-piechartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PieChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class PieChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PieChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A pie or donut chart.

            The ``PieChartVisual`` structure describes a visual that is a member of the pie chart family.

            The following charts can be described by using this structure:

            - Pie charts
            - Donut charts

            For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .

            For more information, see `Using donut charts <https://docs.aws.amazon.com/quicksight/latest/user/donut-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a pie chart.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__87e7c14dfca412c496b31d4eab981e0d21211ce4789fd4bf0fce546b17f97846)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PieChartConfigurationProperty"]]:
            '''The configuration of a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PieChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotFieldSortOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "sort_by": "sortBy"},
    )
    class PivotFieldSortOptionsProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            sort_by: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTableSortByProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The field sort options for a pivot table sort configuration.

            :param field_id: The field ID for the field sort options.
            :param sort_by: The sort by field for the field sort options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivotfieldsortoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_field_sort_options_property = quicksight.CfnAnalysis.PivotFieldSortOptionsProperty(
                    field_id="fieldId",
                    sort_by=quicksight.CfnAnalysis.PivotTableSortByProperty(
                        column=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                            direction="direction",
                            sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                                data_path_type=quicksight.CfnAnalysis.DataPathTypeProperty(
                                    pivot_table_data_path_type="pivotTableDataPathType"
                                ),
                                field_id="fieldId",
                                field_value="fieldValue"
                            )]
                        ),
                        field=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__83e21cb6b3c5836506b0141e8fc413cc57cc44830800cb3aad9bb415285d817e)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument sort_by", value=sort_by, expected_type=type_hints["sort_by"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
                "sort_by": sort_by,
            }

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for the field sort options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivotfieldsortoptions.html#cfn-quicksight-analysis-pivotfieldsortoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_by(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableSortByProperty"]:
            '''The sort by field for the field sort options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivotfieldsortoptions.html#cfn-quicksight-analysis-pivotfieldsortoptions-sortby
            '''
            result = self._values.get("sort_by")
            assert result is not None, "Required property 'sort_by' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableSortByProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotFieldSortOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotTableAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns", "rows": "rows", "values": "values"},
    )
    class PivotTableAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            columns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            rows: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well for the pivot table.

            :param columns: The columns field well for a pivot table. Values are grouped by columns fields.
            :param rows: The rows field well for a pivot table. Values are grouped by rows fields.
            :param values: The values field well for a pivot table. Values are aggregated based on rows and columns fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__99497a9dc0b93024e0ed1774ff7c52e31641478c8255b5451cd89c08495cf683)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument rows", value=rows, expected_type=type_hints["rows"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if columns is not None:
                self._values["columns"] = columns
            if rows is not None:
                self._values["rows"] = rows
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def columns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The columns field well for a pivot table.

            Values are grouped by columns fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableaggregatedfieldwells.html#cfn-quicksight-analysis-pivottableaggregatedfieldwells-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def rows(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The rows field well for a pivot table.

            Values are grouped by rows fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableaggregatedfieldwells.html#cfn-quicksight-analysis-pivottableaggregatedfieldwells-rows
            '''
            result = self._values.get("rows")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The values field well for a pivot table.

            Values are aggregated based on rows and columns fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableaggregatedfieldwells.html#cfn-quicksight-analysis-pivottableaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "scope": "scope",
            "scopes": "scopes",
            "text_format": "textFormat",
        },
    )
    class PivotTableCellConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            scope: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTableConditionalFormattingScopeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scopes: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTableConditionalFormattingScopeProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            text_format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TextConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cell conditional formatting option for a pivot table.

            :param field_id: The field ID of the cell for conditional formatting.
            :param scope: The scope of the cell for conditional formatting.
            :param scopes: A list of cell scopes for conditional formatting.
            :param text_format: The text format of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_cell_conditional_formatting_property = quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    scope=quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                        role="role"
                    ),
                    scopes=[quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                        role="role"
                    )],
                    text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__092c32f9e13e00666ba0509805eff7259870fc11c01a190b4309dd640ba880d7)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
                check_type(argname="argument scopes", value=scopes, expected_type=type_hints["scopes"])
                check_type(argname="argument text_format", value=text_format, expected_type=type_hints["text_format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if scope is not None:
                self._values["scope"] = scope
            if scopes is not None:
                self._values["scopes"] = scopes
            if text_format is not None:
                self._values["text_format"] = text_format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html#cfn-quicksight-analysis-pivottablecellconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def scope(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableConditionalFormattingScopeProperty"]]:
            '''The scope of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html#cfn-quicksight-analysis-pivottablecellconditionalformatting-scope
            '''
            result = self._values.get("scope")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableConditionalFormattingScopeProperty"]], result)

        @builtins.property
        def scopes(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableConditionalFormattingScopeProperty"]]]]:
            '''A list of cell scopes for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html#cfn-quicksight-analysis-pivottablecellconditionalformatting-scopes
            '''
            result = self._values.get("scopes")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableConditionalFormattingScopeProperty"]]]], result)

        @builtins.property
        def text_format(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TextConditionalFormatProperty"]]:
            '''The text format of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html#cfn-quicksight-analysis-pivottablecellconditionalformatting-textformat
            '''
            result = self._values.get("text_format")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TextConditionalFormatProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableCellConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotTableConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"cell": "cell"},
    )
    class PivotTableConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            cell: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTableCellConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :param cell: The cell conditional formatting option for a pivot table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_option_property = quicksight.CfnAnalysis.PivotTableConditionalFormattingOptionProperty(
                    cell=quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        scope=quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                            role="role"
                        ),
                        scopes=[quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                            role="role"
                        )],
                        text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__22adcc402876cc329159f35f7bb36f2c228bf514ddc3d120c6a13c1742c1dd76)
                check_type(argname="argument cell", value=cell, expected_type=type_hints["cell"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell is not None:
                self._values["cell"] = cell

        @builtins.property
        def cell(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableCellConditionalFormattingProperty"]]:
            '''The cell conditional formatting option for a pivot table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformattingoption.html#cfn-quicksight-analysis-pivottableconditionalformattingoption-cell
            '''
            result = self._values.get("cell")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableCellConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotTableConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class PivotTableConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTableConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :param conditional_formatting_options: Conditional formatting options for a ``PivotTableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_property = quicksight.CfnAnalysis.PivotTableConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnAnalysis.PivotTableConditionalFormattingOptionProperty(
                        cell=quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            scope=quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                                role="role"
                            ),
                            scopes=[quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                                role="role"
                            )],
                            text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7e648166813ac500d0d524b4ef391d6c6d4bbf3fb791b9d966ef0fef150b01f7)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableConditionalFormattingOptionProperty"]]]]:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformatting.html#cfn-quicksight-analysis-pivottableconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty",
        jsii_struct_bases=[],
        name_mapping={"role": "role"},
    )
    class PivotTableConditionalFormattingScopeProperty:
        def __init__(self, *, role: typing.Optional[builtins.str] = None) -> None:
            '''The scope of the cell for conditional formatting.

            :param role: The role (field, field total, grand total) of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformattingscope.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_scope_property = quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                    role="role"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ce31bd45e61e635a94490d1892ae11b119c36b6495f844c1222db3409df1a886)
                check_type(argname="argument role", value=role, expected_type=type_hints["role"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if role is not None:
                self._values["role"] = role

        @builtins.property
        def role(self) -> typing.Optional[builtins.str]:
            '''The role (field, field total, grand total) of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformattingscope.html#cfn-quicksight-analysis-pivottableconditionalformattingscope-role
            '''
            result = self._values.get("role")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingScopeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotTableConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_options": "fieldOptions",
            "field_wells": "fieldWells",
            "paginated_report_options": "paginatedReportOptions",
            "sort_configuration": "sortConfiguration",
            "table_options": "tableOptions",
            "total_options": "totalOptions",
        },
    )
    class PivotTableConfigurationProperty:
        def __init__(
            self,
            *,
            field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTableFieldOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTableFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paginated_report_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTablePaginatedReportOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTableSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTableOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTableTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``PivotTableVisual`` .

            :param field_options: The field options for a pivot table visual.
            :param field_wells: The field wells of the visual.
            :param paginated_report_options: The paginated report options for a pivot table visual.
            :param sort_configuration: The sort configuration for a ``PivotTableVisual`` .
            :param table_options: The table options for a pivot table visual.
            :param total_options: The total options for a pivot table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d4434f54ddcd50c24d2ee3ebd81aa73e692d8e676fbf16df83642137b261af73)
                check_type(argname="argument field_options", value=field_options, expected_type=type_hints["field_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument paginated_report_options", value=paginated_report_options, expected_type=type_hints["paginated_report_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument table_options", value=table_options, expected_type=type_hints["table_options"])
                check_type(argname="argument total_options", value=total_options, expected_type=type_hints["total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_options is not None:
                self._values["field_options"] = field_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if paginated_report_options is not None:
                self._values["paginated_report_options"] = paginated_report_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if table_options is not None:
                self._values["table_options"] = table_options
            if total_options is not None:
                self._values["total_options"] = total_options

        @builtins.property
        def field_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableFieldOptionsProperty"]]:
            '''The field options for a pivot table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-fieldoptions
            '''
            result = self._values.get("field_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableFieldOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableFieldWellsProperty"]], result)

        @builtins.property
        def paginated_report_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTablePaginatedReportOptionsProperty"]]:
            '''The paginated report options for a pivot table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-paginatedreportoptions
            '''
            result = self._values.get("paginated_report_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTablePaginatedReportOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableSortConfigurationProperty"]]:
            '''The sort configuration for a ``PivotTableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableSortConfigurationProperty"]], result)

        @builtins.property
        def table_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableOptionsProperty"]]:
            '''The table options for a pivot table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-tableoptions
            '''
            result = self._values.get("table_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableOptionsProperty"]], result)

        @builtins.property
        def total_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableTotalOptionsProperty"]]:
            '''The total options for a pivot table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-totaloptions
            '''
            result = self._values.get("total_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableTotalOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotTableDataPathOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"data_path_list": "dataPathList", "width": "width"},
    )
    class PivotTableDataPathOptionProperty:
        def __init__(
            self,
            *,
            data_path_list: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]]]]],
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The data path options for the pivot table field options.

            :param data_path_list: The list of data path values for the data path options.
            :param width: The width of the data path option.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabledatapathoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_data_path_option_property = quicksight.CfnAnalysis.PivotTableDataPathOptionProperty(
                    data_path_list=[quicksight.CfnAnalysis.DataPathValueProperty(
                        data_path_type=quicksight.CfnAnalysis.DataPathTypeProperty(
                            pivot_table_data_path_type="pivotTableDataPathType"
                        ),
                        field_id="fieldId",
                        field_value="fieldValue"
                    )],
                
                    # the properties below are optional
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2dbcae52b863a76a15d188d1ac324b673884416c60cada64111334eb0d006c5d)
                check_type(argname="argument data_path_list", value=data_path_list, expected_type=type_hints["data_path_list"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_path_list": data_path_list,
            }
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def data_path_list(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataPathValueProperty"]]]:
            '''The list of data path values for the data path options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabledatapathoption.html#cfn-quicksight-analysis-pivottabledatapathoption-datapathlist
            '''
            result = self._values.get("data_path_list")
            assert result is not None, "Required property 'data_path_list' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataPathValueProperty"]]], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width of the data path option.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabledatapathoption.html#cfn-quicksight-analysis-pivottabledatapathoption-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableDataPathOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotTableFieldCollapseStateOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"target": "target", "state": "state"},
    )
    class PivotTableFieldCollapseStateOptionProperty:
        def __init__(
            self,
            *,
            target: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTableFieldCollapseStateTargetProperty", typing.Dict[builtins.str, typing.Any]]],
            state: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The collapse state options for the pivot table field options.

            :param target: A tagged-union object that sets the collapse state.
            :param state: The state of the field target of a pivot table. Choose one of the following options:. - ``COLLAPSED`` - ``EXPANDED``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldcollapsestateoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_field_collapse_state_option_property = quicksight.CfnAnalysis.PivotTableFieldCollapseStateOptionProperty(
                    target=quicksight.CfnAnalysis.PivotTableFieldCollapseStateTargetProperty(
                        field_data_path_values=[quicksight.CfnAnalysis.DataPathValueProperty(
                            data_path_type=quicksight.CfnAnalysis.DataPathTypeProperty(
                                pivot_table_data_path_type="pivotTableDataPathType"
                            ),
                            field_id="fieldId",
                            field_value="fieldValue"
                        )],
                        field_id="fieldId"
                    ),
                
                    # the properties below are optional
                    state="state"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6bbb18f34d16d53e931277e5afae73f4b2e5db3202f4afd6ccec4f44f44128a0)
                check_type(argname="argument target", value=target, expected_type=type_hints["target"])
                check_type(argname="argument state", value=state, expected_type=type_hints["state"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "target": target,
            }
            if state is not None:
                self._values["state"] = state

        @builtins.property
        def target(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableFieldCollapseStateTargetProperty"]:
            '''A tagged-union object that sets the collapse state.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldcollapsestateoption.html#cfn-quicksight-analysis-pivottablefieldcollapsestateoption-target
            '''
            result = self._values.get("target")
            assert result is not None, "Required property 'target' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableFieldCollapseStateTargetProperty"], result)

        @builtins.property
        def state(self) -> typing.Optional[builtins.str]:
            '''The state of the field target of a pivot table. Choose one of the following options:.

            - ``COLLAPSED``
            - ``EXPANDED``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldcollapsestateoption.html#cfn-quicksight-analysis-pivottablefieldcollapsestateoption-state
            '''
            result = self._values.get("state")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldCollapseStateOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotTableFieldCollapseStateTargetProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_data_path_values": "fieldDataPathValues",
            "field_id": "fieldId",
        },
    )
    class PivotTableFieldCollapseStateTargetProperty:
        def __init__(
            self,
            *,
            field_data_path_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            field_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The target of a pivot table field collapse state.

            :param field_data_path_values: The data path of the pivot table's header. Used to set the collapse state.
            :param field_id: The field ID of the pivot table that the collapse state needs to be set to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldcollapsestatetarget.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_field_collapse_state_target_property = quicksight.CfnAnalysis.PivotTableFieldCollapseStateTargetProperty(
                    field_data_path_values=[quicksight.CfnAnalysis.DataPathValueProperty(
                        data_path_type=quicksight.CfnAnalysis.DataPathTypeProperty(
                            pivot_table_data_path_type="pivotTableDataPathType"
                        ),
                        field_id="fieldId",
                        field_value="fieldValue"
                    )],
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__df673c36b8f0e452dc6b082c849ea50fe2fdafe3aea57e30666bd146508b9b94)
                check_type(argname="argument field_data_path_values", value=field_data_path_values, expected_type=type_hints["field_data_path_values"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_data_path_values is not None:
                self._values["field_data_path_values"] = field_data_path_values
            if field_id is not None:
                self._values["field_id"] = field_id

        @builtins.property
        def field_data_path_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataPathValueProperty"]]]]:
            '''The data path of the pivot table's header.

            Used to set the collapse state.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldcollapsestatetarget.html#cfn-quicksight-analysis-pivottablefieldcollapsestatetarget-fielddatapathvalues
            '''
            result = self._values.get("field_data_path_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataPathValueProperty"]]]], result)

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the pivot table that the collapse state needs to be set to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldcollapsestatetarget.html#cfn-quicksight-analysis-pivottablefieldcollapsestatetarget-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldCollapseStateTargetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotTableFieldOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "custom_label": "customLabel",
            "visibility": "visibility",
        },
    )
    class PivotTableFieldOptionProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            custom_label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The selected field options for the pivot table field options.

            :param field_id: The field ID of the pivot table field.
            :param custom_label: The custom label of the pivot table field.
            :param visibility: The visibility of the pivot table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_field_option_property = quicksight.CfnAnalysis.PivotTableFieldOptionProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    custom_label="customLabel",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7a93e7598f842be1c4206dd58bc937dd54c6815dc3bbbbf57f27c2727cc4c7b6)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the pivot table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoption.html#cfn-quicksight-analysis-pivottablefieldoption-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label of the pivot table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoption.html#cfn-quicksight-analysis-pivottablefieldoption-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the pivot table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoption.html#cfn-quicksight-analysis-pivottablefieldoption-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotTableFieldOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "collapse_state_options": "collapseStateOptions",
            "data_path_options": "dataPathOptions",
            "selected_field_options": "selectedFieldOptions",
        },
    )
    class PivotTableFieldOptionsProperty:
        def __init__(
            self,
            *,
            collapse_state_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTableFieldCollapseStateOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_path_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTableDataPathOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            selected_field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTableFieldOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field options for a pivot table visual.

            :param collapse_state_options: The collapse state options for the pivot table field options.
            :param data_path_options: The data path options for the pivot table field options.
            :param selected_field_options: The selected field options for the pivot table field options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_field_options_property = quicksight.CfnAnalysis.PivotTableFieldOptionsProperty(
                    collapse_state_options=[quicksight.CfnAnalysis.PivotTableFieldCollapseStateOptionProperty(
                        target=quicksight.CfnAnalysis.PivotTableFieldCollapseStateTargetProperty(
                            field_data_path_values=[quicksight.CfnAnalysis.DataPathValueProperty(
                                data_path_type=quicksight.CfnAnalysis.DataPathTypeProperty(
                                    pivot_table_data_path_type="pivotTableDataPathType"
                                ),
                                field_id="fieldId",
                                field_value="fieldValue"
                            )],
                            field_id="fieldId"
                        ),
                
                        # the properties below are optional
                        state="state"
                    )],
                    data_path_options=[quicksight.CfnAnalysis.PivotTableDataPathOptionProperty(
                        data_path_list=[quicksight.CfnAnalysis.DataPathValueProperty(
                            data_path_type=quicksight.CfnAnalysis.DataPathTypeProperty(
                                pivot_table_data_path_type="pivotTableDataPathType"
                            ),
                            field_id="fieldId",
                            field_value="fieldValue"
                        )],
                
                        # the properties below are optional
                        width="width"
                    )],
                    selected_field_options=[quicksight.CfnAnalysis.PivotTableFieldOptionProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        custom_label="customLabel",
                        visibility="visibility"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f91436b5f1fd818eea1f37d669c26e7d919a8a787b97ec680904837320b7c12a)
                check_type(argname="argument collapse_state_options", value=collapse_state_options, expected_type=type_hints["collapse_state_options"])
                check_type(argname="argument data_path_options", value=data_path_options, expected_type=type_hints["data_path_options"])
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if collapse_state_options is not None:
                self._values["collapse_state_options"] = collapse_state_options
            if data_path_options is not None:
                self._values["data_path_options"] = data_path_options
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options

        @builtins.property
        def collapse_state_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableFieldCollapseStateOptionProperty"]]]]:
            '''The collapse state options for the pivot table field options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoptions.html#cfn-quicksight-analysis-pivottablefieldoptions-collapsestateoptions
            '''
            result = self._values.get("collapse_state_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableFieldCollapseStateOptionProperty"]]]], result)

        @builtins.property
        def data_path_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableDataPathOptionProperty"]]]]:
            '''The data path options for the pivot table field options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoptions.html#cfn-quicksight-analysis-pivottablefieldoptions-datapathoptions
            '''
            result = self._values.get("data_path_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableDataPathOptionProperty"]]]], result)

        @builtins.property
        def selected_field_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableFieldOptionProperty"]]]]:
            '''The selected field options for the pivot table field options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoptions.html#cfn-quicksight-analysis-pivottablefieldoptions-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableFieldOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId"},
    )
    class PivotTableFieldSubtotalOptionsProperty:
        def __init__(self, *, field_id: typing.Optional[builtins.str] = None) -> None:
            '''The optional configuration of subtotals cells.

            :param field_id: The field ID of the subtotal options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldsubtotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_field_subtotal_options_property = quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__466ef70e11d0eca6ffbed8c594fa2e80b8aaa8db73225578e9dc0ba0b2acd5dc)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the subtotal options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldsubtotaloptions.html#cfn-quicksight-analysis-pivottablefieldsubtotaloptions-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldSubtotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotTableFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pivot_table_aggregated_field_wells": "pivotTableAggregatedFieldWells",
        },
    )
    class PivotTableFieldWellsProperty:
        def __init__(
            self,
            *,
            pivot_table_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTableAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells for a pivot table visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param pivot_table_aggregated_field_wells: The aggregated field well for the pivot table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cbc3fbfa45d45d972e8d1a693a9dedd631616b09d2367fc9eae8c64c3fe4998a)
                check_type(argname="argument pivot_table_aggregated_field_wells", value=pivot_table_aggregated_field_wells, expected_type=type_hints["pivot_table_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pivot_table_aggregated_field_wells is not None:
                self._values["pivot_table_aggregated_field_wells"] = pivot_table_aggregated_field_wells

        @builtins.property
        def pivot_table_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableAggregatedFieldWellsProperty"]]:
            '''The aggregated field well for the pivot table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldwells.html#cfn-quicksight-analysis-pivottablefieldwells-pivottableaggregatedfieldwells
            '''
            result = self._values.get("pivot_table_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotTableOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cell_style": "cellStyle",
            "collapsed_row_dimensions_visibility": "collapsedRowDimensionsVisibility",
            "column_header_style": "columnHeaderStyle",
            "column_names_visibility": "columnNamesVisibility",
            "default_cell_width": "defaultCellWidth",
            "metric_placement": "metricPlacement",
            "row_alternate_color_options": "rowAlternateColorOptions",
            "row_field_names_style": "rowFieldNamesStyle",
            "row_header_style": "rowHeaderStyle",
            "rows_label_options": "rowsLabelOptions",
            "rows_layout": "rowsLayout",
            "single_metric_visibility": "singleMetricVisibility",
            "toggle_buttons_visibility": "toggleButtonsVisibility",
        },
    )
    class PivotTableOptionsProperty:
        def __init__(
            self,
            *,
            cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            collapsed_row_dimensions_visibility: typing.Optional[builtins.str] = None,
            column_header_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_names_visibility: typing.Optional[builtins.str] = None,
            default_cell_width: typing.Optional[builtins.str] = None,
            metric_placement: typing.Optional[builtins.str] = None,
            row_alternate_color_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.RowAlternateColorOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_field_names_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_header_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rows_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTableRowsLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rows_layout: typing.Optional[builtins.str] = None,
            single_metric_visibility: typing.Optional[builtins.str] = None,
            toggle_buttons_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The table options for a pivot table visual.

            :param cell_style: The table cell style of cells.
            :param collapsed_row_dimensions_visibility: The visibility setting of a pivot table's collapsed row dimension fields. If the value of this structure is ``HIDDEN`` , all collapsed columns in a pivot table are automatically hidden. The default value is ``VISIBLE`` .
            :param column_header_style: The table cell style of the column header.
            :param column_names_visibility: The visibility of the column names.
            :param default_cell_width: The default cell width of the pivot table.
            :param metric_placement: The metric placement (row, column) options.
            :param row_alternate_color_options: The row alternate color options (widget status, row alternate colors).
            :param row_field_names_style: The table cell style of row field names.
            :param row_header_style: The table cell style of the row headers.
            :param rows_label_options: The options for the label that is located above the row headers. This option is only applicable when ``RowsLayout`` is set to ``HIERARCHY`` .
            :param rows_layout: The layout for the row dimension headers of a pivot table. Choose one of the following options. - ``TABULAR`` : (Default) Each row field is displayed in a separate column. - ``HIERARCHY`` : All row fields are displayed in a single column. Indentation is used to differentiate row headers of different fields.
            :param single_metric_visibility: The visibility of the single metric options.
            :param toggle_buttons_visibility: Determines the visibility of the pivot table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_options_property = quicksight.CfnAnalysis.PivotTableOptionsProperty(
                    cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    collapsed_row_dimensions_visibility="collapsedRowDimensionsVisibility",
                    column_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    column_names_visibility="columnNamesVisibility",
                    default_cell_width="defaultCellWidth",
                    metric_placement="metricPlacement",
                    row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                        row_alternate_colors=["rowAlternateColors"],
                        status="status",
                        use_primary_background_color="usePrimaryBackgroundColor"
                    ),
                    row_field_names_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    row_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    rows_label_options=quicksight.CfnAnalysis.PivotTableRowsLabelOptionsProperty(
                        custom_label="customLabel",
                        visibility="visibility"
                    ),
                    rows_layout="rowsLayout",
                    single_metric_visibility="singleMetricVisibility",
                    toggle_buttons_visibility="toggleButtonsVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9531b24d9fa16286d9c2255b197252d964a583a8ba3a64d974d6bc5a5bbba143)
                check_type(argname="argument cell_style", value=cell_style, expected_type=type_hints["cell_style"])
                check_type(argname="argument collapsed_row_dimensions_visibility", value=collapsed_row_dimensions_visibility, expected_type=type_hints["collapsed_row_dimensions_visibility"])
                check_type(argname="argument column_header_style", value=column_header_style, expected_type=type_hints["column_header_style"])
                check_type(argname="argument column_names_visibility", value=column_names_visibility, expected_type=type_hints["column_names_visibility"])
                check_type(argname="argument default_cell_width", value=default_cell_width, expected_type=type_hints["default_cell_width"])
                check_type(argname="argument metric_placement", value=metric_placement, expected_type=type_hints["metric_placement"])
                check_type(argname="argument row_alternate_color_options", value=row_alternate_color_options, expected_type=type_hints["row_alternate_color_options"])
                check_type(argname="argument row_field_names_style", value=row_field_names_style, expected_type=type_hints["row_field_names_style"])
                check_type(argname="argument row_header_style", value=row_header_style, expected_type=type_hints["row_header_style"])
                check_type(argname="argument rows_label_options", value=rows_label_options, expected_type=type_hints["rows_label_options"])
                check_type(argname="argument rows_layout", value=rows_layout, expected_type=type_hints["rows_layout"])
                check_type(argname="argument single_metric_visibility", value=single_metric_visibility, expected_type=type_hints["single_metric_visibility"])
                check_type(argname="argument toggle_buttons_visibility", value=toggle_buttons_visibility, expected_type=type_hints["toggle_buttons_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell_style is not None:
                self._values["cell_style"] = cell_style
            if collapsed_row_dimensions_visibility is not None:
                self._values["collapsed_row_dimensions_visibility"] = collapsed_row_dimensions_visibility
            if column_header_style is not None:
                self._values["column_header_style"] = column_header_style
            if column_names_visibility is not None:
                self._values["column_names_visibility"] = column_names_visibility
            if default_cell_width is not None:
                self._values["default_cell_width"] = default_cell_width
            if metric_placement is not None:
                self._values["metric_placement"] = metric_placement
            if row_alternate_color_options is not None:
                self._values["row_alternate_color_options"] = row_alternate_color_options
            if row_field_names_style is not None:
                self._values["row_field_names_style"] = row_field_names_style
            if row_header_style is not None:
                self._values["row_header_style"] = row_header_style
            if rows_label_options is not None:
                self._values["rows_label_options"] = rows_label_options
            if rows_layout is not None:
                self._values["rows_layout"] = rows_layout
            if single_metric_visibility is not None:
                self._values["single_metric_visibility"] = single_metric_visibility
            if toggle_buttons_visibility is not None:
                self._values["toggle_buttons_visibility"] = toggle_buttons_visibility

        @builtins.property
        def cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The table cell style of cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-cellstyle
            '''
            result = self._values.get("cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def collapsed_row_dimensions_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility setting of a pivot table's collapsed row dimension fields.

            If the value of this structure is ``HIDDEN`` , all collapsed columns in a pivot table are automatically hidden. The default value is ``VISIBLE`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-collapsedrowdimensionsvisibility
            '''
            result = self._values.get("collapsed_row_dimensions_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def column_header_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The table cell style of the column header.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-columnheaderstyle
            '''
            result = self._values.get("column_header_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def column_names_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the column names.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-columnnamesvisibility
            '''
            result = self._values.get("column_names_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def default_cell_width(self) -> typing.Optional[builtins.str]:
            '''The default cell width of the pivot table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-defaultcellwidth
            '''
            result = self._values.get("default_cell_width")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def metric_placement(self) -> typing.Optional[builtins.str]:
            '''The metric placement (row, column) options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-metricplacement
            '''
            result = self._values.get("metric_placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def row_alternate_color_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RowAlternateColorOptionsProperty"]]:
            '''The row alternate color options (widget status, row alternate colors).

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-rowalternatecoloroptions
            '''
            result = self._values.get("row_alternate_color_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RowAlternateColorOptionsProperty"]], result)

        @builtins.property
        def row_field_names_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The table cell style of row field names.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-rowfieldnamesstyle
            '''
            result = self._values.get("row_field_names_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def row_header_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The table cell style of the row headers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-rowheaderstyle
            '''
            result = self._values.get("row_header_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def rows_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableRowsLabelOptionsProperty"]]:
            '''The options for the label that is located above the row headers.

            This option is only applicable when ``RowsLayout`` is set to ``HIERARCHY`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-rowslabeloptions
            '''
            result = self._values.get("rows_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableRowsLabelOptionsProperty"]], result)

        @builtins.property
        def rows_layout(self) -> typing.Optional[builtins.str]:
            '''The layout for the row dimension headers of a pivot table. Choose one of the following options.

            - ``TABULAR`` : (Default) Each row field is displayed in a separate column.
            - ``HIERARCHY`` : All row fields are displayed in a single column. Indentation is used to differentiate row headers of different fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-rowslayout
            '''
            result = self._values.get("rows_layout")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def single_metric_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the single metric options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-singlemetricvisibility
            '''
            result = self._values.get("single_metric_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def toggle_buttons_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the pivot table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-togglebuttonsvisibility
            '''
            result = self._values.get("toggle_buttons_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotTablePaginatedReportOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "overflow_column_header_visibility": "overflowColumnHeaderVisibility",
            "vertical_overflow_visibility": "verticalOverflowVisibility",
        },
    )
    class PivotTablePaginatedReportOptionsProperty:
        def __init__(
            self,
            *,
            overflow_column_header_visibility: typing.Optional[builtins.str] = None,
            vertical_overflow_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The paginated report options for a pivot table visual.

            :param overflow_column_header_visibility: The visibility of the repeating header rows on each page.
            :param vertical_overflow_visibility: The visibility of the printing table overflow across pages.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablepaginatedreportoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_paginated_report_options_property = quicksight.CfnAnalysis.PivotTablePaginatedReportOptionsProperty(
                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                    vertical_overflow_visibility="verticalOverflowVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__044288d5534df62c8d1c60d17271f802eb72d58a59aacf39863d17e461ea9959)
                check_type(argname="argument overflow_column_header_visibility", value=overflow_column_header_visibility, expected_type=type_hints["overflow_column_header_visibility"])
                check_type(argname="argument vertical_overflow_visibility", value=vertical_overflow_visibility, expected_type=type_hints["vertical_overflow_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if overflow_column_header_visibility is not None:
                self._values["overflow_column_header_visibility"] = overflow_column_header_visibility
            if vertical_overflow_visibility is not None:
                self._values["vertical_overflow_visibility"] = vertical_overflow_visibility

        @builtins.property
        def overflow_column_header_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the repeating header rows on each page.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablepaginatedreportoptions.html#cfn-quicksight-analysis-pivottablepaginatedreportoptions-overflowcolumnheadervisibility
            '''
            result = self._values.get("overflow_column_header_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_overflow_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the printing table overflow across pages.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablepaginatedreportoptions.html#cfn-quicksight-analysis-pivottablepaginatedreportoptions-verticaloverflowvisibility
            '''
            result = self._values.get("vertical_overflow_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTablePaginatedReportOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotTableRowsLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_label": "customLabel", "visibility": "visibility"},
    )
    class PivotTableRowsLabelOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for the label thta is located above the row headers.

            This option is only applicable when ``RowsLayout`` is set to ``HIERARCHY`` .

            :param custom_label: The custom label string for the rows label.
            :param visibility: The visibility of the rows label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablerowslabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_rows_label_options_property = quicksight.CfnAnalysis.PivotTableRowsLabelOptionsProperty(
                    custom_label="customLabel",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4b28f39c728a912f7a1db539ae54a7e0e4532f76d89484bde663e8b6b61d2b72)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the rows label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablerowslabeloptions.html#cfn-quicksight-analysis-pivottablerowslabeloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the rows label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablerowslabeloptions.html#cfn-quicksight-analysis-pivottablerowslabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableRowsLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotTableSortByProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "data_path": "dataPath", "field": "field"},
    )
    class PivotTableSortByProperty:
        def __init__(
            self,
            *,
            column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_path: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataPathSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The sort by field for the field sort options.

            :param column: The column sort (field id, direction) for the pivot table sort by options.
            :param data_path: The data path sort (data path value, direction) for the pivot table sort by options.
            :param field: The field sort (field id, direction) for the pivot table sort by options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortby.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_sort_by_property = quicksight.CfnAnalysis.PivotTableSortByProperty(
                    column=quicksight.CfnAnalysis.ColumnSortProperty(
                        direction="direction",
                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                            attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                simple_attribute_aggregation="simpleAttributeAggregation",
                                value_for_multiple_values="valueForMultipleValues"
                            ),
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                        direction="direction",
                        sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                            data_path_type=quicksight.CfnAnalysis.DataPathTypeProperty(
                                pivot_table_data_path_type="pivotTableDataPathType"
                            ),
                            field_id="fieldId",
                            field_value="fieldValue"
                        )]
                    ),
                    field=quicksight.CfnAnalysis.FieldSortProperty(
                        direction="direction",
                        field_id="fieldId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dd98202b9ffefccacfbe39eab82674f0d1789ca78a912eab1bf89ace900c613a)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument data_path", value=data_path, expected_type=type_hints["data_path"])
                check_type(argname="argument field", value=field, expected_type=type_hints["field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column is not None:
                self._values["column"] = column
            if data_path is not None:
                self._values["data_path"] = data_path
            if field is not None:
                self._values["field"] = field

        @builtins.property
        def column(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnSortProperty"]]:
            '''The column sort (field id, direction) for the pivot table sort by options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortby.html#cfn-quicksight-analysis-pivottablesortby-column
            '''
            result = self._values.get("column")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnSortProperty"]], result)

        @builtins.property
        def data_path(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataPathSortProperty"]]:
            '''The data path sort (data path value, direction) for the pivot table sort by options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortby.html#cfn-quicksight-analysis-pivottablesortby-datapath
            '''
            result = self._values.get("data_path")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataPathSortProperty"]], result)

        @builtins.property
        def field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortProperty"]]:
            '''The field sort (field id, direction) for the pivot table sort by options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortby.html#cfn-quicksight-analysis-pivottablesortby-field
            '''
            result = self._values.get("field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableSortByProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotTableSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"field_sort_options": "fieldSortOptions"},
    )
    class PivotTableSortConfigurationProperty:
        def __init__(
            self,
            *,
            field_sort_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotFieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration for a ``PivotTableVisual`` .

            :param field_sort_options: The field sort options for a pivot table sort configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_sort_configuration_property = quicksight.CfnAnalysis.PivotTableSortConfigurationProperty(
                    field_sort_options=[quicksight.CfnAnalysis.PivotFieldSortOptionsProperty(
                        field_id="fieldId",
                        sort_by=quicksight.CfnAnalysis.PivotTableSortByProperty(
                            column=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                        simple_attribute_aggregation="simpleAttributeAggregation",
                                        value_for_multiple_values="valueForMultipleValues"
                                    ),
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                                direction="direction",
                                sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                                    data_path_type=quicksight.CfnAnalysis.DataPathTypeProperty(
                                        pivot_table_data_path_type="pivotTableDataPathType"
                                    ),
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                )]
                            ),
                            field=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__201fbaa4313fc073bd3c5df27f6936d11ff61a3f79b8f970642c8f7a5d55b055)
                check_type(argname="argument field_sort_options", value=field_sort_options, expected_type=type_hints["field_sort_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_sort_options is not None:
                self._values["field_sort_options"] = field_sort_options

        @builtins.property
        def field_sort_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotFieldSortOptionsProperty"]]]]:
            '''The field sort options for a pivot table sort configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortconfiguration.html#cfn-quicksight-analysis-pivottablesortconfiguration-fieldsortoptions
            '''
            result = self._values.get("field_sort_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotFieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotTableTotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_subtotal_options": "columnSubtotalOptions",
            "column_total_options": "columnTotalOptions",
            "row_subtotal_options": "rowSubtotalOptions",
            "row_total_options": "rowTotalOptions",
        },
    )
    class PivotTableTotalOptionsProperty:
        def __init__(
            self,
            *,
            column_subtotal_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_subtotal_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The total options for a pivot table visual.

            :param column_subtotal_options: The column subtotal options.
            :param column_total_options: The column total options.
            :param row_subtotal_options: The row subtotal options.
            :param row_total_options: The row total options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__76b32a5384b9698f8fab50938b7df243ef7deac4a95d356fb266adac4a406177)
                check_type(argname="argument column_subtotal_options", value=column_subtotal_options, expected_type=type_hints["column_subtotal_options"])
                check_type(argname="argument column_total_options", value=column_total_options, expected_type=type_hints["column_total_options"])
                check_type(argname="argument row_subtotal_options", value=row_subtotal_options, expected_type=type_hints["row_subtotal_options"])
                check_type(argname="argument row_total_options", value=row_total_options, expected_type=type_hints["row_total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_subtotal_options is not None:
                self._values["column_subtotal_options"] = column_subtotal_options
            if column_total_options is not None:
                self._values["column_total_options"] = column_total_options
            if row_subtotal_options is not None:
                self._values["row_subtotal_options"] = row_subtotal_options
            if row_total_options is not None:
                self._values["row_total_options"] = row_total_options

        @builtins.property
        def column_subtotal_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SubtotalOptionsProperty"]]:
            '''The column subtotal options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html#cfn-quicksight-analysis-pivottabletotaloptions-columnsubtotaloptions
            '''
            result = self._values.get("column_subtotal_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SubtotalOptionsProperty"]], result)

        @builtins.property
        def column_total_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTotalOptionsProperty"]]:
            '''The column total options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html#cfn-quicksight-analysis-pivottabletotaloptions-columntotaloptions
            '''
            result = self._values.get("column_total_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTotalOptionsProperty"]], result)

        @builtins.property
        def row_subtotal_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SubtotalOptionsProperty"]]:
            '''The row subtotal options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html#cfn-quicksight-analysis-pivottabletotaloptions-rowsubtotaloptions
            '''
            result = self._values.get("row_subtotal_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SubtotalOptionsProperty"]], result)

        @builtins.property
        def row_total_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTotalOptionsProperty"]]:
            '''The row total options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html#cfn-quicksight-analysis-pivottabletotaloptions-rowtotaloptions
            '''
            result = self._values.get("row_total_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTotalOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableTotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotTableVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class PivotTableVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTableConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTableConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A pivot table.

            For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param conditional_formatting: The conditional formatting for a ``PivotTableVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c5bcca7d2b66c29bee62ccb437cd3f4de82a019cdaff497b5160d61a7c99cf19)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableConfigurationProperty"]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableConditionalFormattingProperty"]]:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PivotTotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "metric_header_cell_style": "metricHeaderCellStyle",
            "placement": "placement",
            "scroll_status": "scrollStatus",
            "total_aggregation_options": "totalAggregationOptions",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
            "value_cell_style": "valueCellStyle",
        },
    )
    class PivotTotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            metric_header_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            placement: typing.Optional[builtins.str] = None,
            scroll_status: typing.Optional[builtins.str] = None,
            total_aggregation_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TotalAggregationOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            total_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
            value_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The optional configuration of totals cells in a ``PivotTableVisual`` .

            :param custom_label: The custom label string for the total cells.
            :param metric_header_cell_style: The cell styling options for the total of header cells.
            :param placement: The placement (start, end) for the total cells.
            :param scroll_status: The scroll status (pinned, scrolled) for the total cells.
            :param total_aggregation_options: The total aggregation options for each value field.
            :param total_cell_style: The cell styling options for the total cells.
            :param totals_visibility: The visibility configuration for the total cells.
            :param value_cell_style: The cell styling options for the totals of value cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_total_options_property = quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                    custom_label="customLabel",
                    metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    placement="placement",
                    scroll_status="scrollStatus",
                    total_aggregation_options=[quicksight.CfnAnalysis.TotalAggregationOptionProperty(
                        field_id="fieldId",
                        total_aggregation_function=quicksight.CfnAnalysis.TotalAggregationFunctionProperty(
                            simple_total_aggregation_function="simpleTotalAggregationFunction"
                        )
                    )],
                    total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility",
                    value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c081b5f6f16d592bde87159b2375816297265c384b4198d9e8464f37d56d3635)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument metric_header_cell_style", value=metric_header_cell_style, expected_type=type_hints["metric_header_cell_style"])
                check_type(argname="argument placement", value=placement, expected_type=type_hints["placement"])
                check_type(argname="argument scroll_status", value=scroll_status, expected_type=type_hints["scroll_status"])
                check_type(argname="argument total_aggregation_options", value=total_aggregation_options, expected_type=type_hints["total_aggregation_options"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
                check_type(argname="argument value_cell_style", value=value_cell_style, expected_type=type_hints["value_cell_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if metric_header_cell_style is not None:
                self._values["metric_header_cell_style"] = metric_header_cell_style
            if placement is not None:
                self._values["placement"] = placement
            if scroll_status is not None:
                self._values["scroll_status"] = scroll_status
            if total_aggregation_options is not None:
                self._values["total_aggregation_options"] = total_aggregation_options
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility
            if value_cell_style is not None:
                self._values["value_cell_style"] = value_cell_style

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def metric_header_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The cell styling options for the total of header cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-metricheadercellstyle
            '''
            result = self._values.get("metric_header_cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def placement(self) -> typing.Optional[builtins.str]:
            '''The placement (start, end) for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-placement
            '''
            result = self._values.get("placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scroll_status(self) -> typing.Optional[builtins.str]:
            '''The scroll status (pinned, scrolled) for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-scrollstatus
            '''
            result = self._values.get("scroll_status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def total_aggregation_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TotalAggregationOptionProperty"]]]]:
            '''The total aggregation options for each value field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-totalaggregationoptions
            '''
            result = self._values.get("total_aggregation_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TotalAggregationOptionProperty"]]]], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The cell styling options for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The cell styling options for the totals of value cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-valuecellstyle
            '''
            result = self._values.get("value_cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.PredefinedHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class PredefinedHierarchyProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]]],
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields that are defined during data preparation.

            These fields are available to use in any analysis that uses the data source.

            :param columns: The list of columns that define the predefined hierarchy.
            :param hierarchy_id: The hierarchy ID of the predefined hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the predefined hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-predefinedhierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                predefined_hierarchy_property = quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__954204a704fcb35949afef9e42af208d2e15803f6ce4c3c70c77e2f6ca629ed0)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]]]:
            '''The list of columns that define the predefined hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-predefinedhierarchy.html#cfn-quicksight-analysis-predefinedhierarchy-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]]], result)

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the predefined hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-predefinedhierarchy.html#cfn-quicksight-analysis-predefinedhierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DrillDownFilterProperty"]]]]:
            '''The option that determines the drill down filters for the predefined hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-predefinedhierarchy.html#cfn-quicksight-analysis-predefinedhierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DrillDownFilterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PredefinedHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ProgressBarOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ProgressBarOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of the progress bar of a KPI visual.

            :param visibility: The visibility of the progress bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-progressbaroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                progress_bar_options_property = quicksight.CfnAnalysis.ProgressBarOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6d2a0d75dfef36d1e1bdd541b1b87ca5099f709e8e2dcea66428e7aaed8ff01b)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the progress bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-progressbaroptions.html#cfn-quicksight-analysis-progressbaroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ProgressBarOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.RadarChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"category": "category", "color": "color", "values": "values"},
    )
    class RadarChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well configuration of a ``RadarChartVisual`` .

            :param category: The aggregated field well categories of a radar chart.
            :param color: The color that are assigned to the aggregated field wells of a radar chart.
            :param values: The values that are assigned to the aggregated field wells of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__45f39c45ac242411b7c269731f281995cb8e54a35969dbceb1ddd3b5ff128800)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if color is not None:
                self._values["color"] = color
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The aggregated field well categories of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartaggregatedfieldwells.html#cfn-quicksight-analysis-radarchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The color that are assigned to the aggregated field wells of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartaggregatedfieldwells.html#cfn-quicksight-analysis-radarchartaggregatedfieldwells-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The values that are assigned to the aggregated field wells of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartaggregatedfieldwells.html#cfn-quicksight-analysis-radarchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class RadarChartAreaStyleSettingsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configured style settings of a radar chart.

            :param visibility: The visibility settings of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartareastylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                radar_chart_area_style_settings_property = quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__81fc0fef972e910af62d17fd49f01ae9efcf62b169855fa0fc18045fbb5635f5)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility settings of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartareastylesettings.html#cfn-quicksight-analysis-radarchartareastylesettings-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartAreaStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.RadarChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "alternate_band_colors_visibility": "alternateBandColorsVisibility",
            "alternate_band_even_color": "alternateBandEvenColor",
            "alternate_band_odd_color": "alternateBandOddColor",
            "axes_range_scale": "axesRangeScale",
            "base_series_settings": "baseSeriesSettings",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_axis": "colorAxis",
            "color_label_options": "colorLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "shape": "shape",
            "sort_configuration": "sortConfiguration",
            "start_angle": "startAngle",
            "visual_palette": "visualPalette",
        },
    )
    class RadarChartConfigurationProperty:
        def __init__(
            self,
            *,
            alternate_band_colors_visibility: typing.Optional[builtins.str] = None,
            alternate_band_even_color: typing.Optional[builtins.str] = None,
            alternate_band_odd_color: typing.Optional[builtins.str] = None,
            axes_range_scale: typing.Optional[builtins.str] = None,
            base_series_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.RadarChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.RadarChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            shape: typing.Optional[builtins.str] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.RadarChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            start_angle: typing.Optional[jsii.Number] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``RadarChartVisual`` .

            :param alternate_band_colors_visibility: Determines the visibility of the colors of alternatign bands in a radar chart.
            :param alternate_band_even_color: The color of the even-numbered alternate bands of a radar chart.
            :param alternate_band_odd_color: The color of the odd-numbered alternate bands of a radar chart.
            :param axes_range_scale: The axis behavior options of a radar chart.
            :param base_series_settings: The base sreies settings of a radar chart.
            :param category_axis: The category axis of a radar chart.
            :param category_label_options: The category label options of a radar chart.
            :param color_axis: The color axis of a radar chart.
            :param color_label_options: The color label options of a radar chart.
            :param field_wells: The field well configuration of a ``RadarChartVisual`` .
            :param legend: The legend display setup of the visual.
            :param shape: The shape of the radar chart.
            :param sort_configuration: The sort configuration of a ``RadarChartVisual`` .
            :param start_angle: The start angle of a radar chart's axis.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__96a7d9a8bcdc51262f1a45bdf1dd0522bf5be71c987ca3a4e3553326870dd66e)
                check_type(argname="argument alternate_band_colors_visibility", value=alternate_band_colors_visibility, expected_type=type_hints["alternate_band_colors_visibility"])
                check_type(argname="argument alternate_band_even_color", value=alternate_band_even_color, expected_type=type_hints["alternate_band_even_color"])
                check_type(argname="argument alternate_band_odd_color", value=alternate_band_odd_color, expected_type=type_hints["alternate_band_odd_color"])
                check_type(argname="argument axes_range_scale", value=axes_range_scale, expected_type=type_hints["axes_range_scale"])
                check_type(argname="argument base_series_settings", value=base_series_settings, expected_type=type_hints["base_series_settings"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_axis", value=color_axis, expected_type=type_hints["color_axis"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument shape", value=shape, expected_type=type_hints["shape"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument start_angle", value=start_angle, expected_type=type_hints["start_angle"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if alternate_band_colors_visibility is not None:
                self._values["alternate_band_colors_visibility"] = alternate_band_colors_visibility
            if alternate_band_even_color is not None:
                self._values["alternate_band_even_color"] = alternate_band_even_color
            if alternate_band_odd_color is not None:
                self._values["alternate_band_odd_color"] = alternate_band_odd_color
            if axes_range_scale is not None:
                self._values["axes_range_scale"] = axes_range_scale
            if base_series_settings is not None:
                self._values["base_series_settings"] = base_series_settings
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_axis is not None:
                self._values["color_axis"] = color_axis
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if shape is not None:
                self._values["shape"] = shape
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if start_angle is not None:
                self._values["start_angle"] = start_angle
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def alternate_band_colors_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the colors of alternatign bands in a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-alternatebandcolorsvisibility
            '''
            result = self._values.get("alternate_band_colors_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def alternate_band_even_color(self) -> typing.Optional[builtins.str]:
            '''The color of the even-numbered alternate bands of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-alternatebandevencolor
            '''
            result = self._values.get("alternate_band_even_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def alternate_band_odd_color(self) -> typing.Optional[builtins.str]:
            '''The color of the odd-numbered alternate bands of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-alternatebandoddcolor
            '''
            result = self._values.get("alternate_band_odd_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def axes_range_scale(self) -> typing.Optional[builtins.str]:
            '''The axis behavior options of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-axesrangescale
            '''
            result = self._values.get("axes_range_scale")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def base_series_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RadarChartSeriesSettingsProperty"]]:
            '''The base sreies settings of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-baseseriessettings
            '''
            result = self._values.get("base_series_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RadarChartSeriesSettingsProperty"]], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The category axis of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The category label options of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The color axis of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-coloraxis
            '''
            result = self._values.get("color_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The color label options of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RadarChartFieldWellsProperty"]]:
            '''The field well configuration of a ``RadarChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RadarChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def shape(self) -> typing.Optional[builtins.str]:
            '''The shape of the radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-shape
            '''
            result = self._values.get("shape")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RadarChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``RadarChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RadarChartSortConfigurationProperty"]], result)

        @builtins.property
        def start_angle(self) -> typing.Optional[jsii.Number]:
            '''The start angle of a radar chart's axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-startangle
            '''
            result = self._values.get("start_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.RadarChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "radar_chart_aggregated_field_wells": "radarChartAggregatedFieldWells",
        },
    )
    class RadarChartFieldWellsProperty:
        def __init__(
            self,
            *,
            radar_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.RadarChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a radar chart visual.

            :param radar_chart_aggregated_field_wells: The aggregated field wells of a radar chart visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__453e7f7618881f8a73c114f6e2fb35e3341662dd7fb53a09c4c3ccefcd192d4b)
                check_type(argname="argument radar_chart_aggregated_field_wells", value=radar_chart_aggregated_field_wells, expected_type=type_hints["radar_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if radar_chart_aggregated_field_wells is not None:
                self._values["radar_chart_aggregated_field_wells"] = radar_chart_aggregated_field_wells

        @builtins.property
        def radar_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RadarChartAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a radar chart visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartfieldwells.html#cfn-quicksight-analysis-radarchartfieldwells-radarchartaggregatedfieldwells
            '''
            result = self._values.get("radar_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RadarChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.RadarChartSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={"area_style_settings": "areaStyleSettings"},
    )
    class RadarChartSeriesSettingsProperty:
        def __init__(
            self,
            *,
            area_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.RadarChartAreaStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The series settings of a radar chart.

            :param area_style_settings: The area style settings of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                radar_chart_series_settings_property = quicksight.CfnAnalysis.RadarChartSeriesSettingsProperty(
                    area_style_settings=quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d324e35f5d4ddf9a4b1566fcfbb808c9b2ac1accd4ad7e6a8f3389267b9390a8)
                check_type(argname="argument area_style_settings", value=area_style_settings, expected_type=type_hints["area_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if area_style_settings is not None:
                self._values["area_style_settings"] = area_style_settings

        @builtins.property
        def area_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RadarChartAreaStyleSettingsProperty"]]:
            '''The area style settings of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartseriessettings.html#cfn-quicksight-analysis-radarchartseriessettings-areastylesettings
            '''
            result = self._values.get("area_style_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RadarChartAreaStyleSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.RadarChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
        },
    )
    class RadarChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``RadarChartVisual`` .

            :param category_items_limit: The category items limit for a radar chart.
            :param category_sort: The category sort options of a radar chart.
            :param color_items_limit: The color items limit of a radar chart.
            :param color_sort: The color sort configuration of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                radar_chart_sort_configuration_property = quicksight.CfnAnalysis.RadarChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b2937e11266a0001836817467942d2259f27288bb64d2a75a32c17c3fd81fa9c)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The category items limit for a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html#cfn-quicksight-analysis-radarchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The category sort options of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html#cfn-quicksight-analysis-radarchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The color items limit of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html#cfn-quicksight-analysis-radarchartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The color sort configuration of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html#cfn-quicksight-analysis-radarchartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.RadarChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class RadarChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.RadarChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A radar chart visual.

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cb550baaac51820f5bb336fd8259e463a83d8083d629dc5cc76d779c3c165fbb)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RadarChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RadarChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.RangeEndsLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class RangeEndsLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The range ends label type of a data path label.

            :param visibility: The visibility of the range ends label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rangeendslabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                range_ends_label_type_property = quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5fc9853b1f5e62f28eb13991cfdc6d455aa5e01eba6d6fa5c718163e99d91e68)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the range ends label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rangeendslabeltype.html#cfn-quicksight-analysis-rangeendslabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RangeEndsLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_label": "customLabel"},
    )
    class ReferenceLineCustomLabelConfigurationProperty:
        def __init__(self, *, custom_label: builtins.str) -> None:
            '''The configuration for a custom label on a ``ReferenceLine`` .

            :param custom_label: The string text of the custom label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinecustomlabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_custom_label_configuration_property = quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                    custom_label="customLabel"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9dbe4a6d4fe26dc2bb54aeae720796e32e7400656f367d2720d0db312db674a4)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "custom_label": custom_label,
            }

        @builtins.property
        def custom_label(self) -> builtins.str:
            '''The string text of the custom label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinecustomlabelconfiguration.html#cfn-quicksight-analysis-referencelinecustomlabelconfiguration-customlabel
            '''
            result = self._values.get("custom_label")
            assert result is not None, "Required property 'custom_label' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineCustomLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "dynamic_configuration": "dynamicConfiguration",
            "series_type": "seriesType",
            "static_configuration": "staticConfiguration",
        },
    )
    class ReferenceLineDataConfigurationProperty:
        def __init__(
            self,
            *,
            axis_binding: typing.Optional[builtins.str] = None,
            dynamic_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            series_type: typing.Optional[builtins.str] = None,
            static_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ReferenceLineStaticDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The data configuration of the reference line.

            :param axis_binding: The axis binding type of the reference line. Choose one of the following options:. - ``PrimaryY`` - ``SecondaryY``
            :param dynamic_configuration: The dynamic configuration of the reference line data configuration.
            :param series_type: The series type of the reference line data configuration. Choose one of the following options:. - ``BAR`` - ``LINE``
            :param static_configuration: The static data configuration of the reference line data configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_data_configuration_property = quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                    axis_binding="axisBinding",
                    dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                        calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        ),
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                            attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                simple_attribute_aggregation="simpleAttributeAggregation",
                                value_for_multiple_values="valueForMultipleValues"
                            ),
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    series_type="seriesType",
                    static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                        value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1cb097a15cdcf0fb69d650791b2ff1429bb0aa7e52a91254b4770b80c29121d5)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument dynamic_configuration", value=dynamic_configuration, expected_type=type_hints["dynamic_configuration"])
                check_type(argname="argument series_type", value=series_type, expected_type=type_hints["series_type"])
                check_type(argname="argument static_configuration", value=static_configuration, expected_type=type_hints["static_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_binding is not None:
                self._values["axis_binding"] = axis_binding
            if dynamic_configuration is not None:
                self._values["dynamic_configuration"] = dynamic_configuration
            if series_type is not None:
                self._values["series_type"] = series_type
            if static_configuration is not None:
                self._values["static_configuration"] = static_configuration

        @builtins.property
        def axis_binding(self) -> typing.Optional[builtins.str]:
            '''The axis binding type of the reference line. Choose one of the following options:.

            - ``PrimaryY``
            - ``SecondaryY``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html#cfn-quicksight-analysis-referencelinedataconfiguration-axisbinding
            '''
            result = self._values.get("axis_binding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def dynamic_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty"]]:
            '''The dynamic configuration of the reference line data configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html#cfn-quicksight-analysis-referencelinedataconfiguration-dynamicconfiguration
            '''
            result = self._values.get("dynamic_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty"]], result)

        @builtins.property
        def series_type(self) -> typing.Optional[builtins.str]:
            '''The series type of the reference line data configuration. Choose one of the following options:.

            - ``BAR``
            - ``LINE``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html#cfn-quicksight-analysis-referencelinedataconfiguration-seriestype
            '''
            result = self._values.get("series_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def static_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineStaticDataConfigurationProperty"]]:
            '''The static data configuration of the reference line data configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html#cfn-quicksight-analysis-referencelinedataconfiguration-staticconfiguration
            '''
            result = self._values.get("static_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineStaticDataConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "calculation": "calculation",
            "column": "column",
            "measure_aggregation_function": "measureAggregationFunction",
        },
    )
    class ReferenceLineDynamicDataConfigurationProperty:
        def __init__(
            self,
            *,
            calculation: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]],
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            measure_aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The dynamic configuration of the reference line data configuration.

            :param calculation: The calculation that is used in the dynamic data.
            :param column: The column that the dynamic data targets.
            :param measure_aggregation_function: The aggregation function that is used in the dynamic data.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedynamicdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_dynamic_data_configuration_property = quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                    calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    ),
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                        attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                            simple_attribute_aggregation="simpleAttributeAggregation",
                            value_for_multiple_values="valueForMultipleValues"
                        ),
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2c5c6f098cca8f793d79d54880ab08cb572654f3456afcc7ef4d420b197d6613)
                check_type(argname="argument calculation", value=calculation, expected_type=type_hints["calculation"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument measure_aggregation_function", value=measure_aggregation_function, expected_type=type_hints["measure_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "calculation": calculation,
                "column": column,
            }
            if measure_aggregation_function is not None:
                self._values["measure_aggregation_function"] = measure_aggregation_function

        @builtins.property
        def calculation(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericalAggregationFunctionProperty"]:
            '''The calculation that is used in the dynamic data.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedynamicdataconfiguration.html#cfn-quicksight-analysis-referencelinedynamicdataconfiguration-calculation
            '''
            result = self._values.get("calculation")
            assert result is not None, "Required property 'calculation' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericalAggregationFunctionProperty"], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the dynamic data targets.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedynamicdataconfiguration.html#cfn-quicksight-analysis-referencelinedynamicdataconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def measure_aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AggregationFunctionProperty"]]:
            '''The aggregation function that is used in the dynamic data.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedynamicdataconfiguration.html#cfn-quicksight-analysis-referencelinedynamicdataconfiguration-measureaggregationfunction
            '''
            result = self._values.get("measure_aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AggregationFunctionProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineDynamicDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label_configuration": "customLabelConfiguration",
            "font_color": "fontColor",
            "font_configuration": "fontConfiguration",
            "horizontal_position": "horizontalPosition",
            "value_label_configuration": "valueLabelConfiguration",
            "vertical_position": "verticalPosition",
        },
    )
    class ReferenceLineLabelConfigurationProperty:
        def __init__(
            self,
            *,
            custom_label_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            font_color: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            horizontal_position: typing.Optional[builtins.str] = None,
            value_label_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ReferenceLineValueLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            vertical_position: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label configuration of a reference line.

            :param custom_label_configuration: The custom label configuration of the label in a reference line.
            :param font_color: The font color configuration of the label in a reference line.
            :param font_configuration: The font configuration of the label in a reference line.
            :param horizontal_position: The horizontal position configuration of the label in a reference line. Choose one of the following options:. - ``LEFT`` - ``CENTER`` - ``RIGHT``
            :param value_label_configuration: The value label configuration of the label in a reference line.
            :param vertical_position: The vertical position configuration of the label in a reference line. Choose one of the following options:. - ``ABOVE`` - ``BELOW``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_label_configuration_property = quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                    custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                        custom_label="customLabel"
                    ),
                    font_color="fontColor",
                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    horizontal_position="horizontalPosition",
                    value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        relative_position="relativePosition"
                    ),
                    vertical_position="verticalPosition"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e5bb1f9557aa32bcc5aa2306bd1df9653caa2016d934f038d1e82434c441f59c)
                check_type(argname="argument custom_label_configuration", value=custom_label_configuration, expected_type=type_hints["custom_label_configuration"])
                check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument horizontal_position", value=horizontal_position, expected_type=type_hints["horizontal_position"])
                check_type(argname="argument value_label_configuration", value=value_label_configuration, expected_type=type_hints["value_label_configuration"])
                check_type(argname="argument vertical_position", value=vertical_position, expected_type=type_hints["vertical_position"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label_configuration is not None:
                self._values["custom_label_configuration"] = custom_label_configuration
            if font_color is not None:
                self._values["font_color"] = font_color
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if horizontal_position is not None:
                self._values["horizontal_position"] = horizontal_position
            if value_label_configuration is not None:
                self._values["value_label_configuration"] = value_label_configuration
            if vertical_position is not None:
                self._values["vertical_position"] = vertical_position

        @builtins.property
        def custom_label_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty"]]:
            '''The custom label configuration of the label in a reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-customlabelconfiguration
            '''
            result = self._values.get("custom_label_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty"]], result)

        @builtins.property
        def font_color(self) -> typing.Optional[builtins.str]:
            '''The font color configuration of the label in a reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-fontcolor
            '''
            result = self._values.get("font_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"]]:
            '''The font configuration of the label in a reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"]], result)

        @builtins.property
        def horizontal_position(self) -> typing.Optional[builtins.str]:
            '''The horizontal position configuration of the label in a reference line. Choose one of the following options:.

            - ``LEFT``
            - ``CENTER``
            - ``RIGHT``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-horizontalposition
            '''
            result = self._values.get("horizontal_position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_label_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineValueLabelConfigurationProperty"]]:
            '''The value label configuration of the label in a reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-valuelabelconfiguration
            '''
            result = self._values.get("value_label_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineValueLabelConfigurationProperty"]], result)

        @builtins.property
        def vertical_position(self) -> typing.Optional[builtins.str]:
            '''The vertical position configuration of the label in a reference line. Choose one of the following options:.

            - ``ABOVE``
            - ``BELOW``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-verticalposition
            '''
            result = self._values.get("vertical_position")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ReferenceLineProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_configuration": "dataConfiguration",
            "label_configuration": "labelConfiguration",
            "status": "status",
            "style_configuration": "styleConfiguration",
        },
    )
    class ReferenceLineProperty:
        def __init__(
            self,
            *,
            data_configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ReferenceLineDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            label_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ReferenceLineLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            status: typing.Optional[builtins.str] = None,
            style_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ReferenceLineStyleConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The reference line visual display options.

            :param data_configuration: The data configuration of the reference line.
            :param label_configuration: The label configuration of the reference line.
            :param status: The status of the reference line. Choose one of the following options:. - ``ENABLE`` - ``DISABLE``
            :param style_configuration: The style configuration of the reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_property = quicksight.CfnAnalysis.ReferenceLineProperty(
                    data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                        axis_binding="axisBinding",
                        dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                            calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        series_type="seriesType",
                        static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                            value=123
                        )
                    ),
                
                    # the properties below are optional
                    label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                        custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                            custom_label="customLabel"
                        ),
                        font_color="fontColor",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        horizontal_position="horizontalPosition",
                        value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            ),
                            relative_position="relativePosition"
                        ),
                        vertical_position="verticalPosition"
                    ),
                    status="status",
                    style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                        color="color",
                        pattern="pattern"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a08f19110bc4edafd30ad79e373cecf086f672f8948ddaf1d1cc441e3eeba33c)
                check_type(argname="argument data_configuration", value=data_configuration, expected_type=type_hints["data_configuration"])
                check_type(argname="argument label_configuration", value=label_configuration, expected_type=type_hints["label_configuration"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument style_configuration", value=style_configuration, expected_type=type_hints["style_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_configuration": data_configuration,
            }
            if label_configuration is not None:
                self._values["label_configuration"] = label_configuration
            if status is not None:
                self._values["status"] = status
            if style_configuration is not None:
                self._values["style_configuration"] = style_configuration

        @builtins.property
        def data_configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineDataConfigurationProperty"]:
            '''The data configuration of the reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html#cfn-quicksight-analysis-referenceline-dataconfiguration
            '''
            result = self._values.get("data_configuration")
            assert result is not None, "Required property 'data_configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineDataConfigurationProperty"], result)

        @builtins.property
        def label_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineLabelConfigurationProperty"]]:
            '''The label configuration of the reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html#cfn-quicksight-analysis-referenceline-labelconfiguration
            '''
            result = self._values.get("label_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineLabelConfigurationProperty"]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the reference line. Choose one of the following options:.

            - ``ENABLE``
            - ``DISABLE``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html#cfn-quicksight-analysis-referenceline-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineStyleConfigurationProperty"]]:
            '''The style configuration of the reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html#cfn-quicksight-analysis-referenceline-styleconfiguration
            '''
            result = self._values.get("style_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ReferenceLineStyleConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"value": "value"},
    )
    class ReferenceLineStaticDataConfigurationProperty:
        def __init__(self, *, value: jsii.Number) -> None:
            '''The static data configuration of the reference line data configuration.

            :param value: The double input of the static data. Default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestaticdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_static_data_configuration_property = quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d18223189006e114ac4efa7ab47d49cd5392f3d633768997b28d258d6f23b6df)
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "value": value,
            }

        @builtins.property
        def value(self) -> jsii.Number:
            '''The double input of the static data.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestaticdataconfiguration.html#cfn-quicksight-analysis-referencelinestaticdataconfiguration-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineStaticDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "pattern": "pattern"},
    )
    class ReferenceLineStyleConfigurationProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            pattern: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The style configuration of the reference line.

            :param color: The hex color of the reference line.
            :param pattern: The pattern type of the line style. Choose one of the following options:. - ``SOLID`` - ``DASHED`` - ``DOTTED``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestyleconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_style_configuration_property = quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                    color="color",
                    pattern="pattern"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dcc94f78c7d9a63e188d0568f4e7f6b13b9a7454c4d317983a824e2f8a44a8d7)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if pattern is not None:
                self._values["pattern"] = pattern

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The hex color of the reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestyleconfiguration.html#cfn-quicksight-analysis-referencelinestyleconfiguration-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def pattern(self) -> typing.Optional[builtins.str]:
            '''The pattern type of the line style. Choose one of the following options:.

            - ``SOLID``
            - ``DASHED``
            - ``DOTTED``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestyleconfiguration.html#cfn-quicksight-analysis-referencelinestyleconfiguration-pattern
            '''
            result = self._values.get("pattern")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineStyleConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "format_configuration": "formatConfiguration",
            "relative_position": "relativePosition",
        },
    )
    class ReferenceLineValueLabelConfigurationProperty:
        def __init__(
            self,
            *,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relative_position: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The value label configuration of the label in a reference line.

            :param format_configuration: The format configuration of the value label.
            :param relative_position: The relative position of the value label. Choose one of the following options:. - ``BEFORE_CUSTOM_LABEL`` - ``AFTER_CUSTOM_LABEL``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinevaluelabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_value_label_configuration_property = quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    ),
                    relative_position="relativePosition"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8a46e5945af0e46a2dd4cde0c3feef1396df82d6c7180394ec12586329475418)
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument relative_position", value=relative_position, expected_type=type_hints["relative_position"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if relative_position is not None:
                self._values["relative_position"] = relative_position

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericFormatConfigurationProperty"]]:
            '''The format configuration of the value label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinevaluelabelconfiguration.html#cfn-quicksight-analysis-referencelinevaluelabelconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericFormatConfigurationProperty"]], result)

        @builtins.property
        def relative_position(self) -> typing.Optional[builtins.str]:
            '''The relative position of the value label. Choose one of the following options:.

            - ``BEFORE_CUSTOM_LABEL``
            - ``AFTER_CUSTOM_LABEL``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinevaluelabelconfiguration.html#cfn-quicksight-analysis-referencelinevaluelabelconfiguration-relativeposition
            '''
            result = self._values.get("relative_position")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineValueLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "info_icon_label_options": "infoIconLabelOptions",
            "title_options": "titleOptions",
        },
    )
    class RelativeDateTimeControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SheetControlInfoIconLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param date_time_format: Customize how dates are formatted in controls.
            :param info_icon_label_options: The configuration of info icon label options.
            :param title_options: The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatetimecontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                relative_date_time_control_display_options_property = quicksight.CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty(
                    date_time_format="dateTimeFormat",
                    info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                        info_icon_text="infoIconText",
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7019f6ccffd795caef1cac5d1319ebe3300486c56f97572d179ad59e690d616d)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument info_icon_label_options", value=info_icon_label_options, expected_type=type_hints["info_icon_label_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if info_icon_label_options is not None:
                self._values["info_icon_label_options"] = info_icon_label_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Customize how dates are formatted in controls.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatetimecontroldisplayoptions.html#cfn-quicksight-analysis-relativedatetimecontroldisplayoptions-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def info_icon_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetControlInfoIconLabelOptionsProperty"]]:
            '''The configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatetimecontroldisplayoptions.html#cfn-quicksight-analysis-relativedatetimecontroldisplayoptions-infoiconlabeloptions
            '''
            result = self._values.get("info_icon_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetControlInfoIconLabelOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatetimecontroldisplayoptions.html#cfn-quicksight-analysis-relativedatetimecontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RelativeDateTimeControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.RelativeDatesFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "anchor_date_configuration": "anchorDateConfiguration",
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "relative_date_type": "relativeDateType",
            "time_granularity": "timeGranularity",
            "exclude_period_configuration": "excludePeriodConfiguration",
            "minimum_granularity": "minimumGranularity",
            "parameter_name": "parameterName",
            "relative_date_value": "relativeDateValue",
        },
    )
    class RelativeDatesFilterProperty:
        def __init__(
            self,
            *,
            anchor_date_configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AnchorDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            null_option: builtins.str,
            relative_date_type: builtins.str,
            time_granularity: builtins.str,
            exclude_period_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ExcludePeriodConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            minimum_granularity: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            relative_date_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A ``RelativeDatesFilter`` filters relative dates values.

            :param anchor_date_configuration: The date configuration of the filter.
            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param relative_date_type: The range date type of the filter. Choose one of the options below:. - ``PREVIOUS`` - ``THIS`` - ``LAST`` - ``NOW`` - ``NEXT``
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param exclude_period_configuration: The configuration for the exclude period of the filter.
            :param minimum_granularity: The minimum granularity (period granularity) of the relative dates filter.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param relative_date_value: The date value of the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                relative_dates_filter_property = quicksight.CfnAnalysis.RelativeDatesFilterProperty(
                    anchor_date_configuration=quicksight.CfnAnalysis.AnchorDateConfigurationProperty(
                        anchor_option="anchorOption",
                        parameter_name="parameterName"
                    ),
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                    relative_date_type="relativeDateType",
                    time_granularity="timeGranularity",
                
                    # the properties below are optional
                    exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                        amount=123,
                        granularity="granularity",
                
                        # the properties below are optional
                        status="status"
                    ),
                    minimum_granularity="minimumGranularity",
                    parameter_name="parameterName",
                    relative_date_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f7cf02371d12b49ad2afa25a53a6f5e622eacc7d10a4db18e560ce1298407017)
                check_type(argname="argument anchor_date_configuration", value=anchor_date_configuration, expected_type=type_hints["anchor_date_configuration"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument relative_date_type", value=relative_date_type, expected_type=type_hints["relative_date_type"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument exclude_period_configuration", value=exclude_period_configuration, expected_type=type_hints["exclude_period_configuration"])
                check_type(argname="argument minimum_granularity", value=minimum_granularity, expected_type=type_hints["minimum_granularity"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument relative_date_value", value=relative_date_value, expected_type=type_hints["relative_date_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "anchor_date_configuration": anchor_date_configuration,
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
                "relative_date_type": relative_date_type,
                "time_granularity": time_granularity,
            }
            if exclude_period_configuration is not None:
                self._values["exclude_period_configuration"] = exclude_period_configuration
            if minimum_granularity is not None:
                self._values["minimum_granularity"] = minimum_granularity
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if relative_date_value is not None:
                self._values["relative_date_value"] = relative_date_value

        @builtins.property
        def anchor_date_configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AnchorDateConfigurationProperty"]:
            '''The date configuration of the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-anchordateconfiguration
            '''
            result = self._values.get("anchor_date_configuration")
            assert result is not None, "Required property 'anchor_date_configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AnchorDateConfigurationProperty"], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def relative_date_type(self) -> builtins.str:
            '''The range date type of the filter. Choose one of the options below:.

            - ``PREVIOUS``
            - ``THIS``
            - ``LAST``
            - ``NOW``
            - ``NEXT``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-relativedatetype
            '''
            result = self._values.get("relative_date_type")
            assert result is not None, "Required property 'relative_date_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time_granularity(self) -> builtins.str:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            assert result is not None, "Required property 'time_granularity' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def exclude_period_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ExcludePeriodConfigurationProperty"]]:
            '''The configuration for the exclude period of the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-excludeperiodconfiguration
            '''
            result = self._values.get("exclude_period_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ExcludePeriodConfigurationProperty"]], result)

        @builtins.property
        def minimum_granularity(self) -> typing.Optional[builtins.str]:
            '''The minimum granularity (period granularity) of the relative dates filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-minimumgranularity
            '''
            result = self._values.get("minimum_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def relative_date_value(self) -> typing.Optional[jsii.Number]:
            '''The date value of the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-relativedatevalue
            '''
            result = self._values.get("relative_date_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RelativeDatesFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ResourcePermissionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "actions": "actions",
            "principal": "principal",
            "resource": "resource",
        },
    )
    class ResourcePermissionProperty:
        def __init__(
            self,
            *,
            actions: typing.Sequence[builtins.str],
            principal: builtins.str,
            resource: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Permission for the resource.

            :param actions: The IAM action to grant or revoke permissions on.
            :param principal: The Amazon Resource Name (ARN) of the principal. This can be one of the following:. - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.) - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.) - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
            :param resource: 

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-resourcepermission.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                resource_permission_property = quicksight.CfnAnalysis.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal",
                
                    # the properties below are optional
                    resource="resource"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3fc259c5b8c788d6d869a47ae793532e020a49da8fe79d4b395dbea801e2a2ba)
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
                check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "actions": actions,
                "principal": principal,
            }
            if resource is not None:
                self._values["resource"] = resource

        @builtins.property
        def actions(self) -> typing.List[builtins.str]:
            '''The IAM action to grant or revoke permissions on.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-resourcepermission.html#cfn-quicksight-analysis-resourcepermission-actions
            '''
            result = self._values.get("actions")
            assert result is not None, "Required property 'actions' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def principal(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the principal. This can be one of the following:.

            - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
            - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
            - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-resourcepermission.html#cfn-quicksight-analysis-resourcepermission-principal
            '''
            result = self._values.get("principal")
            assert result is not None, "Required property 'principal' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def resource(self) -> typing.Optional[builtins.str]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-resourcepermission.html#cfn-quicksight-analysis-resourcepermission-resource
            '''
            result = self._values.get("resource")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ResourcePermissionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.RollingDateConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "expression": "expression",
            "data_set_identifier": "dataSetIdentifier",
        },
    )
    class RollingDateConfigurationProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            data_set_identifier: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The rolling date configuration of a date time filter.

            :param expression: The expression of the rolling date configuration.
            :param data_set_identifier: The data set that is used in the rolling date configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rollingdateconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                rolling_date_configuration_property = quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                    expression="expression",
                
                    # the properties below are optional
                    data_set_identifier="dataSetIdentifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__072c8a685207594ee5bd1ecf5bae08b2827f5eb3a7072e1e1cfca7c4232a9211)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if data_set_identifier is not None:
                self._values["data_set_identifier"] = data_set_identifier

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the rolling date configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rollingdateconfiguration.html#cfn-quicksight-analysis-rollingdateconfiguration-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_identifier(self) -> typing.Optional[builtins.str]:
            '''The data set that is used in the rolling date configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rollingdateconfiguration.html#cfn-quicksight-analysis-rollingdateconfiguration-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RollingDateConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.RowAlternateColorOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "row_alternate_colors": "rowAlternateColors",
            "status": "status",
            "use_primary_background_color": "usePrimaryBackgroundColor",
        },
    )
    class RowAlternateColorOptionsProperty:
        def __init__(
            self,
            *,
            row_alternate_colors: typing.Optional[typing.Sequence[builtins.str]] = None,
            status: typing.Optional[builtins.str] = None,
            use_primary_background_color: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the row alternate color options.

            :param row_alternate_colors: Determines the list of row alternate colors.
            :param status: Determines the widget status.
            :param use_primary_background_color: The primary background color options for alternate rows.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rowalternatecoloroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                row_alternate_color_options_property = quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                    row_alternate_colors=["rowAlternateColors"],
                    status="status",
                    use_primary_background_color="usePrimaryBackgroundColor"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3c070161f43d2fc8edbe9d6c68b6eb5cfbe06a5ce5598e138dc0991c22a3d58c)
                check_type(argname="argument row_alternate_colors", value=row_alternate_colors, expected_type=type_hints["row_alternate_colors"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument use_primary_background_color", value=use_primary_background_color, expected_type=type_hints["use_primary_background_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if row_alternate_colors is not None:
                self._values["row_alternate_colors"] = row_alternate_colors
            if status is not None:
                self._values["status"] = status
            if use_primary_background_color is not None:
                self._values["use_primary_background_color"] = use_primary_background_color

        @builtins.property
        def row_alternate_colors(self) -> typing.Optional[typing.List[builtins.str]]:
            '''Determines the list of row alternate colors.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rowalternatecoloroptions.html#cfn-quicksight-analysis-rowalternatecoloroptions-rowalternatecolors
            '''
            result = self._values.get("row_alternate_colors")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''Determines the widget status.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rowalternatecoloroptions.html#cfn-quicksight-analysis-rowalternatecoloroptions-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def use_primary_background_color(self) -> typing.Optional[builtins.str]:
            '''The primary background color options for alternate rows.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rowalternatecoloroptions.html#cfn-quicksight-analysis-rowalternatecoloroptions-useprimarybackgroundcolor
            '''
            result = self._values.get("use_primary_background_color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RowAlternateColorOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "target_visual_options": "targetVisualOptions",
            "target_visuals": "targetVisuals",
        },
    )
    class SameSheetTargetVisualConfigurationProperty:
        def __init__(
            self,
            *,
            target_visual_options: typing.Optional[builtins.str] = None,
            target_visuals: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The configuration of the same-sheet target visuals that you want to be filtered.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param target_visual_options: The options that choose the target visual in the same sheet. Valid values are defined as follows: - ``ALL_VISUALS`` : Applies the filter operation to all visuals in the same sheet.
            :param target_visuals: A list of the target visual IDs that are located in the same sheet of the analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-samesheettargetvisualconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                same_sheet_target_visual_configuration_property = quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                    target_visual_options="targetVisualOptions",
                    target_visuals=["targetVisuals"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__89e526567fb30074913a6862beafdb279487dfb95d0b6fdaa90fef9496e03be6)
                check_type(argname="argument target_visual_options", value=target_visual_options, expected_type=type_hints["target_visual_options"])
                check_type(argname="argument target_visuals", value=target_visuals, expected_type=type_hints["target_visuals"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_visual_options is not None:
                self._values["target_visual_options"] = target_visual_options
            if target_visuals is not None:
                self._values["target_visuals"] = target_visuals

        @builtins.property
        def target_visual_options(self) -> typing.Optional[builtins.str]:
            '''The options that choose the target visual in the same sheet.

            Valid values are defined as follows:

            - ``ALL_VISUALS`` : Applies the filter operation to all visuals in the same sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-samesheettargetvisualconfiguration.html#cfn-quicksight-analysis-samesheettargetvisualconfiguration-targetvisualoptions
            '''
            result = self._values.get("target_visual_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def target_visuals(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of the target visual IDs that are located in the same sheet of the analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-samesheettargetvisualconfiguration.html#cfn-quicksight-analysis-samesheettargetvisualconfiguration-targetvisuals
            '''
            result = self._values.get("target_visuals")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SameSheetTargetVisualConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination": "destination",
            "source": "source",
            "weight": "weight",
        },
    )
    class SankeyDiagramAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            destination: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            source: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            weight: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a sankey diagram.

            :param destination: The destination field wells of a sankey diagram.
            :param source: The source field wells of a sankey diagram.
            :param weight: The weight field wells of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__50299c6f810ee6463d3f47777302d443da6a8c9db881dd5c4375616077b89b7b)
                check_type(argname="argument destination", value=destination, expected_type=type_hints["destination"])
                check_type(argname="argument source", value=source, expected_type=type_hints["source"])
                check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if destination is not None:
                self._values["destination"] = destination
            if source is not None:
                self._values["source"] = source
            if weight is not None:
                self._values["weight"] = weight

        @builtins.property
        def destination(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The destination field wells of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-analysis-sankeydiagramaggregatedfieldwells-destination
            '''
            result = self._values.get("destination")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def source(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The source field wells of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-analysis-sankeydiagramaggregatedfieldwells-source
            '''
            result = self._values.get("source")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def weight(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The weight field wells of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-analysis-sankeydiagramaggregatedfieldwells-weight
            '''
            result = self._values.get("weight")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SankeyDiagramChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
        },
    )
    class SankeyDiagramChartConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SankeyDiagramFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SankeyDiagramSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a sankey diagram.

            :param data_labels: The data label configuration of a sankey diagram.
            :param field_wells: The field well configuration of a sankey diagram.
            :param sort_configuration: The sort configuration of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c5a5533c4ca22fd4d80f034a87056d31f75b96e2deb491503c35d0a60209168b)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The data label configuration of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramchartconfiguration.html#cfn-quicksight-analysis-sankeydiagramchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SankeyDiagramFieldWellsProperty"]]:
            '''The field well configuration of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramchartconfiguration.html#cfn-quicksight-analysis-sankeydiagramchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SankeyDiagramFieldWellsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SankeyDiagramSortConfigurationProperty"]]:
            '''The sort configuration of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramchartconfiguration.html#cfn-quicksight-analysis-sankeydiagramchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SankeyDiagramSortConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SankeyDiagramFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sankey_diagram_aggregated_field_wells": "sankeyDiagramAggregatedFieldWells",
        },
    )
    class SankeyDiagramFieldWellsProperty:
        def __init__(
            self,
            *,
            sankey_diagram_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a sankey diagram.

            :param sankey_diagram_aggregated_field_wells: The field well configuration of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d4059e9b42014a9d3db916fd3c4db2cd2ebbbaeb44fd25b78f27646655e3599b)
                check_type(argname="argument sankey_diagram_aggregated_field_wells", value=sankey_diagram_aggregated_field_wells, expected_type=type_hints["sankey_diagram_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sankey_diagram_aggregated_field_wells is not None:
                self._values["sankey_diagram_aggregated_field_wells"] = sankey_diagram_aggregated_field_wells

        @builtins.property
        def sankey_diagram_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramfieldwells.html#cfn-quicksight-analysis-sankeydiagramfieldwells-sankeydiagramaggregatedfieldwells
            '''
            result = self._values.get("sankey_diagram_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SankeyDiagramSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination_items_limit": "destinationItemsLimit",
            "source_items_limit": "sourceItemsLimit",
            "weight_sort": "weightSort",
        },
    )
    class SankeyDiagramSortConfigurationProperty:
        def __init__(
            self,
            *,
            destination_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            source_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            weight_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a sankey diagram.

            :param destination_items_limit: The limit on the number of destination nodes that are displayed in a sankey diagram.
            :param source_items_limit: The limit on the number of source nodes that are displayed in a sankey diagram.
            :param weight_sort: The sort configuration of the weight fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sankey_diagram_sort_configuration_property = quicksight.CfnAnalysis.SankeyDiagramSortConfigurationProperty(
                    destination_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    source_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    weight_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2bfb095608374613b7cc02d318d9945afb9ad79d77907c4fa782441e3bf54a9f)
                check_type(argname="argument destination_items_limit", value=destination_items_limit, expected_type=type_hints["destination_items_limit"])
                check_type(argname="argument source_items_limit", value=source_items_limit, expected_type=type_hints["source_items_limit"])
                check_type(argname="argument weight_sort", value=weight_sort, expected_type=type_hints["weight_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if destination_items_limit is not None:
                self._values["destination_items_limit"] = destination_items_limit
            if source_items_limit is not None:
                self._values["source_items_limit"] = source_items_limit
            if weight_sort is not None:
                self._values["weight_sort"] = weight_sort

        @builtins.property
        def destination_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of destination nodes that are displayed in a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramsortconfiguration.html#cfn-quicksight-analysis-sankeydiagramsortconfiguration-destinationitemslimit
            '''
            result = self._values.get("destination_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def source_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of source nodes that are displayed in a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramsortconfiguration.html#cfn-quicksight-analysis-sankeydiagramsortconfiguration-sourceitemslimit
            '''
            result = self._values.get("source_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def weight_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the weight fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramsortconfiguration.html#cfn-quicksight-analysis-sankeydiagramsortconfiguration-weightsort
            '''
            result = self._values.get("weight_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SankeyDiagramVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class SankeyDiagramVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SankeyDiagramChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A sankey diagram.

            For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a sankey diagram.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2353770320f91671da6dd30bf1a1d0bf55664663dc4fe05b4ac973a2aae51ca3)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SankeyDiagramChartConfigurationProperty"]]:
            '''The configuration of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SankeyDiagramChartConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "label": "label",
            "size": "size",
            "x_axis": "xAxis",
            "y_axis": "yAxis",
        },
    )
    class ScatterPlotCategoricallyAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            label: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            x_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            y_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well of a scatter plot.

            :param category: The category field well of a scatter plot.
            :param label: The label field well of a scatter plot.
            :param size: The size field well of a scatter plot.
            :param x_axis: The x-axis field well of a scatter plot. The x-axis is aggregated by category.
            :param y_axis: The y-axis field well of a scatter plot. The y-axis is aggregated by category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__faa44e5cb215d7adb725a5c8a0f77e69ca1295ee1a5d6ff71800b7da005fd513)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
                check_type(argname="argument x_axis", value=x_axis, expected_type=type_hints["x_axis"])
                check_type(argname="argument y_axis", value=y_axis, expected_type=type_hints["y_axis"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if label is not None:
                self._values["label"] = label
            if size is not None:
                self._values["size"] = size
            if x_axis is not None:
                self._values["x_axis"] = x_axis
            if y_axis is not None:
                self._values["y_axis"] = y_axis

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The category field well of a scatter plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def label(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The label field well of a scatter plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The size field well of a scatter plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        @builtins.property
        def x_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The x-axis field well of a scatter plot.

            The x-axis is aggregated by category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-xaxis
            '''
            result = self._values.get("x_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        @builtins.property
        def y_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The y-axis field well of a scatter plot.

            The y-axis is aggregated by category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-yaxis
            '''
            result = self._values.get("y_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotCategoricallyAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ScatterPlotConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
            "y_axis_display_options": "yAxisDisplayOptions",
            "y_axis_label_options": "yAxisLabelOptions",
        },
    )
    class ScatterPlotConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ScatterPlotFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a scatter plot.

            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param tooltip: The legend display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.
            :param x_axis_display_options: The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.
            :param x_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.
            :param y_axis_display_options: The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.
            :param y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d3558e5a1dd91d7ad934b186aca3f342288f486c4aa011b888c3a6931ff09ed9)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
                check_type(argname="argument y_axis_display_options", value=y_axis_display_options, expected_type=type_hints["y_axis_display_options"])
                check_type(argname="argument y_axis_label_options", value=y_axis_label_options, expected_type=type_hints["y_axis_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options
            if y_axis_display_options is not None:
                self._values["y_axis_display_options"] = y_axis_display_options
            if y_axis_label_options is not None:
                self._values["y_axis_label_options"] = y_axis_label_options

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ScatterPlotFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ScatterPlotFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-yaxisdisplayoptions
            '''
            result = self._values.get("y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-yaxislabeloptions
            '''
            result = self._values.get("y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ScatterPlotFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "scatter_plot_categorically_aggregated_field_wells": "scatterPlotCategoricallyAggregatedFieldWells",
            "scatter_plot_unaggregated_field_wells": "scatterPlotUnaggregatedFieldWells",
        },
    )
    class ScatterPlotFieldWellsProperty:
        def __init__(
            self,
            *,
            scatter_plot_categorically_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scatter_plot_unaggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a scatter plot.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param scatter_plot_categorically_aggregated_field_wells: The aggregated field wells of a scatter plot. The x and y-axes of scatter plots with aggregated field wells are aggregated by category, label, or both.
            :param scatter_plot_unaggregated_field_wells: The unaggregated field wells of a scatter plot. The x and y-axes of these scatter plots are unaggregated.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b7e7a9e207db7329012d816002b5869adc45404d6f220108d397752c7de99343)
                check_type(argname="argument scatter_plot_categorically_aggregated_field_wells", value=scatter_plot_categorically_aggregated_field_wells, expected_type=type_hints["scatter_plot_categorically_aggregated_field_wells"])
                check_type(argname="argument scatter_plot_unaggregated_field_wells", value=scatter_plot_unaggregated_field_wells, expected_type=type_hints["scatter_plot_unaggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if scatter_plot_categorically_aggregated_field_wells is not None:
                self._values["scatter_plot_categorically_aggregated_field_wells"] = scatter_plot_categorically_aggregated_field_wells
            if scatter_plot_unaggregated_field_wells is not None:
                self._values["scatter_plot_unaggregated_field_wells"] = scatter_plot_unaggregated_field_wells

        @builtins.property
        def scatter_plot_categorically_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a scatter plot.

            The x and y-axes of scatter plots with aggregated field wells are aggregated by category, label, or both.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotfieldwells.html#cfn-quicksight-analysis-scatterplotfieldwells-scatterplotcategoricallyaggregatedfieldwells
            '''
            result = self._values.get("scatter_plot_categorically_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty"]], result)

        @builtins.property
        def scatter_plot_unaggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty"]]:
            '''The unaggregated field wells of a scatter plot.

            The x and y-axes of these scatter plots are unaggregated.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotfieldwells.html#cfn-quicksight-analysis-scatterplotfieldwells-scatterplotunaggregatedfieldwells
            '''
            result = self._values.get("scatter_plot_unaggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "label": "label",
            "size": "size",
            "x_axis": "xAxis",
            "y_axis": "yAxis",
        },
    )
    class ScatterPlotUnaggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            label: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            x_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            y_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The unaggregated field wells of a scatter plot.

            :param category: The category field well of a scatter plot.
            :param label: The label field well of a scatter plot.
            :param size: The size field well of a scatter plot.
            :param x_axis: The x-axis field well of a scatter plot. The x-axis is a dimension field and cannot be aggregated.
            :param y_axis: The y-axis field well of a scatter plot. The y-axis is a dimension field and cannot be aggregated.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__324ea17b5f516a9f672c539911f13d7467cb4a350317a6326e8a1c5b4fe4b068)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
                check_type(argname="argument x_axis", value=x_axis, expected_type=type_hints["x_axis"])
                check_type(argname="argument y_axis", value=y_axis, expected_type=type_hints["y_axis"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if label is not None:
                self._values["label"] = label
            if size is not None:
                self._values["size"] = size
            if x_axis is not None:
                self._values["x_axis"] = x_axis
            if y_axis is not None:
                self._values["y_axis"] = y_axis

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The category field well of a scatter plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotunaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def label(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The label field well of a scatter plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotunaggregatedfieldwells-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The size field well of a scatter plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotunaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        @builtins.property
        def x_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The x-axis field well of a scatter plot.

            The x-axis is a dimension field and cannot be aggregated.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotunaggregatedfieldwells-xaxis
            '''
            result = self._values.get("x_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def y_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The y-axis field well of a scatter plot.

            The y-axis is a dimension field and cannot be aggregated.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotunaggregatedfieldwells-yaxis
            '''
            result = self._values.get("y_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotUnaggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ScatterPlotVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class ScatterPlotVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ScatterPlotConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A scatter plot.

            For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ad04c34cf5d4ce97fd40417bbbd85dc659c5df4f5b628ab84eec51d046d328de)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ScatterPlotConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ScatterPlotConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ScrollBarOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility", "visible_range": "visibleRange"},
    )
    class ScrollBarOptionsProperty:
        def __init__(
            self,
            *,
            visibility: typing.Optional[builtins.str] = None,
            visible_range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisibleRangeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The visual display options for a data zoom scroll bar.

            :param visibility: The visibility of the data zoom scroll bar.
            :param visible_range: The visibility range for the data zoom scroll bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scrollbaroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                scroll_bar_options_property = quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                    visibility="visibility",
                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                            from=123,
                            to=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__faa25bee43d1791f93596ed4633b3a4c843fb3d5965d93b28ebd221e6bc3af57)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument visible_range", value=visible_range, expected_type=type_hints["visible_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility
            if visible_range is not None:
                self._values["visible_range"] = visible_range

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the data zoom scroll bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scrollbaroptions.html#cfn-quicksight-analysis-scrollbaroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visible_range(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisibleRangeOptionsProperty"]]:
            '''The visibility range for the data zoom scroll bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scrollbaroptions.html#cfn-quicksight-analysis-scrollbaroptions-visiblerange
            '''
            result = self._values.get("visible_range")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisibleRangeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScrollBarOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SecondaryValueOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class SecondaryValueOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of the secondary value of a KPI visual.

            :param visibility: Determines the visibility of the secondary value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-secondaryvalueoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                secondary_value_options_property = quicksight.CfnAnalysis.SecondaryValueOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d2dd76bf736d3e5632977889f5090daaf4044ab1614c1f86c6ef522aeb640104)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the secondary value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-secondaryvalueoptions.html#cfn-quicksight-analysis-secondaryvalueoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SecondaryValueOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SectionAfterPageBreakProperty",
        jsii_struct_bases=[],
        name_mapping={"status": "status"},
    )
    class SectionAfterPageBreakProperty:
        def __init__(self, *, status: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of a page break after a section.

            :param status: The option that enables or disables a page break at the end of a section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionafterpagebreak.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                section_after_page_break_property = quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__88ec9551bb5dee706cc3d3782ed825d3dfc9f41b36092eeb3ede128f138774f5)
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The option that enables or disables a page break at the end of a section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionafterpagebreak.html#cfn-quicksight-analysis-sectionafterpagebreak-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionAfterPageBreakProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"paper_canvas_size_options": "paperCanvasSizeOptions"},
    )
    class SectionBasedLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            paper_canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options for the canvas of a section-based layout.

            :param paper_canvas_size_options: The options for a paper canvas of a section-based layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                section_based_layout_canvas_size_options_property = quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                    paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                        paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        ),
                        paper_orientation="paperOrientation",
                        paper_size="paperSize"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__777bb33b4832168efefbc4ab232bed80c935c2e9eacbfab8c276b6340a5546a8)
                check_type(argname="argument paper_canvas_size_options", value=paper_canvas_size_options, expected_type=type_hints["paper_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if paper_canvas_size_options is not None:
                self._values["paper_canvas_size_options"] = paper_canvas_size_options

        @builtins.property
        def paper_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty"]]:
            '''The options for a paper canvas of a section-based layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutcanvassizeoptions.html#cfn-quicksight-analysis-sectionbasedlayoutcanvassizeoptions-papercanvassizeoptions
            '''
            result = self._values.get("paper_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SectionBasedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "body_sections": "bodySections",
            "canvas_size_options": "canvasSizeOptions",
            "footer_sections": "footerSections",
            "header_sections": "headerSections",
        },
    )
    class SectionBasedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            body_sections: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.BodySectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
            footer_sections: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.HeaderFooterSectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            header_sections: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.HeaderFooterSectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The configuration for a section-based layout.

            :param body_sections: A list of body section configurations.
            :param canvas_size_options: The options for the canvas of a section-based layout.
            :param footer_sections: A list of footer section configurations.
            :param header_sections: A list of header section configurations.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                section_based_layout_configuration_property = quicksight.CfnAnalysis.SectionBasedLayoutConfigurationProperty(
                    body_sections=[quicksight.CfnAnalysis.BodySectionConfigurationProperty(
                        content=quicksight.CfnAnalysis.BodySectionContentProperty(
                            layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        page_break_configuration=quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                            after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                                status="status"
                            )
                        ),
                        style=quicksight.CfnAnalysis.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnAnalysis.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )],
                    canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                        paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                            paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            ),
                            paper_orientation="paperOrientation",
                            paper_size="paperSize"
                        )
                    ),
                    footer_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                        layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        style=quicksight.CfnAnalysis.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnAnalysis.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )],
                    header_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                        layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        style=quicksight.CfnAnalysis.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnAnalysis.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0a3267d1b6d1fbe17cee04ffdf5ff17a7fe7df847cc8e442e054953efce15a4e)
                check_type(argname="argument body_sections", value=body_sections, expected_type=type_hints["body_sections"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
                check_type(argname="argument footer_sections", value=footer_sections, expected_type=type_hints["footer_sections"])
                check_type(argname="argument header_sections", value=header_sections, expected_type=type_hints["header_sections"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "body_sections": body_sections,
                "canvas_size_options": canvas_size_options,
                "footer_sections": footer_sections,
                "header_sections": header_sections,
            }

        @builtins.property
        def body_sections(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BodySectionConfigurationProperty"]]]:
            '''A list of body section configurations.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-sectionbasedlayoutconfiguration-bodysections
            '''
            result = self._values.get("body_sections")
            assert result is not None, "Required property 'body_sections' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BodySectionConfigurationProperty"]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty"]:
            '''The options for the canvas of a section-based layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-sectionbasedlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty"], result)

        @builtins.property
        def footer_sections(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HeaderFooterSectionConfigurationProperty"]]]:
            '''A list of footer section configurations.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-sectionbasedlayoutconfiguration-footersections
            '''
            result = self._values.get("footer_sections")
            assert result is not None, "Required property 'footer_sections' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HeaderFooterSectionConfigurationProperty"]]], result)

        @builtins.property
        def header_sections(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HeaderFooterSectionConfigurationProperty"]]]:
            '''A list of header section configurations.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-sectionbasedlayoutconfiguration-headersections
            '''
            result = self._values.get("header_sections")
            assert result is not None, "Required property 'header_sections' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HeaderFooterSectionConfigurationProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "paper_margin": "paperMargin",
            "paper_orientation": "paperOrientation",
            "paper_size": "paperSize",
        },
    )
    class SectionBasedLayoutPaperCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            paper_margin: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SpacingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paper_orientation: typing.Optional[builtins.str] = None,
            paper_size: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for a paper canvas of a section-based layout.

            :param paper_margin: Defines the spacing between the canvas content and the top, bottom, left, and right edges.
            :param paper_orientation: The paper orientation that is used to define canvas dimensions. Choose one of the following options:. - PORTRAIT - LANDSCAPE
            :param paper_size: The paper size that is used to define canvas dimensions.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                section_based_layout_paper_canvas_size_options_property = quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                    paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                        bottom="bottom",
                        left="left",
                        right="right",
                        top="top"
                    ),
                    paper_orientation="paperOrientation",
                    paper_size="paperSize"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2d590df6a368659c4d4ecfc52def43dec31727bec51d00dd7a438e813b6e2afd)
                check_type(argname="argument paper_margin", value=paper_margin, expected_type=type_hints["paper_margin"])
                check_type(argname="argument paper_orientation", value=paper_orientation, expected_type=type_hints["paper_orientation"])
                check_type(argname="argument paper_size", value=paper_size, expected_type=type_hints["paper_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if paper_margin is not None:
                self._values["paper_margin"] = paper_margin
            if paper_orientation is not None:
                self._values["paper_orientation"] = paper_orientation
            if paper_size is not None:
                self._values["paper_size"] = paper_size

        @builtins.property
        def paper_margin(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SpacingProperty"]]:
            '''Defines the spacing between the canvas content and the top, bottom, left, and right edges.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions-papermargin
            '''
            result = self._values.get("paper_margin")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SpacingProperty"]], result)

        @builtins.property
        def paper_orientation(self) -> typing.Optional[builtins.str]:
            '''The paper orientation that is used to define canvas dimensions. Choose one of the following options:.

            - PORTRAIT
            - LANDSCAPE

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions-paperorientation
            '''
            result = self._values.get("paper_orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def paper_size(self) -> typing.Optional[builtins.str]:
            '''The paper size that is used to define canvas dimensions.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions-papersize
            '''
            result = self._values.get("paper_size")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutPaperCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SectionLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"free_form_layout": "freeFormLayout"},
    )
    class SectionLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form_layout: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FreeFormSectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The layout configuration of a section.

            :param free_form_layout: The free-form layout configuration of a section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                section_layout_configuration_property = quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                    free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                        elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                            element_id="elementId",
                            element_type="elementType",
                            height="height",
                            width="width",
                            x_axis_location="xAxisLocation",
                            y_axis_location="yAxisLocation",
                
                            # the properties below are optional
                            background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                visibility="visibility"
                            ),
                            rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                    visibility="visibility"
                                ),
                                expression="expression"
                            )],
                            selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            visibility="visibility"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3c65f04561e71fc4a19fb3d1ac1cda84e2a78daad416381565d1349cf083a67a)
                check_type(argname="argument free_form_layout", value=free_form_layout, expected_type=type_hints["free_form_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "free_form_layout": free_form_layout,
            }

        @builtins.property
        def free_form_layout(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FreeFormSectionLayoutConfigurationProperty"]:
            '''The free-form layout configuration of a section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionlayoutconfiguration.html#cfn-quicksight-analysis-sectionlayoutconfiguration-freeformlayout
            '''
            result = self._values.get("free_form_layout")
            assert result is not None, "Required property 'free_form_layout' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FreeFormSectionLayoutConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"after": "after"},
    )
    class SectionPageBreakConfigurationProperty:
        def __init__(
            self,
            *,
            after: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SectionAfterPageBreakProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a page break for a section.

            :param after: The configuration of a page break after a section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionpagebreakconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                section_page_break_configuration_property = quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                    after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                        status="status"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__defdb7bfada569e5f2c1020b3a96bb6774eafc9634dc86cecac3628e230ee973)
                check_type(argname="argument after", value=after, expected_type=type_hints["after"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if after is not None:
                self._values["after"] = after

        @builtins.property
        def after(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SectionAfterPageBreakProperty"]]:
            '''The configuration of a page break after a section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionpagebreakconfiguration.html#cfn-quicksight-analysis-sectionpagebreakconfiguration-after
            '''
            result = self._values.get("after")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SectionAfterPageBreakProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionPageBreakConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SectionStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"height": "height", "padding": "padding"},
    )
    class SectionStyleProperty:
        def __init__(
            self,
            *,
            height: typing.Optional[builtins.str] = None,
            padding: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SpacingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that style a section.

            :param height: The height of a section. Heights can only be defined for header and footer sections. The default height margin is 0.5 inches.
            :param padding: The spacing between section content and its top, bottom, left, and right edges. There is no padding by default.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                section_style_property = quicksight.CfnAnalysis.SectionStyleProperty(
                    height="height",
                    padding=quicksight.CfnAnalysis.SpacingProperty(
                        bottom="bottom",
                        left="left",
                        right="right",
                        top="top"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0697b4fa2716229534da9c6fee84dc9de18d7d03738eaccc0fdafbf7fd495793)
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument padding", value=padding, expected_type=type_hints["padding"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if height is not None:
                self._values["height"] = height
            if padding is not None:
                self._values["padding"] = padding

        @builtins.property
        def height(self) -> typing.Optional[builtins.str]:
            '''The height of a section.

            Heights can only be defined for header and footer sections. The default height margin is 0.5 inches.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionstyle.html#cfn-quicksight-analysis-sectionstyle-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def padding(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SpacingProperty"]]:
            '''The spacing between section content and its top, bottom, left, and right edges.

            There is no padding by default.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionstyle.html#cfn-quicksight-analysis-sectionstyle-padding
            '''
            result = self._values.get("padding")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SpacingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sheet_visual_scoping_configurations": "sheetVisualScopingConfigurations",
        },
    )
    class SelectedSheetsFilterScopeConfigurationProperty:
        def __init__(
            self,
            *,
            sheet_visual_scoping_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SheetVisualScopingConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The configuration for applying a filter to specific sheets or visuals.

            You can apply this filter to multiple visuals that are on one sheet or to all visuals on a sheet.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param sheet_visual_scoping_configurations: The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-selectedsheetsfilterscopeconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                selected_sheets_filter_scope_configuration_property = quicksight.CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty(
                    sheet_visual_scoping_configurations=[quicksight.CfnAnalysis.SheetVisualScopingConfigurationProperty(
                        scope="scope",
                        sheet_id="sheetId",
                
                        # the properties below are optional
                        visual_ids=["visualIds"]
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ad9033f84e25c4425f427965b03952db637cf11d92af34433afc52b7b5b47b49)
                check_type(argname="argument sheet_visual_scoping_configurations", value=sheet_visual_scoping_configurations, expected_type=type_hints["sheet_visual_scoping_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sheet_visual_scoping_configurations is not None:
                self._values["sheet_visual_scoping_configurations"] = sheet_visual_scoping_configurations

        @builtins.property
        def sheet_visual_scoping_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetVisualScopingConfigurationProperty"]]]]:
            '''The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-selectedsheetsfilterscopeconfiguration.html#cfn-quicksight-analysis-selectedsheetsfilterscopeconfiguration-sheetvisualscopingconfigurations
            '''
            result = self._values.get("sheet_visual_scoping_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetVisualScopingConfigurationProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SelectedSheetsFilterScopeConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_field_series_item": "dataFieldSeriesItem",
            "field_series_item": "fieldSeriesItem",
        },
    )
    class SeriesItemProperty:
        def __init__(
            self,
            *,
            data_field_series_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataFieldSeriesItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_series_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSeriesItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The series item configuration of a line chart.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_field_series_item: The data field series item configuration of a line chart.
            :param field_series_item: The field series item configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-seriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                series_item_property = quicksight.CfnAnalysis.SeriesItemProperty(
                    data_field_series_item=quicksight.CfnAnalysis.DataFieldSeriesItemProperty(
                        axis_binding="axisBinding",
                        field_id="fieldId",
                
                        # the properties below are optional
                        field_value="fieldValue",
                        settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                            line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        )
                    ),
                    field_series_item=quicksight.CfnAnalysis.FieldSeriesItemProperty(
                        axis_binding="axisBinding",
                        field_id="fieldId",
                
                        # the properties below are optional
                        settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                            line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__efd787a350939d10901b7e5bc810e65e208713666be87e6829df664426981f1e)
                check_type(argname="argument data_field_series_item", value=data_field_series_item, expected_type=type_hints["data_field_series_item"])
                check_type(argname="argument field_series_item", value=field_series_item, expected_type=type_hints["field_series_item"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_field_series_item is not None:
                self._values["data_field_series_item"] = data_field_series_item
            if field_series_item is not None:
                self._values["field_series_item"] = field_series_item

        @builtins.property
        def data_field_series_item(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataFieldSeriesItemProperty"]]:
            '''The data field series item configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-seriesitem.html#cfn-quicksight-analysis-seriesitem-datafieldseriesitem
            '''
            result = self._values.get("data_field_series_item")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataFieldSeriesItemProperty"]], result)

        @builtins.property
        def field_series_item(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSeriesItemProperty"]]:
            '''The field series item configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-seriesitem.html#cfn-quicksight-analysis-seriesitem-fieldseriesitem
            '''
            result = self._values.get("field_series_item")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSeriesItemProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SetParameterValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination_parameter_name": "destinationParameterName",
            "value": "value",
        },
    )
    class SetParameterValueConfigurationProperty:
        def __init__(
            self,
            *,
            destination_parameter_name: builtins.str,
            value: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DestinationParameterValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The configuration of adding parameters in action.

            :param destination_parameter_name: The destination parameter name of the ``SetParameterValueConfiguration`` .
            :param value: 

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-setparametervalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                set_parameter_value_configuration_property = quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                    destination_parameter_name="destinationParameterName",
                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                date_time_values=["dateTimeValues"],
                                decimal_values=[123],
                                integer_values=[123],
                                string_values=["stringValues"]
                            ),
                
                            # the properties below are optional
                            include_null_value=False
                        ),
                        select_all_value_options="selectAllValueOptions",
                        source_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        source_field="sourceField",
                        source_parameter_name="sourceParameterName"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aedce8df67ce22c917db59aef867b8fd6bf5034c72d7f80f6675439d8dd08681)
                check_type(argname="argument destination_parameter_name", value=destination_parameter_name, expected_type=type_hints["destination_parameter_name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "destination_parameter_name": destination_parameter_name,
                "value": value,
            }

        @builtins.property
        def destination_parameter_name(self) -> builtins.str:
            '''The destination parameter name of the ``SetParameterValueConfiguration`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-setparametervalueconfiguration.html#cfn-quicksight-analysis-setparametervalueconfiguration-destinationparametername
            '''
            result = self._values.get("destination_parameter_name")
            assert result is not None, "Required property 'destination_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DestinationParameterValueConfigurationProperty"]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-setparametervalueconfiguration.html#cfn-quicksight-analysis-setparametervalueconfiguration-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DestinationParameterValueConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SetParameterValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ShapeConditionalFormatProperty",
        jsii_struct_bases=[],
        name_mapping={"background_color": "backgroundColor"},
    )
    class ShapeConditionalFormatProperty:
        def __init__(
            self,
            *,
            background_color: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The shape conditional formatting of a filled map visual.

            :param background_color: The conditional formatting for the shape background color of a filled map visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shapeconditionalformat.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                shape_conditional_format_property = quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                    background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0e0733bca0c1f8ee8fc46df84996390623d311b8ecfd7b77b2383d22ceba53b1)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "background_color": background_color,
            }

        @builtins.property
        def background_color(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"]:
            '''The conditional formatting for the shape background color of a filled map visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shapeconditionalformat.html#cfn-quicksight-analysis-shapeconditionalformat-backgroundcolor
            '''
            result = self._values.get("background_color")
            assert result is not None, "Required property 'background_color' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ShapeConditionalFormatProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"info_icon_text": "infoIconText", "visibility": "visibility"},
    )
    class SheetControlInfoIconLabelOptionsProperty:
        def __init__(
            self,
            *,
            info_icon_text: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display info icons for filters and parameters.

            :param info_icon_text: The text content of info icon.
            :param visibility: The visibility configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrolinfoiconlabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_control_info_icon_label_options_property = quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                    info_icon_text="infoIconText",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e353f2a6a8caeb0e2a758cfd608d620197c3071f69d05e49e318aa117caadd65)
                check_type(argname="argument info_icon_text", value=info_icon_text, expected_type=type_hints["info_icon_text"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if info_icon_text is not None:
                self._values["info_icon_text"] = info_icon_text
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def info_icon_text(self) -> typing.Optional[builtins.str]:
            '''The text content of info icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrolinfoiconlabeloptions.html#cfn-quicksight-analysis-sheetcontrolinfoiconlabeloptions-infoicontext
            '''
            result = self._values.get("info_icon_text")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrolinfoiconlabeloptions.html#cfn-quicksight-analysis-sheetcontrolinfoiconlabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlInfoIconLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SheetControlLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"grid_layout": "gridLayout"},
    )
    class SheetControlLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            grid_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :param grid_layout: The configuration that determines the elements and canvas size options of sheet control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrollayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_control_layout_configuration_property = quicksight.CfnAnalysis.SheetControlLayoutConfigurationProperty(
                    grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                        elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                            column_span=123,
                            element_id="elementId",
                            element_type="elementType",
                            row_span=123,
                
                            # the properties below are optional
                            column_index=123,
                            row_index=123
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__900d3a0a0f9ea5d3eea4d1ad691a3d9db273acdff56340a1125779a252a70e4e)
                check_type(argname="argument grid_layout", value=grid_layout, expected_type=type_hints["grid_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if grid_layout is not None:
                self._values["grid_layout"] = grid_layout

        @builtins.property
        def grid_layout(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GridLayoutConfigurationProperty"]]:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrollayoutconfiguration.html#cfn-quicksight-analysis-sheetcontrollayoutconfiguration-gridlayout
            '''
            result = self._values.get("grid_layout")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GridLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SheetControlLayoutProperty",
        jsii_struct_bases=[],
        name_mapping={"configuration": "configuration"},
    )
    class SheetControlLayoutProperty:
        def __init__(
            self,
            *,
            configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SheetControlLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''A grid layout to define the placement of sheet control.

            :param configuration: The configuration that determines the elements and canvas size options of sheet control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrollayout.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_control_layout_property = quicksight.CfnAnalysis.SheetControlLayoutProperty(
                    configuration=quicksight.CfnAnalysis.SheetControlLayoutConfigurationProperty(
                        grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                            elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                column_span=123,
                                element_id="elementId",
                                element_type="elementType",
                                row_span=123,
                
                                # the properties below are optional
                                column_index=123,
                                row_index=123
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2f533c8857e8a92377dea47384ae82306d231e834285a3024834fe22049d4c79)
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration": configuration,
            }

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetControlLayoutConfigurationProperty"]:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrollayout.html#cfn-quicksight-analysis-sheetcontrollayout-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetControlLayoutConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlLayoutProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SheetDefinitionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sheet_id": "sheetId",
            "content_type": "contentType",
            "description": "description",
            "filter_controls": "filterControls",
            "layouts": "layouts",
            "name": "name",
            "parameter_controls": "parameterControls",
            "sheet_control_layouts": "sheetControlLayouts",
            "text_boxes": "textBoxes",
            "title": "title",
            "visuals": "visuals",
        },
    )
    class SheetDefinitionProperty:
        def __init__(
            self,
            *,
            sheet_id: builtins.str,
            content_type: typing.Optional[builtins.str] = None,
            description: typing.Optional[builtins.str] = None,
            filter_controls: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilterControlProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            layouts: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LayoutProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            name: typing.Optional[builtins.str] = None,
            parameter_controls: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ParameterControlProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sheet_control_layouts: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SheetControlLayoutProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            text_boxes: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SheetTextBoxProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            title: typing.Optional[builtins.str] = None,
            visuals: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''A sheet is an object that contains a set of visuals that are viewed together on one page in a paginated report.

            Every analysis and dashboard must contain at least one sheet.

            :param sheet_id: The unique identifier of a sheet.
            :param content_type: The layout content type of the sheet. Choose one of the following options:. - ``PAGINATED`` : Creates a sheet for a paginated report. - ``INTERACTIVE`` : Creates a sheet for an interactive dashboard.
            :param description: A description of the sheet.
            :param filter_controls: The list of filter controls that are on a sheet. For more information, see `Adding filter controls to analysis sheets <https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html>`_ in the *Amazon QuickSight User Guide* .
            :param layouts: Layouts define how the components of a sheet are arranged. For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .
            :param name: The name of the sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
            :param parameter_controls: The list of parameter controls that are on a sheet. For more information, see `Using a Control with a Parameter in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html>`_ in the *Amazon QuickSight User Guide* .
            :param sheet_control_layouts: The control layouts of the sheet.
            :param text_boxes: The text boxes that are on a sheet.
            :param title: The title of the sheet.
            :param visuals: A list of the visuals that are on a sheet. Visual placement is determined by the layout of the sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__444d28cb486ba1164dd020bc7463801728002da0058ea20910a57c1354b73fbe)
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
                check_type(argname="argument content_type", value=content_type, expected_type=type_hints["content_type"])
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
                check_type(argname="argument filter_controls", value=filter_controls, expected_type=type_hints["filter_controls"])
                check_type(argname="argument layouts", value=layouts, expected_type=type_hints["layouts"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_controls", value=parameter_controls, expected_type=type_hints["parameter_controls"])
                check_type(argname="argument sheet_control_layouts", value=sheet_control_layouts, expected_type=type_hints["sheet_control_layouts"])
                check_type(argname="argument text_boxes", value=text_boxes, expected_type=type_hints["text_boxes"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument visuals", value=visuals, expected_type=type_hints["visuals"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "sheet_id": sheet_id,
            }
            if content_type is not None:
                self._values["content_type"] = content_type
            if description is not None:
                self._values["description"] = description
            if filter_controls is not None:
                self._values["filter_controls"] = filter_controls
            if layouts is not None:
                self._values["layouts"] = layouts
            if name is not None:
                self._values["name"] = name
            if parameter_controls is not None:
                self._values["parameter_controls"] = parameter_controls
            if sheet_control_layouts is not None:
                self._values["sheet_control_layouts"] = sheet_control_layouts
            if text_boxes is not None:
                self._values["text_boxes"] = text_boxes
            if title is not None:
                self._values["title"] = title
            if visuals is not None:
                self._values["visuals"] = visuals

        @builtins.property
        def sheet_id(self) -> builtins.str:
            '''The unique identifier of a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-sheetid
            '''
            result = self._values.get("sheet_id")
            assert result is not None, "Required property 'sheet_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def content_type(self) -> typing.Optional[builtins.str]:
            '''The layout content type of the sheet. Choose one of the following options:.

            - ``PAGINATED`` : Creates a sheet for a paginated report.
            - ``INTERACTIVE`` : Creates a sheet for an interactive dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-contenttype
            '''
            result = self._values.get("content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''A description of the sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def filter_controls(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterControlProperty"]]]]:
            '''The list of filter controls that are on a sheet.

            For more information, see `Adding filter controls to analysis sheets <https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-filtercontrols
            '''
            result = self._values.get("filter_controls")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilterControlProperty"]]]], result)

        @builtins.property
        def layouts(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LayoutProperty"]]]]:
            '''Layouts define how the components of a sheet are arranged.

            For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-layouts
            '''
            result = self._values.get("layouts")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LayoutProperty"]]]], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of the sheet.

            This name is displayed on the sheet's tab in the Amazon QuickSight console.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_controls(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParameterControlProperty"]]]]:
            '''The list of parameter controls that are on a sheet.

            For more information, see `Using a Control with a Parameter in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-parametercontrols
            '''
            result = self._values.get("parameter_controls")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ParameterControlProperty"]]]], result)

        @builtins.property
        def sheet_control_layouts(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetControlLayoutProperty"]]]]:
            '''The control layouts of the sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-sheetcontrollayouts
            '''
            result = self._values.get("sheet_control_layouts")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetControlLayoutProperty"]]]], result)

        @builtins.property
        def text_boxes(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetTextBoxProperty"]]]]:
            '''The text boxes that are on a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-textboxes
            '''
            result = self._values.get("text_boxes")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetTextBoxProperty"]]]], result)

        @builtins.property
        def title(self) -> typing.Optional[builtins.str]:
            '''The title of the sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visuals(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualProperty"]]]]:
            '''A list of the visuals that are on a sheet.

            Visual placement is determined by the layout of the sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-visuals
            '''
            result = self._values.get("visuals")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetDefinitionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class SheetElementConfigurationOverridesProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The override configuration of the rendering rules of a sheet.

            :param visibility: Determines whether or not the overrides are visible. Choose one of the following options:. - ``VISIBLE`` - ``HIDDEN``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementconfigurationoverrides.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_element_configuration_overrides_property = quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2454e8a4231cee409a6a522180530bb5a80782f7d884021fa3949718ecad255b)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the overrides are visible. Choose one of the following options:.

            - ``VISIBLE``
            - ``HIDDEN``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementconfigurationoverrides.html#cfn-quicksight-analysis-sheetelementconfigurationoverrides-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetElementConfigurationOverridesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SheetElementRenderingRuleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "configuration_overrides": "configurationOverrides",
            "expression": "expression",
        },
    )
    class SheetElementRenderingRuleProperty:
        def __init__(
            self,
            *,
            configuration_overrides: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SheetElementConfigurationOverridesProperty", typing.Dict[builtins.str, typing.Any]]],
            expression: builtins.str,
        ) -> None:
            '''The rendering rules of a sheet that uses a free-form layout.

            :param configuration_overrides: The override configuration of the rendering rules of a sheet.
            :param expression: The expression of the rendering rules of a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementrenderingrule.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_element_rendering_rule_property = quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                        visibility="visibility"
                    ),
                    expression="expression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2edb43696086015de50681bdc9e50bf3a95081b0bf9af02af8a8c2bd38fc7c88)
                check_type(argname="argument configuration_overrides", value=configuration_overrides, expected_type=type_hints["configuration_overrides"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration_overrides": configuration_overrides,
                "expression": expression,
            }

        @builtins.property
        def configuration_overrides(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetElementConfigurationOverridesProperty"]:
            '''The override configuration of the rendering rules of a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementrenderingrule.html#cfn-quicksight-analysis-sheetelementrenderingrule-configurationoverrides
            '''
            result = self._values.get("configuration_overrides")
            assert result is not None, "Required property 'configuration_overrides' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetElementConfigurationOverridesProperty"], result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the rendering rules of a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementrenderingrule.html#cfn-quicksight-analysis-sheetelementrenderingrule-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetElementRenderingRuleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SheetProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "sheet_id": "sheetId"},
    )
    class SheetProperty:
        def __init__(
            self,
            *,
            name: typing.Optional[builtins.str] = None,
            sheet_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A *sheet* , which is an object that contains a set of visuals that are viewed together on one page in Amazon QuickSight.

            Every analysis and dashboard contains at least one sheet. Each sheet contains at least one visualization widget, for example a chart, pivot table, or narrative insight. Sheets can be associated with other components, such as controls, filters, and so on.

            :param name: The name of a sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
            :param sheet_id: The unique identifier associated with a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheet.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_property = quicksight.CfnAnalysis.SheetProperty(
                    name="name",
                    sheet_id="sheetId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fc7433bf24865199eabab7626a356c448f05a915887952c4a2780712050f4f7b)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if name is not None:
                self._values["name"] = name
            if sheet_id is not None:
                self._values["sheet_id"] = sheet_id

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a sheet.

            This name is displayed on the sheet's tab in the Amazon QuickSight console.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheet.html#cfn-quicksight-analysis-sheet-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sheet_id(self) -> typing.Optional[builtins.str]:
            '''The unique identifier associated with a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheet.html#cfn-quicksight-analysis-sheet-sheetid
            '''
            result = self._values.get("sheet_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SheetTextBoxProperty",
        jsii_struct_bases=[],
        name_mapping={"sheet_text_box_id": "sheetTextBoxId", "content": "content"},
    )
    class SheetTextBoxProperty:
        def __init__(
            self,
            *,
            sheet_text_box_id: builtins.str,
            content: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A text box.

            :param sheet_text_box_id: The unique identifier for a text box. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.
            :param content: The content that is displayed in the text box.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheettextbox.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_text_box_property = quicksight.CfnAnalysis.SheetTextBoxProperty(
                    sheet_text_box_id="sheetTextBoxId",
                
                    # the properties below are optional
                    content="content"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c11f3c0decba2e94eb6cd10f2ebc916ccb6c9fb2b5a2f1337a971d1e0c1b2502)
                check_type(argname="argument sheet_text_box_id", value=sheet_text_box_id, expected_type=type_hints["sheet_text_box_id"])
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "sheet_text_box_id": sheet_text_box_id,
            }
            if content is not None:
                self._values["content"] = content

        @builtins.property
        def sheet_text_box_id(self) -> builtins.str:
            '''The unique identifier for a text box.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheettextbox.html#cfn-quicksight-analysis-sheettextbox-sheettextboxid
            '''
            result = self._values.get("sheet_text_box_id")
            assert result is not None, "Required property 'sheet_text_box_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def content(self) -> typing.Optional[builtins.str]:
            '''The content that is displayed in the text box.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheettextbox.html#cfn-quicksight-analysis-sheettextbox-content
            '''
            result = self._values.get("content")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetTextBoxProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SheetVisualScopingConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "scope": "scope",
            "sheet_id": "sheetId",
            "visual_ids": "visualIds",
        },
    )
    class SheetVisualScopingConfigurationProperty:
        def __init__(
            self,
            *,
            scope: builtins.str,
            sheet_id: builtins.str,
            visual_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The filter that is applied to the options.

            :param scope: The scope of the applied entities. Choose one of the following options:. - ``ALL_VISUALS`` - ``SELECTED_VISUALS``
            :param sheet_id: The selected sheet that the filter is applied to.
            :param visual_ids: The selected visuals that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetvisualscopingconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_visual_scoping_configuration_property = quicksight.CfnAnalysis.SheetVisualScopingConfigurationProperty(
                    scope="scope",
                    sheet_id="sheetId",
                
                    # the properties below are optional
                    visual_ids=["visualIds"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6f871c830482a742c2d47597062ce7160448858d0eb4aec9ca1323c6d3e2c1e3)
                check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
                check_type(argname="argument visual_ids", value=visual_ids, expected_type=type_hints["visual_ids"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "scope": scope,
                "sheet_id": sheet_id,
            }
            if visual_ids is not None:
                self._values["visual_ids"] = visual_ids

        @builtins.property
        def scope(self) -> builtins.str:
            '''The scope of the applied entities. Choose one of the following options:.

            - ``ALL_VISUALS``
            - ``SELECTED_VISUALS``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetvisualscopingconfiguration.html#cfn-quicksight-analysis-sheetvisualscopingconfiguration-scope
            '''
            result = self._values.get("scope")
            assert result is not None, "Required property 'scope' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sheet_id(self) -> builtins.str:
            '''The selected sheet that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetvisualscopingconfiguration.html#cfn-quicksight-analysis-sheetvisualscopingconfiguration-sheetid
            '''
            result = self._values.get("sheet_id")
            assert result is not None, "Required property 'sheet_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_ids(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The selected visuals that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetvisualscopingconfiguration.html#cfn-quicksight-analysis-sheetvisualscopingconfiguration-visualids
            '''
            result = self._values.get("visual_ids")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetVisualScopingConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ShortFormatTextProperty",
        jsii_struct_bases=[],
        name_mapping={"plain_text": "plainText", "rich_text": "richText"},
    )
    class ShortFormatTextProperty:
        def __init__(
            self,
            *,
            plain_text: typing.Optional[builtins.str] = None,
            rich_text: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The text format for the title.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param plain_text: Plain text format.
            :param rich_text: Rich text. Examples of rich text include bold, underline, and italics.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shortformattext.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                short_format_text_property = quicksight.CfnAnalysis.ShortFormatTextProperty(
                    plain_text="plainText",
                    rich_text="richText"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8acbf14306b0d4386ff90d2e8d282f658306641e2b39833e7dfaa076d1ef7d0e)
                check_type(argname="argument plain_text", value=plain_text, expected_type=type_hints["plain_text"])
                check_type(argname="argument rich_text", value=rich_text, expected_type=type_hints["rich_text"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if plain_text is not None:
                self._values["plain_text"] = plain_text
            if rich_text is not None:
                self._values["rich_text"] = rich_text

        @builtins.property
        def plain_text(self) -> typing.Optional[builtins.str]:
            '''Plain text format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shortformattext.html#cfn-quicksight-analysis-shortformattext-plaintext
            '''
            result = self._values.get("plain_text")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rich_text(self) -> typing.Optional[builtins.str]:
            '''Rich text.

            Examples of rich text include bold, underline, and italics.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shortformattext.html#cfn-quicksight-analysis-shortformattext-richtext
            '''
            result = self._values.get("rich_text")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ShortFormatTextProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SimpleClusterMarkerProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color"},
    )
    class SimpleClusterMarkerProperty:
        def __init__(self, *, color: typing.Optional[builtins.str] = None) -> None:
            '''The simple cluster marker of the cluster marker.

            :param color: The color of the simple cluster marker.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-simpleclustermarker.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                simple_cluster_marker_property = quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                    color="color"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1f4a055a47f0538eca137de3275943606ae2840c4df9da8eba48407751bdd907)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color of the simple cluster marker.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-simpleclustermarker.html#cfn-quicksight-analysis-simpleclustermarker-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SimpleClusterMarkerProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "info_icon_label_options": "infoIconLabelOptions",
            "title_options": "titleOptions",
        },
    )
    class SliderControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SheetControlInfoIconLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param info_icon_label_options: The configuration of info icon label options.
            :param title_options: The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-slidercontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                slider_control_display_options_property = quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                    info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                        info_icon_text="infoIconText",
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__680207b3c486d874ece8a1090dd922474d41adabcd8426ad4ea5182a9ebb18e6)
                check_type(argname="argument info_icon_label_options", value=info_icon_label_options, expected_type=type_hints["info_icon_label_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if info_icon_label_options is not None:
                self._values["info_icon_label_options"] = info_icon_label_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def info_icon_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetControlInfoIconLabelOptionsProperty"]]:
            '''The configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-slidercontroldisplayoptions.html#cfn-quicksight-analysis-slidercontroldisplayoptions-infoiconlabeloptions
            '''
            result = self._values.get("info_icon_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetControlInfoIconLabelOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-slidercontroldisplayoptions.html#cfn-quicksight-analysis-slidercontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SliderControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SmallMultiplesAxisPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={"placement": "placement", "scale": "scale"},
    )
    class SmallMultiplesAxisPropertiesProperty:
        def __init__(
            self,
            *,
            placement: typing.Optional[builtins.str] = None,
            scale: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Configures the properties of a chart's axes that are used by small multiples panels.

            :param placement: Defines the placement of the axis. By default, axes are rendered ``OUTSIDE`` of the panels. Axes with ``INDEPENDENT`` scale are rendered ``INSIDE`` the panels.
            :param scale: Determines whether scale of the axes are shared or independent. The default value is ``SHARED`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesaxisproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                small_multiples_axis_properties_property = quicksight.CfnAnalysis.SmallMultiplesAxisPropertiesProperty(
                    placement="placement",
                    scale="scale"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__525e3f793bfdedaa2c2a78f882fd6dbda738d0988a76cdc5055da1facf015a90)
                check_type(argname="argument placement", value=placement, expected_type=type_hints["placement"])
                check_type(argname="argument scale", value=scale, expected_type=type_hints["scale"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if placement is not None:
                self._values["placement"] = placement
            if scale is not None:
                self._values["scale"] = scale

        @builtins.property
        def placement(self) -> typing.Optional[builtins.str]:
            '''Defines the placement of the axis.

            By default, axes are rendered ``OUTSIDE`` of the panels. Axes with ``INDEPENDENT`` scale are rendered ``INSIDE`` the panels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesaxisproperties.html#cfn-quicksight-analysis-smallmultiplesaxisproperties-placement
            '''
            result = self._values.get("placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scale(self) -> typing.Optional[builtins.str]:
            '''Determines whether scale of the axes are shared or independent.

            The default value is ``SHARED`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesaxisproperties.html#cfn-quicksight-analysis-smallmultiplesaxisproperties-scale
            '''
            result = self._values.get("scale")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SmallMultiplesAxisPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SmallMultiplesOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "max_visible_columns": "maxVisibleColumns",
            "max_visible_rows": "maxVisibleRows",
            "panel_configuration": "panelConfiguration",
            "x_axis": "xAxis",
            "y_axis": "yAxis",
        },
    )
    class SmallMultiplesOptionsProperty:
        def __init__(
            self,
            *,
            max_visible_columns: typing.Optional[jsii.Number] = None,
            max_visible_rows: typing.Optional[jsii.Number] = None,
            panel_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PanelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SmallMultiplesAxisPropertiesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            y_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SmallMultiplesAxisPropertiesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Options that determine the layout and display options of a chart's small multiples.

            :param max_visible_columns: Sets the maximum number of visible columns to display in the grid of small multiples panels. The default is ``Auto`` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.
            :param max_visible_rows: Sets the maximum number of visible rows to display in the grid of small multiples panels. The default value is ``Auto`` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.
            :param panel_configuration: Configures the display options for each small multiples panel.
            :param x_axis: The properties of a small multiples X axis.
            :param y_axis: The properties of a small multiples Y axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                small_multiples_options_property = quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                    max_visible_columns=123,
                    max_visible_rows=123,
                    panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                        background_color="backgroundColor",
                        background_visibility="backgroundVisibility",
                        border_color="borderColor",
                        border_style="borderStyle",
                        border_thickness="borderThickness",
                        border_visibility="borderVisibility",
                        gutter_spacing="gutterSpacing",
                        gutter_visibility="gutterVisibility",
                        title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_text_alignment="horizontalTextAlignment",
                            visibility="visibility"
                        )
                    ),
                    x_axis=quicksight.CfnAnalysis.SmallMultiplesAxisPropertiesProperty(
                        placement="placement",
                        scale="scale"
                    ),
                    y_axis=quicksight.CfnAnalysis.SmallMultiplesAxisPropertiesProperty(
                        placement="placement",
                        scale="scale"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d76f5307fa5855024b7b03891a98f0c653788b08e89ee70e480b9a224693d673)
                check_type(argname="argument max_visible_columns", value=max_visible_columns, expected_type=type_hints["max_visible_columns"])
                check_type(argname="argument max_visible_rows", value=max_visible_rows, expected_type=type_hints["max_visible_rows"])
                check_type(argname="argument panel_configuration", value=panel_configuration, expected_type=type_hints["panel_configuration"])
                check_type(argname="argument x_axis", value=x_axis, expected_type=type_hints["x_axis"])
                check_type(argname="argument y_axis", value=y_axis, expected_type=type_hints["y_axis"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if max_visible_columns is not None:
                self._values["max_visible_columns"] = max_visible_columns
            if max_visible_rows is not None:
                self._values["max_visible_rows"] = max_visible_rows
            if panel_configuration is not None:
                self._values["panel_configuration"] = panel_configuration
            if x_axis is not None:
                self._values["x_axis"] = x_axis
            if y_axis is not None:
                self._values["y_axis"] = y_axis

        @builtins.property
        def max_visible_columns(self) -> typing.Optional[jsii.Number]:
            '''Sets the maximum number of visible columns to display in the grid of small multiples panels.

            The default is ``Auto`` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html#cfn-quicksight-analysis-smallmultiplesoptions-maxvisiblecolumns
            '''
            result = self._values.get("max_visible_columns")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def max_visible_rows(self) -> typing.Optional[jsii.Number]:
            '''Sets the maximum number of visible rows to display in the grid of small multiples panels.

            The default value is ``Auto`` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html#cfn-quicksight-analysis-smallmultiplesoptions-maxvisiblerows
            '''
            result = self._values.get("max_visible_rows")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def panel_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PanelConfigurationProperty"]]:
            '''Configures the display options for each small multiples panel.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html#cfn-quicksight-analysis-smallmultiplesoptions-panelconfiguration
            '''
            result = self._values.get("panel_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PanelConfigurationProperty"]], result)

        @builtins.property
        def x_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SmallMultiplesAxisPropertiesProperty"]]:
            '''The properties of a small multiples X axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html#cfn-quicksight-analysis-smallmultiplesoptions-xaxis
            '''
            result = self._values.get("x_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SmallMultiplesAxisPropertiesProperty"]], result)

        @builtins.property
        def y_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SmallMultiplesAxisPropertiesProperty"]]:
            '''The properties of a small multiples Y axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html#cfn-quicksight-analysis-smallmultiplesoptions-yaxis
            '''
            result = self._values.get("y_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SmallMultiplesAxisPropertiesProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SmallMultiplesOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SpacingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bottom": "bottom",
            "left": "left",
            "right": "right",
            "top": "top",
        },
    )
    class SpacingProperty:
        def __init__(
            self,
            *,
            bottom: typing.Optional[builtins.str] = None,
            left: typing.Optional[builtins.str] = None,
            right: typing.Optional[builtins.str] = None,
            top: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of spacing (often a margin or padding).

            :param bottom: Define the bottom spacing.
            :param left: Define the left spacing.
            :param right: Define the right spacing.
            :param top: Define the top spacing.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                spacing_property = quicksight.CfnAnalysis.SpacingProperty(
                    bottom="bottom",
                    left="left",
                    right="right",
                    top="top"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__93a9c0b71a789a9a6753aff39c48b82714e50d6f70f27de79485d7ff5004650f)
                check_type(argname="argument bottom", value=bottom, expected_type=type_hints["bottom"])
                check_type(argname="argument left", value=left, expected_type=type_hints["left"])
                check_type(argname="argument right", value=right, expected_type=type_hints["right"])
                check_type(argname="argument top", value=top, expected_type=type_hints["top"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bottom is not None:
                self._values["bottom"] = bottom
            if left is not None:
                self._values["left"] = left
            if right is not None:
                self._values["right"] = right
            if top is not None:
                self._values["top"] = top

        @builtins.property
        def bottom(self) -> typing.Optional[builtins.str]:
            '''Define the bottom spacing.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html#cfn-quicksight-analysis-spacing-bottom
            '''
            result = self._values.get("bottom")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def left(self) -> typing.Optional[builtins.str]:
            '''Define the left spacing.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html#cfn-quicksight-analysis-spacing-left
            '''
            result = self._values.get("left")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def right(self) -> typing.Optional[builtins.str]:
            '''Define the right spacing.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html#cfn-quicksight-analysis-spacing-right
            '''
            result = self._values.get("right")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def top(self) -> typing.Optional[builtins.str]:
            '''Define the top spacing.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html#cfn-quicksight-analysis-spacing-top
            '''
            result = self._values.get("top")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SpacingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.StringDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class StringDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The default values of the ``StringParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``StringDefaultValues`` . Different defaults displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``DecimalDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                string_default_values_property = quicksight.CfnAnalysis.StringDefaultValuesProperty(
                    dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=["staticValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b359254c6f8fe384458a61511ff8ae0a2c3bd5a0c9eaa89cd1e2cb9ec767be0b)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``StringDefaultValues`` .

            Different defaults displayed according to users, groups, and values mapping.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringdefaultvalues.html#cfn-quicksight-analysis-stringdefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The static values of the ``DecimalDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringdefaultvalues.html#cfn-quicksight-analysis-stringdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.StringFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "numeric_format_configuration": "numericFormatConfiguration",
        },
    )
    class StringFormatConfigurationProperty:
        def __init__(
            self,
            *,
            null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Formatting configuration for string fields.

            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param numeric_format_configuration: The formatting configuration for numeric strings.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                string_format_configuration_property = quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__68653c83770caa5cbfaf25386c1832c4e54fceae84611a32d57ed2743fcd99ec)
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument numeric_format_configuration", value=numeric_format_configuration, expected_type=type_hints["numeric_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if numeric_format_configuration is not None:
                self._values["numeric_format_configuration"] = numeric_format_configuration

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringformatconfiguration.html#cfn-quicksight-analysis-stringformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def numeric_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericFormatConfigurationProperty"]]:
            '''The formatting configuration for numeric strings.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringformatconfiguration.html#cfn-quicksight-analysis-stringformatconfiguration-numericformatconfiguration
            '''
            result = self._values.get("numeric_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.NumericFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.StringParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class StringParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.StringDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.StringValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``String`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: 
            :param value_when_unset: The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                string_parameter_declaration_property = quicksight.CfnAnalysis.StringParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnAnalysis.StringDefaultValuesProperty(
                        dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=["staticValues"]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnAnalysis.StringValueWhenUnsetConfigurationProperty(
                        custom_value="customValue",
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b44eb1c0291cf5dd68a2688e3a71e5e58179106f24cea169041818bae36610f9)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.StringDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.StringDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MappedDataSetParameterProperty"]]]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.StringValueWhenUnsetConfigurationProperty"]]:
            '''The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.StringValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.StringParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class StringParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Sequence[builtins.str],
        ) -> None:
            '''A string parameter.

            :param name: A display name for a string parameter.
            :param values: The values of a string parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                string_parameter_property = quicksight.CfnAnalysis.StringParameterProperty(
                    name="name",
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8ec4069b8eaf48d878fb98ab75830bf982b6f3ede4454ee340b48ddf71f0e7ab)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for a string parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameter.html#cfn-quicksight-analysis-stringparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(self) -> typing.List[builtins.str]:
            '''The values of a string parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameter.html#cfn-quicksight-analysis-stringparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.List[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.StringValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class StringValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[builtins.str] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringvaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                string_value_when_unset_configuration_property = quicksight.CfnAnalysis.StringValueWhenUnsetConfigurationProperty(
                    custom_value="customValue",
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9e595612b4356f9a83c2c2ace559c78cf6e1e88c93f5cfe5e11fb120a37b83cc)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[builtins.str]:
            '''A custom value that's used when the value of a parameter isn't set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringvaluewhenunsetconfiguration.html#cfn-quicksight-analysis-stringvaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringvaluewhenunsetconfiguration.html#cfn-quicksight-analysis-stringvaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.SubtotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "field_level": "fieldLevel",
            "field_level_options": "fieldLevelOptions",
            "metric_header_cell_style": "metricHeaderCellStyle",
            "style_targets": "styleTargets",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
            "value_cell_style": "valueCellStyle",
        },
    )
    class SubtotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            field_level: typing.Optional[builtins.str] = None,
            field_level_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTableFieldSubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            metric_header_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            style_targets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableStyleTargetProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            total_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
            value_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The subtotal options.

            :param custom_label: The custom label string for the subtotal cells.
            :param field_level: The field level (all, custom, last) for the subtotal cells.
            :param field_level_options: The optional configuration of subtotal cells.
            :param metric_header_cell_style: The cell styling options for the subtotals of header cells.
            :param style_targets: The style targets options for subtotals.
            :param total_cell_style: The cell styling options for the subtotal cells.
            :param totals_visibility: The visibility configuration for the subtotal cells.
            :param value_cell_style: The cell styling options for the subtotals of value cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                subtotal_options_property = quicksight.CfnAnalysis.SubtotalOptionsProperty(
                    custom_label="customLabel",
                    field_level="fieldLevel",
                    field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                        field_id="fieldId"
                    )],
                    metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    style_targets=[quicksight.CfnAnalysis.TableStyleTargetProperty(
                        cell_type="cellType"
                    )],
                    total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility",
                    value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e930f8b6f4e75f7f203526058e059dfd426ce57b19160806172e87de2f679a65)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument field_level", value=field_level, expected_type=type_hints["field_level"])
                check_type(argname="argument field_level_options", value=field_level_options, expected_type=type_hints["field_level_options"])
                check_type(argname="argument metric_header_cell_style", value=metric_header_cell_style, expected_type=type_hints["metric_header_cell_style"])
                check_type(argname="argument style_targets", value=style_targets, expected_type=type_hints["style_targets"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
                check_type(argname="argument value_cell_style", value=value_cell_style, expected_type=type_hints["value_cell_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if field_level is not None:
                self._values["field_level"] = field_level
            if field_level_options is not None:
                self._values["field_level_options"] = field_level_options
            if metric_header_cell_style is not None:
                self._values["metric_header_cell_style"] = metric_header_cell_style
            if style_targets is not None:
                self._values["style_targets"] = style_targets
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility
            if value_cell_style is not None:
                self._values["value_cell_style"] = value_cell_style

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the subtotal cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_level(self) -> typing.Optional[builtins.str]:
            '''The field level (all, custom, last) for the subtotal cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-fieldlevel
            '''
            result = self._values.get("field_level")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_level_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableFieldSubtotalOptionsProperty"]]]]:
            '''The optional configuration of subtotal cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-fieldleveloptions
            '''
            result = self._values.get("field_level_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableFieldSubtotalOptionsProperty"]]]], result)

        @builtins.property
        def metric_header_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The cell styling options for the subtotals of header cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-metricheadercellstyle
            '''
            result = self._values.get("metric_header_cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def style_targets(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableStyleTargetProperty"]]]]:
            '''The style targets options for subtotals.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-styletargets
            '''
            result = self._values.get("style_targets")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableStyleTargetProperty"]]]], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The cell styling options for the subtotal cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the subtotal cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The cell styling options for the subtotals of value cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-valuecellstyle
            '''
            result = self._values.get("value_cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SubtotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "values": "values"},
    )
    class TableAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well for the table.

            :param group_by: The group by field well for a pivot table. Values are grouped by group by fields.
            :param values: The values field well for a pivot table. Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_aggregated_field_wells_property = quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7df4c749435be88997e66195988368c40ca30a0927a406feb41c9ba653148ada)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The group by field well for a pivot table.

            Values are grouped by group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableaggregatedfieldwells.html#cfn-quicksight-analysis-tableaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The values field well for a pivot table.

            Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableaggregatedfieldwells.html#cfn-quicksight-analysis-tableaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "style": "style", "thickness": "thickness"},
    )
    class TableBorderOptionsProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            style: typing.Optional[builtins.str] = None,
            thickness: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The border options for a table border.

            :param color: The color of a table border.
            :param style: The style (none, solid) of a table border.
            :param thickness: The thickness of a table border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_border_options_property = quicksight.CfnAnalysis.TableBorderOptionsProperty(
                    color="color",
                    style="style",
                    thickness=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__51a8c2b6852c2d23b50f95cf588e45c481a2eba16e9778d2f5697f3d8862df0e)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
                check_type(argname="argument thickness", value=thickness, expected_type=type_hints["thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if style is not None:
                self._values["style"] = style
            if thickness is not None:
                self._values["thickness"] = thickness

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color of a table border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableborderoptions.html#cfn-quicksight-analysis-tableborderoptions-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style(self) -> typing.Optional[builtins.str]:
            '''The style (none, solid) of a table border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableborderoptions.html#cfn-quicksight-analysis-tableborderoptions-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def thickness(self) -> typing.Optional[jsii.Number]:
            '''The thickness of a table border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableborderoptions.html#cfn-quicksight-analysis-tableborderoptions-thickness
            '''
            result = self._values.get("thickness")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableCellConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "text_format": "textFormat"},
    )
    class TableCellConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            text_format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TextConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cell conditional formatting option for a table.

            :param field_id: The field ID of the cell for conditional formatting.
            :param text_format: The text format of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_cell_conditional_formatting_property = quicksight.CfnAnalysis.TableCellConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a9139deb319cc7938945526cf487e4625cb693d034ef0c8dc39f3bf43dc32057)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument text_format", value=text_format, expected_type=type_hints["text_format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if text_format is not None:
                self._values["text_format"] = text_format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellconditionalformatting.html#cfn-quicksight-analysis-tablecellconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def text_format(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TextConditionalFormatProperty"]]:
            '''The text format of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellconditionalformatting.html#cfn-quicksight-analysis-tablecellconditionalformatting-textformat
            '''
            result = self._values.get("text_format")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TextConditionalFormatProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "table_cell_image_scaling_configuration": "tableCellImageScalingConfiguration",
        },
    )
    class TableCellImageSizingConfigurationProperty:
        def __init__(
            self,
            *,
            table_cell_image_scaling_configuration: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The sizing options for the table image configuration.

            :param table_cell_image_scaling_configuration: The cell scaling configuration of the sizing options for the table image configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellimagesizingconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_cell_image_sizing_configuration_property = quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5b3e711cb7976d7cd94bddd7931f5b7a74e1a8c6a200e960995c9f19b3af8dcc)
                check_type(argname="argument table_cell_image_scaling_configuration", value=table_cell_image_scaling_configuration, expected_type=type_hints["table_cell_image_scaling_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if table_cell_image_scaling_configuration is not None:
                self._values["table_cell_image_scaling_configuration"] = table_cell_image_scaling_configuration

        @builtins.property
        def table_cell_image_scaling_configuration(
            self,
        ) -> typing.Optional[builtins.str]:
            '''The cell scaling configuration of the sizing options for the table image configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellimagesizingconfiguration.html#cfn-quicksight-analysis-tablecellimagesizingconfiguration-tablecellimagescalingconfiguration
            '''
            result = self._values.get("table_cell_image_scaling_configuration")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellImageSizingConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableCellStyleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "border": "border",
            "font_configuration": "fontConfiguration",
            "height": "height",
            "horizontal_text_alignment": "horizontalTextAlignment",
            "text_wrap": "textWrap",
            "vertical_text_alignment": "verticalTextAlignment",
            "visibility": "visibility",
        },
    )
    class TableCellStyleProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[builtins.str] = None,
            border: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GlobalTableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            height: typing.Optional[jsii.Number] = None,
            horizontal_text_alignment: typing.Optional[builtins.str] = None,
            text_wrap: typing.Optional[builtins.str] = None,
            vertical_text_alignment: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The table cell style for a cell in pivot table or table visual.

            :param background_color: The background color for the table cells.
            :param border: The borders for the table cells.
            :param font_configuration: The font configuration of the table cells.
            :param height: The height color for the table cells.
            :param horizontal_text_alignment: The horizontal text alignment (left, center, right, auto) for the table cells.
            :param text_wrap: The text wrap (none, wrap) for the table cells.
            :param vertical_text_alignment: The vertical text alignment (top, middle, bottom) for the table cells.
            :param visibility: The visibility of the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_cell_style_property = quicksight.CfnAnalysis.TableCellStyleProperty(
                    background_color="backgroundColor",
                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        )
                    ),
                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    height=123,
                    horizontal_text_alignment="horizontalTextAlignment",
                    text_wrap="textWrap",
                    vertical_text_alignment="verticalTextAlignment",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bdcbd7af1c2204ce271393208454e9f0e2964ff896f50f21f6f3583b1f8d1556)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument border", value=border, expected_type=type_hints["border"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument horizontal_text_alignment", value=horizontal_text_alignment, expected_type=type_hints["horizontal_text_alignment"])
                check_type(argname="argument text_wrap", value=text_wrap, expected_type=type_hints["text_wrap"])
                check_type(argname="argument vertical_text_alignment", value=vertical_text_alignment, expected_type=type_hints["vertical_text_alignment"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if border is not None:
                self._values["border"] = border
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if height is not None:
                self._values["height"] = height
            if horizontal_text_alignment is not None:
                self._values["horizontal_text_alignment"] = horizontal_text_alignment
            if text_wrap is not None:
                self._values["text_wrap"] = text_wrap
            if vertical_text_alignment is not None:
                self._values["vertical_text_alignment"] = vertical_text_alignment
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def background_color(self) -> typing.Optional[builtins.str]:
            '''The background color for the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GlobalTableBorderOptionsProperty"]]:
            '''The borders for the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-border
            '''
            result = self._values.get("border")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GlobalTableBorderOptionsProperty"]], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"]]:
            '''The font configuration of the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"]], result)

        @builtins.property
        def height(self) -> typing.Optional[jsii.Number]:
            '''The height color for the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def horizontal_text_alignment(self) -> typing.Optional[builtins.str]:
            '''The horizontal text alignment (left, center, right, auto) for the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-horizontaltextalignment
            '''
            result = self._values.get("horizontal_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def text_wrap(self) -> typing.Optional[builtins.str]:
            '''The text wrap (none, wrap) for the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-textwrap
            '''
            result = self._values.get("text_wrap")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_text_alignment(self) -> typing.Optional[builtins.str]:
            '''The vertical text alignment (top, middle, bottom) for the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-verticaltextalignment
            '''
            result = self._values.get("vertical_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"cell": "cell", "row": "row"},
    )
    class TableConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            cell: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableCellConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableRowConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :param cell: The cell conditional formatting option for a table.
            :param row: The row conditional formatting option for a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_conditional_formatting_option_property = quicksight.CfnAnalysis.TableConditionalFormattingOptionProperty(
                    cell=quicksight.CfnAnalysis.TableCellConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    ),
                    row=quicksight.CfnAnalysis.TableRowConditionalFormattingProperty(
                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9cdf869d1249d677d97a668a3b96be6e28a187fb43ef3eff78363fc4a3537c69)
                check_type(argname="argument cell", value=cell, expected_type=type_hints["cell"])
                check_type(argname="argument row", value=row, expected_type=type_hints["row"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell is not None:
                self._values["cell"] = cell
            if row is not None:
                self._values["row"] = row

        @builtins.property
        def cell(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellConditionalFormattingProperty"]]:
            '''The cell conditional formatting option for a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformattingoption.html#cfn-quicksight-analysis-tableconditionalformattingoption-cell
            '''
            result = self._values.get("cell")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellConditionalFormattingProperty"]], result)

        @builtins.property
        def row(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableRowConditionalFormattingProperty"]]:
            '''The row conditional formatting option for a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformattingoption.html#cfn-quicksight-analysis-tableconditionalformattingoption-row
            '''
            result = self._values.get("row")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableRowConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class TableConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :param conditional_formatting_options: Conditional formatting options for a ``PivotTableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_conditional_formatting_property = quicksight.CfnAnalysis.TableConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnAnalysis.TableConditionalFormattingOptionProperty(
                        cell=quicksight.CfnAnalysis.TableCellConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        ),
                        row=quicksight.CfnAnalysis.TableRowConditionalFormattingProperty(
                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4fccc271167ce71a03385d6677025882f8b2d3b5c01722d7d6e82fcb541e4f15)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableConditionalFormattingOptionProperty"]]]]:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformatting.html#cfn-quicksight-analysis-tableconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_options": "fieldOptions",
            "field_wells": "fieldWells",
            "paginated_report_options": "paginatedReportOptions",
            "sort_configuration": "sortConfiguration",
            "table_inline_visualizations": "tableInlineVisualizations",
            "table_options": "tableOptions",
            "total_options": "totalOptions",
        },
    )
    class TableConfigurationProperty:
        def __init__(
            self,
            *,
            field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableFieldOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paginated_report_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TablePaginatedReportOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_inline_visualizations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableInlineVisualizationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            table_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``TableVisual`` .

            :param field_options: The field options for a table visual.
            :param field_wells: The field wells of the visual.
            :param paginated_report_options: The paginated report options for a table visual.
            :param sort_configuration: The sort configuration for a ``TableVisual`` .
            :param table_inline_visualizations: A collection of inline visualizations to display within a chart.
            :param table_options: The table options for a table visual.
            :param total_options: The total options for a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d479d7b59ced444940f30c08826632cf29685d2eabe615aa98c6e35d7f7df7c5)
                check_type(argname="argument field_options", value=field_options, expected_type=type_hints["field_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument paginated_report_options", value=paginated_report_options, expected_type=type_hints["paginated_report_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument table_inline_visualizations", value=table_inline_visualizations, expected_type=type_hints["table_inline_visualizations"])
                check_type(argname="argument table_options", value=table_options, expected_type=type_hints["table_options"])
                check_type(argname="argument total_options", value=total_options, expected_type=type_hints["total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_options is not None:
                self._values["field_options"] = field_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if paginated_report_options is not None:
                self._values["paginated_report_options"] = paginated_report_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if table_inline_visualizations is not None:
                self._values["table_inline_visualizations"] = table_inline_visualizations
            if table_options is not None:
                self._values["table_options"] = table_options
            if total_options is not None:
                self._values["total_options"] = total_options

        @builtins.property
        def field_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableFieldOptionsProperty"]]:
            '''The field options for a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-fieldoptions
            '''
            result = self._values.get("field_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableFieldOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableFieldWellsProperty"]], result)

        @builtins.property
        def paginated_report_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TablePaginatedReportOptionsProperty"]]:
            '''The paginated report options for a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-paginatedreportoptions
            '''
            result = self._values.get("paginated_report_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TablePaginatedReportOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableSortConfigurationProperty"]]:
            '''The sort configuration for a ``TableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableSortConfigurationProperty"]], result)

        @builtins.property
        def table_inline_visualizations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableInlineVisualizationProperty"]]]]:
            '''A collection of inline visualizations to display within a chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-tableinlinevisualizations
            '''
            result = self._values.get("table_inline_visualizations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableInlineVisualizationProperty"]]]], result)

        @builtins.property
        def table_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableOptionsProperty"]]:
            '''The table options for a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-tableoptions
            '''
            result = self._values.get("table_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableOptionsProperty"]], result)

        @builtins.property
        def total_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TotalOptionsProperty"]]:
            '''The total options for a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-totaloptions
            '''
            result = self._values.get("total_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TotalOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableFieldCustomIconContentProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon"},
    )
    class TableFieldCustomIconContentProperty:
        def __init__(self, *, icon: typing.Optional[builtins.str] = None) -> None:
            '''The custom icon content for the table link content configuration.

            :param icon: The icon set type (link) of the custom icon content for table URL link content.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomiconcontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_custom_icon_content_property = quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                    icon="icon"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d772be5cbd5e3987bd745c9b0f10ee81bb1f29b601e445782fc139f81b5f388c)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon

        @builtins.property
        def icon(self) -> typing.Optional[builtins.str]:
            '''The icon set type (link) of the custom icon content for table URL link content.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomiconcontent.html#cfn-quicksight-analysis-tablefieldcustomiconcontent-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldCustomIconContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableFieldCustomTextContentProperty",
        jsii_struct_bases=[],
        name_mapping={"font_configuration": "fontConfiguration", "value": "value"},
    )
    class TableFieldCustomTextContentProperty:
        def __init__(
            self,
            *,
            font_configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The custom text content (value, font configuration) for the table link content configuration.

            :param font_configuration: The font configuration of the custom text content for the table URL link content.
            :param value: The string value of the custom text content for the table URL link content.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomtextcontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_custom_text_content_property = quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                
                    # the properties below are optional
                    value="value"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a3db2acd9e14cb038b557d6e50e2d21b975a89f5a46c9c38448db432d3a57287)
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "font_configuration": font_configuration,
            }
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"]:
            '''The font configuration of the custom text content for the table URL link content.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomtextcontent.html#cfn-quicksight-analysis-tablefieldcustomtextcontent-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            assert result is not None, "Required property 'font_configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FontConfigurationProperty"], result)

        @builtins.property
        def value(self) -> typing.Optional[builtins.str]:
            '''The string value of the custom text content for the table URL link content.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomtextcontent.html#cfn-quicksight-analysis-tablefieldcustomtextcontent-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldCustomTextContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableFieldImageConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"sizing_options": "sizingOptions"},
    )
    class TableFieldImageConfigurationProperty:
        def __init__(
            self,
            *,
            sizing_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableCellImageSizingConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The image configuration of a table field URL.

            :param sizing_options: The sizing options for the table image configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldimageconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_image_configuration_property = quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                    sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e3ef444ac27c5feabed3f7957db9f333898dfc2b6548f21156f6d020aaf37aad)
                check_type(argname="argument sizing_options", value=sizing_options, expected_type=type_hints["sizing_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sizing_options is not None:
                self._values["sizing_options"] = sizing_options

        @builtins.property
        def sizing_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellImageSizingConfigurationProperty"]]:
            '''The sizing options for the table image configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldimageconfiguration.html#cfn-quicksight-analysis-tablefieldimageconfiguration-sizingoptions
            '''
            result = self._values.get("sizing_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellImageSizingConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldImageConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"content": "content", "target": "target"},
    )
    class TableFieldLinkConfigurationProperty:
        def __init__(
            self,
            *,
            content: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableFieldLinkContentConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            target: builtins.str,
        ) -> None:
            '''The link configuration of a table field URL.

            :param content: The URL content (text, icon) for the table link configuration.
            :param target: The URL target (new tab, new window, same tab) for the table link configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_link_configuration_property = quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                    content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                        custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                            icon="icon"
                        ),
                        custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                
                            # the properties below are optional
                            value="value"
                        )
                    ),
                    target="target"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__be14eae3127037193252ac11a55fa9913ef8bc09d02cfe83885f57966dda16a4)
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
                check_type(argname="argument target", value=target, expected_type=type_hints["target"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "content": content,
                "target": target,
            }

        @builtins.property
        def content(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableFieldLinkContentConfigurationProperty"]:
            '''The URL content (text, icon) for the table link configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkconfiguration.html#cfn-quicksight-analysis-tablefieldlinkconfiguration-content
            '''
            result = self._values.get("content")
            assert result is not None, "Required property 'content' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableFieldLinkContentConfigurationProperty"], result)

        @builtins.property
        def target(self) -> builtins.str:
            '''The URL target (new tab, new window, same tab) for the table link configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkconfiguration.html#cfn-quicksight-analysis-tablefieldlinkconfiguration-target
            '''
            result = self._values.get("target")
            assert result is not None, "Required property 'target' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldLinkConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_icon_content": "customIconContent",
            "custom_text_content": "customTextContent",
        },
    )
    class TableFieldLinkContentConfigurationProperty:
        def __init__(
            self,
            *,
            custom_icon_content: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableFieldCustomIconContentProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_text_content: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableFieldCustomTextContentProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The URL content (text, icon) for the table link configuration.

            :param custom_icon_content: The custom icon content for the table link content configuration.
            :param custom_text_content: The custom text content (value, font configuration) for the table link content configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkcontentconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_link_content_configuration_property = quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                    custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                        icon="icon"
                    ),
                    custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                
                        # the properties below are optional
                        value="value"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5f9166017a92518eeedadfbe16d02a0d969909159406cc6155ffce3aec828478)
                check_type(argname="argument custom_icon_content", value=custom_icon_content, expected_type=type_hints["custom_icon_content"])
                check_type(argname="argument custom_text_content", value=custom_text_content, expected_type=type_hints["custom_text_content"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_icon_content is not None:
                self._values["custom_icon_content"] = custom_icon_content
            if custom_text_content is not None:
                self._values["custom_text_content"] = custom_text_content

        @builtins.property
        def custom_icon_content(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableFieldCustomIconContentProperty"]]:
            '''The custom icon content for the table link content configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkcontentconfiguration.html#cfn-quicksight-analysis-tablefieldlinkcontentconfiguration-customiconcontent
            '''
            result = self._values.get("custom_icon_content")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableFieldCustomIconContentProperty"]], result)

        @builtins.property
        def custom_text_content(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableFieldCustomTextContentProperty"]]:
            '''The custom text content (value, font configuration) for the table link content configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkcontentconfiguration.html#cfn-quicksight-analysis-tablefieldlinkcontentconfiguration-customtextcontent
            '''
            result = self._values.get("custom_text_content")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableFieldCustomTextContentProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldLinkContentConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableFieldOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "custom_label": "customLabel",
            "url_styling": "urlStyling",
            "visibility": "visibility",
            "width": "width",
        },
    )
    class TableFieldOptionProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            custom_label: typing.Optional[builtins.str] = None,
            url_styling: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableFieldURLConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for a table field.

            :param field_id: The field ID for a table field.
            :param custom_label: The custom label for a table field.
            :param url_styling: The URL configuration for a table field.
            :param visibility: The visibility of a table field.
            :param width: The width for a table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_option_property = quicksight.CfnAnalysis.TableFieldOptionProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    custom_label="customLabel",
                    url_styling=quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                        image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                            sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                                table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                            )
                        ),
                        link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                            content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                                custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                    icon="icon"
                                ),
                                custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    value="value"
                                )
                            ),
                            target="target"
                        )
                    ),
                    visibility="visibility",
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3e2fbb1b2e487ba844b115dc8c6c8e9e7d13396a1c9163a272f6cc5237232a28)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument url_styling", value=url_styling, expected_type=type_hints["url_styling"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if url_styling is not None:
                self._values["url_styling"] = url_styling
            if visibility is not None:
                self._values["visibility"] = visibility
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for a table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label for a table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def url_styling(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableFieldURLConfigurationProperty"]]:
            '''The URL configuration for a table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-urlstyling
            '''
            result = self._values.get("url_styling")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableFieldURLConfigurationProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of a table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width for a table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableFieldOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "order": "order",
            "pinned_field_options": "pinnedFieldOptions",
            "selected_field_options": "selectedFieldOptions",
        },
    )
    class TableFieldOptionsProperty:
        def __init__(
            self,
            *,
            order: typing.Optional[typing.Sequence[builtins.str]] = None,
            pinned_field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TablePinnedFieldOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selected_field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableFieldOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field options of a table visual.

            :param order: The order of the field IDs that are configured as field options for a table visual.
            :param pinned_field_options: The settings for the pinned columns of a table visual.
            :param selected_field_options: The field options to be configured to a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_options_property = quicksight.CfnAnalysis.TableFieldOptionsProperty(
                    order=["order"],
                    pinned_field_options=quicksight.CfnAnalysis.TablePinnedFieldOptionsProperty(
                        pinned_left_fields=["pinnedLeftFields"]
                    ),
                    selected_field_options=[quicksight.CfnAnalysis.TableFieldOptionProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        custom_label="customLabel",
                        url_styling=quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                            image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                                sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                )
                            ),
                            link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                                content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                                    custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                        icon="icon"
                                    ),
                                    custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        value="value"
                                    )
                                ),
                                target="target"
                            )
                        ),
                        visibility="visibility",
                        width="width"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4b1581ac01a2a6068fe7519e9017b2a7cf534ecaa479c68cb2a0e30864b41438)
                check_type(argname="argument order", value=order, expected_type=type_hints["order"])
                check_type(argname="argument pinned_field_options", value=pinned_field_options, expected_type=type_hints["pinned_field_options"])
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if order is not None:
                self._values["order"] = order
            if pinned_field_options is not None:
                self._values["pinned_field_options"] = pinned_field_options
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options

        @builtins.property
        def order(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The order of the field IDs that are configured as field options for a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoptions.html#cfn-quicksight-analysis-tablefieldoptions-order
            '''
            result = self._values.get("order")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def pinned_field_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TablePinnedFieldOptionsProperty"]]:
            '''The settings for the pinned columns of a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoptions.html#cfn-quicksight-analysis-tablefieldoptions-pinnedfieldoptions
            '''
            result = self._values.get("pinned_field_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TablePinnedFieldOptionsProperty"]], result)

        @builtins.property
        def selected_field_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableFieldOptionProperty"]]]]:
            '''The field options to be configured to a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoptions.html#cfn-quicksight-analysis-tablefieldoptions-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableFieldOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableFieldURLConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "image_configuration": "imageConfiguration",
            "link_configuration": "linkConfiguration",
        },
    )
    class TableFieldURLConfigurationProperty:
        def __init__(
            self,
            *,
            image_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableFieldImageConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            link_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableFieldLinkConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The URL configuration for a table field.

            :param image_configuration: The image configuration of a table field URL.
            :param link_configuration: The link configuration of a table field URL.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldurlconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_uRLConfiguration_property = quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                    image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                        sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                            table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                        )
                    ),
                    link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                        content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                            custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                icon="icon"
                            ),
                            custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                
                                # the properties below are optional
                                value="value"
                            )
                        ),
                        target="target"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a3fdea35643ddf9297e747860efc7c7229baa86dfc971776257b482e1f652762)
                check_type(argname="argument image_configuration", value=image_configuration, expected_type=type_hints["image_configuration"])
                check_type(argname="argument link_configuration", value=link_configuration, expected_type=type_hints["link_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if image_configuration is not None:
                self._values["image_configuration"] = image_configuration
            if link_configuration is not None:
                self._values["link_configuration"] = link_configuration

        @builtins.property
        def image_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableFieldImageConfigurationProperty"]]:
            '''The image configuration of a table field URL.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldurlconfiguration.html#cfn-quicksight-analysis-tablefieldurlconfiguration-imageconfiguration
            '''
            result = self._values.get("image_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableFieldImageConfigurationProperty"]], result)

        @builtins.property
        def link_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableFieldLinkConfigurationProperty"]]:
            '''The link configuration of a table field URL.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldurlconfiguration.html#cfn-quicksight-analysis-tablefieldurlconfiguration-linkconfiguration
            '''
            result = self._values.get("link_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableFieldLinkConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldURLConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "table_aggregated_field_wells": "tableAggregatedFieldWells",
            "table_unaggregated_field_wells": "tableUnaggregatedFieldWells",
        },
    )
    class TableFieldWellsProperty:
        def __init__(
            self,
            *,
            table_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_unaggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableUnaggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells for a table visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param table_aggregated_field_wells: The aggregated field well for the table.
            :param table_unaggregated_field_wells: The unaggregated field well for the table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fd14fef22d98862a207b478c3118cb9f6030eb2fa414716578f4b629aab25e71)
                check_type(argname="argument table_aggregated_field_wells", value=table_aggregated_field_wells, expected_type=type_hints["table_aggregated_field_wells"])
                check_type(argname="argument table_unaggregated_field_wells", value=table_unaggregated_field_wells, expected_type=type_hints["table_unaggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if table_aggregated_field_wells is not None:
                self._values["table_aggregated_field_wells"] = table_aggregated_field_wells
            if table_unaggregated_field_wells is not None:
                self._values["table_unaggregated_field_wells"] = table_unaggregated_field_wells

        @builtins.property
        def table_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableAggregatedFieldWellsProperty"]]:
            '''The aggregated field well for the table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldwells.html#cfn-quicksight-analysis-tablefieldwells-tableaggregatedfieldwells
            '''
            result = self._values.get("table_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableAggregatedFieldWellsProperty"]], result)

        @builtins.property
        def table_unaggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableUnaggregatedFieldWellsProperty"]]:
            '''The unaggregated field well for the table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldwells.html#cfn-quicksight-analysis-tablefieldwells-tableunaggregatedfieldwells
            '''
            result = self._values.get("table_unaggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableUnaggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableInlineVisualizationProperty",
        jsii_struct_bases=[],
        name_mapping={"data_bars": "dataBars"},
    )
    class TableInlineVisualizationProperty:
        def __init__(
            self,
            *,
            data_bars: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataBarsOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The inline visualization of a specific type to display within a chart.

            :param data_bars: The configuration of the inline visualization of the data bars within a chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableinlinevisualization.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_inline_visualization_property = quicksight.CfnAnalysis.TableInlineVisualizationProperty(
                    data_bars=quicksight.CfnAnalysis.DataBarsOptionsProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        negative_color="negativeColor",
                        positive_color="positiveColor"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__810e05c0a905353900a83e8ee198d496eeff6cbbf388cff25e8ac22b0c3e6541)
                check_type(argname="argument data_bars", value=data_bars, expected_type=type_hints["data_bars"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_bars is not None:
                self._values["data_bars"] = data_bars

        @builtins.property
        def data_bars(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataBarsOptionsProperty"]]:
            '''The configuration of the inline visualization of the data bars within a chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableinlinevisualization.html#cfn-quicksight-analysis-tableinlinevisualization-databars
            '''
            result = self._values.get("data_bars")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataBarsOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableInlineVisualizationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cell_style": "cellStyle",
            "header_style": "headerStyle",
            "orientation": "orientation",
            "row_alternate_color_options": "rowAlternateColorOptions",
        },
    )
    class TableOptionsProperty:
        def __init__(
            self,
            *,
            cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            header_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            orientation: typing.Optional[builtins.str] = None,
            row_alternate_color_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.RowAlternateColorOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The table options for a table visual.

            :param cell_style: The table cell style of table cells.
            :param header_style: The table cell style of a table header.
            :param orientation: The orientation (vertical, horizontal) for a table.
            :param row_alternate_color_options: The row alternate color options (widget status, row alternate colors) for a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_options_property = quicksight.CfnAnalysis.TableOptionsProperty(
                    cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    orientation="orientation",
                    row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                        row_alternate_colors=["rowAlternateColors"],
                        status="status",
                        use_primary_background_color="usePrimaryBackgroundColor"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__10fa49cf346714935975a4b77d4bf031a5df3e29edbc8792455f5863265ead89)
                check_type(argname="argument cell_style", value=cell_style, expected_type=type_hints["cell_style"])
                check_type(argname="argument header_style", value=header_style, expected_type=type_hints["header_style"])
                check_type(argname="argument orientation", value=orientation, expected_type=type_hints["orientation"])
                check_type(argname="argument row_alternate_color_options", value=row_alternate_color_options, expected_type=type_hints["row_alternate_color_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell_style is not None:
                self._values["cell_style"] = cell_style
            if header_style is not None:
                self._values["header_style"] = header_style
            if orientation is not None:
                self._values["orientation"] = orientation
            if row_alternate_color_options is not None:
                self._values["row_alternate_color_options"] = row_alternate_color_options

        @builtins.property
        def cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The table cell style of table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html#cfn-quicksight-analysis-tableoptions-cellstyle
            '''
            result = self._values.get("cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def header_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The table cell style of a table header.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html#cfn-quicksight-analysis-tableoptions-headerstyle
            '''
            result = self._values.get("header_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def orientation(self) -> typing.Optional[builtins.str]:
            '''The orientation (vertical, horizontal) for a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html#cfn-quicksight-analysis-tableoptions-orientation
            '''
            result = self._values.get("orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def row_alternate_color_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RowAlternateColorOptionsProperty"]]:
            '''The row alternate color options (widget status, row alternate colors) for a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html#cfn-quicksight-analysis-tableoptions-rowalternatecoloroptions
            '''
            result = self._values.get("row_alternate_color_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RowAlternateColorOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TablePaginatedReportOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "overflow_column_header_visibility": "overflowColumnHeaderVisibility",
            "vertical_overflow_visibility": "verticalOverflowVisibility",
        },
    )
    class TablePaginatedReportOptionsProperty:
        def __init__(
            self,
            *,
            overflow_column_header_visibility: typing.Optional[builtins.str] = None,
            vertical_overflow_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The paginated report options for a table visual.

            :param overflow_column_header_visibility: The visibility of repeating header rows on each page.
            :param vertical_overflow_visibility: The visibility of printing table overflow across pages.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablepaginatedreportoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_paginated_report_options_property = quicksight.CfnAnalysis.TablePaginatedReportOptionsProperty(
                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                    vertical_overflow_visibility="verticalOverflowVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ea5c6548516cd73443b2c8ca738d90c5d45f6c6d183d60f11d28d228b404cf20)
                check_type(argname="argument overflow_column_header_visibility", value=overflow_column_header_visibility, expected_type=type_hints["overflow_column_header_visibility"])
                check_type(argname="argument vertical_overflow_visibility", value=vertical_overflow_visibility, expected_type=type_hints["vertical_overflow_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if overflow_column_header_visibility is not None:
                self._values["overflow_column_header_visibility"] = overflow_column_header_visibility
            if vertical_overflow_visibility is not None:
                self._values["vertical_overflow_visibility"] = vertical_overflow_visibility

        @builtins.property
        def overflow_column_header_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of repeating header rows on each page.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablepaginatedreportoptions.html#cfn-quicksight-analysis-tablepaginatedreportoptions-overflowcolumnheadervisibility
            '''
            result = self._values.get("overflow_column_header_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_overflow_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of printing table overflow across pages.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablepaginatedreportoptions.html#cfn-quicksight-analysis-tablepaginatedreportoptions-verticaloverflowvisibility
            '''
            result = self._values.get("vertical_overflow_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TablePaginatedReportOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TablePinnedFieldOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"pinned_left_fields": "pinnedLeftFields"},
    )
    class TablePinnedFieldOptionsProperty:
        def __init__(
            self,
            *,
            pinned_left_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The settings for the pinned columns of a table visual.

            :param pinned_left_fields: A list of columns to be pinned to the left of a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablepinnedfieldoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_pinned_field_options_property = quicksight.CfnAnalysis.TablePinnedFieldOptionsProperty(
                    pinned_left_fields=["pinnedLeftFields"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__77c1903cf87e0cd86e49cbaf852606e51b0ebc014ef8e0eec7540fbab943946e)
                check_type(argname="argument pinned_left_fields", value=pinned_left_fields, expected_type=type_hints["pinned_left_fields"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pinned_left_fields is not None:
                self._values["pinned_left_fields"] = pinned_left_fields

        @builtins.property
        def pinned_left_fields(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of columns to be pinned to the left of a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablepinnedfieldoptions.html#cfn-quicksight-analysis-tablepinnedfieldoptions-pinnedleftfields
            '''
            result = self._values.get("pinned_left_fields")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TablePinnedFieldOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableRowConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "text_color": "textColor",
        },
    )
    class TableRowConditionalFormattingProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting of a table row.

            :param background_color: The conditional formatting color (solid, gradient) of the background for a table row.
            :param text_color: The conditional formatting color (solid, gradient) of the text for a table row.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablerowconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_row_conditional_formatting_property = quicksight.CfnAnalysis.TableRowConditionalFormattingProperty(
                    background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    ),
                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7158087ab33dc66b9914fb7e235c4a5085d753991dc219088d154df66fa5a712)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def background_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting color (solid, gradient) of the background for a table row.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablerowconditionalformatting.html#cfn-quicksight-analysis-tablerowconditionalformatting-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting color (solid, gradient) of the text for a table row.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablerowconditionalformatting.html#cfn-quicksight-analysis-tablerowconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableRowConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableSideBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bottom": "bottom",
            "inner_horizontal": "innerHorizontal",
            "inner_vertical": "innerVertical",
            "left": "left",
            "right": "right",
            "top": "top",
        },
    )
    class TableSideBorderOptionsProperty:
        def __init__(
            self,
            *,
            bottom: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            inner_horizontal: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            inner_vertical: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            left: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            right: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The side border options for a table.

            :param bottom: The table border options of the bottom border.
            :param inner_horizontal: The table border options of the inner horizontal border.
            :param inner_vertical: The table border options of the inner vertical border.
            :param left: The table border options of the left border.
            :param right: The table border options of the right border.
            :param top: The table border options of the top border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_side_border_options_property = quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f92106246e4f4db8102d1f6a7103f1060c88395281fc50e23c4618493e511906)
                check_type(argname="argument bottom", value=bottom, expected_type=type_hints["bottom"])
                check_type(argname="argument inner_horizontal", value=inner_horizontal, expected_type=type_hints["inner_horizontal"])
                check_type(argname="argument inner_vertical", value=inner_vertical, expected_type=type_hints["inner_vertical"])
                check_type(argname="argument left", value=left, expected_type=type_hints["left"])
                check_type(argname="argument right", value=right, expected_type=type_hints["right"])
                check_type(argname="argument top", value=top, expected_type=type_hints["top"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bottom is not None:
                self._values["bottom"] = bottom
            if inner_horizontal is not None:
                self._values["inner_horizontal"] = inner_horizontal
            if inner_vertical is not None:
                self._values["inner_vertical"] = inner_vertical
            if left is not None:
                self._values["left"] = left
            if right is not None:
                self._values["right"] = right
            if top is not None:
                self._values["top"] = top

        @builtins.property
        def bottom(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableBorderOptionsProperty"]]:
            '''The table border options of the bottom border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-bottom
            '''
            result = self._values.get("bottom")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableBorderOptionsProperty"]], result)

        @builtins.property
        def inner_horizontal(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableBorderOptionsProperty"]]:
            '''The table border options of the inner horizontal border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-innerhorizontal
            '''
            result = self._values.get("inner_horizontal")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableBorderOptionsProperty"]], result)

        @builtins.property
        def inner_vertical(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableBorderOptionsProperty"]]:
            '''The table border options of the inner vertical border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-innervertical
            '''
            result = self._values.get("inner_vertical")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableBorderOptionsProperty"]], result)

        @builtins.property
        def left(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableBorderOptionsProperty"]]:
            '''The table border options of the left border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-left
            '''
            result = self._values.get("left")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableBorderOptionsProperty"]], result)

        @builtins.property
        def right(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableBorderOptionsProperty"]]:
            '''The table border options of the right border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-right
            '''
            result = self._values.get("right")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableBorderOptionsProperty"]], result)

        @builtins.property
        def top(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableBorderOptionsProperty"]]:
            '''The table border options of the top border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-top
            '''
            result = self._values.get("top")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableBorderOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableSideBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pagination_configuration": "paginationConfiguration",
            "row_sort": "rowSort",
        },
    )
    class TableSortConfigurationProperty:
        def __init__(
            self,
            *,
            pagination_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PaginationConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration for a ``TableVisual`` .

            :param pagination_configuration: The pagination configuration (page size, page number) for the table.
            :param row_sort: The field sort options for rows in the table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_sort_configuration_property = quicksight.CfnAnalysis.TableSortConfigurationProperty(
                    pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                        page_number=123,
                        page_size=123
                    ),
                    row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6d0cde3a0e979aba1c778ad7af547de4a799a7f027a559f18325130fe479b6b1)
                check_type(argname="argument pagination_configuration", value=pagination_configuration, expected_type=type_hints["pagination_configuration"])
                check_type(argname="argument row_sort", value=row_sort, expected_type=type_hints["row_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pagination_configuration is not None:
                self._values["pagination_configuration"] = pagination_configuration
            if row_sort is not None:
                self._values["row_sort"] = row_sort

        @builtins.property
        def pagination_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PaginationConfigurationProperty"]]:
            '''The pagination configuration (page size, page number) for the table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesortconfiguration.html#cfn-quicksight-analysis-tablesortconfiguration-paginationconfiguration
            '''
            result = self._values.get("pagination_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PaginationConfigurationProperty"]], result)

        @builtins.property
        def row_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The field sort options for rows in the table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesortconfiguration.html#cfn-quicksight-analysis-tablesortconfiguration-rowsort
            '''
            result = self._values.get("row_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableStyleTargetProperty",
        jsii_struct_bases=[],
        name_mapping={"cell_type": "cellType"},
    )
    class TableStyleTargetProperty:
        def __init__(self, *, cell_type: builtins.str) -> None:
            '''The table style target.

            :param cell_type: The cell type of the table style target.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablestyletarget.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_style_target_property = quicksight.CfnAnalysis.TableStyleTargetProperty(
                    cell_type="cellType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fe62e22e099a5ed5a887a278cdd3fffd1bdb6a32c6ef3727c7eb6d076dd2e880)
                check_type(argname="argument cell_type", value=cell_type, expected_type=type_hints["cell_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "cell_type": cell_type,
            }

        @builtins.property
        def cell_type(self) -> builtins.str:
            '''The cell type of the table style target.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablestyletarget.html#cfn-quicksight-analysis-tablestyletarget-celltype
            '''
            result = self._values.get("cell_type")
            assert result is not None, "Required property 'cell_type' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableStyleTargetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class TableUnaggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.UnaggregatedFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The unaggregated field well for the table.

            :param values: The values field well for a pivot table. Values are unaggregated for an unaggregated table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableunaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_unaggregated_field_wells_property = quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty(
                    values=[quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                            date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__01dccc33f12dd41827ae118d6858cf5b812b7596731ca5d9b1f4ec62401d1ec8)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.UnaggregatedFieldProperty"]]]]:
            '''The values field well for a pivot table.

            Values are unaggregated for an unaggregated table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableunaggregatedfieldwells.html#cfn-quicksight-analysis-tableunaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.UnaggregatedFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableUnaggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TableVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class TableVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A table visual.

            For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param conditional_formatting: The conditional formatting for a ``PivotTableVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8b1d32cf007ed6361655217afb26978623793bdc6386c3378e333494bebead8f)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableConfigurationProperty"]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableConditionalFormattingProperty"]]:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "info_icon_label_options": "infoIconLabelOptions",
            "placeholder_options": "placeholderOptions",
            "title_options": "titleOptions",
        },
    )
    class TextAreaControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SheetControlInfoIconLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            placeholder_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TextControlPlaceholderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param info_icon_label_options: The configuration of info icon label options.
            :param placeholder_options: The configuration of the placeholder options in a text area control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textareacontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                text_area_control_display_options_property = quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                    info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                        info_icon_text="infoIconText",
                        visibility="visibility"
                    ),
                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__62227d81d7f79659a91b57c80c2d9b79fe22947cd125b71d46f55315864adae9)
                check_type(argname="argument info_icon_label_options", value=info_icon_label_options, expected_type=type_hints["info_icon_label_options"])
                check_type(argname="argument placeholder_options", value=placeholder_options, expected_type=type_hints["placeholder_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if info_icon_label_options is not None:
                self._values["info_icon_label_options"] = info_icon_label_options
            if placeholder_options is not None:
                self._values["placeholder_options"] = placeholder_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def info_icon_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetControlInfoIconLabelOptionsProperty"]]:
            '''The configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textareacontroldisplayoptions.html#cfn-quicksight-analysis-textareacontroldisplayoptions-infoiconlabeloptions
            '''
            result = self._values.get("info_icon_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetControlInfoIconLabelOptionsProperty"]], result)

        @builtins.property
        def placeholder_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TextControlPlaceholderOptionsProperty"]]:
            '''The configuration of the placeholder options in a text area control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textareacontroldisplayoptions.html#cfn-quicksight-analysis-textareacontroldisplayoptions-placeholderoptions
            '''
            result = self._values.get("placeholder_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TextControlPlaceholderOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textareacontroldisplayoptions.html#cfn-quicksight-analysis-textareacontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextAreaControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TextConditionalFormatProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "icon": "icon",
            "text_color": "textColor",
        },
    )
    class TextConditionalFormatProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the text.

            :param background_color: The conditional formatting for the text background color.
            :param icon: The conditional formatting for the icon.
            :param text_color: The conditional formatting for the text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textconditionalformat.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                text_conditional_format_property = quicksight.CfnAnalysis.TextConditionalFormatProperty(
                    background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    ),
                    icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__82cc65cd3f6af3cdc1a4cbff102520a82c4a8f0581ff816803ef4d21615908e1)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def background_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting for the text background color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textconditionalformat.html#cfn-quicksight-analysis-textconditionalformat-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"]], result)

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting for the icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textconditionalformat.html#cfn-quicksight-analysis-textconditionalformat-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting for the text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textconditionalformat.html#cfn-quicksight-analysis-textconditionalformat-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextConditionalFormatProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class TextControlPlaceholderOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the placeholder options in a text control.

            :param visibility: The visibility configuration of the placeholder options in a text control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textcontrolplaceholderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                text_control_placeholder_options_property = quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0b0c4784d2a7a0eac281890ccc7318934a741558158cf58bfc2f756d599d014d)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the placeholder options in a text control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textcontrolplaceholderoptions.html#cfn-quicksight-analysis-textcontrolplaceholderoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextControlPlaceholderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "info_icon_label_options": "infoIconLabelOptions",
            "placeholder_options": "placeholderOptions",
            "title_options": "titleOptions",
        },
    )
    class TextFieldControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SheetControlInfoIconLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            placeholder_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TextControlPlaceholderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param info_icon_label_options: The configuration of info icon label options.
            :param placeholder_options: The configuration of the placeholder options in a text field control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textfieldcontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                text_field_control_display_options_property = quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                    info_icon_label_options=quicksight.CfnAnalysis.SheetControlInfoIconLabelOptionsProperty(
                        info_icon_text="infoIconText",
                        visibility="visibility"
                    ),
                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c69caedc5c0054033434114a10cc23c28a2ca34b55f79a221720febf8966ca66)
                check_type(argname="argument info_icon_label_options", value=info_icon_label_options, expected_type=type_hints["info_icon_label_options"])
                check_type(argname="argument placeholder_options", value=placeholder_options, expected_type=type_hints["placeholder_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if info_icon_label_options is not None:
                self._values["info_icon_label_options"] = info_icon_label_options
            if placeholder_options is not None:
                self._values["placeholder_options"] = placeholder_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def info_icon_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetControlInfoIconLabelOptionsProperty"]]:
            '''The configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textfieldcontroldisplayoptions.html#cfn-quicksight-analysis-textfieldcontroldisplayoptions-infoiconlabeloptions
            '''
            result = self._values.get("info_icon_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SheetControlInfoIconLabelOptionsProperty"]], result)

        @builtins.property
        def placeholder_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TextControlPlaceholderOptionsProperty"]]:
            '''The configuration of the placeholder options in a text field control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textfieldcontroldisplayoptions.html#cfn-quicksight-analysis-textfieldcontroldisplayoptions-placeholderoptions
            '''
            result = self._values.get("placeholder_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TextControlPlaceholderOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textfieldcontroldisplayoptions.html#cfn-quicksight-analysis-textfieldcontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextFieldControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"symbol": "symbol", "visibility": "visibility"},
    )
    class ThousandSeparatorOptionsProperty:
        def __init__(
            self,
            *,
            symbol: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the thousands separator configuration.

            :param symbol: Determines the thousands separator symbol.
            :param visibility: Determines the visibility of the thousands separator.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-thousandseparatoroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                thousand_separator_options_property = quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                    symbol="symbol",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__22d4a6cb9abc6ec1f35afdb861c719850a2d5d1aa38f4fb1ab6f4d14a2d652b3)
                check_type(argname="argument symbol", value=symbol, expected_type=type_hints["symbol"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if symbol is not None:
                self._values["symbol"] = symbol
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def symbol(self) -> typing.Optional[builtins.str]:
            '''Determines the thousands separator symbol.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-thousandseparatoroptions.html#cfn-quicksight-analysis-thousandseparatoroptions-symbol
            '''
            result = self._values.get("symbol")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the thousands separator.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-thousandseparatoroptions.html#cfn-quicksight-analysis-thousandseparatoroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ThousandSeparatorOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "lower_boundary": "lowerBoundary",
            "periods_backward": "periodsBackward",
            "periods_forward": "periodsForward",
            "prediction_interval": "predictionInterval",
            "seasonality": "seasonality",
            "upper_boundary": "upperBoundary",
        },
    )
    class TimeBasedForecastPropertiesProperty:
        def __init__(
            self,
            *,
            lower_boundary: typing.Optional[jsii.Number] = None,
            periods_backward: typing.Optional[jsii.Number] = None,
            periods_forward: typing.Optional[jsii.Number] = None,
            prediction_interval: typing.Optional[jsii.Number] = None,
            seasonality: typing.Optional[jsii.Number] = None,
            upper_boundary: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The forecast properties setup of a forecast in the line chart.

            :param lower_boundary: The lower boundary setup of a forecast computation.
            :param periods_backward: The periods backward setup of a forecast computation.
            :param periods_forward: The periods forward setup of a forecast computation.
            :param prediction_interval: The prediction interval setup of a forecast computation.
            :param seasonality: The seasonality setup of a forecast computation. Choose one of the following options:. - ``NULL`` : The input is set to ``NULL`` . - ``NON_NULL`` : The input is set to a custom value.
            :param upper_boundary: The upper boundary setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                time_based_forecast_properties_property = quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty(
                    lower_boundary=123,
                    periods_backward=123,
                    periods_forward=123,
                    prediction_interval=123,
                    seasonality=123,
                    upper_boundary=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c2b183c9976b41cd50bef5eef0913ff9e90922c570ffdf3211e59c9555b9e513)
                check_type(argname="argument lower_boundary", value=lower_boundary, expected_type=type_hints["lower_boundary"])
                check_type(argname="argument periods_backward", value=periods_backward, expected_type=type_hints["periods_backward"])
                check_type(argname="argument periods_forward", value=periods_forward, expected_type=type_hints["periods_forward"])
                check_type(argname="argument prediction_interval", value=prediction_interval, expected_type=type_hints["prediction_interval"])
                check_type(argname="argument seasonality", value=seasonality, expected_type=type_hints["seasonality"])
                check_type(argname="argument upper_boundary", value=upper_boundary, expected_type=type_hints["upper_boundary"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if lower_boundary is not None:
                self._values["lower_boundary"] = lower_boundary
            if periods_backward is not None:
                self._values["periods_backward"] = periods_backward
            if periods_forward is not None:
                self._values["periods_forward"] = periods_forward
            if prediction_interval is not None:
                self._values["prediction_interval"] = prediction_interval
            if seasonality is not None:
                self._values["seasonality"] = seasonality
            if upper_boundary is not None:
                self._values["upper_boundary"] = upper_boundary

        @builtins.property
        def lower_boundary(self) -> typing.Optional[jsii.Number]:
            '''The lower boundary setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-lowerboundary
            '''
            result = self._values.get("lower_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_backward(self) -> typing.Optional[jsii.Number]:
            '''The periods backward setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-periodsbackward
            '''
            result = self._values.get("periods_backward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_forward(self) -> typing.Optional[jsii.Number]:
            '''The periods forward setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-periodsforward
            '''
            result = self._values.get("periods_forward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def prediction_interval(self) -> typing.Optional[jsii.Number]:
            '''The prediction interval setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-predictioninterval
            '''
            result = self._values.get("prediction_interval")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def seasonality(self) -> typing.Optional[jsii.Number]:
            '''The seasonality setup of a forecast computation. Choose one of the following options:.

            - ``NULL`` : The input is set to ``NULL`` .
            - ``NON_NULL`` : The input is set to a custom value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-seasonality
            '''
            result = self._values.get("seasonality")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def upper_boundary(self) -> typing.Optional[jsii.Number]:
            '''The upper boundary setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-upperboundary
            '''
            result = self._values.get("upper_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeBasedForecastPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TimeEqualityFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "parameter_name": "parameterName",
            "rolling_date": "rollingDate",
            "time_granularity": "timeGranularity",
            "value": "value",
        },
    )
    class TimeEqualityFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            parameter_name: typing.Optional[builtins.str] = None,
            rolling_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.RollingDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
            value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TimeEqualityFilter`` filters values that are equal to a given value.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param parameter_name: The parameter whose value should be used for the filter value. This field is mutually exclusive to ``Value`` and ``RollingDate`` .
            :param rolling_date: The rolling date input for the ``TimeEquality`` filter. This field is mutually exclusive to ``Value`` and ``ParameterName`` .
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param value: The value of a ``TimeEquality`` filter. This field is mutually exclusive to ``RollingDate`` and ``ParameterName`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                time_equality_filter_property = quicksight.CfnAnalysis.TimeEqualityFilterProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                
                    # the properties below are optional
                    parameter_name="parameterName",
                    rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                        expression="expression",
                
                        # the properties below are optional
                        data_set_identifier="dataSetIdentifier"
                    ),
                    time_granularity="timeGranularity",
                    value="value"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c5261cc45c74d4595359f0c36c5f0cdfbb6bd77676f6a05b1da5cc5e3c1cad0a)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument rolling_date", value=rolling_date, expected_type=type_hints["rolling_date"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
            }
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if rolling_date is not None:
                self._values["rolling_date"] = rolling_date
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            This field is mutually exclusive to ``Value`` and ``RollingDate`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rolling_date(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RollingDateConfigurationProperty"]]:
            '''The rolling date input for the ``TimeEquality`` filter.

            This field is mutually exclusive to ``Value`` and ``ParameterName`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-rollingdate
            '''
            result = self._values.get("rolling_date")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RollingDateConfigurationProperty"]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(self) -> typing.Optional[builtins.str]:
            '''The value of a ``TimeEquality`` filter.

            This field is mutually exclusive to ``RollingDate`` and ``ParameterName`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeEqualityFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "range_maximum": "rangeMaximum",
            "range_minimum": "rangeMinimum",
            "time_granularity": "timeGranularity",
        },
    )
    class TimeRangeDrillDownFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            range_maximum: builtins.str,
            range_minimum: builtins.str,
            time_granularity: builtins.str,
        ) -> None:
            '''The time range drill down filter.

            :param column: The column that the filter is applied to.
            :param range_maximum: The maximum value for the filter value range.
            :param range_minimum: The minimum value for the filter value range.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                time_range_drill_down_filter_property = quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    range_maximum="rangeMaximum",
                    range_minimum="rangeMinimum",
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__31707933e62e4bb441ca44e793fcd7b850d92ec40f8afad5fbf0866039c76e35)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument range_maximum", value=range_maximum, expected_type=type_hints["range_maximum"])
                check_type(argname="argument range_minimum", value=range_minimum, expected_type=type_hints["range_minimum"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "range_maximum": range_maximum,
                "range_minimum": range_minimum,
                "time_granularity": time_granularity,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html#cfn-quicksight-analysis-timerangedrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def range_maximum(self) -> builtins.str:
            '''The maximum value for the filter value range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html#cfn-quicksight-analysis-timerangedrilldownfilter-rangemaximum
            '''
            result = self._values.get("range_maximum")
            assert result is not None, "Required property 'range_maximum' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def range_minimum(self) -> builtins.str:
            '''The minimum value for the filter value range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html#cfn-quicksight-analysis-timerangedrilldownfilter-rangeminimum
            '''
            result = self._values.get("range_minimum")
            assert result is not None, "Required property 'range_minimum' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time_granularity(self) -> builtins.str:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html#cfn-quicksight-analysis-timerangedrilldownfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            assert result is not None, "Required property 'time_granularity' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TimeRangeFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "exclude_period_configuration": "excludePeriodConfiguration",
            "include_maximum": "includeMaximum",
            "include_minimum": "includeMinimum",
            "range_maximum_value": "rangeMaximumValue",
            "range_minimum_value": "rangeMinimumValue",
            "time_granularity": "timeGranularity",
        },
    )
    class TimeRangeFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            null_option: builtins.str,
            exclude_period_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ExcludePeriodConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
            include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
            range_maximum_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TimeRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            range_minimum_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TimeRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TimeRangeFilter`` filters values that are between two specified values.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param exclude_period_configuration: The exclude period of the time range filter.
            :param include_maximum: Determines whether the maximum value in the filter value range should be included in the filtered results.
            :param include_minimum: Determines whether the minimum value in the filter value range should be included in the filtered results.
            :param range_maximum_value: The maximum value for the filter value range.
            :param range_minimum_value: The minimum value for the filter value range.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                time_range_filter_property = quicksight.CfnAnalysis.TimeRangeFilterProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                
                    # the properties below are optional
                    exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                        amount=123,
                        granularity="granularity",
                
                        # the properties below are optional
                        status="status"
                    ),
                    include_maximum=False,
                    include_minimum=False,
                    range_maximum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                        parameter="parameter",
                        rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_value="staticValue"
                    ),
                    range_minimum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                        parameter="parameter",
                        rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_value="staticValue"
                    ),
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9f8ccf49248be5697abf1c959c4220e99d49abb8c65dc25bb44e648bbeffef1f)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument exclude_period_configuration", value=exclude_period_configuration, expected_type=type_hints["exclude_period_configuration"])
                check_type(argname="argument include_maximum", value=include_maximum, expected_type=type_hints["include_maximum"])
                check_type(argname="argument include_minimum", value=include_minimum, expected_type=type_hints["include_minimum"])
                check_type(argname="argument range_maximum_value", value=range_maximum_value, expected_type=type_hints["range_maximum_value"])
                check_type(argname="argument range_minimum_value", value=range_minimum_value, expected_type=type_hints["range_minimum_value"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
            }
            if exclude_period_configuration is not None:
                self._values["exclude_period_configuration"] = exclude_period_configuration
            if include_maximum is not None:
                self._values["include_maximum"] = include_maximum
            if include_minimum is not None:
                self._values["include_minimum"] = include_minimum
            if range_maximum_value is not None:
                self._values["range_maximum_value"] = range_maximum_value
            if range_minimum_value is not None:
                self._values["range_minimum_value"] = range_minimum_value
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def exclude_period_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ExcludePeriodConfigurationProperty"]]:
            '''The exclude period of the time range filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-excludeperiodconfiguration
            '''
            result = self._values.get("exclude_period_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ExcludePeriodConfigurationProperty"]], result)

        @builtins.property
        def include_maximum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''Determines whether the maximum value in the filter value range should be included in the filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-includemaximum
            '''
            result = self._values.get("include_maximum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        @builtins.property
        def include_minimum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''Determines whether the minimum value in the filter value range should be included in the filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-includeminimum
            '''
            result = self._values.get("include_minimum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        @builtins.property
        def range_maximum_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TimeRangeFilterValueProperty"]]:
            '''The maximum value for the filter value range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-rangemaximumvalue
            '''
            result = self._values.get("range_maximum_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TimeRangeFilterValueProperty"]], result)

        @builtins.property
        def range_minimum_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TimeRangeFilterValueProperty"]]:
            '''The minimum value for the filter value range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-rangeminimumvalue
            '''
            result = self._values.get("range_minimum_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TimeRangeFilterValueProperty"]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TimeRangeFilterValueProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter": "parameter",
            "rolling_date": "rollingDate",
            "static_value": "staticValue",
        },
    )
    class TimeRangeFilterValueProperty:
        def __init__(
            self,
            *,
            parameter: typing.Optional[builtins.str] = None,
            rolling_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.RollingDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The value of a time range filter.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param parameter: The parameter type input value.
            :param rolling_date: The rolling date input value.
            :param static_value: The static input value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefiltervalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                time_range_filter_value_property = quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                    parameter="parameter",
                    rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                        expression="expression",
                
                        # the properties below are optional
                        data_set_identifier="dataSetIdentifier"
                    ),
                    static_value="staticValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e5ac68f0a19c8f46798572c936b379a0a7776666dd4ebfb8c3fe1acf6fa17f40)
                check_type(argname="argument parameter", value=parameter, expected_type=type_hints["parameter"])
                check_type(argname="argument rolling_date", value=rolling_date, expected_type=type_hints["rolling_date"])
                check_type(argname="argument static_value", value=static_value, expected_type=type_hints["static_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if parameter is not None:
                self._values["parameter"] = parameter
            if rolling_date is not None:
                self._values["rolling_date"] = rolling_date
            if static_value is not None:
                self._values["static_value"] = static_value

        @builtins.property
        def parameter(self) -> typing.Optional[builtins.str]:
            '''The parameter type input value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefiltervalue.html#cfn-quicksight-analysis-timerangefiltervalue-parameter
            '''
            result = self._values.get("parameter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rolling_date(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RollingDateConfigurationProperty"]]:
            '''The rolling date input value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefiltervalue.html#cfn-quicksight-analysis-timerangefiltervalue-rollingdate
            '''
            result = self._values.get("rolling_date")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RollingDateConfigurationProperty"]], result)

        @builtins.property
        def static_value(self) -> typing.Optional[builtins.str]:
            '''The static input value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefiltervalue.html#cfn-quicksight-analysis-timerangefiltervalue-staticvalue
            '''
            result = self._values.get("static_value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeFilterValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_tooltip_item": "columnTooltipItem",
            "field_tooltip_item": "fieldTooltipItem",
        },
    )
    class TooltipItemProperty:
        def __init__(
            self,
            *,
            column_tooltip_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnTooltipItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_tooltip_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldTooltipItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The tooltip.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param column_tooltip_item: The tooltip item for the columns that are not part of a field well.
            :param field_tooltip_item: The tooltip item for the fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                tooltip_item_property = quicksight.CfnAnalysis.TooltipItemProperty(
                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                            attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                simple_attribute_aggregation="simpleAttributeAggregation",
                                value_for_multiple_values="valueForMultipleValues"
                            ),
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        label="label",
                        visibility="visibility"
                    ),
                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        label="label",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3289d94cc42dcc093fdc87e358875e83c5c1ce3e66b270faeedda2c33b7bca47)
                check_type(argname="argument column_tooltip_item", value=column_tooltip_item, expected_type=type_hints["column_tooltip_item"])
                check_type(argname="argument field_tooltip_item", value=field_tooltip_item, expected_type=type_hints["field_tooltip_item"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_tooltip_item is not None:
                self._values["column_tooltip_item"] = column_tooltip_item
            if field_tooltip_item is not None:
                self._values["field_tooltip_item"] = field_tooltip_item

        @builtins.property
        def column_tooltip_item(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnTooltipItemProperty"]]:
            '''The tooltip item for the columns that are not part of a field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipitem.html#cfn-quicksight-analysis-tooltipitem-columntooltipitem
            '''
            result = self._values.get("column_tooltip_item")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnTooltipItemProperty"]], result)

        @builtins.property
        def field_tooltip_item(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldTooltipItemProperty"]]:
            '''The tooltip item for the fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipitem.html#cfn-quicksight-analysis-tooltipitem-fieldtooltipitem
            '''
            result = self._values.get("field_tooltip_item")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldTooltipItemProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TooltipOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_based_tooltip": "fieldBasedTooltip",
            "selected_tooltip_type": "selectedTooltipType",
            "tooltip_visibility": "tooltipVisibility",
        },
    )
    class TooltipOptionsProperty:
        def __init__(
            self,
            *,
            field_based_tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldBasedTooltipProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selected_tooltip_type: typing.Optional[builtins.str] = None,
            tooltip_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The display options for the visual tooltip.

            :param field_based_tooltip: The setup for the detailed tooltip. The tooltip setup is always saved. The display type is decided based on the tooltip type.
            :param selected_tooltip_type: The selected type for the tooltip. Choose one of the following options:. - ``BASIC`` : A basic tooltip. - ``DETAILED`` : A detailed tooltip.
            :param tooltip_visibility: Determines whether or not the tooltip is visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                tooltip_options_property = quicksight.CfnAnalysis.TooltipOptionsProperty(
                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                        aggregation_visibility="aggregationVisibility",
                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                        simple_attribute_aggregation="simpleAttributeAggregation",
                                        value_for_multiple_values="valueForMultipleValues"
                                    ),
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                label="label",
                                visibility="visibility"
                            ),
                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                label="label",
                                visibility="visibility"
                            )
                        )],
                        tooltip_title_type="tooltipTitleType"
                    ),
                    selected_tooltip_type="selectedTooltipType",
                    tooltip_visibility="tooltipVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3c83462475afd4a1e5f404ecaa84f1b3a88d90c73412b37833fc1303e8648a85)
                check_type(argname="argument field_based_tooltip", value=field_based_tooltip, expected_type=type_hints["field_based_tooltip"])
                check_type(argname="argument selected_tooltip_type", value=selected_tooltip_type, expected_type=type_hints["selected_tooltip_type"])
                check_type(argname="argument tooltip_visibility", value=tooltip_visibility, expected_type=type_hints["tooltip_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_based_tooltip is not None:
                self._values["field_based_tooltip"] = field_based_tooltip
            if selected_tooltip_type is not None:
                self._values["selected_tooltip_type"] = selected_tooltip_type
            if tooltip_visibility is not None:
                self._values["tooltip_visibility"] = tooltip_visibility

        @builtins.property
        def field_based_tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldBasedTooltipProperty"]]:
            '''The setup for the detailed tooltip.

            The tooltip setup is always saved. The display type is decided based on the tooltip type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipoptions.html#cfn-quicksight-analysis-tooltipoptions-fieldbasedtooltip
            '''
            result = self._values.get("field_based_tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldBasedTooltipProperty"]], result)

        @builtins.property
        def selected_tooltip_type(self) -> typing.Optional[builtins.str]:
            '''The selected type for the tooltip. Choose one of the following options:.

            - ``BASIC`` : A basic tooltip.
            - ``DETAILED`` : A detailed tooltip.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipoptions.html#cfn-quicksight-analysis-tooltipoptions-selectedtooltiptype
            '''
            result = self._values.get("selected_tooltip_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tooltip_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the tooltip is visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipoptions.html#cfn-quicksight-analysis-tooltipoptions-tooltipvisibility
            '''
            result = self._values.get("tooltip_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TooltipOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TopBottomFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_sort_configurations": "aggregationSortConfigurations",
            "column": "column",
            "filter_id": "filterId",
            "limit": "limit",
            "parameter_name": "parameterName",
            "time_granularity": "timeGranularity",
        },
    )
    class TopBottomFilterProperty:
        def __init__(
            self,
            *,
            aggregation_sort_configurations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AggregationSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            limit: typing.Optional[jsii.Number] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TopBottomFilter`` filters values that are at the top or the bottom.

            :param aggregation_sort_configurations: The aggregation and sort configuration of the top bottom filter.
            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param limit: The number of items to include in the top bottom filter results.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                top_bottom_filter_property = quicksight.CfnAnalysis.TopBottomFilterProperty(
                    aggregation_sort_configurations=[quicksight.CfnAnalysis.AggregationSortConfigurationProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        sort_direction="sortDirection",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                            attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                simple_attribute_aggregation="simpleAttributeAggregation",
                                value_for_multiple_values="valueForMultipleValues"
                            ),
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    )],
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                
                    # the properties below are optional
                    limit=123,
                    parameter_name="parameterName",
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__797cab8d6c63536edf46d79183956235577ff52f6151c755628360993af35153)
                check_type(argname="argument aggregation_sort_configurations", value=aggregation_sort_configurations, expected_type=type_hints["aggregation_sort_configurations"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "aggregation_sort_configurations": aggregation_sort_configurations,
                "column": column,
                "filter_id": filter_id,
            }
            if limit is not None:
                self._values["limit"] = limit
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def aggregation_sort_configurations(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AggregationSortConfigurationProperty"]]]:
            '''The aggregation and sort configuration of the top bottom filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-aggregationsortconfigurations
            '''
            result = self._values.get("aggregation_sort_configurations")
            assert result is not None, "Required property 'aggregation_sort_configurations' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AggregationSortConfigurationProperty"]]], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def limit(self) -> typing.Optional[jsii.Number]:
            '''The number of items to include in the top bottom filter results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-limit
            '''
            result = self._values.get("limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TopBottomMoversComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "type": "type",
            "category": "category",
            "mover_size": "moverSize",
            "name": "name",
            "sort_order": "sortOrder",
            "time": "time",
            "value": "value",
        },
    )
    class TopBottomMoversComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            type: builtins.str,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mover_size: typing.Optional[jsii.Number] = None,
            name: typing.Optional[builtins.str] = None,
            sort_order: typing.Optional[builtins.str] = None,
            time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The top movers and bottom movers computation setup.

            :param computation_id: The ID for a computation.
            :param type: The computation type. Choose from the following options:. - TOP: Top movers computation. - BOTTOM: Bottom movers computation.
            :param category: The category field that is used in a computation.
            :param mover_size: The mover size setup of the top and bottom movers computation. Default: - 0
            :param name: The name of a computation.
            :param sort_order: The sort order setup of the top and bottom movers computation.
            :param time: The time field that is used in a computation.
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8add4baf39d0c008085931a458a6dabc8a0398f7d526ac3812f3fdd977c6ffa3)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument mover_size", value=mover_size, expected_type=type_hints["mover_size"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sort_order", value=sort_order, expected_type=type_hints["sort_order"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "type": type,
            }
            if category is not None:
                self._values["category"] = category
            if mover_size is not None:
                self._values["mover_size"] = mover_size
            if name is not None:
                self._values["name"] = name
            if sort_order is not None:
                self._values["sort_order"] = sort_order
            if time is not None:
                self._values["time"] = time
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The computation type. Choose from the following options:.

            - TOP: Top movers computation.
            - BOTTOM: Bottom movers computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]:
            '''The category field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]], result)

        @builtins.property
        def mover_size(self) -> typing.Optional[jsii.Number]:
            '''The mover size setup of the top and bottom movers computation.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-moversize
            '''
            result = self._values.get("mover_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sort_order(self) -> typing.Optional[builtins.str]:
            '''The sort order setup of the top and bottom movers computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-sortorder
            '''
            result = self._values.get("sort_order")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]:
            '''The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-time
            '''
            result = self._values.get("time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomMoversComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TopBottomRankedComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "type": "type",
            "category": "category",
            "name": "name",
            "result_size": "resultSize",
            "value": "value",
        },
    )
    class TopBottomRankedComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            type: builtins.str,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            name: typing.Optional[builtins.str] = None,
            result_size: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The top ranked and bottom ranked computation configuration.

            :param computation_id: The ID for a computation.
            :param type: The computation type. Choose one of the following options:. - TOP: A top ranked computation. - BOTTOM: A bottom ranked computation.
            :param category: The category field that is used in a computation.
            :param name: The name of a computation.
            :param result_size: The result size of a top and bottom ranked computation. Default: - 0
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__28735e743dd0651f6b742574ac00814fc1a0f6d214e1106c81085facf5ef67a1)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument result_size", value=result_size, expected_type=type_hints["result_size"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "type": type,
            }
            if category is not None:
                self._values["category"] = category
            if name is not None:
                self._values["name"] = name
            if result_size is not None:
                self._values["result_size"] = result_size
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The computation type. Choose one of the following options:.

            - TOP: A top ranked computation.
            - BOTTOM: A bottom ranked computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]:
            '''The category field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def result_size(self) -> typing.Optional[jsii.Number]:
            '''The result size of a top and bottom ranked computation.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-resultsize
            '''
            result = self._values.get("result_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomRankedComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TotalAggregationComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "name": "name",
            "value": "value",
        },
    )
    class TotalAggregationComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            name: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The total aggregation computation configuration.

            :param computation_id: The ID for a computation.
            :param name: The name of a computation.
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                total_aggregation_computation_property = quicksight.CfnAnalysis.TotalAggregationComputationProperty(
                    computation_id="computationId",
                
                    # the properties below are optional
                    name="name",
                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__32f39adfbd8ec8fb473b1a5b4ed6c65df8be4d61566a8fbfcb5b5e164717629f)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
            }
            if name is not None:
                self._values["name"] = name
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationcomputation.html#cfn-quicksight-analysis-totalaggregationcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationcomputation.html#cfn-quicksight-analysis-totalaggregationcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationcomputation.html#cfn-quicksight-analysis-totalaggregationcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalAggregationComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TotalAggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "simple_total_aggregation_function": "simpleTotalAggregationFunction",
        },
    )
    class TotalAggregationFunctionProperty:
        def __init__(
            self,
            *,
            simple_total_aggregation_function: typing.Optional[builtins.str] = None,
        ) -> None:
            '''An aggregation function that aggregates the total values of a measure.

            :param simple_total_aggregation_function: A built in aggregation function for total values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                total_aggregation_function_property = quicksight.CfnAnalysis.TotalAggregationFunctionProperty(
                    simple_total_aggregation_function="simpleTotalAggregationFunction"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9c454514da67d5bc4e329556a6bfdf3bd41b48a98461affad16103890078f34e)
                check_type(argname="argument simple_total_aggregation_function", value=simple_total_aggregation_function, expected_type=type_hints["simple_total_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if simple_total_aggregation_function is not None:
                self._values["simple_total_aggregation_function"] = simple_total_aggregation_function

        @builtins.property
        def simple_total_aggregation_function(self) -> typing.Optional[builtins.str]:
            '''A built in aggregation function for total values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationfunction.html#cfn-quicksight-analysis-totalaggregationfunction-simpletotalaggregationfunction
            '''
            result = self._values.get("simple_total_aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalAggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TotalAggregationOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "total_aggregation_function": "totalAggregationFunction",
        },
    )
    class TotalAggregationOptionProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            total_aggregation_function: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TotalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The total aggregation settings map of a field id.

            :param field_id: The field id that's associated with the total aggregation option.
            :param total_aggregation_function: The total aggregation function that you want to set for a specified field id.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                total_aggregation_option_property = quicksight.CfnAnalysis.TotalAggregationOptionProperty(
                    field_id="fieldId",
                    total_aggregation_function=quicksight.CfnAnalysis.TotalAggregationFunctionProperty(
                        simple_total_aggregation_function="simpleTotalAggregationFunction"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1f2203386ff7dbe43c0f91a466eb584b39055cdc3f8385733ef3f20d01c3ba80)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument total_aggregation_function", value=total_aggregation_function, expected_type=type_hints["total_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
                "total_aggregation_function": total_aggregation_function,
            }

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field id that's associated with the total aggregation option.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationoption.html#cfn-quicksight-analysis-totalaggregationoption-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def total_aggregation_function(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TotalAggregationFunctionProperty"]:
            '''The total aggregation function that you want to set for a specified field id.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationoption.html#cfn-quicksight-analysis-totalaggregationoption-totalaggregationfunction
            '''
            result = self._values.get("total_aggregation_function")
            assert result is not None, "Required property 'total_aggregation_function' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TotalAggregationFunctionProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalAggregationOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "placement": "placement",
            "scroll_status": "scrollStatus",
            "total_aggregation_options": "totalAggregationOptions",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
        },
    )
    class TotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            placement: typing.Optional[builtins.str] = None,
            scroll_status: typing.Optional[builtins.str] = None,
            total_aggregation_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TotalAggregationOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            total_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The total options for a table visual.

            :param custom_label: The custom label string for the total cells.
            :param placement: The placement (start, end) for the total cells.
            :param scroll_status: The scroll status (pinned, scrolled) for the total cells.
            :param total_aggregation_options: The total aggregation settings for each value field.
            :param total_cell_style: Cell styling options for the total cells.
            :param totals_visibility: The visibility configuration for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                total_options_property = quicksight.CfnAnalysis.TotalOptionsProperty(
                    custom_label="customLabel",
                    placement="placement",
                    scroll_status="scrollStatus",
                    total_aggregation_options=[quicksight.CfnAnalysis.TotalAggregationOptionProperty(
                        field_id="fieldId",
                        total_aggregation_function=quicksight.CfnAnalysis.TotalAggregationFunctionProperty(
                            simple_total_aggregation_function="simpleTotalAggregationFunction"
                        )
                    )],
                    total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3cb9d3d986ec951750d2fa88755ce590fd2b1a0ccf297c5bb4e33c75aaceba54)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument placement", value=placement, expected_type=type_hints["placement"])
                check_type(argname="argument scroll_status", value=scroll_status, expected_type=type_hints["scroll_status"])
                check_type(argname="argument total_aggregation_options", value=total_aggregation_options, expected_type=type_hints["total_aggregation_options"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if placement is not None:
                self._values["placement"] = placement
            if scroll_status is not None:
                self._values["scroll_status"] = scroll_status
            if total_aggregation_options is not None:
                self._values["total_aggregation_options"] = total_aggregation_options
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def placement(self) -> typing.Optional[builtins.str]:
            '''The placement (start, end) for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-placement
            '''
            result = self._values.get("placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scroll_status(self) -> typing.Optional[builtins.str]:
            '''The scroll status (pinned, scrolled) for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-scrollstatus
            '''
            result = self._values.get("scroll_status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def total_aggregation_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TotalAggregationOptionProperty"]]]]:
            '''The total aggregation settings for each value field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-totalaggregationoptions
            '''
            result = self._values.get("total_aggregation_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TotalAggregationOptionProperty"]]]], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]]:
            '''Cell styling options for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TreeMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"colors": "colors", "groups": "groups", "sizes": "sizes"},
    )
    class TreeMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sizes: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''Aggregated field wells of a tree map.

            :param colors: The color field well of a tree map. Values are grouped by aggregations based on group by fields.
            :param groups: The group by field well of a tree map. Values are grouped based on group by fields.
            :param sizes: The size field well of a tree map. Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__00f03c70e82683586cbc7648798b3e82e87a1f835ad6b4820077ed676d11c138)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument groups", value=groups, expected_type=type_hints["groups"])
                check_type(argname="argument sizes", value=sizes, expected_type=type_hints["sizes"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors
            if groups is not None:
                self._values["groups"] = groups
            if sizes is not None:
                self._values["sizes"] = sizes

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The color field well of a tree map.

            Values are grouped by aggregations based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapaggregatedfieldwells.html#cfn-quicksight-analysis-treemapaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        @builtins.property
        def groups(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The group by field well of a tree map.

            Values are grouped based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapaggregatedfieldwells.html#cfn-quicksight-analysis-treemapaggregatedfieldwells-groups
            '''
            result = self._values.get("groups")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def sizes(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The size field well of a tree map.

            Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapaggregatedfieldwells.html#cfn-quicksight-analysis-treemapaggregatedfieldwells-sizes
            '''
            result = self._values.get("sizes")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TreeMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_label_options": "colorLabelOptions",
            "color_scale": "colorScale",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "group_label_options": "groupLabelOptions",
            "legend": "legend",
            "size_label_options": "sizeLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
        },
    )
    class TreeMapConfigurationProperty:
        def __init__(
            self,
            *,
            color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_scale: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColorScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TreeMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            group_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            size_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TreeMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a tree map.

            :param color_label_options: The label options (label text, label visibility) for the colors displayed in a tree map.
            :param color_scale: The color options (gradient color, point of divergence) of a tree map.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param group_label_options: The label options (label text, label visibility) of the groups that are displayed in a tree map.
            :param legend: The legend display setup of the visual.
            :param size_label_options: The label options (label text, label visibility) of the sizes that are displayed in a tree map.
            :param sort_configuration: The sort configuration of a tree map.
            :param tooltip: The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__93a6b0d40965a02d73b77d2d474696c59c68c0869ffcd790194093a704ee2250)
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument color_scale", value=color_scale, expected_type=type_hints["color_scale"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument group_label_options", value=group_label_options, expected_type=type_hints["group_label_options"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument size_label_options", value=size_label_options, expected_type=type_hints["size_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if color_scale is not None:
                self._values["color_scale"] = color_scale
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if group_label_options is not None:
                self._values["group_label_options"] = group_label_options
            if legend is not None:
                self._values["legend"] = legend
            if size_label_options is not None:
                self._values["size_label_options"] = size_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility) for the colors displayed in a tree map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_scale(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColorScaleProperty"]]:
            '''The color options (gradient color, point of divergence) of a tree map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-colorscale
            '''
            result = self._values.get("color_scale")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColorScaleProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TreeMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TreeMapFieldWellsProperty"]], result)

        @builtins.property
        def group_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility) of the groups that are displayed in a tree map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-grouplabeloptions
            '''
            result = self._values.get("group_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def size_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility) of the sizes that are displayed in a tree map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-sizelabeloptions
            '''
            result = self._values.get("size_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TreeMapSortConfigurationProperty"]]:
            '''The sort configuration of a tree map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TreeMapSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TooltipOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TreeMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "tree_map_aggregated_field_wells": "treeMapAggregatedFieldWells",
        },
    )
    class TreeMapFieldWellsProperty:
        def __init__(
            self,
            *,
            tree_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TreeMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a tree map.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param tree_map_aggregated_field_wells: The aggregated field wells of a tree map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__83130f39540a83f1e210175fe90ca34238d440a8c276f05557269bf72a378098)
                check_type(argname="argument tree_map_aggregated_field_wells", value=tree_map_aggregated_field_wells, expected_type=type_hints["tree_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if tree_map_aggregated_field_wells is not None:
                self._values["tree_map_aggregated_field_wells"] = tree_map_aggregated_field_wells

        @builtins.property
        def tree_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TreeMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a tree map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapfieldwells.html#cfn-quicksight-analysis-treemapfieldwells-treemapaggregatedfieldwells
            '''
            result = self._values.get("tree_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TreeMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TreeMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "tree_map_group_items_limit_configuration": "treeMapGroupItemsLimitConfiguration",
            "tree_map_sort": "treeMapSort",
        },
    )
    class TreeMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            tree_map_group_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tree_map_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a tree map.

            :param tree_map_group_items_limit_configuration: The limit on the number of groups that are displayed.
            :param tree_map_sort: The sort configuration of group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                tree_map_sort_configuration_property = quicksight.CfnAnalysis.TreeMapSortConfigurationProperty(
                    tree_map_group_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    tree_map_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__267bd6a67c18b49c2ce0cfb16e0aaf4407aa19766c92fd828fa8d158290dea72)
                check_type(argname="argument tree_map_group_items_limit_configuration", value=tree_map_group_items_limit_configuration, expected_type=type_hints["tree_map_group_items_limit_configuration"])
                check_type(argname="argument tree_map_sort", value=tree_map_sort, expected_type=type_hints["tree_map_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if tree_map_group_items_limit_configuration is not None:
                self._values["tree_map_group_items_limit_configuration"] = tree_map_group_items_limit_configuration
            if tree_map_sort is not None:
                self._values["tree_map_sort"] = tree_map_sort

        @builtins.property
        def tree_map_group_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of groups that are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapsortconfiguration.html#cfn-quicksight-analysis-treemapsortconfiguration-treemapgroupitemslimitconfiguration
            '''
            result = self._values.get("tree_map_group_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def tree_map_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapsortconfiguration.html#cfn-quicksight-analysis-treemapsortconfiguration-treemapsort
            '''
            result = self._values.get("tree_map_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TreeMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class TreeMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TreeMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A tree map.

            For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__987c134dcdfc1a8aad1f606a18f8e3de2feb30ff23e7bc1fb4e8c208de05831d)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TreeMapConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TreeMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.TrendArrowOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class TrendArrowOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of trend arrows in a KPI visual.

            :param visibility: The visibility of the trend arrows.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-trendarrowoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                trend_arrow_options_property = quicksight.CfnAnalysis.TrendArrowOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fa687045085dc8d72af87858985acf96ef909e9f440a2dcdc152e45f6d7ceaf4)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the trend arrows.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-trendarrowoptions.html#cfn-quicksight-analysis-trendarrowoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TrendArrowOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.UnaggregatedFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
        },
    )
    class UnaggregatedFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The unaggregated field for a table.

            :param column: The column that is used in the ``UnaggregatedField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-unaggregatedfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                unaggregated_field_property = quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d265618d94c82fa33595fa63cf601981fc46655fc4e54c08237a64a02f0e8e7c)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that is used in the ``UnaggregatedField`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-unaggregatedfield.html#cfn-quicksight-analysis-unaggregatedfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-unaggregatedfield.html#cfn-quicksight-analysis-unaggregatedfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-unaggregatedfield.html#cfn-quicksight-analysis-unaggregatedfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UnaggregatedFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.UniqueValuesComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "category": "category",
            "name": "name",
        },
    )
    class UniqueValuesComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The unique values computation configuration.

            :param computation_id: The ID for a computation.
            :param category: The category field that is used in a computation.
            :param name: The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-uniquevaluescomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                unique_values_computation_property = quicksight.CfnAnalysis.UniqueValuesComputationProperty(
                    computation_id="computationId",
                
                    # the properties below are optional
                    category=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__694d5d0b7cd15aed71341557fca998d4eb548ee61966a5ea32f3acd7f3fb6dce)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
            }
            if category is not None:
                self._values["category"] = category
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-uniquevaluescomputation.html#cfn-quicksight-analysis-uniquevaluescomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]:
            '''The category field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-uniquevaluescomputation.html#cfn-quicksight-analysis-uniquevaluescomputation-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-uniquevaluescomputation.html#cfn-quicksight-analysis-uniquevaluescomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UniqueValuesComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.ValidationStrategyProperty",
        jsii_struct_bases=[],
        name_mapping={"mode": "mode"},
    )
    class ValidationStrategyProperty:
        def __init__(self, *, mode: builtins.str) -> None:
            '''The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects.

            When you set this value to ``LENIENT`` , validation is skipped for specific errors.

            :param mode: The mode of validation for the asset to be created or updated. When you set this value to ``STRICT`` , strict validation for every error is enforced. When you set this value to ``LENIENT`` , validation is skipped for specific UI errors.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-validationstrategy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                validation_strategy_property = quicksight.CfnAnalysis.ValidationStrategyProperty(
                    mode="mode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__456be41f5014f6703a82594f94da2668fdb18d0ecf4d83c19f807a998aade12f)
                check_type(argname="argument mode", value=mode, expected_type=type_hints["mode"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "mode": mode,
            }

        @builtins.property
        def mode(self) -> builtins.str:
            '''The mode of validation for the asset to be created or updated.

            When you set this value to ``STRICT`` , strict validation for every error is enforced. When you set this value to ``LENIENT`` , validation is skipped for specific UI errors.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-validationstrategy.html#cfn-quicksight-analysis-validationstrategy-mode
            '''
            result = self._values.get("mode")
            assert result is not None, "Required property 'mode' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ValidationStrategyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.VisibleRangeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"percent_range": "percentRange"},
    )
    class VisibleRangeOptionsProperty:
        def __init__(
            self,
            *,
            percent_range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PercentVisibleRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The range options for the data zoom scroll bar.

            :param percent_range: The percent range in the visible range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visiblerangeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                visible_range_options_property = quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                        from=123,
                        to=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d102b1a87dae33760dd66fce1802286441d09b8befc4e9f886fa64b0359ab043)
                check_type(argname="argument percent_range", value=percent_range, expected_type=type_hints["percent_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percent_range is not None:
                self._values["percent_range"] = percent_range

        @builtins.property
        def percent_range(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PercentVisibleRangeProperty"]]:
            '''The percent range in the visible range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visiblerangeoptions.html#cfn-quicksight-analysis-visiblerangeoptions-percentrange
            '''
            result = self._values.get("percent_range")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PercentVisibleRangeProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisibleRangeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.VisualCustomActionOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_operation": "filterOperation",
            "navigation_operation": "navigationOperation",
            "set_parameters_operation": "setParametersOperation",
            "url_operation": "urlOperation",
        },
    )
    class VisualCustomActionOperationProperty:
        def __init__(
            self,
            *,
            filter_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CustomActionFilterOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            navigation_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CustomActionNavigationOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            set_parameters_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CustomActionSetParametersOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            url_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CustomActionURLOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The operation that is defined by the custom action.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param filter_operation: The filter operation that filters data included in a visual or in an entire sheet.
            :param navigation_operation: The navigation operation that navigates between different sheets in the same analysis.
            :param set_parameters_operation: The set parameter operation that sets parameters in custom action.
            :param url_operation: The URL operation that opens a link to another webpage.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                visual_custom_action_operation_property = quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                            selected_columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            selected_field_options="selectedFieldOptions",
                            selected_fields=["selectedFields"]
                        ),
                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                target_visual_options="targetVisualOptions",
                                target_visuals=["targetVisuals"]
                            )
                        )
                    ),
                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                            target_sheet_id="targetSheetId"
                        )
                    ),
                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                            destination_parameter_name="destinationParameterName",
                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                        date_time_values=["dateTimeValues"],
                                        decimal_values=[123],
                                        integer_values=[123],
                                        string_values=["stringValues"]
                                    ),
                
                                    # the properties below are optional
                                    include_null_value=False
                                ),
                                select_all_value_options="selectAllValueOptions",
                                source_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_field="sourceField",
                                source_parameter_name="sourceParameterName"
                            )
                        )]
                    ),
                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                        url_target="urlTarget",
                        url_template="urlTemplate"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5d730b715d9e6cdd475e9a82496f99af47fe31dfb0ff5679d9658ae40227ae56)
                check_type(argname="argument filter_operation", value=filter_operation, expected_type=type_hints["filter_operation"])
                check_type(argname="argument navigation_operation", value=navigation_operation, expected_type=type_hints["navigation_operation"])
                check_type(argname="argument set_parameters_operation", value=set_parameters_operation, expected_type=type_hints["set_parameters_operation"])
                check_type(argname="argument url_operation", value=url_operation, expected_type=type_hints["url_operation"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if filter_operation is not None:
                self._values["filter_operation"] = filter_operation
            if navigation_operation is not None:
                self._values["navigation_operation"] = navigation_operation
            if set_parameters_operation is not None:
                self._values["set_parameters_operation"] = set_parameters_operation
            if url_operation is not None:
                self._values["url_operation"] = url_operation

        @builtins.property
        def filter_operation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomActionFilterOperationProperty"]]:
            '''The filter operation that filters data included in a visual or in an entire sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html#cfn-quicksight-analysis-visualcustomactionoperation-filteroperation
            '''
            result = self._values.get("filter_operation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomActionFilterOperationProperty"]], result)

        @builtins.property
        def navigation_operation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomActionNavigationOperationProperty"]]:
            '''The navigation operation that navigates between different sheets in the same analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html#cfn-quicksight-analysis-visualcustomactionoperation-navigationoperation
            '''
            result = self._values.get("navigation_operation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomActionNavigationOperationProperty"]], result)

        @builtins.property
        def set_parameters_operation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomActionSetParametersOperationProperty"]]:
            '''The set parameter operation that sets parameters in custom action.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html#cfn-quicksight-analysis-visualcustomactionoperation-setparametersoperation
            '''
            result = self._values.get("set_parameters_operation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomActionSetParametersOperationProperty"]], result)

        @builtins.property
        def url_operation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomActionURLOperationProperty"]]:
            '''The URL operation that opens a link to another webpage.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html#cfn-quicksight-analysis-visualcustomactionoperation-urloperation
            '''
            result = self._values.get("url_operation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomActionURLOperationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualCustomActionOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.VisualCustomActionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "action_operations": "actionOperations",
            "custom_action_id": "customActionId",
            "name": "name",
            "trigger": "trigger",
            "status": "status",
        },
    )
    class VisualCustomActionProperty:
        def __init__(
            self,
            *,
            action_operations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionOperationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            custom_action_id: builtins.str,
            name: builtins.str,
            trigger: builtins.str,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A custom action defined on a visual.

            :param action_operations: A list of ``VisualCustomActionOperations`` . This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
            :param custom_action_id: The ID of the ``VisualCustomAction`` .
            :param name: The name of the ``VisualCustomAction`` .
            :param trigger: The trigger of the ``VisualCustomAction`` . Valid values are defined as follows: - ``DATA_POINT_CLICK`` : Initiates a custom action by a left pointer click on a data point. - ``DATA_POINT_MENU`` : Initiates a custom action by right pointer click from the menu.
            :param status: The status of the ``VisualCustomAction`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                visual_custom_action_property = quicksight.CfnAnalysis.VisualCustomActionProperty(
                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                selected_columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                selected_field_options="selectedFieldOptions",
                                selected_fields=["selectedFields"]
                            ),
                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                    target_visual_options="targetVisualOptions",
                                    target_visuals=["targetVisuals"]
                                )
                            )
                        ),
                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                target_sheet_id="targetSheetId"
                            )
                        ),
                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                destination_parameter_name="destinationParameterName",
                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                            date_time_values=["dateTimeValues"],
                                            decimal_values=[123],
                                            integer_values=[123],
                                            string_values=["stringValues"]
                                        ),
                
                                        # the properties below are optional
                                        include_null_value=False
                                    ),
                                    select_all_value_options="selectAllValueOptions",
                                    source_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_field="sourceField",
                                    source_parameter_name="sourceParameterName"
                                )
                            )]
                        ),
                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                            url_target="urlTarget",
                            url_template="urlTemplate"
                        )
                    )],
                    custom_action_id="customActionId",
                    name="name",
                    trigger="trigger",
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__26f7459afa8caf596af826ad5a11c161931b24cc757b9501abfe4c8f6c46ecc2)
                check_type(argname="argument action_operations", value=action_operations, expected_type=type_hints["action_operations"])
                check_type(argname="argument custom_action_id", value=custom_action_id, expected_type=type_hints["custom_action_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument trigger", value=trigger, expected_type=type_hints["trigger"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "action_operations": action_operations,
                "custom_action_id": custom_action_id,
                "name": name,
                "trigger": trigger,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def action_operations(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionOperationProperty"]]]:
            '''A list of ``VisualCustomActionOperations`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-actionoperations
            '''
            result = self._values.get("action_operations")
            assert result is not None, "Required property 'action_operations' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionOperationProperty"]]], result)

        @builtins.property
        def custom_action_id(self) -> builtins.str:
            '''The ID of the ``VisualCustomAction`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-customactionid
            '''
            result = self._values.get("custom_action_id")
            assert result is not None, "Required property 'custom_action_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the ``VisualCustomAction`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def trigger(self) -> builtins.str:
            '''The trigger of the ``VisualCustomAction`` .

            Valid values are defined as follows:

            - ``DATA_POINT_CLICK`` : Initiates a custom action by a left pointer click on a data point.
            - ``DATA_POINT_MENU`` : Initiates a custom action by right pointer click from the menu.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-trigger
            '''
            result = self._values.get("trigger")
            assert result is not None, "Required property 'trigger' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the ``VisualCustomAction`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualCustomActionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.VisualPaletteProperty",
        jsii_struct_bases=[],
        name_mapping={"chart_color": "chartColor", "color_map": "colorMap"},
    )
    class VisualPaletteProperty:
        def __init__(
            self,
            *,
            chart_color: typing.Optional[builtins.str] = None,
            color_map: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataPathColorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The visual display options for the visual palette.

            :param chart_color: The chart color options for the visual palette.
            :param color_map: The color map options for the visual palette.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualpalette.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                visual_palette_property = quicksight.CfnAnalysis.VisualPaletteProperty(
                    chart_color="chartColor",
                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                        color="color",
                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                            data_path_type=quicksight.CfnAnalysis.DataPathTypeProperty(
                                pivot_table_data_path_type="pivotTableDataPathType"
                            ),
                            field_id="fieldId",
                            field_value="fieldValue"
                        ),
                
                        # the properties below are optional
                        time_granularity="timeGranularity"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ff6c93ffc3eca56e7f0801d3fa31d4e3847be4e43ecc2931cb65086f639b9ce3)
                check_type(argname="argument chart_color", value=chart_color, expected_type=type_hints["chart_color"])
                check_type(argname="argument color_map", value=color_map, expected_type=type_hints["color_map"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if chart_color is not None:
                self._values["chart_color"] = chart_color
            if color_map is not None:
                self._values["color_map"] = color_map

        @builtins.property
        def chart_color(self) -> typing.Optional[builtins.str]:
            '''The chart color options for the visual palette.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualpalette.html#cfn-quicksight-analysis-visualpalette-chartcolor
            '''
            result = self._values.get("chart_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def color_map(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataPathColorProperty"]]]]:
            '''The color map options for the visual palette.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualpalette.html#cfn-quicksight-analysis-visualpalette-colormap
            '''
            result = self._values.get("color_map")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataPathColorProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualPaletteProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.VisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_chart_visual": "barChartVisual",
            "box_plot_visual": "boxPlotVisual",
            "combo_chart_visual": "comboChartVisual",
            "custom_content_visual": "customContentVisual",
            "empty_visual": "emptyVisual",
            "filled_map_visual": "filledMapVisual",
            "funnel_chart_visual": "funnelChartVisual",
            "gauge_chart_visual": "gaugeChartVisual",
            "geospatial_map_visual": "geospatialMapVisual",
            "heat_map_visual": "heatMapVisual",
            "histogram_visual": "histogramVisual",
            "insight_visual": "insightVisual",
            "kpi_visual": "kpiVisual",
            "line_chart_visual": "lineChartVisual",
            "pie_chart_visual": "pieChartVisual",
            "pivot_table_visual": "pivotTableVisual",
            "radar_chart_visual": "radarChartVisual",
            "sankey_diagram_visual": "sankeyDiagramVisual",
            "scatter_plot_visual": "scatterPlotVisual",
            "table_visual": "tableVisual",
            "tree_map_visual": "treeMapVisual",
            "waterfall_visual": "waterfallVisual",
            "word_cloud_visual": "wordCloudVisual",
        },
    )
    class VisualProperty:
        def __init__(
            self,
            *,
            bar_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.BarChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            box_plot_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.BoxPlotVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            combo_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ComboChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_content_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.CustomContentVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            empty_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.EmptyVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            filled_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FilledMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            funnel_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FunnelChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            gauge_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GaugeChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            geospatial_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.GeospatialMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            heat_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.HeatMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            histogram_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.HistogramVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            insight_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.InsightVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            kpi_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.KPIVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            line_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LineChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            pie_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PieChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            pivot_table_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.PivotTableVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            radar_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.RadarChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sankey_diagram_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.SankeyDiagramVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scatter_plot_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ScatterPlotVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TableVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tree_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.TreeMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            waterfall_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.WaterfallVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            word_cloud_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.WordCloudVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A visual displayed on a sheet in an analysis, dashboard, or template.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param bar_chart_visual: A bar chart. For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param box_plot_visual: A box plot. For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .
            :param combo_chart_visual: A combo chart. For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param custom_content_visual: A visual that contains custom content. For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .
            :param empty_visual: An empty visual.
            :param filled_map_visual: A filled map. For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .
            :param funnel_chart_visual: A funnel chart. For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .
            :param gauge_chart_visual: A gauge chart. For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param geospatial_map_visual: A geospatial map or a points on map visual. For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .
            :param heat_map_visual: A heat map. For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .
            :param histogram_visual: A histogram. For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param insight_visual: An insight visual. For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .
            :param kpi_visual: A key performance indicator (KPI). For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .
            :param line_chart_visual: A line chart. For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param pie_chart_visual: A pie or donut chart. For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param pivot_table_visual: A pivot table. For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .
            :param radar_chart_visual: A radar chart visual. For more information, see `Using radar charts <https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param sankey_diagram_visual: A sankey diagram. For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .
            :param scatter_plot_visual: A scatter plot. For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .
            :param table_visual: A table visual. For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .
            :param tree_map_visual: A tree map. For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .
            :param waterfall_visual: A waterfall chart. For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param word_cloud_visual: A word cloud. For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f255411e656ca1f80f15bc1962254eae5a33e9f73c7698b1cc40068a94f39e20)
                check_type(argname="argument bar_chart_visual", value=bar_chart_visual, expected_type=type_hints["bar_chart_visual"])
                check_type(argname="argument box_plot_visual", value=box_plot_visual, expected_type=type_hints["box_plot_visual"])
                check_type(argname="argument combo_chart_visual", value=combo_chart_visual, expected_type=type_hints["combo_chart_visual"])
                check_type(argname="argument custom_content_visual", value=custom_content_visual, expected_type=type_hints["custom_content_visual"])
                check_type(argname="argument empty_visual", value=empty_visual, expected_type=type_hints["empty_visual"])
                check_type(argname="argument filled_map_visual", value=filled_map_visual, expected_type=type_hints["filled_map_visual"])
                check_type(argname="argument funnel_chart_visual", value=funnel_chart_visual, expected_type=type_hints["funnel_chart_visual"])
                check_type(argname="argument gauge_chart_visual", value=gauge_chart_visual, expected_type=type_hints["gauge_chart_visual"])
                check_type(argname="argument geospatial_map_visual", value=geospatial_map_visual, expected_type=type_hints["geospatial_map_visual"])
                check_type(argname="argument heat_map_visual", value=heat_map_visual, expected_type=type_hints["heat_map_visual"])
                check_type(argname="argument histogram_visual", value=histogram_visual, expected_type=type_hints["histogram_visual"])
                check_type(argname="argument insight_visual", value=insight_visual, expected_type=type_hints["insight_visual"])
                check_type(argname="argument kpi_visual", value=kpi_visual, expected_type=type_hints["kpi_visual"])
                check_type(argname="argument line_chart_visual", value=line_chart_visual, expected_type=type_hints["line_chart_visual"])
                check_type(argname="argument pie_chart_visual", value=pie_chart_visual, expected_type=type_hints["pie_chart_visual"])
                check_type(argname="argument pivot_table_visual", value=pivot_table_visual, expected_type=type_hints["pivot_table_visual"])
                check_type(argname="argument radar_chart_visual", value=radar_chart_visual, expected_type=type_hints["radar_chart_visual"])
                check_type(argname="argument sankey_diagram_visual", value=sankey_diagram_visual, expected_type=type_hints["sankey_diagram_visual"])
                check_type(argname="argument scatter_plot_visual", value=scatter_plot_visual, expected_type=type_hints["scatter_plot_visual"])
                check_type(argname="argument table_visual", value=table_visual, expected_type=type_hints["table_visual"])
                check_type(argname="argument tree_map_visual", value=tree_map_visual, expected_type=type_hints["tree_map_visual"])
                check_type(argname="argument waterfall_visual", value=waterfall_visual, expected_type=type_hints["waterfall_visual"])
                check_type(argname="argument word_cloud_visual", value=word_cloud_visual, expected_type=type_hints["word_cloud_visual"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_chart_visual is not None:
                self._values["bar_chart_visual"] = bar_chart_visual
            if box_plot_visual is not None:
                self._values["box_plot_visual"] = box_plot_visual
            if combo_chart_visual is not None:
                self._values["combo_chart_visual"] = combo_chart_visual
            if custom_content_visual is not None:
                self._values["custom_content_visual"] = custom_content_visual
            if empty_visual is not None:
                self._values["empty_visual"] = empty_visual
            if filled_map_visual is not None:
                self._values["filled_map_visual"] = filled_map_visual
            if funnel_chart_visual is not None:
                self._values["funnel_chart_visual"] = funnel_chart_visual
            if gauge_chart_visual is not None:
                self._values["gauge_chart_visual"] = gauge_chart_visual
            if geospatial_map_visual is not None:
                self._values["geospatial_map_visual"] = geospatial_map_visual
            if heat_map_visual is not None:
                self._values["heat_map_visual"] = heat_map_visual
            if histogram_visual is not None:
                self._values["histogram_visual"] = histogram_visual
            if insight_visual is not None:
                self._values["insight_visual"] = insight_visual
            if kpi_visual is not None:
                self._values["kpi_visual"] = kpi_visual
            if line_chart_visual is not None:
                self._values["line_chart_visual"] = line_chart_visual
            if pie_chart_visual is not None:
                self._values["pie_chart_visual"] = pie_chart_visual
            if pivot_table_visual is not None:
                self._values["pivot_table_visual"] = pivot_table_visual
            if radar_chart_visual is not None:
                self._values["radar_chart_visual"] = radar_chart_visual
            if sankey_diagram_visual is not None:
                self._values["sankey_diagram_visual"] = sankey_diagram_visual
            if scatter_plot_visual is not None:
                self._values["scatter_plot_visual"] = scatter_plot_visual
            if table_visual is not None:
                self._values["table_visual"] = table_visual
            if tree_map_visual is not None:
                self._values["tree_map_visual"] = tree_map_visual
            if waterfall_visual is not None:
                self._values["waterfall_visual"] = waterfall_visual
            if word_cloud_visual is not None:
                self._values["word_cloud_visual"] = word_cloud_visual

        @builtins.property
        def bar_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BarChartVisualProperty"]]:
            '''A bar chart.

            For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-barchartvisual
            '''
            result = self._values.get("bar_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BarChartVisualProperty"]], result)

        @builtins.property
        def box_plot_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BoxPlotVisualProperty"]]:
            '''A box plot.

            For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-boxplotvisual
            '''
            result = self._values.get("box_plot_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.BoxPlotVisualProperty"]], result)

        @builtins.property
        def combo_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ComboChartVisualProperty"]]:
            '''A combo chart.

            For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-combochartvisual
            '''
            result = self._values.get("combo_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ComboChartVisualProperty"]], result)

        @builtins.property
        def custom_content_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomContentVisualProperty"]]:
            '''A visual that contains custom content.

            For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-customcontentvisual
            '''
            result = self._values.get("custom_content_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.CustomContentVisualProperty"]], result)

        @builtins.property
        def empty_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.EmptyVisualProperty"]]:
            '''An empty visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-emptyvisual
            '''
            result = self._values.get("empty_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.EmptyVisualProperty"]], result)

        @builtins.property
        def filled_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilledMapVisualProperty"]]:
            '''A filled map.

            For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-filledmapvisual
            '''
            result = self._values.get("filled_map_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FilledMapVisualProperty"]], result)

        @builtins.property
        def funnel_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FunnelChartVisualProperty"]]:
            '''A funnel chart.

            For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-funnelchartvisual
            '''
            result = self._values.get("funnel_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FunnelChartVisualProperty"]], result)

        @builtins.property
        def gauge_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GaugeChartVisualProperty"]]:
            '''A gauge chart.

            For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-gaugechartvisual
            '''
            result = self._values.get("gauge_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GaugeChartVisualProperty"]], result)

        @builtins.property
        def geospatial_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialMapVisualProperty"]]:
            '''A geospatial map or a points on map visual.

            For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-geospatialmapvisual
            '''
            result = self._values.get("geospatial_map_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.GeospatialMapVisualProperty"]], result)

        @builtins.property
        def heat_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HeatMapVisualProperty"]]:
            '''A heat map.

            For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-heatmapvisual
            '''
            result = self._values.get("heat_map_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HeatMapVisualProperty"]], result)

        @builtins.property
        def histogram_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HistogramVisualProperty"]]:
            '''A histogram.

            For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-histogramvisual
            '''
            result = self._values.get("histogram_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.HistogramVisualProperty"]], result)

        @builtins.property
        def insight_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.InsightVisualProperty"]]:
            '''An insight visual.

            For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-insightvisual
            '''
            result = self._values.get("insight_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.InsightVisualProperty"]], result)

        @builtins.property
        def kpi_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIVisualProperty"]]:
            '''A key performance indicator (KPI).

            For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-kpivisual
            '''
            result = self._values.get("kpi_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.KPIVisualProperty"]], result)

        @builtins.property
        def line_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartVisualProperty"]]:
            '''A line chart.

            For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-linechartvisual
            '''
            result = self._values.get("line_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LineChartVisualProperty"]], result)

        @builtins.property
        def pie_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PieChartVisualProperty"]]:
            '''A pie or donut chart.

            For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-piechartvisual
            '''
            result = self._values.get("pie_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PieChartVisualProperty"]], result)

        @builtins.property
        def pivot_table_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableVisualProperty"]]:
            '''A pivot table.

            For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-pivottablevisual
            '''
            result = self._values.get("pivot_table_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.PivotTableVisualProperty"]], result)

        @builtins.property
        def radar_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RadarChartVisualProperty"]]:
            '''A radar chart visual.

            For more information, see `Using radar charts <https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-radarchartvisual
            '''
            result = self._values.get("radar_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.RadarChartVisualProperty"]], result)

        @builtins.property
        def sankey_diagram_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SankeyDiagramVisualProperty"]]:
            '''A sankey diagram.

            For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-sankeydiagramvisual
            '''
            result = self._values.get("sankey_diagram_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.SankeyDiagramVisualProperty"]], result)

        @builtins.property
        def scatter_plot_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ScatterPlotVisualProperty"]]:
            '''A scatter plot.

            For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-scatterplotvisual
            '''
            result = self._values.get("scatter_plot_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ScatterPlotVisualProperty"]], result)

        @builtins.property
        def table_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableVisualProperty"]]:
            '''A table visual.

            For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-tablevisual
            '''
            result = self._values.get("table_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TableVisualProperty"]], result)

        @builtins.property
        def tree_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TreeMapVisualProperty"]]:
            '''A tree map.

            For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-treemapvisual
            '''
            result = self._values.get("tree_map_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.TreeMapVisualProperty"]], result)

        @builtins.property
        def waterfall_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WaterfallVisualProperty"]]:
            '''A waterfall chart.

            For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-waterfallvisual
            '''
            result = self._values.get("waterfall_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WaterfallVisualProperty"]], result)

        @builtins.property
        def word_cloud_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WordCloudVisualProperty"]]:
            '''A word cloud.

            For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-wordcloudvisual
            '''
            result = self._values.get("word_cloud_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WordCloudVisualProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"format_text": "formatText", "visibility": "visibility"},
    )
    class VisualSubtitleLabelOptionsProperty:
        def __init__(
            self,
            *,
            format_text: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LongFormatTextProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The subtitle label options for a visual.

            :param format_text: The long text format of the subtitle label, such as plain text or rich text.
            :param visibility: The visibility of the subtitle label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualsubtitlelabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                visual_subtitle_label_options_property = quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                        plain_text="plainText",
                        rich_text="richText"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d683e2ad0f21809d44229a086ce440f5462ae165dd3a315ab74869b0e5b0b762)
                check_type(argname="argument format_text", value=format_text, expected_type=type_hints["format_text"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_text is not None:
                self._values["format_text"] = format_text
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def format_text(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LongFormatTextProperty"]]:
            '''The long text format of the subtitle label, such as plain text or rich text.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualsubtitlelabeloptions.html#cfn-quicksight-analysis-visualsubtitlelabeloptions-formattext
            '''
            result = self._values.get("format_text")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LongFormatTextProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the subtitle label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualsubtitlelabeloptions.html#cfn-quicksight-analysis-visualsubtitlelabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualSubtitleLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"format_text": "formatText", "visibility": "visibility"},
    )
    class VisualTitleLabelOptionsProperty:
        def __init__(
            self,
            *,
            format_text: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ShortFormatTextProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The title label options for a visual.

            :param format_text: The short text format of the title label, such as plain text or rich text.
            :param visibility: The visibility of the title label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualtitlelabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                visual_title_label_options_property = quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                        plain_text="plainText",
                        rich_text="richText"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9883ad736a97a666a3231edbd524ba550df305268911cf601e2ca8c945ed4162)
                check_type(argname="argument format_text", value=format_text, expected_type=type_hints["format_text"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_text is not None:
                self._values["format_text"] = format_text
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def format_text(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ShortFormatTextProperty"]]:
            '''The short text format of the title label, such as plain text or rich text.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualtitlelabeloptions.html#cfn-quicksight-analysis-visualtitlelabeloptions-formattext
            '''
            result = self._values.get("format_text")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ShortFormatTextProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the title label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualtitlelabeloptions.html#cfn-quicksight-analysis-visualtitlelabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualTitleLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "breakdowns": "breakdowns",
            "categories": "categories",
            "values": "values",
        },
    )
    class WaterfallChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            breakdowns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            categories: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a waterfall visual.

            :param breakdowns: The breakdown field wells of a waterfall visual.
            :param categories: The category field wells of a waterfall visual.
            :param values: The value field wells of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__343b90d1d1f60be1da3b32504455647c43c866d0cd8d04ce82e70d749476640d)
                check_type(argname="argument breakdowns", value=breakdowns, expected_type=type_hints["breakdowns"])
                check_type(argname="argument categories", value=categories, expected_type=type_hints["categories"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if breakdowns is not None:
                self._values["breakdowns"] = breakdowns
            if categories is not None:
                self._values["categories"] = categories
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def breakdowns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The breakdown field wells of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartaggregatedfieldwells.html#cfn-quicksight-analysis-waterfallchartaggregatedfieldwells-breakdowns
            '''
            result = self._values.get("breakdowns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def categories(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The category field wells of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartaggregatedfieldwells.html#cfn-quicksight-analysis-waterfallchartaggregatedfieldwells-categories
            '''
            result = self._values.get("categories")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The value field wells of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartaggregatedfieldwells.html#cfn-quicksight-analysis-waterfallchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.WaterfallChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_axis_display_options": "categoryAxisDisplayOptions",
            "category_axis_label_options": "categoryAxisLabelOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "sort_configuration": "sortConfiguration",
            "visual_palette": "visualPalette",
            "waterfall_chart_options": "waterfallChartOptions",
        },
    )
    class WaterfallChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.WaterfallChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.WaterfallChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            waterfall_chart_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.WaterfallChartOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a waterfall visual.

            :param category_axis_display_options: The options that determine the presentation of the category axis.
            :param category_axis_label_options: The options that determine the presentation of the category axis label.
            :param data_labels: The data label configuration of a waterfall visual.
            :param field_wells: The field well configuration of a waterfall visual.
            :param legend: The legend configuration of a waterfall visual.
            :param primary_y_axis_display_options: The options that determine the presentation of the y-axis.
            :param primary_y_axis_label_options: The options that determine the presentation of the y-axis label.
            :param sort_configuration: The sort configuration of a waterfall visual.
            :param visual_palette: The visual palette configuration of a waterfall visual.
            :param waterfall_chart_options: The options that determine the presentation of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__75ae0cd00a859a42a1332a4d93c1d71b4e79cc32c4fc2987b7e7ce1a632b86ba)
                check_type(argname="argument category_axis_display_options", value=category_axis_display_options, expected_type=type_hints["category_axis_display_options"])
                check_type(argname="argument category_axis_label_options", value=category_axis_label_options, expected_type=type_hints["category_axis_label_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument waterfall_chart_options", value=waterfall_chart_options, expected_type=type_hints["waterfall_chart_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_axis_display_options is not None:
                self._values["category_axis_display_options"] = category_axis_display_options
            if category_axis_label_options is not None:
                self._values["category_axis_label_options"] = category_axis_label_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if waterfall_chart_options is not None:
                self._values["waterfall_chart_options"] = waterfall_chart_options

        @builtins.property
        def category_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the category axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-categoryaxisdisplayoptions
            '''
            result = self._values.get("category_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the category axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-categoryaxislabeloptions
            '''
            result = self._values.get("category_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The data label configuration of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WaterfallChartFieldWellsProperty"]]:
            '''The field well configuration of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WaterfallChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend configuration of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WaterfallChartSortConfigurationProperty"]]:
            '''The sort configuration of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WaterfallChartSortConfigurationProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The visual palette configuration of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualPaletteProperty"]], result)

        @builtins.property
        def waterfall_chart_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WaterfallChartOptionsProperty"]]:
            '''The options that determine the presentation of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-waterfallchartoptions
            '''
            result = self._values.get("waterfall_chart_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WaterfallChartOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.WaterfallChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "waterfall_chart_aggregated_field_wells": "waterfallChartAggregatedFieldWells",
        },
    )
    class WaterfallChartFieldWellsProperty:
        def __init__(
            self,
            *,
            waterfall_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a waterfall visual.

            :param waterfall_chart_aggregated_field_wells: The field well configuration of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7ec4f9ec60221194aff4531500e7d5af0acea034a948f159b18d9fe6ecaf54c0)
                check_type(argname="argument waterfall_chart_aggregated_field_wells", value=waterfall_chart_aggregated_field_wells, expected_type=type_hints["waterfall_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if waterfall_chart_aggregated_field_wells is not None:
                self._values["waterfall_chart_aggregated_field_wells"] = waterfall_chart_aggregated_field_wells

        @builtins.property
        def waterfall_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartfieldwells.html#cfn-quicksight-analysis-waterfallchartfieldwells-waterfallchartaggregatedfieldwells
            '''
            result = self._values.get("waterfall_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.WaterfallChartOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"total_bar_label": "totalBarLabel"},
    )
    class WaterfallChartOptionsProperty:
        def __init__(
            self,
            *,
            total_bar_label: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of a waterfall visual.

            :param total_bar_label: This option determines the total bar label of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                waterfall_chart_options_property = quicksight.CfnAnalysis.WaterfallChartOptionsProperty(
                    total_bar_label="totalBarLabel"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8e5d92a2cd1f949db1beff67c02d8dd87b474b8230ee6de91d7c93aeaacf647e)
                check_type(argname="argument total_bar_label", value=total_bar_label, expected_type=type_hints["total_bar_label"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if total_bar_label is not None:
                self._values["total_bar_label"] = total_bar_label

        @builtins.property
        def total_bar_label(self) -> typing.Optional[builtins.str]:
            '''This option determines the total bar label of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartoptions.html#cfn-quicksight-analysis-waterfallchartoptions-totalbarlabel
            '''
            result = self._values.get("total_bar_label")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.WaterfallChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "breakdown_items_limit": "breakdownItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class WaterfallChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            breakdown_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a waterfall visual.

            :param breakdown_items_limit: The limit on the number of bar groups that are displayed.
            :param category_sort: The sort configuration of the category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                waterfall_chart_sort_configuration_property = quicksight.CfnAnalysis.WaterfallChartSortConfigurationProperty(
                    breakdown_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6f35cc442456795e1468b1cc1cde921a548f247049594e35047bd94da4729cab)
                check_type(argname="argument breakdown_items_limit", value=breakdown_items_limit, expected_type=type_hints["breakdown_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if breakdown_items_limit is not None:
                self._values["breakdown_items_limit"] = breakdown_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def breakdown_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of bar groups that are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartsortconfiguration.html#cfn-quicksight-analysis-waterfallchartsortconfiguration-breakdownitemslimit
            '''
            result = self._values.get("breakdown_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartsortconfiguration.html#cfn-quicksight-analysis-waterfallchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.WaterfallVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class WaterfallVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.WaterfallChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A waterfall chart.

            For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration for a waterfall visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bf59b78ee88dbb638d6c2a941030ec8725a7095b2ae1c9a64b544ca521444d12)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WaterfallChartConfigurationProperty"]]:
            '''The configuration for a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WaterfallChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.WhatIfPointScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={"date": "date", "value": "value"},
    )
    class WhatIfPointScenarioProperty:
        def __init__(self, *, date: builtins.str, value: jsii.Number) -> None:
            '''Provides the forecast to meet the target for a particular date.

            :param date: The date that you need the forecast results for.
            :param value: The target value that you want to meet for the provided date. Default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifpointscenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                what_if_point_scenario_property = quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                    date="date",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__52aff22a9290b492f489ce7b770ce0dc729b9674414758e503ba5b8bcc95233b)
                check_type(argname="argument date", value=date, expected_type=type_hints["date"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "date": date,
                "value": value,
            }

        @builtins.property
        def date(self) -> builtins.str:
            '''The date that you need the forecast results for.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifpointscenario.html#cfn-quicksight-analysis-whatifpointscenario-date
            '''
            result = self._values.get("date")
            assert result is not None, "Required property 'date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The target value that you want to meet for the provided date.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifpointscenario.html#cfn-quicksight-analysis-whatifpointscenario-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WhatIfPointScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.WhatIfRangeScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={
            "end_date": "endDate",
            "start_date": "startDate",
            "value": "value",
        },
    )
    class WhatIfRangeScenarioProperty:
        def __init__(
            self,
            *,
            end_date: builtins.str,
            start_date: builtins.str,
            value: jsii.Number,
        ) -> None:
            '''Provides the forecast to meet the target for a particular date range.

            :param end_date: The end date in the date range that you need the forecast results for.
            :param start_date: The start date in the date range that you need the forecast results for.
            :param value: The target value that you want to meet for the provided date range. Default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifrangescenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                what_if_range_scenario_property = quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                    end_date="endDate",
                    start_date="startDate",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__92496b50237d86b48e4daf1d174f99a542d6b83b3ccfa0138826df49d28221a8)
                check_type(argname="argument end_date", value=end_date, expected_type=type_hints["end_date"])
                check_type(argname="argument start_date", value=start_date, expected_type=type_hints["start_date"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "end_date": end_date,
                "start_date": start_date,
                "value": value,
            }

        @builtins.property
        def end_date(self) -> builtins.str:
            '''The end date in the date range that you need the forecast results for.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifrangescenario.html#cfn-quicksight-analysis-whatifrangescenario-enddate
            '''
            result = self._values.get("end_date")
            assert result is not None, "Required property 'end_date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def start_date(self) -> builtins.str:
            '''The start date in the date range that you need the forecast results for.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifrangescenario.html#cfn-quicksight-analysis-whatifrangescenario-startdate
            '''
            result = self._values.get("start_date")
            assert result is not None, "Required property 'start_date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The target value that you want to meet for the provided date range.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifrangescenario.html#cfn-quicksight-analysis-whatifrangescenario-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WhatIfRangeScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "size": "size"},
    )
    class WordCloudAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a word cloud.

            :param group_by: The group by field well of a word cloud. Values are grouped by group by fields.
            :param size: The size field well of a word cloud. Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                word_cloud_aggregated_field_wells_property = quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__373a402df7e927c2c85e65fa94a21613232d0a972e423ade32a703dc3b1a4ced)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if size is not None:
                self._values["size"] = size

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The group by field well of a word cloud.

            Values are grouped by group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudaggregatedfieldwells.html#cfn-quicksight-analysis-wordcloudaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The size field well of a word cloud.

            Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudaggregatedfieldwells.html#cfn-quicksight-analysis-wordcloudaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.WordCloudChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
            "word_cloud_options": "wordCloudOptions",
        },
    )
    class WordCloudChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.WordCloudFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.WordCloudSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            word_cloud_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.WordCloudOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a word cloud visual.

            :param category_label_options: The label options (label text, label visibility, and sort icon visibility) for the word cloud category.
            :param field_wells: The field wells of the visual.
            :param sort_configuration: The sort configuration of a word cloud visual.
            :param word_cloud_options: The options for a word cloud visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c61f02db0f5b87a3117c8981ab8e656e1cb96625e8bdd63f06db8c476b3f4298)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument word_cloud_options", value=word_cloud_options, expected_type=type_hints["word_cloud_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if word_cloud_options is not None:
                self._values["word_cloud_options"] = word_cloud_options

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) for the word cloud category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html#cfn-quicksight-analysis-wordcloudchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WordCloudFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html#cfn-quicksight-analysis-wordcloudchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WordCloudFieldWellsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WordCloudSortConfigurationProperty"]]:
            '''The sort configuration of a word cloud visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html#cfn-quicksight-analysis-wordcloudchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WordCloudSortConfigurationProperty"]], result)

        @builtins.property
        def word_cloud_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WordCloudOptionsProperty"]]:
            '''The options for a word cloud visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html#cfn-quicksight-analysis-wordcloudchartconfiguration-wordcloudoptions
            '''
            result = self._values.get("word_cloud_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WordCloudOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.WordCloudFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "word_cloud_aggregated_field_wells": "wordCloudAggregatedFieldWells",
        },
    )
    class WordCloudFieldWellsProperty:
        def __init__(
            self,
            *,
            word_cloud_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.WordCloudAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a word cloud visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param word_cloud_aggregated_field_wells: The aggregated field wells of a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                word_cloud_field_wells_property = quicksight.CfnAnalysis.WordCloudFieldWellsProperty(
                    word_cloud_aggregated_field_wells=quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3f7474daf95a3ffcf615923aa66f95fa514281ad7c6a888ec688e31f801b6b7a)
                check_type(argname="argument word_cloud_aggregated_field_wells", value=word_cloud_aggregated_field_wells, expected_type=type_hints["word_cloud_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if word_cloud_aggregated_field_wells is not None:
                self._values["word_cloud_aggregated_field_wells"] = word_cloud_aggregated_field_wells

        @builtins.property
        def word_cloud_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WordCloudAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudfieldwells.html#cfn-quicksight-analysis-wordcloudfieldwells-wordcloudaggregatedfieldwells
            '''
            result = self._values.get("word_cloud_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WordCloudAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.WordCloudOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cloud_layout": "cloudLayout",
            "maximum_string_length": "maximumStringLength",
            "word_casing": "wordCasing",
            "word_orientation": "wordOrientation",
            "word_padding": "wordPadding",
            "word_scaling": "wordScaling",
        },
    )
    class WordCloudOptionsProperty:
        def __init__(
            self,
            *,
            cloud_layout: typing.Optional[builtins.str] = None,
            maximum_string_length: typing.Optional[jsii.Number] = None,
            word_casing: typing.Optional[builtins.str] = None,
            word_orientation: typing.Optional[builtins.str] = None,
            word_padding: typing.Optional[builtins.str] = None,
            word_scaling: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The word cloud options for a word cloud visual.

            :param cloud_layout: The cloud layout options (fluid, normal) of a word cloud.
            :param maximum_string_length: The length limit of each word from 1-100.
            :param word_casing: The word casing options (lower_case, existing_case) for the words in a word cloud.
            :param word_orientation: The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.
            :param word_padding: The word padding options (none, small, medium, large) for the words in a word cloud.
            :param word_scaling: The word scaling options (emphasize, normal) for the words in a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                word_cloud_options_property = quicksight.CfnAnalysis.WordCloudOptionsProperty(
                    cloud_layout="cloudLayout",
                    maximum_string_length=123,
                    word_casing="wordCasing",
                    word_orientation="wordOrientation",
                    word_padding="wordPadding",
                    word_scaling="wordScaling"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a5fe959060fd86dc83a2189d6257e9981928a92b0c4ed0b8683201c03e90770c)
                check_type(argname="argument cloud_layout", value=cloud_layout, expected_type=type_hints["cloud_layout"])
                check_type(argname="argument maximum_string_length", value=maximum_string_length, expected_type=type_hints["maximum_string_length"])
                check_type(argname="argument word_casing", value=word_casing, expected_type=type_hints["word_casing"])
                check_type(argname="argument word_orientation", value=word_orientation, expected_type=type_hints["word_orientation"])
                check_type(argname="argument word_padding", value=word_padding, expected_type=type_hints["word_padding"])
                check_type(argname="argument word_scaling", value=word_scaling, expected_type=type_hints["word_scaling"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cloud_layout is not None:
                self._values["cloud_layout"] = cloud_layout
            if maximum_string_length is not None:
                self._values["maximum_string_length"] = maximum_string_length
            if word_casing is not None:
                self._values["word_casing"] = word_casing
            if word_orientation is not None:
                self._values["word_orientation"] = word_orientation
            if word_padding is not None:
                self._values["word_padding"] = word_padding
            if word_scaling is not None:
                self._values["word_scaling"] = word_scaling

        @builtins.property
        def cloud_layout(self) -> typing.Optional[builtins.str]:
            '''The cloud layout options (fluid, normal) of a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-cloudlayout
            '''
            result = self._values.get("cloud_layout")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def maximum_string_length(self) -> typing.Optional[jsii.Number]:
            '''The length limit of each word from 1-100.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-maximumstringlength
            '''
            result = self._values.get("maximum_string_length")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def word_casing(self) -> typing.Optional[builtins.str]:
            '''The word casing options (lower_case, existing_case) for the words in a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-wordcasing
            '''
            result = self._values.get("word_casing")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_orientation(self) -> typing.Optional[builtins.str]:
            '''The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-wordorientation
            '''
            result = self._values.get("word_orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_padding(self) -> typing.Optional[builtins.str]:
            '''The word padding options (none, small, medium, large) for the words in a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-wordpadding
            '''
            result = self._values.get("word_padding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_scaling(self) -> typing.Optional[builtins.str]:
            '''The word scaling options (emphasize, normal) for the words in a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-wordscaling
            '''
            result = self._values.get("word_scaling")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.WordCloudSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class WordCloudSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a word cloud visual.

            :param category_items_limit: The limit on the number of groups that are displayed in a word cloud.
            :param category_sort: The sort configuration of group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                word_cloud_sort_configuration_property = quicksight.CfnAnalysis.WordCloudSortConfigurationProperty(
                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnAnalysis.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0904993cf85c74d5ad6d90c98ebddc9295efd54a60aa45dac229ea25f0697daf)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of groups that are displayed in a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudsortconfiguration.html#cfn-quicksight-analysis-wordcloudsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudsortconfiguration.html#cfn-quicksight-analysis-wordcloudsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysis.WordCloudVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class WordCloudVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.WordCloudChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A word cloud.

            For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0d8cc190e86df93e83a4af8c07e28d53ce2bd0cfe3305e61db3cfef703acd44d)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WordCloudChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.WordCloudChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="aws-cdk-lib.aws_quicksight.CfnAnalysisProps",
    jsii_struct_bases=[],
    name_mapping={
        "analysis_id": "analysisId",
        "aws_account_id": "awsAccountId",
        "name": "name",
        "definition": "definition",
        "errors": "errors",
        "parameters": "parameters",
        "permissions": "permissions",
        "sheets": "sheets",
        "source_entity": "sourceEntity",
        "status": "status",
        "tags": "tags",
        "theme_arn": "themeArn",
        "validation_strategy": "validationStrategy",
    },
)
class CfnAnalysisProps:
    def __init__(
        self,
        *,
        analysis_id: builtins.str,
        aws_account_id: builtins.str,
        name: builtins.str,
        definition: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AnalysisDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        errors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AnalysisErrorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        sheets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SheetProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        source_entity: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AnalysisSourceEntityProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        status: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
        theme_arn: typing.Optional[builtins.str] = None,
        validation_strategy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ValidationStrategyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    ) -> None:
        '''Properties for defining a ``CfnAnalysis``.

        :param analysis_id: The ID for the analysis that you're creating. This ID displays in the URL of the analysis.
        :param aws_account_id: The ID of the AWS account where you are creating an analysis.
        :param name: A descriptive name for the analysis that you're creating. This name displays for the analysis in the Amazon QuickSight console.
        :param definition: 
        :param errors: Errors associated with the analysis.
        :param parameters: The parameter names and override values that you want to use. An analysis can have any parameter type, and some parameters might accept multiple values.
        :param permissions: A structure that describes the principals and the resource-level permissions on an analysis. You can use the ``Permissions`` structure to grant permissions by providing a list of AWS Identity and Access Management (IAM) action information for each principal listed by Amazon Resource Name (ARN). To specify no permissions, omit ``Permissions`` .
        :param sheets: A list of the associated sheets with the unique identifier and name of each sheet.
        :param source_entity: A source entity to use for the analysis that you're creating. This metadata structure contains details that describe a source template and one or more datasets. Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.
        :param status: Status associated with the analysis.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.
        :param theme_arn: The ARN for the theme to apply to the analysis that you're creating. To see the theme in the Amazon QuickSight console, make sure that you have access to it.
        :param validation_strategy: The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects. When you set this value to ``LENIENT`` , validation is skipped for specific errors.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html
        :exampleMetadata: fixture=_generated

        Example::

            
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__abc87c90adc8752b5b24a67c2541ecb565aedcfc0265e29359b671502ad3539f)
            check_type(argname="argument analysis_id", value=analysis_id, expected_type=type_hints["analysis_id"])
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument definition", value=definition, expected_type=type_hints["definition"])
            check_type(argname="argument errors", value=errors, expected_type=type_hints["errors"])
            check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
            check_type(argname="argument permissions", value=permissions, expected_type=type_hints["permissions"])
            check_type(argname="argument sheets", value=sheets, expected_type=type_hints["sheets"])
            check_type(argname="argument source_entity", value=source_entity, expected_type=type_hints["source_entity"])
            check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument theme_arn", value=theme_arn, expected_type=type_hints["theme_arn"])
            check_type(argname="argument validation_strategy", value=validation_strategy, expected_type=type_hints["validation_strategy"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "analysis_id": analysis_id,
            "aws_account_id": aws_account_id,
            "name": name,
        }
        if definition is not None:
            self._values["definition"] = definition
        if errors is not None:
            self._values["errors"] = errors
        if parameters is not None:
            self._values["parameters"] = parameters
        if permissions is not None:
            self._values["permissions"] = permissions
        if sheets is not None:
            self._values["sheets"] = sheets
        if source_entity is not None:
            self._values["source_entity"] = source_entity
        if status is not None:
            self._values["status"] = status
        if tags is not None:
            self._values["tags"] = tags
        if theme_arn is not None:
            self._values["theme_arn"] = theme_arn
        if validation_strategy is not None:
            self._values["validation_strategy"] = validation_strategy

    @builtins.property
    def analysis_id(self) -> builtins.str:
        '''The ID for the analysis that you're creating.

        This ID displays in the URL of the analysis.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-analysisid
        '''
        result = self._values.get("analysis_id")
        assert result is not None, "Required property 'analysis_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aws_account_id(self) -> builtins.str:
        '''The ID of the AWS account where you are creating an analysis.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        assert result is not None, "Required property 'aws_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''A descriptive name for the analysis that you're creating.

        This name displays for the analysis in the Amazon QuickSight console.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-name
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def definition(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnAnalysis.AnalysisDefinitionProperty]]:
        '''
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-definition
        '''
        result = self._values.get("definition")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnAnalysis.AnalysisDefinitionProperty]], result)

    @builtins.property
    def errors(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnAnalysis.AnalysisErrorProperty]]]]:
        '''Errors associated with the analysis.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-errors
        '''
        result = self._values.get("errors")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnAnalysis.AnalysisErrorProperty]]]], result)

    @builtins.property
    def parameters(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnAnalysis.ParametersProperty]]:
        '''The parameter names and override values that you want to use.

        An analysis can have any parameter type, and some parameters might accept multiple values.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-parameters
        '''
        result = self._values.get("parameters")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnAnalysis.ParametersProperty]], result)

    @builtins.property
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnAnalysis.ResourcePermissionProperty]]]]:
        '''A structure that describes the principals and the resource-level permissions on an analysis.

        You can use the ``Permissions`` structure to grant permissions by providing a list of AWS Identity and Access Management (IAM) action information for each principal listed by Amazon Resource Name (ARN).

        To specify no permissions, omit ``Permissions`` .

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-permissions
        '''
        result = self._values.get("permissions")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnAnalysis.ResourcePermissionProperty]]]], result)

    @builtins.property
    def sheets(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnAnalysis.SheetProperty]]]]:
        '''A list of the associated sheets with the unique identifier and name of each sheet.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-sheets
        '''
        result = self._values.get("sheets")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnAnalysis.SheetProperty]]]], result)

    @builtins.property
    def source_entity(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnAnalysis.AnalysisSourceEntityProperty]]:
        '''A source entity to use for the analysis that you're creating.

        This metadata structure contains details that describe a source template and one or more datasets.

        Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-sourceentity
        '''
        result = self._values.get("source_entity")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnAnalysis.AnalysisSourceEntityProperty]], result)

    @builtins.property
    def status(self) -> typing.Optional[builtins.str]:
        '''Status associated with the analysis.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-status
        '''
        result = self._values.get("status")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[_CfnTag_f6864754]]:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-tags
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[_CfnTag_f6864754]], result)

    @builtins.property
    def theme_arn(self) -> typing.Optional[builtins.str]:
        '''The ARN for the theme to apply to the analysis that you're creating.

        To see the theme in the Amazon QuickSight console, make sure that you have access to it.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-themearn
        '''
        result = self._values.get("theme_arn")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def validation_strategy(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnAnalysis.ValidationStrategyProperty]]:
        '''The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects.

        When you set this value to ``LENIENT`` , validation is skipped for specific errors.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-validationstrategy
        '''
        result = self._values.get("validation_strategy")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnAnalysis.ValidationStrategyProperty]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnAnalysisProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_IInspectable_c2943556, _ITaggable_36806126)
class CfnDashboard(
    _CfnResource_9df397a6,
    metaclass=jsii.JSIIMeta,
    jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard",
):
    '''Creates a dashboard from a template. To first create a template, see the ``CreateTemplate`` API operation.

    A dashboard is an entity in Amazon QuickSight that identifies Amazon QuickSight reports, created from analyses. You can share Amazon QuickSight dashboards. With the right permissions, you can create scheduled email reports from them. If you have the correct permissions, you can create a dashboard from a template that exists in a different AWS account .

    :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html
    :cloudformationResource: AWS::QuickSight::Dashboard
    :exampleMetadata: fixture=_generated

    Example::

        
    '''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.Construct,
        id: builtins.str,
        *,
        aws_account_id: builtins.str,
        dashboard_id: builtins.str,
        name: builtins.str,
        dashboard_publish_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DashboardPublishOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        definition: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DashboardVersionDefinitionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        link_sharing_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LinkSharingConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ResourcePermissionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        source_entity: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DashboardSourceEntityProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
        theme_arn: typing.Optional[builtins.str] = None,
        validation_strategy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ValidationStrategyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        version_description: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param scope: Scope in which this resource is defined.
        :param id: Construct identifier for this resource (unique in its scope).
        :param aws_account_id: The ID of the AWS account where you want to create the dashboard.
        :param dashboard_id: The ID for the dashboard, also added to the IAM policy.
        :param name: The display name of the dashboard.
        :param dashboard_publish_options: Options for publishing the dashboard when you create it:. - ``AvailabilityStatus`` for ``AdHocFilteringOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . When this is set to ``DISABLED`` , Amazon QuickSight disables the left filter pane on the published dashboard, which can be used for ad hoc (one-time) filtering. This option is ``ENABLED`` by default. - ``AvailabilityStatus`` for ``ExportToCSVOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . The visual option to export data to .CSV format isn't enabled when this is set to ``DISABLED`` . This option is ``ENABLED`` by default. - ``VisibilityState`` for ``SheetControlsOption`` - This visibility state can be either ``COLLAPSED`` or ``EXPANDED`` . This option is ``COLLAPSED`` by default.
        :param definition: 
        :param link_sharing_configuration: A structure that contains the link sharing configurations that you want to apply overrides to.
        :param parameters: The parameters for the creation of the dashboard, which you want to use to override the default settings. A dashboard can have any type of parameters, and some parameters might accept multiple values.
        :param permissions: A structure that contains the permissions of the dashboard. You can use this structure for granting permissions by providing a list of IAM action information for each principal ARN. To specify no permissions, omit the permissions list.
        :param source_entity: The entity that you are using as a source when you create the dashboard. In ``SourceEntity`` , you specify the type of object that you want to use. You can only create a dashboard from a template, so you use a ``SourceTemplate`` entity. If you need to create a dashboard from an analysis, first convert the analysis to a template by using the ``CreateTemplate`` API operation. For ``SourceTemplate`` , specify the Amazon Resource Name (ARN) of the source template. The ``SourceTemplate`` ARN can contain any AWS account; and any QuickSight-supported AWS Region . Use the ``DataSetReferences`` entity within ``SourceTemplate`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the dashboard.
        :param theme_arn: The Amazon Resource Name (ARN) of the theme that is being used for this dashboard. If you add a value for this field, it overrides the value that is used in the source entity. The theme ARN must exist in the same AWS account where you create the dashboard.
        :param validation_strategy: The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects. When you set this value to ``LENIENT`` , validation is skipped for specific errors.
        :param version_description: A description for the first version of the dashboard being created.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fb817240753e3d59e412d7399827ca12667d95592c4f14cac4aa2bc90e05aac9)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnDashboardProps(
            aws_account_id=aws_account_id,
            dashboard_id=dashboard_id,
            name=name,
            dashboard_publish_options=dashboard_publish_options,
            definition=definition,
            link_sharing_configuration=link_sharing_configuration,
            parameters=parameters,
            permissions=permissions,
            source_entity=source_entity,
            tags=tags,
            theme_arn=theme_arn,
            validation_strategy=validation_strategy,
            version_description=version_description,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _TreeInspector_488e0dd5) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__412eac5ba9b84fad29d3fb0fc5bc08a39c12fde7fe443b5d36f14a92962aa789)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__97bb1e16e0dd8cb01d1fd3d923b8a8a113088cdb29859897b478c5f49b7473fa)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) of the dashboard.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="attrCreatedTime")
    def attr_created_time(self) -> builtins.str:
        '''The time this dashboard version was created.

        :cloudformationAttribute: CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrLastPublishedTime")
    def attr_last_published_time(self) -> builtins.str:
        '''The time that the dashboard was last published.

        :cloudformationAttribute: LastPublishedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastPublishedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrLastUpdatedTime")
    def attr_last_updated_time(self) -> builtins.str:
        '''The time that the dashboard was last updated.

        :cloudformationAttribute: LastUpdatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastUpdatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrVersion")
    def attr_version(self) -> _IResolvable_da3f097b:
        '''The version of the dashboard.

        :cloudformationAttribute: Version
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrVersion"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionArn")
    def attr_version_arn(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionArn"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionCreatedTime")
    def attr_version_created_time(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionDataSetArns")
    def attr_version_data_set_arns(self) -> typing.List[builtins.str]:
        '''
        :cloudformationAttribute: Version.DataSetArns
        '''
        return typing.cast(typing.List[builtins.str], jsii.get(self, "attrVersionDataSetArns"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionDescription")
    def attr_version_description(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Description
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionDescription"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionErrors")
    def attr_version_errors(self) -> _IResolvable_da3f097b:
        '''
        :cloudformationAttribute: Version.Errors
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrVersionErrors"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionSheets")
    def attr_version_sheets(self) -> _IResolvable_da3f097b:
        '''
        :cloudformationAttribute: Version.Sheets
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrVersionSheets"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionSourceEntityArn")
    def attr_version_source_entity_arn(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.SourceEntityArn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionSourceEntityArn"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionStatus")
    def attr_version_status(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Status
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionStatus"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionThemeArn")
    def attr_version_theme_arn(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.ThemeArn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionThemeArn"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionVersionNumber")
    def attr_version_version_number(self) -> _IResolvable_da3f097b:
        '''
        :cloudformationAttribute: Version.VersionNumber
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrVersionVersionNumber"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> _TagManager_0a598cb3:
        '''Tag Manager which manages the tags for this resource.'''
        return typing.cast(_TagManager_0a598cb3, jsii.get(self, "tags"))

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> builtins.str:
        '''The ID of the AWS account where you want to create the dashboard.'''
        return typing.cast(builtins.str, jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__615e0bd2b1c3bd4595e9d0ea4ed6f68b41ca848ac8c3c1cf2ba39792a8771b44)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="dashboardId")
    def dashboard_id(self) -> builtins.str:
        '''The ID for the dashboard, also added to the IAM policy.'''
        return typing.cast(builtins.str, jsii.get(self, "dashboardId"))

    @dashboard_id.setter
    def dashboard_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c89a833c31b0fc06912b32690c09f2a8802775534838f0ffbef4ea3672c0ea9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dashboardId", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        '''The display name of the dashboard.'''
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c30d525ed240c5dd3551080fdf34334a76db433f35c8086308f632d5e12516f9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="dashboardPublishOptions")
    def dashboard_publish_options(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DashboardPublishOptionsProperty"]]:
        '''Options for publishing the dashboard when you create it:.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DashboardPublishOptionsProperty"]], jsii.get(self, "dashboardPublishOptions"))

    @dashboard_publish_options.setter
    def dashboard_publish_options(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DashboardPublishOptionsProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6922d759425c2e9eea8660b1308a87edb23ef8f1ae2ac877cff87014f13b9343)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dashboardPublishOptions", value)

    @builtins.property
    @jsii.member(jsii_name="definition")
    def definition(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DashboardVersionDefinitionProperty"]]:
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DashboardVersionDefinitionProperty"]], jsii.get(self, "definition"))

    @definition.setter
    def definition(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DashboardVersionDefinitionProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__401dc566ec96e95f727379b41bac659021acc2d797b3988116201d56fa8c05d8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "definition", value)

    @builtins.property
    @jsii.member(jsii_name="linkSharingConfiguration")
    def link_sharing_configuration(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LinkSharingConfigurationProperty"]]:
        '''A structure that contains the link sharing configurations that you want to apply overrides to.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LinkSharingConfigurationProperty"]], jsii.get(self, "linkSharingConfiguration"))

    @link_sharing_configuration.setter
    def link_sharing_configuration(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LinkSharingConfigurationProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7fda2bf7eb1470e85b100b1d47852c3742a93f9f7e2b54931f0b4796a4e232a7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "linkSharingConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="parameters")
    def parameters(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParametersProperty"]]:
        '''The parameters for the creation of the dashboard, which you want to use to override the default settings.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParametersProperty"]], jsii.get(self, "parameters"))

    @parameters.setter
    def parameters(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParametersProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2bf4c69a2a3050bf7570d3061c6ad8502b1f961fd6c97d7c1485c095c648aea2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "parameters", value)

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ResourcePermissionProperty"]]]]:
        '''A structure that contains the permissions of the dashboard.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ResourcePermissionProperty"]]]], jsii.get(self, "permissions"))

    @permissions.setter
    def permissions(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ResourcePermissionProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f59a510ec4cdf0a418a9845b18e0f18e35eaaa4656abc24ad2fea0d4d19f388)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "permissions", value)

    @builtins.property
    @jsii.member(jsii_name="sourceEntity")
    def source_entity(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DashboardSourceEntityProperty"]]:
        '''The entity that you are using as a source when you create the dashboard.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DashboardSourceEntityProperty"]], jsii.get(self, "sourceEntity"))

    @source_entity.setter
    def source_entity(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DashboardSourceEntityProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f26a2d47ee4e9448c33ec5aa138cdb72b5d9471a7548e1c79563d427ac834024)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sourceEntity", value)

    @builtins.property
    @jsii.member(jsii_name="tagsRaw")
    def tags_raw(self) -> typing.Optional[typing.List[_CfnTag_f6864754]]:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the dashboard.'''
        return typing.cast(typing.Optional[typing.List[_CfnTag_f6864754]], jsii.get(self, "tagsRaw"))

    @tags_raw.setter
    def tags_raw(self, value: typing.Optional[typing.List[_CfnTag_f6864754]]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4157d1e43ba9269c34a9144492ba9d8b026c8ad8b806f6f0e6f37879005b2f7d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tagsRaw", value)

    @builtins.property
    @jsii.member(jsii_name="themeArn")
    def theme_arn(self) -> typing.Optional[builtins.str]:
        '''The Amazon Resource Name (ARN) of the theme that is being used for this dashboard.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "themeArn"))

    @theme_arn.setter
    def theme_arn(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__46c4aa8ff62c92f0ce2798499a03c58f9959885ce816cb9469ed1d4779a76ab7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "themeArn", value)

    @builtins.property
    @jsii.member(jsii_name="validationStrategy")
    def validation_strategy(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ValidationStrategyProperty"]]:
        '''The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ValidationStrategyProperty"]], jsii.get(self, "validationStrategy"))

    @validation_strategy.setter
    def validation_strategy(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ValidationStrategyProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__62fb6c466147b908ac2657c256baa86531607acd72249e030ebe5469c50cd22b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "validationStrategy", value)

    @builtins.property
    @jsii.member(jsii_name="versionDescription")
    def version_description(self) -> typing.Optional[builtins.str]:
        '''A description for the first version of the dashboard being created.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionDescription"))

    @version_description.setter
    def version_description(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c4e2c4c6bc181883a6266972f618c6a00770ccdb0e57d73a95f61def1f2e65ff)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "versionDescription", value)

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.AdHocFilteringOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class AdHocFilteringOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''An ad hoc (one-time) filtering option.

            :param availability_status: Availability status.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-adhocfilteringoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                ad_hoc_filtering_option_property = quicksight.CfnDashboard.AdHocFilteringOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__80d1f8fd6845423e319bb8174878b6a29f2f7963379f7f8c451ccb38af7b08dd)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''Availability status.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-adhocfilteringoption.html#cfn-quicksight-dashboard-adhocfilteringoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AdHocFilteringOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.AggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "attribute_aggregation_function": "attributeAggregationFunction",
            "categorical_aggregation_function": "categoricalAggregationFunction",
            "date_aggregation_function": "dateAggregationFunction",
            "numerical_aggregation_function": "numericalAggregationFunction",
        },
    )
    class AggregationFunctionProperty:
        def __init__(
            self,
            *,
            attribute_aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AttributeAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            categorical_aggregation_function: typing.Optional[builtins.str] = None,
            date_aggregation_function: typing.Optional[builtins.str] = None,
            numerical_aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''An aggregation function aggregates values from a dimension or measure.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param attribute_aggregation_function: Aggregation for attributes.
            :param categorical_aggregation_function: Aggregation for categorical values. - ``COUNT`` : Aggregate by the total number of values, including duplicates. - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.
            :param date_aggregation_function: Aggregation for date values. - ``COUNT`` : Aggregate by the total number of values, including duplicates. - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values. - ``MIN`` : Select the smallest date value. - ``MAX`` : Select the largest date value.
            :param numerical_aggregation_function: Aggregation for numerical values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                aggregation_function_property = quicksight.CfnDashboard.AggregationFunctionProperty(
                    attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                        simple_attribute_aggregation="simpleAttributeAggregation",
                        value_for_multiple_values="valueForMultipleValues"
                    ),
                    categorical_aggregation_function="categoricalAggregationFunction",
                    date_aggregation_function="dateAggregationFunction",
                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e8d4df527a885403ed8019364af71fb386efea9c65e5986b9cb0e65bb7dd8e76)
                check_type(argname="argument attribute_aggregation_function", value=attribute_aggregation_function, expected_type=type_hints["attribute_aggregation_function"])
                check_type(argname="argument categorical_aggregation_function", value=categorical_aggregation_function, expected_type=type_hints["categorical_aggregation_function"])
                check_type(argname="argument date_aggregation_function", value=date_aggregation_function, expected_type=type_hints["date_aggregation_function"])
                check_type(argname="argument numerical_aggregation_function", value=numerical_aggregation_function, expected_type=type_hints["numerical_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if attribute_aggregation_function is not None:
                self._values["attribute_aggregation_function"] = attribute_aggregation_function
            if categorical_aggregation_function is not None:
                self._values["categorical_aggregation_function"] = categorical_aggregation_function
            if date_aggregation_function is not None:
                self._values["date_aggregation_function"] = date_aggregation_function
            if numerical_aggregation_function is not None:
                self._values["numerical_aggregation_function"] = numerical_aggregation_function

        @builtins.property
        def attribute_aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AttributeAggregationFunctionProperty"]]:
            '''Aggregation for attributes.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html#cfn-quicksight-dashboard-aggregationfunction-attributeaggregationfunction
            '''
            result = self._values.get("attribute_aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AttributeAggregationFunctionProperty"]], result)

        @builtins.property
        def categorical_aggregation_function(self) -> typing.Optional[builtins.str]:
            '''Aggregation for categorical values.

            - ``COUNT`` : Aggregate by the total number of values, including duplicates.
            - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html#cfn-quicksight-dashboard-aggregationfunction-categoricalaggregationfunction
            '''
            result = self._values.get("categorical_aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def date_aggregation_function(self) -> typing.Optional[builtins.str]:
            '''Aggregation for date values.

            - ``COUNT`` : Aggregate by the total number of values, including duplicates.
            - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.
            - ``MIN`` : Select the smallest date value.
            - ``MAX`` : Select the largest date value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html#cfn-quicksight-dashboard-aggregationfunction-dateaggregationfunction
            '''
            result = self._values.get("date_aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def numerical_aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericalAggregationFunctionProperty"]]:
            '''Aggregation for numerical values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html#cfn-quicksight-dashboard-aggregationfunction-numericalaggregationfunction
            '''
            result = self._values.get("numerical_aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericalAggregationFunctionProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.AggregationSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "sort_direction": "sortDirection",
            "aggregation_function": "aggregationFunction",
        },
    )
    class AggregationSortConfigurationProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            sort_direction: builtins.str,
            aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration options to sort aggregated values.

            :param column: The column that determines the sort order of aggregated values.
            :param sort_direction: The sort direction of values. - ``ASC`` : Sort in ascending order. - ``DESC`` : Sort in descending order.
            :param aggregation_function: The function that aggregates the values in ``Column`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                aggregation_sort_configuration_property = quicksight.CfnDashboard.AggregationSortConfigurationProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    sort_direction="sortDirection",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                        attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                            simple_attribute_aggregation="simpleAttributeAggregation",
                            value_for_multiple_values="valueForMultipleValues"
                        ),
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__87de744665253e4cca52f594ac3382d9eb4a61d617bd92b8b43f9c2d1fc42820)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument sort_direction", value=sort_direction, expected_type=type_hints["sort_direction"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "sort_direction": sort_direction,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that determines the sort order of aggregated values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationsortconfiguration.html#cfn-quicksight-dashboard-aggregationsortconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def sort_direction(self) -> builtins.str:
            '''The sort direction of values.

            - ``ASC`` : Sort in ascending order.
            - ``DESC`` : Sort in descending order.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationsortconfiguration.html#cfn-quicksight-dashboard-aggregationsortconfiguration-sortdirection
            '''
            result = self._values.get("sort_direction")
            assert result is not None, "Required property 'sort_direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AggregationFunctionProperty"]]:
            '''The function that aggregates the values in ``Column`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationsortconfiguration.html#cfn-quicksight-dashboard-aggregationsortconfiguration-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AggregationFunctionProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AggregationSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.AnalysisDefaultsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "default_new_sheet_configuration": "defaultNewSheetConfiguration",
        },
    )
    class AnalysisDefaultsProperty:
        def __init__(
            self,
            *,
            default_new_sheet_configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DefaultNewSheetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The configuration for default analysis settings.

            :param default_new_sheet_configuration: The configuration for default new sheet settings.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-analysisdefaults.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                analysis_defaults_property = quicksight.CfnDashboard.AnalysisDefaultsProperty(
                    default_new_sheet_configuration=quicksight.CfnDashboard.DefaultNewSheetConfigurationProperty(
                        interactive_layout_configuration=quicksight.CfnDashboard.DefaultInteractiveLayoutConfigurationProperty(
                            free_form=quicksight.CfnDashboard.DefaultFreeFormLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid=quicksight.CfnDashboard.DefaultGridLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
                
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        ),
                        paginated_layout_configuration=quicksight.CfnDashboard.DefaultPaginatedLayoutConfigurationProperty(
                            section_based=quicksight.CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                )
                            )
                        ),
                        sheet_content_type="sheetContentType"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e66a4877ba1c474f6bbcc57dbe4e56056271dd2d6abb4a9a4381350408d60b6a)
                check_type(argname="argument default_new_sheet_configuration", value=default_new_sheet_configuration, expected_type=type_hints["default_new_sheet_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "default_new_sheet_configuration": default_new_sheet_configuration,
            }

        @builtins.property
        def default_new_sheet_configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.DefaultNewSheetConfigurationProperty"]:
            '''The configuration for default new sheet settings.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-analysisdefaults.html#cfn-quicksight-dashboard-analysisdefaults-defaultnewsheetconfiguration
            '''
            result = self._values.get("default_new_sheet_configuration")
            assert result is not None, "Required property 'default_new_sheet_configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.DefaultNewSheetConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnalysisDefaultsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.AnchorDateConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "anchor_option": "anchorOption",
            "parameter_name": "parameterName",
        },
    )
    class AnchorDateConfigurationProperty:
        def __init__(
            self,
            *,
            anchor_option: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The date configuration of the filter.

            :param anchor_option: The options for the date configuration. Choose one of the options below:. - ``NOW``
            :param parameter_name: The name of the parameter that is used for the anchor date configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-anchordateconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                anchor_date_configuration_property = quicksight.CfnDashboard.AnchorDateConfigurationProperty(
                    anchor_option="anchorOption",
                    parameter_name="parameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7cb9daee34ebdd50819f56f8d83bc6aface0248fdc107ababc393ffaad4a2d92)
                check_type(argname="argument anchor_option", value=anchor_option, expected_type=type_hints["anchor_option"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if anchor_option is not None:
                self._values["anchor_option"] = anchor_option
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name

        @builtins.property
        def anchor_option(self) -> typing.Optional[builtins.str]:
            '''The options for the date configuration. Choose one of the options below:.

            - ``NOW``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-anchordateconfiguration.html#cfn-quicksight-dashboard-anchordateconfiguration-anchoroption
            '''
            result = self._values.get("anchor_option")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The name of the parameter that is used for the anchor date configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-anchordateconfiguration.html#cfn-quicksight-dashboard-anchordateconfiguration-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnchorDateConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ArcAxisConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"range": "range", "reserve_range": "reserveRange"},
    )
    class ArcAxisConfigurationProperty:
        def __init__(
            self,
            *,
            range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ArcAxisDisplayRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reserve_range: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The arc axis configuration of a ``GaugeChartVisual`` .

            :param range: The arc axis range of a ``GaugeChartVisual`` .
            :param reserve_range: The reserved range of the arc axis. Default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                arc_axis_configuration_property = quicksight.CfnDashboard.ArcAxisConfigurationProperty(
                    range=quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                        max=123,
                        min=123
                    ),
                    reserve_range=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9dc01a84a29061262b25649d5568967863dad18aacccf2197b0708ac48b92f99)
                check_type(argname="argument range", value=range, expected_type=type_hints["range"])
                check_type(argname="argument reserve_range", value=reserve_range, expected_type=type_hints["reserve_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if range is not None:
                self._values["range"] = range
            if reserve_range is not None:
                self._values["reserve_range"] = reserve_range

        @builtins.property
        def range(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ArcAxisDisplayRangeProperty"]]:
            '''The arc axis range of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisconfiguration.html#cfn-quicksight-dashboard-arcaxisconfiguration-range
            '''
            result = self._values.get("range")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ArcAxisDisplayRangeProperty"]], result)

        @builtins.property
        def reserve_range(self) -> typing.Optional[jsii.Number]:
            '''The reserved range of the arc axis.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisconfiguration.html#cfn-quicksight-dashboard-arcaxisconfiguration-reserverange
            '''
            result = self._values.get("reserve_range")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcAxisConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ArcAxisDisplayRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"max": "max", "min": "min"},
    )
    class ArcAxisDisplayRangeProperty:
        def __init__(
            self,
            *,
            max: typing.Optional[jsii.Number] = None,
            min: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The arc axis range of a ``GaugeChartVisual`` .

            :param max: The maximum value of the arc axis range.
            :param min: The minimum value of the arc axis range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisdisplayrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                arc_axis_display_range_property = quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                    max=123,
                    min=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5649f4fd37011ee236c577679430af27d7ca3e76dda160958575f38193c6b6cf)
                check_type(argname="argument max", value=max, expected_type=type_hints["max"])
                check_type(argname="argument min", value=min, expected_type=type_hints["min"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if max is not None:
                self._values["max"] = max
            if min is not None:
                self._values["min"] = min

        @builtins.property
        def max(self) -> typing.Optional[jsii.Number]:
            '''The maximum value of the arc axis range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisdisplayrange.html#cfn-quicksight-dashboard-arcaxisdisplayrange-max
            '''
            result = self._values.get("max")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def min(self) -> typing.Optional[jsii.Number]:
            '''The minimum value of the arc axis range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisdisplayrange.html#cfn-quicksight-dashboard-arcaxisdisplayrange-min
            '''
            result = self._values.get("min")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcAxisDisplayRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ArcConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"arc_angle": "arcAngle", "arc_thickness": "arcThickness"},
    )
    class ArcConfigurationProperty:
        def __init__(
            self,
            *,
            arc_angle: typing.Optional[jsii.Number] = None,
            arc_thickness: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The arc configuration of a ``GaugeChartVisual`` .

            :param arc_angle: The option that determines the arc angle of a ``GaugeChartVisual`` .
            :param arc_thickness: The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                arc_configuration_property = quicksight.CfnDashboard.ArcConfigurationProperty(
                    arc_angle=123,
                    arc_thickness="arcThickness"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8d36a7bc2680302d589cab761ee9ff97e7c873d9f1cdee854cf8844dcdbb049c)
                check_type(argname="argument arc_angle", value=arc_angle, expected_type=type_hints["arc_angle"])
                check_type(argname="argument arc_thickness", value=arc_thickness, expected_type=type_hints["arc_thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_angle is not None:
                self._values["arc_angle"] = arc_angle
            if arc_thickness is not None:
                self._values["arc_thickness"] = arc_thickness

        @builtins.property
        def arc_angle(self) -> typing.Optional[jsii.Number]:
            '''The option that determines the arc angle of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcconfiguration.html#cfn-quicksight-dashboard-arcconfiguration-arcangle
            '''
            result = self._values.get("arc_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def arc_thickness(self) -> typing.Optional[builtins.str]:
            '''The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcconfiguration.html#cfn-quicksight-dashboard-arcconfiguration-arcthickness
            '''
            result = self._values.get("arc_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ArcOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"arc_thickness": "arcThickness"},
    )
    class ArcOptionsProperty:
        def __init__(
            self,
            *,
            arc_thickness: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :param arc_thickness: The arc thickness of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                arc_options_property = quicksight.CfnDashboard.ArcOptionsProperty(
                    arc_thickness="arcThickness"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__481cb554cc890bb96e4eda3f6a02011deec5a79bda05bdb3da22002fe160dee6)
                check_type(argname="argument arc_thickness", value=arc_thickness, expected_type=type_hints["arc_thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_thickness is not None:
                self._values["arc_thickness"] = arc_thickness

        @builtins.property
        def arc_thickness(self) -> typing.Optional[builtins.str]:
            '''The arc thickness of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcoptions.html#cfn-quicksight-dashboard-arcoptions-arcthickness
            '''
            result = self._values.get("arc_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.AssetOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"timezone": "timezone", "week_start": "weekStart"},
    )
    class AssetOptionsProperty:
        def __init__(
            self,
            *,
            timezone: typing.Optional[builtins.str] = None,
            week_start: typing.Optional[builtins.str] = None,
        ) -> None:
            '''An array of analysis level configurations.

            :param timezone: Determines the timezone for the analysis.
            :param week_start: Determines the week start day for an analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-assetoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                asset_options_property = quicksight.CfnDashboard.AssetOptionsProperty(
                    timezone="timezone",
                    week_start="weekStart"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5ef7224a58786a2e22a434b451d86c92e851f6806306809a88f0fbe39f212105)
                check_type(argname="argument timezone", value=timezone, expected_type=type_hints["timezone"])
                check_type(argname="argument week_start", value=week_start, expected_type=type_hints["week_start"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if timezone is not None:
                self._values["timezone"] = timezone
            if week_start is not None:
                self._values["week_start"] = week_start

        @builtins.property
        def timezone(self) -> typing.Optional[builtins.str]:
            '''Determines the timezone for the analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-assetoptions.html#cfn-quicksight-dashboard-assetoptions-timezone
            '''
            result = self._values.get("timezone")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def week_start(self) -> typing.Optional[builtins.str]:
            '''Determines the week start day for an analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-assetoptions.html#cfn-quicksight-dashboard-assetoptions-weekstart
            '''
            result = self._values.get("week_start")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AssetOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.AttributeAggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "simple_attribute_aggregation": "simpleAttributeAggregation",
            "value_for_multiple_values": "valueForMultipleValues",
        },
    )
    class AttributeAggregationFunctionProperty:
        def __init__(
            self,
            *,
            simple_attribute_aggregation: typing.Optional[builtins.str] = None,
            value_for_multiple_values: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Aggregation for attributes.

            :param simple_attribute_aggregation: The built-in aggregation functions for attributes. - ``UNIQUE_VALUE`` : Returns the unique value for a field, aggregated by the dimension fields.
            :param value_for_multiple_values: Used by the ``UNIQUE_VALUE`` aggregation function. If there are multiple values for the field used by the aggregation, the value for this property will be returned instead. Defaults to '*'.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-attributeaggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                attribute_aggregation_function_property = quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                    simple_attribute_aggregation="simpleAttributeAggregation",
                    value_for_multiple_values="valueForMultipleValues"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9ca70fe3ccaa6fc1d88b1b2ca26586296956ad88d392ddc9c6bec881f6862bc6)
                check_type(argname="argument simple_attribute_aggregation", value=simple_attribute_aggregation, expected_type=type_hints["simple_attribute_aggregation"])
                check_type(argname="argument value_for_multiple_values", value=value_for_multiple_values, expected_type=type_hints["value_for_multiple_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if simple_attribute_aggregation is not None:
                self._values["simple_attribute_aggregation"] = simple_attribute_aggregation
            if value_for_multiple_values is not None:
                self._values["value_for_multiple_values"] = value_for_multiple_values

        @builtins.property
        def simple_attribute_aggregation(self) -> typing.Optional[builtins.str]:
            '''The built-in aggregation functions for attributes.

            - ``UNIQUE_VALUE`` : Returns the unique value for a field, aggregated by the dimension fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-attributeaggregationfunction.html#cfn-quicksight-dashboard-attributeaggregationfunction-simpleattributeaggregation
            '''
            result = self._values.get("simple_attribute_aggregation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_for_multiple_values(self) -> typing.Optional[builtins.str]:
            '''Used by the ``UNIQUE_VALUE`` aggregation function.

            If there are multiple values for the field used by the aggregation, the value for this property will be returned instead. Defaults to '*'.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-attributeaggregationfunction.html#cfn-quicksight-dashboard-attributeaggregationfunction-valueformultiplevalues
            '''
            result = self._values.get("value_for_multiple_values")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AttributeAggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.AxisDataOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_axis_options": "dateAxisOptions",
            "numeric_axis_options": "numericAxisOptions",
        },
    )
    class AxisDataOptionsProperty:
        def __init__(
            self,
            *,
            date_axis_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DateAxisOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_axis_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumericAxisOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The data options for an axis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_axis_options: The options for an axis with a date field.
            :param numeric_axis_options: The options for an axis with a numeric field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdataoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_data_options_property = quicksight.CfnDashboard.AxisDataOptionsProperty(
                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                        missing_date_visibility="missingDateVisibility"
                    ),
                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                            data_driven=data_driven,
                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                maximum=123,
                                minimum=123
                            )
                        ),
                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                step_count=123,
                                step_size=123
                            ),
                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                base=123
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fa2762d74557d61b2a9607be978b6ae2e7747e81adedbe834f60012b3d9530f6)
                check_type(argname="argument date_axis_options", value=date_axis_options, expected_type=type_hints["date_axis_options"])
                check_type(argname="argument numeric_axis_options", value=numeric_axis_options, expected_type=type_hints["numeric_axis_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_axis_options is not None:
                self._values["date_axis_options"] = date_axis_options
            if numeric_axis_options is not None:
                self._values["numeric_axis_options"] = numeric_axis_options

        @builtins.property
        def date_axis_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateAxisOptionsProperty"]]:
            '''The options for an axis with a date field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdataoptions.html#cfn-quicksight-dashboard-axisdataoptions-dateaxisoptions
            '''
            result = self._values.get("date_axis_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateAxisOptionsProperty"]], result)

        @builtins.property
        def numeric_axis_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericAxisOptionsProperty"]]:
            '''The options for an axis with a numeric field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdataoptions.html#cfn-quicksight-dashboard-axisdataoptions-numericaxisoptions
            '''
            result = self._values.get("numeric_axis_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericAxisOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDataOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"maximum": "maximum", "minimum": "minimum"},
    )
    class AxisDisplayMinMaxRangeProperty:
        def __init__(
            self,
            *,
            maximum: typing.Optional[jsii.Number] = None,
            minimum: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The minimum and maximum setup for an axis display range.

            :param maximum: The maximum setup for an axis display range.
            :param minimum: The minimum setup for an axis display range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayminmaxrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                axis_display_min_max_range_property = quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                    maximum=123,
                    minimum=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c5e6d56dd32f73723d00e039ca2aa3946b1be5e335ad0252d16173a7ea5b0ae1)
                check_type(argname="argument maximum", value=maximum, expected_type=type_hints["maximum"])
                check_type(argname="argument minimum", value=minimum, expected_type=type_hints["minimum"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if maximum is not None:
                self._values["maximum"] = maximum
            if minimum is not None:
                self._values["minimum"] = minimum

        @builtins.property
        def maximum(self) -> typing.Optional[jsii.Number]:
            '''The maximum setup for an axis display range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayminmaxrange.html#cfn-quicksight-dashboard-axisdisplayminmaxrange-maximum
            '''
            result = self._values.get("maximum")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def minimum(self) -> typing.Optional[jsii.Number]:
            '''The minimum setup for an axis display range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayminmaxrange.html#cfn-quicksight-dashboard-axisdisplayminmaxrange-minimum
            '''
            result = self._values.get("minimum")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayMinMaxRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.AxisDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_line_visibility": "axisLineVisibility",
            "axis_offset": "axisOffset",
            "data_options": "dataOptions",
            "grid_line_visibility": "gridLineVisibility",
            "scrollbar_options": "scrollbarOptions",
            "tick_label_options": "tickLabelOptions",
        },
    )
    class AxisDisplayOptionsProperty:
        def __init__(
            self,
            *,
            axis_line_visibility: typing.Optional[builtins.str] = None,
            axis_offset: typing.Optional[builtins.str] = None,
            data_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisDataOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            grid_line_visibility: typing.Optional[builtins.str] = None,
            scrollbar_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ScrollBarOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tick_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisTickLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options for the axis label.

            :param axis_line_visibility: Determines whether or not the axis line is visible.
            :param axis_offset: The offset value that determines the starting placement of the axis within a visual's bounds.
            :param data_options: The data options for an axis.
            :param grid_line_visibility: Determines whether or not the grid line is visible.
            :param scrollbar_options: The scroll bar options for an axis.
            :param tick_label_options: The tick label options of an axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_display_options_property = quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                    axis_line_visibility="axisLineVisibility",
                    axis_offset="axisOffset",
                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                            missing_date_visibility="missingDateVisibility"
                        ),
                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                data_driven=data_driven,
                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                    maximum=123,
                                    minimum=123
                                )
                            ),
                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                    step_count=123,
                                    step_size=123
                                ),
                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                    base=123
                                )
                            )
                        )
                    ),
                    grid_line_visibility="gridLineVisibility",
                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                        visibility="visibility",
                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                from=123,
                                to=123
                            )
                        )
                    ),
                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        rotation_angle=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2b8d9c49a4641f149f4e798dc4b5ac9b09bcb9f5eefdeba4ea7752c803a4ba34)
                check_type(argname="argument axis_line_visibility", value=axis_line_visibility, expected_type=type_hints["axis_line_visibility"])
                check_type(argname="argument axis_offset", value=axis_offset, expected_type=type_hints["axis_offset"])
                check_type(argname="argument data_options", value=data_options, expected_type=type_hints["data_options"])
                check_type(argname="argument grid_line_visibility", value=grid_line_visibility, expected_type=type_hints["grid_line_visibility"])
                check_type(argname="argument scrollbar_options", value=scrollbar_options, expected_type=type_hints["scrollbar_options"])
                check_type(argname="argument tick_label_options", value=tick_label_options, expected_type=type_hints["tick_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_line_visibility is not None:
                self._values["axis_line_visibility"] = axis_line_visibility
            if axis_offset is not None:
                self._values["axis_offset"] = axis_offset
            if data_options is not None:
                self._values["data_options"] = data_options
            if grid_line_visibility is not None:
                self._values["grid_line_visibility"] = grid_line_visibility
            if scrollbar_options is not None:
                self._values["scrollbar_options"] = scrollbar_options
            if tick_label_options is not None:
                self._values["tick_label_options"] = tick_label_options

        @builtins.property
        def axis_line_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the axis line is visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-axislinevisibility
            '''
            result = self._values.get("axis_line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def axis_offset(self) -> typing.Optional[builtins.str]:
            '''The offset value that determines the starting placement of the axis within a visual's bounds.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-axisoffset
            '''
            result = self._values.get("axis_offset")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDataOptionsProperty"]]:
            '''The data options for an axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-dataoptions
            '''
            result = self._values.get("data_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDataOptionsProperty"]], result)

        @builtins.property
        def grid_line_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the grid line is visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-gridlinevisibility
            '''
            result = self._values.get("grid_line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scrollbar_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ScrollBarOptionsProperty"]]:
            '''The scroll bar options for an axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-scrollbaroptions
            '''
            result = self._values.get("scrollbar_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ScrollBarOptionsProperty"]], result)

        @builtins.property
        def tick_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisTickLabelOptionsProperty"]]:
            '''The tick label options of an axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-ticklabeloptions
            '''
            result = self._values.get("tick_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisTickLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.AxisDisplayRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"data_driven": "dataDriven", "min_max": "minMax"},
    )
    class AxisDisplayRangeProperty:
        def __init__(
            self,
            *,
            data_driven: typing.Any = None,
            min_max: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisDisplayMinMaxRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The range setup of a numeric axis display range.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_driven: The data-driven setup of an axis display range.
            :param min_max: The minimum and maximum setup of an axis display range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_display_range_property = quicksight.CfnDashboard.AxisDisplayRangeProperty(
                    data_driven=data_driven,
                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                        maximum=123,
                        minimum=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7d922b60b7031c4ed20c7f87045d35b7d2c6cadc6d572114f4bb88d4e7ebd95b)
                check_type(argname="argument data_driven", value=data_driven, expected_type=type_hints["data_driven"])
                check_type(argname="argument min_max", value=min_max, expected_type=type_hints["min_max"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_driven is not None:
                self._values["data_driven"] = data_driven
            if min_max is not None:
                self._values["min_max"] = min_max

        @builtins.property
        def data_driven(self) -> typing.Any:
            '''The data-driven setup of an axis display range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayrange.html#cfn-quicksight-dashboard-axisdisplayrange-datadriven
            '''
            result = self._values.get("data_driven")
            return typing.cast(typing.Any, result)

        @builtins.property
        def min_max(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayMinMaxRangeProperty"]]:
            '''The minimum and maximum setup of an axis display range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayrange.html#cfn-quicksight-dashboard-axisdisplayrange-minmax
            '''
            result = self._values.get("min_max")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayMinMaxRangeProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.AxisLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "apply_to": "applyTo",
            "custom_label": "customLabel",
            "font_configuration": "fontConfiguration",
        },
    )
    class AxisLabelOptionsProperty:
        def __init__(
            self,
            *,
            apply_to: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisLabelReferenceOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_label: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The label options for a chart axis.

            You must specify the field that the label is targeted to.

            :param apply_to: The options that indicate which field the label belongs to.
            :param custom_label: The text for the axis label.
            :param font_configuration: The font configuration of the axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                axis_label_options_property = quicksight.CfnDashboard.AxisLabelOptionsProperty(
                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId"
                    ),
                    custom_label="customLabel",
                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__26f01f53047b36789cdd9eff7482799552aaef6a4e512fadd96ab690a34e8a23)
                check_type(argname="argument apply_to", value=apply_to, expected_type=type_hints["apply_to"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if apply_to is not None:
                self._values["apply_to"] = apply_to
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration

        @builtins.property
        def apply_to(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisLabelReferenceOptionsProperty"]]:
            '''The options that indicate which field the label belongs to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabeloptions.html#cfn-quicksight-dashboard-axislabeloptions-applyto
            '''
            result = self._values.get("apply_to")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisLabelReferenceOptionsProperty"]], result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The text for the axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabeloptions.html#cfn-quicksight-dashboard-axislabeloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"]]:
            '''The font configuration of the axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabeloptions.html#cfn-quicksight-dashboard-axislabeloptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "field_id": "fieldId"},
    )
    class AxisLabelReferenceOptionsProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
        ) -> None:
            '''The reference that specifies where the axis label is applied to.

            :param column: The column that the axis label is targeted to.
            :param field_id: The field that the axis label is targeted to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabelreferenceoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                axis_label_reference_options_property = quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cf532ce08c0ea9f48c9be0918c2611c5f0876418688222f7a99a25db0eceab7f)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the axis label is targeted to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabelreferenceoptions.html#cfn-quicksight-dashboard-axislabelreferenceoptions-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field that the axis label is targeted to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabelreferenceoptions.html#cfn-quicksight-dashboard-axislabelreferenceoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLabelReferenceOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.AxisLinearScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"step_count": "stepCount", "step_size": "stepSize"},
    )
    class AxisLinearScaleProperty:
        def __init__(
            self,
            *,
            step_count: typing.Optional[jsii.Number] = None,
            step_size: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The liner axis scale setup.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param step_count: The step count setup of a linear axis.
            :param step_size: The step size setup of a linear axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislinearscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                axis_linear_scale_property = quicksight.CfnDashboard.AxisLinearScaleProperty(
                    step_count=123,
                    step_size=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bb6db4c2d0d9c586c058b692d5b6e1e98f66d1ef04af899644f8b234aa8cb3c1)
                check_type(argname="argument step_count", value=step_count, expected_type=type_hints["step_count"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if step_count is not None:
                self._values["step_count"] = step_count
            if step_size is not None:
                self._values["step_size"] = step_size

        @builtins.property
        def step_count(self) -> typing.Optional[jsii.Number]:
            '''The step count setup of a linear axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislinearscale.html#cfn-quicksight-dashboard-axislinearscale-stepcount
            '''
            result = self._values.get("step_count")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def step_size(self) -> typing.Optional[jsii.Number]:
            '''The step size setup of a linear axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislinearscale.html#cfn-quicksight-dashboard-axislinearscale-stepsize
            '''
            result = self._values.get("step_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLinearScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.AxisLogarithmicScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"base": "base"},
    )
    class AxisLogarithmicScaleProperty:
        def __init__(self, *, base: typing.Optional[jsii.Number] = None) -> None:
            '''The logarithmic axis scale setup.

            :param base: The base setup of a logarithmic axis scale.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislogarithmicscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                axis_logarithmic_scale_property = quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                    base=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ccc37977aa419d9a622b33647ead381959402d7c3be9adc4c45524782da0e92d)
                check_type(argname="argument base", value=base, expected_type=type_hints["base"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if base is not None:
                self._values["base"] = base

        @builtins.property
        def base(self) -> typing.Optional[jsii.Number]:
            '''The base setup of a logarithmic axis scale.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislogarithmicscale.html#cfn-quicksight-dashboard-axislogarithmicscale-base
            '''
            result = self._values.get("base")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLogarithmicScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.AxisScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"linear": "linear", "logarithmic": "logarithmic"},
    )
    class AxisScaleProperty:
        def __init__(
            self,
            *,
            linear: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisLinearScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            logarithmic: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisLogarithmicScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The scale setup options for a numeric axis display.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param linear: The linear axis scale setup.
            :param logarithmic: The logarithmic axis scale setup.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                axis_scale_property = quicksight.CfnDashboard.AxisScaleProperty(
                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                        step_count=123,
                        step_size=123
                    ),
                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                        base=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bd1850237626981d9668ea38df38f3effa756b373f7a650ba4e578a40ceeab1a)
                check_type(argname="argument linear", value=linear, expected_type=type_hints["linear"])
                check_type(argname="argument logarithmic", value=logarithmic, expected_type=type_hints["logarithmic"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if linear is not None:
                self._values["linear"] = linear
            if logarithmic is not None:
                self._values["logarithmic"] = logarithmic

        @builtins.property
        def linear(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisLinearScaleProperty"]]:
            '''The linear axis scale setup.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisscale.html#cfn-quicksight-dashboard-axisscale-linear
            '''
            result = self._values.get("linear")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisLinearScaleProperty"]], result)

        @builtins.property
        def logarithmic(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisLogarithmicScaleProperty"]]:
            '''The logarithmic axis scale setup.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisscale.html#cfn-quicksight-dashboard-axisscale-logarithmic
            '''
            result = self._values.get("logarithmic")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisLogarithmicScaleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.AxisTickLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "label_options": "labelOptions",
            "rotation_angle": "rotationAngle",
        },
    )
    class AxisTickLabelOptionsProperty:
        def __init__(
            self,
            *,
            label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rotation_angle: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The tick label options of an axis.

            :param label_options: Determines whether or not the axis ticks are visible.
            :param rotation_angle: The rotation angle of the axis tick labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisticklabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                axis_tick_label_options_property = quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    ),
                    rotation_angle=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ec5f01cd553710c3fc06803a8fc9f80232f647d4e67ef1ba28934f926f1650ff)
                check_type(argname="argument label_options", value=label_options, expected_type=type_hints["label_options"])
                check_type(argname="argument rotation_angle", value=rotation_angle, expected_type=type_hints["rotation_angle"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if label_options is not None:
                self._values["label_options"] = label_options
            if rotation_angle is not None:
                self._values["rotation_angle"] = rotation_angle

        @builtins.property
        def label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LabelOptionsProperty"]]:
            '''Determines whether or not the axis ticks are visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisticklabeloptions.html#cfn-quicksight-dashboard-axisticklabeloptions-labeloptions
            '''
            result = self._values.get("label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LabelOptionsProperty"]], result)

        @builtins.property
        def rotation_angle(self) -> typing.Optional[jsii.Number]:
            '''The rotation angle of the axis tick labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisticklabeloptions.html#cfn-quicksight-dashboard-axisticklabeloptions-rotationangle
            '''
            result = self._values.get("rotation_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisTickLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.BarChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "colors": "colors",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class BarChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a bar chart.

            :param category: The category (y-axis) field well of a bar chart.
            :param colors: The color (group/color) field well of a bar chart.
            :param small_multiples: The small multiples field well of a bar chart.
            :param values: The value field wells of a bar chart. Values are aggregated by category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e599230a609a8a880efa0612bb0a7effbc9f24060decc9b29887f5b874aced74)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The category (y-axis) field well of a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html#cfn-quicksight-dashboard-barchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The color (group/color) field well of a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html#cfn-quicksight-dashboard-barchartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The small multiples field well of a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html#cfn-quicksight-dashboard-barchartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The value field wells of a bar chart.

            Values are aggregated by category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html#cfn-quicksight-dashboard-barchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.BarChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bars_arrangement": "barsArrangement",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_label_options": "colorLabelOptions",
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "orientation": "orientation",
            "reference_lines": "referenceLines",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_axis": "valueAxis",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class BarChartConfigurationProperty:
        def __init__(
            self,
            *,
            bars_arrangement: typing.Optional[builtins.str] = None,
            category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.BarChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            orientation: typing.Optional[builtins.str] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.BarChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``BarChartVisual`` .

            :param bars_arrangement: Determines the arrangement of the bars. The orientation and arrangement of bars determine the type of bar that is used in the visual.
            :param category_axis: The label display options (grid line, range, scale, axis step) for bar chart category.
            :param category_label_options: The label options (label text, label visibility and sort icon visibility) for a bar chart.
            :param color_label_options: The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.
            :param contribution_analysis_defaults: The contribution analysis (anomaly configuration) setup of the visual.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param orientation: The orientation of the bars in a bar chart visual. There are two valid values in this structure:. - ``HORIZONTAL`` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts. - ``VERTICAL`` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.
            :param reference_lines: The reference line setup of the visual.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a ``BarChartVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param value_axis: The label display options (grid line, range, scale, axis step) for a bar chart value.
            :param value_label_options: The label options (label text, label visibility and sort icon visibility) for a bar chart value.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b1ff0bb5689a9ba65351ed14a14017a9194ce5dc1ece1f84c4658f087286e46f)
                check_type(argname="argument bars_arrangement", value=bars_arrangement, expected_type=type_hints["bars_arrangement"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument orientation", value=orientation, expected_type=type_hints["orientation"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_axis", value=value_axis, expected_type=type_hints["value_axis"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bars_arrangement is not None:
                self._values["bars_arrangement"] = bars_arrangement
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if orientation is not None:
                self._values["orientation"] = orientation
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_axis is not None:
                self._values["value_axis"] = value_axis
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def bars_arrangement(self) -> typing.Optional[builtins.str]:
            '''Determines the arrangement of the bars.

            The orientation and arrangement of bars determine the type of bar that is used in the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-barsarrangement
            '''
            result = self._values.get("bars_arrangement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) for bar chart category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) for a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ContributionAnalysisDefaultProperty"]]]]:
            '''The contribution analysis (anomaly configuration) setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ContributionAnalysisDefaultProperty"]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BarChartFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BarChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def orientation(self) -> typing.Optional[builtins.str]:
            '''The orientation of the bars in a bar chart visual. There are two valid values in this structure:.

            - ``HORIZONTAL`` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts.
            - ``VERTICAL`` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-orientation
            '''
            result = self._values.get("orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineProperty"]]]]:
            '''The reference line setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineProperty"]]]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SmallMultiplesOptionsProperty"]]:
            '''The small multiples setup for the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SmallMultiplesOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BarChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``BarChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BarChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def value_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) for a bar chart value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-valueaxis
            '''
            result = self._values.get("value_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) for a bar chart value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.BarChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_chart_aggregated_field_wells": "barChartAggregatedFieldWells",
        },
    )
    class BarChartFieldWellsProperty:
        def __init__(
            self,
            *,
            bar_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.BarChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``BarChartVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param bar_chart_aggregated_field_wells: The aggregated field wells of a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__93d79566d5f799cf9659899378dd246ea2fde3c6d132c7ced0e20c5dde3b663b)
                check_type(argname="argument bar_chart_aggregated_field_wells", value=bar_chart_aggregated_field_wells, expected_type=type_hints["bar_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_chart_aggregated_field_wells is not None:
                self._values["bar_chart_aggregated_field_wells"] = bar_chart_aggregated_field_wells

        @builtins.property
        def bar_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BarChartAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartfieldwells.html#cfn-quicksight-dashboard-barchartfieldwells-barchartaggregatedfieldwells
            '''
            result = self._values.get("bar_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BarChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.BarChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class BarChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''sort-configuration-description.

            :param category_items_limit: The limit on the number of categories displayed in a bar chart.
            :param category_sort: The sort configuration of category fields.
            :param color_items_limit: The limit on the number of values displayed in a bar chart.
            :param color_sort: The sort configuration of color fields in a bar chart.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                bar_chart_sort_configuration_property = quicksight.CfnDashboard.BarChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__449b0053804e16ec30a454f821cb952ae185e3546706d3f119064c2072fa15cc)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories displayed in a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of values displayed in a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of color fields in a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of small multiples panels that are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the small multiples field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.BarChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class BarChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.BarChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A bar chart.

            The ``BarChartVisual`` structure describes a visual that is a member of the bar chart family. The following charts can be described using this structure:

            - Horizontal bar chart
            - Vertical bar chart
            - Horizontal stacked bar chart
            - Vertical stacked bar chart
            - Horizontal stacked 100% bar chart
            - Vertical stacked 100% bar chart

            For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__13bc9ee0dfc8b3edb99af3d075bc421a183b0db9f7faeb1687c866447c07f3fe)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BarChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BarChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.BinCountOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"value": "value"},
    )
    class BinCountOptionsProperty:
        def __init__(self, *, value: typing.Optional[jsii.Number] = None) -> None:
            '''The options that determine the bin count of a histogram.

            :param value: The options that determine the bin count value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bincountoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                bin_count_options_property = quicksight.CfnDashboard.BinCountOptionsProperty(
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__158023b1b7442c555790d0e08899f7a174d506adcefa2ca8e9eab6397c7403c1)
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin count value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bincountoptions.html#cfn-quicksight-dashboard-bincountoptions-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BinCountOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.BinWidthOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"bin_count_limit": "binCountLimit", "value": "value"},
    )
    class BinWidthOptionsProperty:
        def __init__(
            self,
            *,
            bin_count_limit: typing.Optional[jsii.Number] = None,
            value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The options that determine the bin width of a histogram.

            :param bin_count_limit: The options that determine the bin count limit.
            :param value: The options that determine the bin width value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-binwidthoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                bin_width_options_property = quicksight.CfnDashboard.BinWidthOptionsProperty(
                    bin_count_limit=123,
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1f26b9de7e7198f77ed125fd5fbb1ef13cafe9e3cc5e9f1a39c635456f8c2ae0)
                check_type(argname="argument bin_count_limit", value=bin_count_limit, expected_type=type_hints["bin_count_limit"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_count_limit is not None:
                self._values["bin_count_limit"] = bin_count_limit
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def bin_count_limit(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin count limit.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-binwidthoptions.html#cfn-quicksight-dashboard-binwidthoptions-bincountlimit
            '''
            result = self._values.get("bin_count_limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin width value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-binwidthoptions.html#cfn-quicksight-dashboard-binwidthoptions-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BinWidthOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.BodySectionConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "content": "content",
            "section_id": "sectionId",
            "page_break_configuration": "pageBreakConfiguration",
            "style": "style",
        },
    )
    class BodySectionConfigurationProperty:
        def __init__(
            self,
            *,
            content: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.BodySectionContentProperty", typing.Dict[builtins.str, typing.Any]]],
            section_id: builtins.str,
            page_break_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SectionPageBreakConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SectionStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a body section.

            :param content: The configuration of content in a body section.
            :param section_id: The unique identifier of a body section.
            :param page_break_configuration: The configuration of a page break for a section.
            :param style: The style options of a body section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                body_section_configuration_property = quicksight.CfnDashboard.BodySectionConfigurationProperty(
                    content=quicksight.CfnDashboard.BodySectionContentProperty(
                        layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        )
                    ),
                    section_id="sectionId",
                
                    # the properties below are optional
                    page_break_configuration=quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                        after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                            status="status"
                        )
                    ),
                    style=quicksight.CfnDashboard.SectionStyleProperty(
                        height="height",
                        padding=quicksight.CfnDashboard.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c1a29e2f869a375361f1457d2d8d2d62bb6da12ce784c6a841edb821bcabf32f)
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
                check_type(argname="argument section_id", value=section_id, expected_type=type_hints["section_id"])
                check_type(argname="argument page_break_configuration", value=page_break_configuration, expected_type=type_hints["page_break_configuration"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "content": content,
                "section_id": section_id,
            }
            if page_break_configuration is not None:
                self._values["page_break_configuration"] = page_break_configuration
            if style is not None:
                self._values["style"] = style

        @builtins.property
        def content(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.BodySectionContentProperty"]:
            '''The configuration of content in a body section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html#cfn-quicksight-dashboard-bodysectionconfiguration-content
            '''
            result = self._values.get("content")
            assert result is not None, "Required property 'content' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.BodySectionContentProperty"], result)

        @builtins.property
        def section_id(self) -> builtins.str:
            '''The unique identifier of a body section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html#cfn-quicksight-dashboard-bodysectionconfiguration-sectionid
            '''
            result = self._values.get("section_id")
            assert result is not None, "Required property 'section_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def page_break_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SectionPageBreakConfigurationProperty"]]:
            '''The configuration of a page break for a section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html#cfn-quicksight-dashboard-bodysectionconfiguration-pagebreakconfiguration
            '''
            result = self._values.get("page_break_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SectionPageBreakConfigurationProperty"]], result)

        @builtins.property
        def style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SectionStyleProperty"]]:
            '''The style options of a body section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html#cfn-quicksight-dashboard-bodysectionconfiguration-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SectionStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BodySectionConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.BodySectionContentProperty",
        jsii_struct_bases=[],
        name_mapping={"layout": "layout"},
    )
    class BodySectionContentProperty:
        def __init__(
            self,
            *,
            layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of content in a body section.

            :param layout: The layout configuration of a body section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectioncontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                body_section_content_property = quicksight.CfnDashboard.BodySectionContentProperty(
                    layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                            elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6d656bf89c920f00562e5e81dd1b005dcc04092818a276279f64efa0894c43e6)
                check_type(argname="argument layout", value=layout, expected_type=type_hints["layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if layout is not None:
                self._values["layout"] = layout

        @builtins.property
        def layout(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SectionLayoutConfigurationProperty"]]:
            '''The layout configuration of a body section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectioncontent.html#cfn-quicksight-dashboard-bodysectioncontent-layout
            '''
            result = self._values.get("layout")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SectionLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BodySectionContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "values": "values"},
    )
    class BoxPlotAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well for a box plot.

            :param group_by: The group by field well of a box plot chart. Values are grouped based on group by fields.
            :param values: The value field well of a box plot chart. Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                box_plot_aggregated_field_wells_property = quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3f43d0c132e73d4c4fb3185440fb489afbe7cdca06b70ebc0cf5048e68683e00)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The group by field well of a box plot chart.

            Values are grouped based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotaggregatedfieldwells.html#cfn-quicksight-dashboard-boxplotaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The value field well of a box plot chart.

            Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotaggregatedfieldwells.html#cfn-quicksight-dashboard-boxplotaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.BoxPlotChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "box_plot_options": "boxPlotOptions",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
        },
    )
    class BoxPlotChartConfigurationProperty:
        def __init__(
            self,
            *,
            box_plot_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.BoxPlotOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.BoxPlotFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.BoxPlotSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``BoxPlotVisual`` .

            :param box_plot_options: The box plot chart options for a box plot visual.
            :param category_axis: The label display options (grid line, range, scale, axis step) of a box plot category.
            :param category_label_options: The label options (label text, label visibility and sort Icon visibility) of a box plot category.
            :param field_wells: The field wells of the visual.
            :param legend: 
            :param primary_y_axis_display_options: The label display options (grid line, range, scale, axis step) of a box plot category.
            :param primary_y_axis_label_options: The label options (label text, label visibility and sort icon visibility) of a box plot value.
            :param reference_lines: The reference line setup of the visual.
            :param sort_configuration: The sort configuration of a ``BoxPlotVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__01df5e1eb0635348166c2d99fc223dfa1d5b1e8e830385bf311f3de56d7005a3)
                check_type(argname="argument box_plot_options", value=box_plot_options, expected_type=type_hints["box_plot_options"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if box_plot_options is not None:
                self._values["box_plot_options"] = box_plot_options
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def box_plot_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BoxPlotOptionsProperty"]]:
            '''The box plot chart options for a box plot visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-boxplotoptions
            '''
            result = self._values.get("box_plot_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BoxPlotOptionsProperty"]], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) of a box plot category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort Icon visibility) of a box plot category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BoxPlotFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BoxPlotFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) of a box plot category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) of a box plot value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineProperty"]]]]:
            '''The reference line setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineProperty"]]]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BoxPlotSortConfigurationProperty"]]:
            '''The sort configuration of a ``BoxPlotVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BoxPlotSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.BoxPlotFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "box_plot_aggregated_field_wells": "boxPlotAggregatedFieldWells",
        },
    )
    class BoxPlotFieldWellsProperty:
        def __init__(
            self,
            *,
            box_plot_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.BoxPlotAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``BoxPlotVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param box_plot_aggregated_field_wells: The aggregated field wells of a box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                box_plot_field_wells_property = quicksight.CfnDashboard.BoxPlotFieldWellsProperty(
                    box_plot_aggregated_field_wells=quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__68c14f4ba8e1d9c0e7b8a5047e66270d26e8b3fb4402ef1c8e59200bf235a5bf)
                check_type(argname="argument box_plot_aggregated_field_wells", value=box_plot_aggregated_field_wells, expected_type=type_hints["box_plot_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if box_plot_aggregated_field_wells is not None:
                self._values["box_plot_aggregated_field_wells"] = box_plot_aggregated_field_wells

        @builtins.property
        def box_plot_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BoxPlotAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotfieldwells.html#cfn-quicksight-dashboard-boxplotfieldwells-boxplotaggregatedfieldwells
            '''
            result = self._values.get("box_plot_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BoxPlotAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.BoxPlotOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "all_data_points_visibility": "allDataPointsVisibility",
            "outlier_visibility": "outlierVisibility",
            "style_options": "styleOptions",
        },
    )
    class BoxPlotOptionsProperty:
        def __init__(
            self,
            *,
            all_data_points_visibility: typing.Optional[builtins.str] = None,
            outlier_visibility: typing.Optional[builtins.str] = None,
            style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.BoxPlotStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options of a box plot visual.

            :param all_data_points_visibility: Determines the visibility of all data points of the box plot.
            :param outlier_visibility: Determines the visibility of the outlier in a box plot.
            :param style_options: The style options of the box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                box_plot_options_property = quicksight.CfnDashboard.BoxPlotOptionsProperty(
                    all_data_points_visibility="allDataPointsVisibility",
                    outlier_visibility="outlierVisibility",
                    style_options=quicksight.CfnDashboard.BoxPlotStyleOptionsProperty(
                        fill_style="fillStyle"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5bf206ce413babb986996d60b6decb3eab4d40bb05923a5b5000fde519f2de89)
                check_type(argname="argument all_data_points_visibility", value=all_data_points_visibility, expected_type=type_hints["all_data_points_visibility"])
                check_type(argname="argument outlier_visibility", value=outlier_visibility, expected_type=type_hints["outlier_visibility"])
                check_type(argname="argument style_options", value=style_options, expected_type=type_hints["style_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if all_data_points_visibility is not None:
                self._values["all_data_points_visibility"] = all_data_points_visibility
            if outlier_visibility is not None:
                self._values["outlier_visibility"] = outlier_visibility
            if style_options is not None:
                self._values["style_options"] = style_options

        @builtins.property
        def all_data_points_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of all data points of the box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotoptions.html#cfn-quicksight-dashboard-boxplotoptions-alldatapointsvisibility
            '''
            result = self._values.get("all_data_points_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def outlier_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the outlier in a box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotoptions.html#cfn-quicksight-dashboard-boxplotoptions-outliervisibility
            '''
            result = self._values.get("outlier_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BoxPlotStyleOptionsProperty"]]:
            '''The style options of the box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotoptions.html#cfn-quicksight-dashboard-boxplotoptions-styleoptions
            '''
            result = self._values.get("style_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BoxPlotStyleOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.BoxPlotSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_sort": "categorySort",
            "pagination_configuration": "paginationConfiguration",
        },
    )
    class BoxPlotSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            pagination_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PaginationConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The sort configuration of a ``BoxPlotVisual`` .

            :param category_sort: The sort configuration of a group by fields.
            :param pagination_configuration: The pagination configuration of a table visual or box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                box_plot_sort_configuration_property = quicksight.CfnDashboard.BoxPlotSortConfigurationProperty(
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                        page_number=123,
                        page_size=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9d4c47e5ff8be5d2e1c80d5dace93d8d3c7b83ea3a46a74db659e4a2bf895fea)
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument pagination_configuration", value=pagination_configuration, expected_type=type_hints["pagination_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if pagination_configuration is not None:
                self._values["pagination_configuration"] = pagination_configuration

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of a group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotsortconfiguration.html#cfn-quicksight-dashboard-boxplotsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def pagination_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PaginationConfigurationProperty"]]:
            '''The pagination configuration of a table visual or box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotsortconfiguration.html#cfn-quicksight-dashboard-boxplotsortconfiguration-paginationconfiguration
            '''
            result = self._values.get("pagination_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PaginationConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.BoxPlotStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"fill_style": "fillStyle"},
    )
    class BoxPlotStyleOptionsProperty:
        def __init__(self, *, fill_style: typing.Optional[builtins.str] = None) -> None:
            '''The style options of the box plot.

            :param fill_style: The fill styles (solid, transparent) of the box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                box_plot_style_options_property = quicksight.CfnDashboard.BoxPlotStyleOptionsProperty(
                    fill_style="fillStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__78f1d53f124a66b7fd71695a56d4755f435c5db02e2c4ab2fd0e16fcbf6ea831)
                check_type(argname="argument fill_style", value=fill_style, expected_type=type_hints["fill_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if fill_style is not None:
                self._values["fill_style"] = fill_style

        @builtins.property
        def fill_style(self) -> typing.Optional[builtins.str]:
            '''The fill styles (solid, transparent) of the box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotstyleoptions.html#cfn-quicksight-dashboard-boxplotstyleoptions-fillstyle
            '''
            result = self._values.get("fill_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.BoxPlotVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class BoxPlotVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.BoxPlotChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A box plot.

            For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6e7d07262a49481c1b16d3eb00e514013399279dbc4b987427e9d553f396f0de)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BoxPlotChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BoxPlotChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CalculatedFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "expression": "expression",
            "name": "name",
        },
    )
    class CalculatedFieldProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            expression: builtins.str,
            name: builtins.str,
        ) -> None:
            '''The calculated field of an analysis.

            :param data_set_identifier: The data set that is used in this calculated field.
            :param expression: The expression of the calculated field.
            :param name: The name of the calculated field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                calculated_field_property = quicksight.CfnDashboard.CalculatedFieldProperty(
                    data_set_identifier="dataSetIdentifier",
                    expression="expression",
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f12ce35813ba424693d1bffa215127246838647ff2a48f4e10407a6b36ffed36)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "expression": expression,
                "name": name,
            }

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that is used in this calculated field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedfield.html#cfn-quicksight-dashboard-calculatedfield-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the calculated field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedfield.html#cfn-quicksight-dashboard-calculatedfield-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the calculated field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedfield.html#cfn-quicksight-dashboard-calculatedfield-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CalculatedFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CalculatedMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "field_id": "fieldId"},
    )
    class CalculatedMeasureFieldProperty:
        def __init__(self, *, expression: builtins.str, field_id: builtins.str) -> None:
            '''The table calculation measure field for pivot tables.

            :param expression: The expression in the table calculation.
            :param field_id: The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                calculated_measure_field_property = quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                    expression="expression",
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__68ee0c43e3791511488fbd00cb4903c434ee2ab14120f95bf33394e3d75af65d)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
                "field_id": field_id,
            }

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression in the table calculation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedmeasurefield.html#cfn-quicksight-dashboard-calculatedmeasurefield-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedmeasurefield.html#cfn-quicksight-dashboard-calculatedmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CalculatedMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CascadingControlConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"source_controls": "sourceControls"},
    )
    class CascadingControlConfigurationProperty:
        def __init__(
            self,
            *,
            source_controls: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CascadingControlSourceProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :param source_controls: A list of source controls that determine the values that are used in the current control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                cascading_control_configuration_property = quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                    source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                        column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        source_sheet_control_id="sourceSheetControlId"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a32bbc3f9db67b28f010d69ebbeab91fbad354e6f54009a3893f2dccb3a8a18b)
                check_type(argname="argument source_controls", value=source_controls, expected_type=type_hints["source_controls"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if source_controls is not None:
                self._values["source_controls"] = source_controls

        @builtins.property
        def source_controls(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CascadingControlSourceProperty"]]]]:
            '''A list of source controls that determine the values that are used in the current control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolconfiguration.html#cfn-quicksight-dashboard-cascadingcontrolconfiguration-sourcecontrols
            '''
            result = self._values.get("source_controls")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CascadingControlSourceProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CascadingControlConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CascadingControlSourceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_to_match": "columnToMatch",
            "source_sheet_control_id": "sourceSheetControlId",
        },
    )
    class CascadingControlSourceProperty:
        def __init__(
            self,
            *,
            column_to_match: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            source_sheet_control_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The source controls that are used in a ``CascadingControlConfiguration`` .

            :param column_to_match: The column identifier that determines which column to look up for the source sheet control.
            :param source_sheet_control_id: The source sheet control ID of a ``CascadingControlSource`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolsource.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                cascading_control_source_property = quicksight.CfnDashboard.CascadingControlSourceProperty(
                    column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    source_sheet_control_id="sourceSheetControlId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c02a590bcd0eaadcc7074756fce7fad5e61b1a9c0eebb0c647871898b2721209)
                check_type(argname="argument column_to_match", value=column_to_match, expected_type=type_hints["column_to_match"])
                check_type(argname="argument source_sheet_control_id", value=source_sheet_control_id, expected_type=type_hints["source_sheet_control_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_to_match is not None:
                self._values["column_to_match"] = column_to_match
            if source_sheet_control_id is not None:
                self._values["source_sheet_control_id"] = source_sheet_control_id

        @builtins.property
        def column_to_match(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]]:
            '''The column identifier that determines which column to look up for the source sheet control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolsource.html#cfn-quicksight-dashboard-cascadingcontrolsource-columntomatch
            '''
            result = self._values.get("column_to_match")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]], result)

        @builtins.property
        def source_sheet_control_id(self) -> typing.Optional[builtins.str]:
            '''The source sheet control ID of a ``CascadingControlSource`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolsource.html#cfn-quicksight-dashboard-cascadingcontrolsource-sourcesheetcontrolid
            '''
            result = self._values.get("source_sheet_control_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CascadingControlSourceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CategoricalDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class CategoricalDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with categorical type columns..

            :param column: The column that is used in the ``CategoricalDimensionField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                categorical_dimension_field_property = quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a6e5c66bf00442c0eebdc5de0c7b9d2a38f50ea8eae071438274ab96ec42f7ff)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that is used in the ``CategoricalDimensionField`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html#cfn-quicksight-dashboard-categoricaldimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html#cfn-quicksight-dashboard-categoricaldimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.StringFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html#cfn-quicksight-dashboard-categoricaldimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.StringFormatConfigurationProperty"]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html#cfn-quicksight-dashboard-categoricaldimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoricalDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CategoricalMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class CategoricalMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            aggregation_function: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure type field with categorical type columns.

            :param column: The column that is used in the ``CategoricalMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                categorical_measure_field_property = quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function="aggregationFunction",
                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__af71f7d7520e1e79839cde391f8a3e325b9eec9ace905498bc58af1a02b60d25)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that is used in the ``CategoricalMeasureField`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html#cfn-quicksight-dashboard-categoricalmeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html#cfn-quicksight-dashboard-categoricalmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(self) -> typing.Optional[builtins.str]:
            '''The aggregation function of the measure field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html#cfn-quicksight-dashboard-categoricalmeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.StringFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html#cfn-quicksight-dashboard-categoricalmeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.StringFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoricalMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CategoryDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={"category_values": "categoryValues", "column": "column"},
    )
    class CategoryDrillDownFilterProperty:
        def __init__(
            self,
            *,
            category_values: typing.Sequence[builtins.str],
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The numeric equality type drill down filter.

            :param category_values: A list of the string inputs that are the values of the category drill down filter.
            :param column: The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categorydrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                category_drill_down_filter_property = quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                    category_values=["categoryValues"],
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7319d068924e45b7795aa89f7eb88e392e746c224673742657c94782a36c2a1a)
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category_values": category_values,
                "column": column,
            }

        @builtins.property
        def category_values(self) -> typing.List[builtins.str]:
            '''A list of the string inputs that are the values of the category drill down filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categorydrilldownfilter.html#cfn-quicksight-dashboard-categorydrilldownfilter-categoryvalues
            '''
            result = self._values.get("category_values")
            assert result is not None, "Required property 'category_values' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categorydrilldownfilter.html#cfn-quicksight-dashboard-categorydrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CategoryFilterConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_filter_configuration": "customFilterConfiguration",
            "custom_filter_list_configuration": "customFilterListConfiguration",
            "filter_list_configuration": "filterListConfiguration",
        },
    )
    class CategoryFilterConfigurationProperty:
        def __init__(
            self,
            *,
            custom_filter_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CustomFilterConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_filter_list_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CustomFilterListConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            filter_list_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilterListConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``CategoryFilter`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_filter_configuration: A custom filter that filters based on a single value. This filter can be partially matched.
            :param custom_filter_list_configuration: A list of custom filter values. In the Amazon QuickSight console, this filter type is called a custom filter list.
            :param filter_list_configuration: A list of filter configurations. In the Amazon QuickSight console, this filter type is called a filter list.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilterconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                category_filter_configuration_property = quicksight.CfnDashboard.CategoryFilterConfigurationProperty(
                    custom_filter_configuration=quicksight.CfnDashboard.CustomFilterConfigurationProperty(
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        category_value="categoryValue",
                        parameter_name="parameterName",
                        select_all_options="selectAllOptions"
                    ),
                    custom_filter_list_configuration=quicksight.CfnDashboard.CustomFilterListConfigurationProperty(
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        category_values=["categoryValues"],
                        select_all_options="selectAllOptions"
                    ),
                    filter_list_configuration=quicksight.CfnDashboard.FilterListConfigurationProperty(
                        match_operator="matchOperator",
                
                        # the properties below are optional
                        category_values=["categoryValues"],
                        null_option="nullOption",
                        select_all_options="selectAllOptions"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8ffab7ada39f61dd0aa2dfa460d57cb66bcaf9438627f6d913ee997f170a8652)
                check_type(argname="argument custom_filter_configuration", value=custom_filter_configuration, expected_type=type_hints["custom_filter_configuration"])
                check_type(argname="argument custom_filter_list_configuration", value=custom_filter_list_configuration, expected_type=type_hints["custom_filter_list_configuration"])
                check_type(argname="argument filter_list_configuration", value=filter_list_configuration, expected_type=type_hints["filter_list_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_filter_configuration is not None:
                self._values["custom_filter_configuration"] = custom_filter_configuration
            if custom_filter_list_configuration is not None:
                self._values["custom_filter_list_configuration"] = custom_filter_list_configuration
            if filter_list_configuration is not None:
                self._values["filter_list_configuration"] = filter_list_configuration

        @builtins.property
        def custom_filter_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomFilterConfigurationProperty"]]:
            '''A custom filter that filters based on a single value.

            This filter can be partially matched.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilterconfiguration.html#cfn-quicksight-dashboard-categoryfilterconfiguration-customfilterconfiguration
            '''
            result = self._values.get("custom_filter_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomFilterConfigurationProperty"]], result)

        @builtins.property
        def custom_filter_list_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomFilterListConfigurationProperty"]]:
            '''A list of custom filter values.

            In the Amazon QuickSight console, this filter type is called a custom filter list.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilterconfiguration.html#cfn-quicksight-dashboard-categoryfilterconfiguration-customfilterlistconfiguration
            '''
            result = self._values.get("custom_filter_list_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomFilterListConfigurationProperty"]], result)

        @builtins.property
        def filter_list_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterListConfigurationProperty"]]:
            '''A list of filter configurations.

            In the Amazon QuickSight console, this filter type is called a filter list.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilterconfiguration.html#cfn-quicksight-dashboard-categoryfilterconfiguration-filterlistconfiguration
            '''
            result = self._values.get("filter_list_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterListConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryFilterConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CategoryFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "configuration": "configuration",
            "filter_id": "filterId",
        },
    )
    class CategoryFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CategoryFilterConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
        ) -> None:
            '''A ``CategoryFilter`` filters text values.

            For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .

            :param column: The column that the filter is applied to.
            :param configuration: The configuration for a ``CategoryFilter`` .
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                category_filter_property = quicksight.CfnDashboard.CategoryFilterProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    configuration=quicksight.CfnDashboard.CategoryFilterConfigurationProperty(
                        custom_filter_configuration=quicksight.CfnDashboard.CustomFilterConfigurationProperty(
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            category_value="categoryValue",
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions"
                        ),
                        custom_filter_list_configuration=quicksight.CfnDashboard.CustomFilterListConfigurationProperty(
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            category_values=["categoryValues"],
                            select_all_options="selectAllOptions"
                        ),
                        filter_list_configuration=quicksight.CfnDashboard.FilterListConfigurationProperty(
                            match_operator="matchOperator",
                
                            # the properties below are optional
                            category_values=["categoryValues"],
                            null_option="nullOption",
                            select_all_options="selectAllOptions"
                        )
                    ),
                    filter_id="filterId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f69313d9472c41cb99afc1e0281076733ee261b50594b22b59ec1b43d81a685e)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "configuration": configuration,
                "filter_id": filter_id,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilter.html#cfn-quicksight-dashboard-categoryfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.CategoryFilterConfigurationProperty"]:
            '''The configuration for a ``CategoryFilter`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilter.html#cfn-quicksight-dashboard-categoryfilter-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.CategoryFilterConfigurationProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilter.html#cfn-quicksight-dashboard-categoryfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ChartAxisLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_label_options": "axisLabelOptions",
            "sort_icon_visibility": "sortIconVisibility",
            "visibility": "visibility",
        },
    )
    class ChartAxisLabelOptionsProperty:
        def __init__(
            self,
            *,
            axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sort_icon_visibility: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label options for an axis on a chart.

            :param axis_label_options: The label options for a chart axis.
            :param sort_icon_visibility: The visibility configuration of the sort icon on a chart's axis label.
            :param visibility: The visibility of an axis label on a chart. Choose one of the following options:. - ``VISIBLE`` : Shows the axis. - ``HIDDEN`` : Hides the axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-chartaxislabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                chart_axis_label_options_property = quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId"
                        ),
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        )
                    )],
                    sort_icon_visibility="sortIconVisibility",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c83f5a1113c0da518a3850e90d9d9ac8ff08085a4eca5440484a162b0c459183)
                check_type(argname="argument axis_label_options", value=axis_label_options, expected_type=type_hints["axis_label_options"])
                check_type(argname="argument sort_icon_visibility", value=sort_icon_visibility, expected_type=type_hints["sort_icon_visibility"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_label_options is not None:
                self._values["axis_label_options"] = axis_label_options
            if sort_icon_visibility is not None:
                self._values["sort_icon_visibility"] = sort_icon_visibility
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisLabelOptionsProperty"]]]]:
            '''The label options for a chart axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-chartaxislabeloptions.html#cfn-quicksight-dashboard-chartaxislabeloptions-axislabeloptions
            '''
            result = self._values.get("axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisLabelOptionsProperty"]]]], result)

        @builtins.property
        def sort_icon_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the sort icon on a chart's axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-chartaxislabeloptions.html#cfn-quicksight-dashboard-chartaxislabeloptions-sorticonvisibility
            '''
            result = self._values.get("sort_icon_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of an axis label on a chart. Choose one of the following options:.

            - ``VISIBLE`` : Shows the axis.
            - ``HIDDEN`` : Hides the axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-chartaxislabeloptions.html#cfn-quicksight-dashboard-chartaxislabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ChartAxisLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ClusterMarkerConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"cluster_marker": "clusterMarker"},
    )
    class ClusterMarkerConfigurationProperty:
        def __init__(
            self,
            *,
            cluster_marker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ClusterMarkerProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cluster marker configuration of the geospatial map selected point style.

            :param cluster_marker: The cluster marker that is a part of the cluster marker configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-clustermarkerconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                cluster_marker_configuration_property = quicksight.CfnDashboard.ClusterMarkerConfigurationProperty(
                    cluster_marker=quicksight.CfnDashboard.ClusterMarkerProperty(
                        simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__06b5323baf0942a5cce8f4420ba55857c98b8ad01ca16abb52b10bb4f34c57d1)
                check_type(argname="argument cluster_marker", value=cluster_marker, expected_type=type_hints["cluster_marker"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cluster_marker is not None:
                self._values["cluster_marker"] = cluster_marker

        @builtins.property
        def cluster_marker(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ClusterMarkerProperty"]]:
            '''The cluster marker that is a part of the cluster marker configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-clustermarkerconfiguration.html#cfn-quicksight-dashboard-clustermarkerconfiguration-clustermarker
            '''
            result = self._values.get("cluster_marker")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ClusterMarkerProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ClusterMarkerConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ClusterMarkerProperty",
        jsii_struct_bases=[],
        name_mapping={"simple_cluster_marker": "simpleClusterMarker"},
    )
    class ClusterMarkerProperty:
        def __init__(
            self,
            *,
            simple_cluster_marker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SimpleClusterMarkerProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cluster marker that is a part of the cluster marker configuration.

            :param simple_cluster_marker: The simple cluster marker of the cluster marker.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-clustermarker.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                cluster_marker_property = quicksight.CfnDashboard.ClusterMarkerProperty(
                    simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                        color="color"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__37859f9ab1588836940dc064c2713f729b55ad4a5260f19ed5bab1a3b0db82b9)
                check_type(argname="argument simple_cluster_marker", value=simple_cluster_marker, expected_type=type_hints["simple_cluster_marker"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if simple_cluster_marker is not None:
                self._values["simple_cluster_marker"] = simple_cluster_marker

        @builtins.property
        def simple_cluster_marker(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SimpleClusterMarkerProperty"]]:
            '''The simple cluster marker of the cluster marker.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-clustermarker.html#cfn-quicksight-dashboard-clustermarker-simpleclustermarker
            '''
            result = self._values.get("simple_cluster_marker")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SimpleClusterMarkerProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ClusterMarkerProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ColorScaleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_fill_type": "colorFillType",
            "colors": "colors",
            "null_value_color": "nullValueColor",
        },
    )
    class ColorScaleProperty:
        def __init__(
            self,
            *,
            color_fill_type: builtins.str,
            colors: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataColorProperty", typing.Dict[builtins.str, typing.Any]]]]],
            null_value_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Determines the color scale that is applied to the visual.

            :param color_fill_type: Determines the color fill type.
            :param colors: Determines the list of colors that are applied to the visual.
            :param null_value_color: Determines the color that is applied to null values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                color_scale_property = quicksight.CfnDashboard.ColorScaleProperty(
                    color_fill_type="colorFillType",
                    colors=[quicksight.CfnDashboard.DataColorProperty(
                        color="color",
                        data_value=123
                    )],
                
                    # the properties below are optional
                    null_value_color=quicksight.CfnDashboard.DataColorProperty(
                        color="color",
                        data_value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1ef6d004039d77188e133eb812b5bb1a71e2f59ea99edf0658ba4310036867c8)
                check_type(argname="argument color_fill_type", value=color_fill_type, expected_type=type_hints["color_fill_type"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument null_value_color", value=null_value_color, expected_type=type_hints["null_value_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color_fill_type": color_fill_type,
                "colors": colors,
            }
            if null_value_color is not None:
                self._values["null_value_color"] = null_value_color

        @builtins.property
        def color_fill_type(self) -> builtins.str:
            '''Determines the color fill type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorscale.html#cfn-quicksight-dashboard-colorscale-colorfilltype
            '''
            result = self._values.get("color_fill_type")
            assert result is not None, "Required property 'color_fill_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataColorProperty"]]]:
            '''Determines the list of colors that are applied to the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorscale.html#cfn-quicksight-dashboard-colorscale-colors
            '''
            result = self._values.get("colors")
            assert result is not None, "Required property 'colors' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataColorProperty"]]], result)

        @builtins.property
        def null_value_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataColorProperty"]]:
            '''Determines the color that is applied to null values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorscale.html#cfn-quicksight-dashboard-colorscale-nullvaluecolor
            '''
            result = self._values.get("null_value_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColorScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ColorsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_colors": "customColors"},
    )
    class ColorsConfigurationProperty:
        def __init__(
            self,
            *,
            custom_colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CustomColorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The color configurations for a column.

            :param custom_colors: A list of up to 50 custom colors.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                colors_configuration_property = quicksight.CfnDashboard.ColorsConfigurationProperty(
                    custom_colors=[quicksight.CfnDashboard.CustomColorProperty(
                        color="color",
                
                        # the properties below are optional
                        field_value="fieldValue",
                        special_value="specialValue"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__52954c514bd9a5c2a13250713fc7bd9334e24f7fa9b821dbf31d62fe42d76c87)
                check_type(argname="argument custom_colors", value=custom_colors, expected_type=type_hints["custom_colors"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_colors is not None:
                self._values["custom_colors"] = custom_colors

        @builtins.property
        def custom_colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomColorProperty"]]]]:
            '''A list of up to 50 custom colors.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorsconfiguration.html#cfn-quicksight-dashboard-colorsconfiguration-customcolors
            '''
            result = self._values.get("custom_colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomColorProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColorsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ColumnConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "colors_configuration": "colorsConfiguration",
            "format_configuration": "formatConfiguration",
            "role": "role",
        },
    )
    class ColumnConfigurationProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            colors_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColorsConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            role: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The general configuration of a column.

            :param column: The column.
            :param colors_configuration: The color configurations of the column.
            :param format_configuration: The format configuration of a column.
            :param role: The role of the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_configuration_property = quicksight.CfnDashboard.ColumnConfigurationProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    colors_configuration=quicksight.CfnDashboard.ColorsConfigurationProperty(
                        custom_colors=[quicksight.CfnDashboard.CustomColorProperty(
                            color="color",
                
                            # the properties below are optional
                            field_value="fieldValue",
                            special_value="specialValue"
                        )]
                    ),
                    format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    role="role"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__66e8622dd0c8db8493d8da8c1167e0b0a505d50767f6e093b2b735f2df9803e6)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument colors_configuration", value=colors_configuration, expected_type=type_hints["colors_configuration"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument role", value=role, expected_type=type_hints["role"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
            }
            if colors_configuration is not None:
                self._values["colors_configuration"] = colors_configuration
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if role is not None:
                self._values["role"] = role

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html#cfn-quicksight-dashboard-columnconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def colors_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColorsConfigurationProperty"]]:
            '''The color configurations of the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html#cfn-quicksight-dashboard-columnconfiguration-colorsconfiguration
            '''
            result = self._values.get("colors_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColorsConfigurationProperty"]], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FormatConfigurationProperty"]]:
            '''The format configuration of a column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html#cfn-quicksight-dashboard-columnconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FormatConfigurationProperty"]], result)

        @builtins.property
        def role(self) -> typing.Optional[builtins.str]:
            '''The role of the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html#cfn-quicksight-dashboard-columnconfiguration-role
            '''
            result = self._values.get("role")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ColumnHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_hierarchy": "dateTimeHierarchy",
            "explicit_hierarchy": "explicitHierarchy",
            "predefined_hierarchy": "predefinedHierarchy",
        },
    )
    class ColumnHierarchyProperty:
        def __init__(
            self,
            *,
            date_time_hierarchy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DateTimeHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            explicit_hierarchy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ExplicitHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            predefined_hierarchy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PredefinedHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields for a visual element.

            :param date_time_hierarchy: The option that determines the hierarchy of any ``DateTime`` fields.
            :param explicit_hierarchy: The option that determines the hierarchy of the fields that are built within a visual's field wells. These fields can't be duplicated to other visuals.
            :param predefined_hierarchy: The option that determines the hierarchy of the fields that are defined during data preparation. These fields are available to use in any analysis that uses the data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnhierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_hierarchy_property = quicksight.CfnDashboard.ColumnHierarchyProperty(
                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    ),
                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    ),
                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b63144265450fdc5b5275547424ee378cbcf9fc800a0977b591e602816678322)
                check_type(argname="argument date_time_hierarchy", value=date_time_hierarchy, expected_type=type_hints["date_time_hierarchy"])
                check_type(argname="argument explicit_hierarchy", value=explicit_hierarchy, expected_type=type_hints["explicit_hierarchy"])
                check_type(argname="argument predefined_hierarchy", value=predefined_hierarchy, expected_type=type_hints["predefined_hierarchy"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_hierarchy is not None:
                self._values["date_time_hierarchy"] = date_time_hierarchy
            if explicit_hierarchy is not None:
                self._values["explicit_hierarchy"] = explicit_hierarchy
            if predefined_hierarchy is not None:
                self._values["predefined_hierarchy"] = predefined_hierarchy

        @builtins.property
        def date_time_hierarchy(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateTimeHierarchyProperty"]]:
            '''The option that determines the hierarchy of any ``DateTime`` fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnhierarchy.html#cfn-quicksight-dashboard-columnhierarchy-datetimehierarchy
            '''
            result = self._values.get("date_time_hierarchy")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateTimeHierarchyProperty"]], result)

        @builtins.property
        def explicit_hierarchy(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ExplicitHierarchyProperty"]]:
            '''The option that determines the hierarchy of the fields that are built within a visual's field wells.

            These fields can't be duplicated to other visuals.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnhierarchy.html#cfn-quicksight-dashboard-columnhierarchy-explicithierarchy
            '''
            result = self._values.get("explicit_hierarchy")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ExplicitHierarchyProperty"]], result)

        @builtins.property
        def predefined_hierarchy(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PredefinedHierarchyProperty"]]:
            '''The option that determines the hierarchy of the fields that are defined during data preparation.

            These fields are available to use in any analysis that uses the data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnhierarchy.html#cfn-quicksight-dashboard-columnhierarchy-predefinedhierarchy
            '''
            result = self._values.get("predefined_hierarchy")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PredefinedHierarchyProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ColumnIdentifierProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_name": "columnName",
            "data_set_identifier": "dataSetIdentifier",
        },
    )
    class ColumnIdentifierProperty:
        def __init__(
            self,
            *,
            column_name: builtins.str,
            data_set_identifier: builtins.str,
        ) -> None:
            '''A column of a data set.

            :param column_name: The name of the column.
            :param data_set_identifier: The data set that the column belongs to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnidentifier.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_identifier_property = quicksight.CfnDashboard.ColumnIdentifierProperty(
                    column_name="columnName",
                    data_set_identifier="dataSetIdentifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e6093774649cb04a44dfc42910e63be012b473b61ae6f7c9d7f87a698cb17b9f)
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_name": column_name,
                "data_set_identifier": data_set_identifier,
            }

        @builtins.property
        def column_name(self) -> builtins.str:
            '''The name of the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnidentifier.html#cfn-quicksight-dashboard-columnidentifier-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that the column belongs to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnidentifier.html#cfn-quicksight-dashboard-columnidentifier-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnIdentifierProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ColumnSortProperty",
        jsii_struct_bases=[],
        name_mapping={
            "direction": "direction",
            "sort_by": "sortBy",
            "aggregation_function": "aggregationFunction",
        },
    )
    class ColumnSortProperty:
        def __init__(
            self,
            *,
            direction: builtins.str,
            sort_by: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The sort configuration for a column that is not used in a field well.

            :param direction: The sort direction.
            :param sort_by: 
            :param aggregation_function: The aggregation function that is defined in the column sort.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_sort_property = quicksight.CfnDashboard.ColumnSortProperty(
                    direction="direction",
                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                        attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                            simple_attribute_aggregation="simpleAttributeAggregation",
                            value_for_multiple_values="valueForMultipleValues"
                        ),
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1fb2eeff7f74c0642923c7c6e763c4172f199943d0c6394282e00bd021bba412)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument sort_by", value=sort_by, expected_type=type_hints["sort_by"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "sort_by": sort_by,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function

        @builtins.property
        def direction(self) -> builtins.str:
            '''The sort direction.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnsort.html#cfn-quicksight-dashboard-columnsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_by(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnsort.html#cfn-quicksight-dashboard-columnsort-sortby
            '''
            result = self._values.get("sort_by")
            assert result is not None, "Required property 'sort_by' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AggregationFunctionProperty"]]:
            '''The aggregation function that is defined in the column sort.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnsort.html#cfn-quicksight-dashboard-columnsort-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AggregationFunctionProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ColumnTooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "aggregation": "aggregation",
            "label": "label",
            "visibility": "visibility",
        },
    )
    class ColumnTooltipItemProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            aggregation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The tooltip item for the columns that are not part of a field well.

            :param column: The target column of the tooltip item.
            :param aggregation: The aggregation function of the column tooltip item.
            :param label: The label of the tooltip item.
            :param visibility: The visibility of the tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_tooltip_item_property = quicksight.CfnDashboard.ColumnTooltipItemProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                        attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                            simple_attribute_aggregation="simpleAttributeAggregation",
                            value_for_multiple_values="valueForMultipleValues"
                        ),
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    label="label",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__96d6011056d24680d9b2e7f70ada41725b936a7dcab8464ea73d0a8637c042b7)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
            }
            if aggregation is not None:
                self._values["aggregation"] = aggregation
            if label is not None:
                self._values["label"] = label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The target column of the tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html#cfn-quicksight-dashboard-columntooltipitem-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def aggregation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AggregationFunctionProperty"]]:
            '''The aggregation function of the column tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html#cfn-quicksight-dashboard-columntooltipitem-aggregation
            '''
            result = self._values.get("aggregation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AggregationFunctionProperty"]], result)

        @builtins.property
        def label(self) -> typing.Optional[builtins.str]:
            '''The label of the tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html#cfn-quicksight-dashboard-columntooltipitem-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html#cfn-quicksight-dashboard-columntooltipitem-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnTooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ComboChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_values": "barValues",
            "category": "category",
            "colors": "colors",
            "line_values": "lineValues",
        },
    )
    class ComboChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            bar_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            line_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a combo chart.

            :param bar_values: The aggregated ``BarValues`` field well of a combo chart.
            :param category: The aggregated category field wells of a combo chart.
            :param colors: The aggregated colors field well of a combo chart.
            :param line_values: The aggregated ``LineValues`` field well of a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a4601f505db680f166cbaa94b69275e49fbce5a7804dcde939f285ff4ff26d28)
                check_type(argname="argument bar_values", value=bar_values, expected_type=type_hints["bar_values"])
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument line_values", value=line_values, expected_type=type_hints["line_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_values is not None:
                self._values["bar_values"] = bar_values
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if line_values is not None:
                self._values["line_values"] = line_values

        @builtins.property
        def bar_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The aggregated ``BarValues`` field well of a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html#cfn-quicksight-dashboard-combochartaggregatedfieldwells-barvalues
            '''
            result = self._values.get("bar_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The aggregated category field wells of a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html#cfn-quicksight-dashboard-combochartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The aggregated colors field well of a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html#cfn-quicksight-dashboard-combochartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def line_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The aggregated ``LineValues`` field well of a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html#cfn-quicksight-dashboard-combochartaggregatedfieldwells-linevalues
            '''
            result = self._values.get("line_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ComboChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_data_labels": "barDataLabels",
            "bars_arrangement": "barsArrangement",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_label_options": "colorLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "line_data_labels": "lineDataLabels",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "secondary_y_axis_display_options": "secondaryYAxisDisplayOptions",
            "secondary_y_axis_label_options": "secondaryYAxisLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
        },
    )
    class ComboChartConfigurationProperty:
        def __init__(
            self,
            *,
            bar_data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            bars_arrangement: typing.Optional[builtins.str] = None,
            category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ComboChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            line_data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            secondary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ComboChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``ComboChartVisual`` .

            :param bar_data_labels: The options that determine if visual data labels are displayed. The data label options for a bar in a combo chart.
            :param bars_arrangement: Determines the bar arrangement in a combo chart. The following are valid values in this structure:. - ``CLUSTERED`` : For clustered bar combo charts. - ``STACKED`` : For stacked bar combo charts. - ``STACKED_PERCENT`` : Do not use. If you use this value, the operation returns a validation error.
            :param category_axis: The category axis of a combo chart.
            :param category_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.
            :param color_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param line_data_labels: The options that determine if visual data labels are displayed. The data label options for a line in a combo chart.
            :param primary_y_axis_display_options: The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.
            :param primary_y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.
            :param reference_lines: The reference line setup of the visual.
            :param secondary_y_axis_display_options: The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.
            :param secondary_y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.
            :param sort_configuration: The sort configuration of a ``ComboChartVisual`` .
            :param tooltip: The legend display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6d19c08bcb98b3e98b8a21eef8b0850a746a9fd4262bb397c2526d270dd02022)
                check_type(argname="argument bar_data_labels", value=bar_data_labels, expected_type=type_hints["bar_data_labels"])
                check_type(argname="argument bars_arrangement", value=bars_arrangement, expected_type=type_hints["bars_arrangement"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument line_data_labels", value=line_data_labels, expected_type=type_hints["line_data_labels"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument secondary_y_axis_display_options", value=secondary_y_axis_display_options, expected_type=type_hints["secondary_y_axis_display_options"])
                check_type(argname="argument secondary_y_axis_label_options", value=secondary_y_axis_label_options, expected_type=type_hints["secondary_y_axis_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_data_labels is not None:
                self._values["bar_data_labels"] = bar_data_labels
            if bars_arrangement is not None:
                self._values["bars_arrangement"] = bars_arrangement
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if line_data_labels is not None:
                self._values["line_data_labels"] = line_data_labels
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if secondary_y_axis_display_options is not None:
                self._values["secondary_y_axis_display_options"] = secondary_y_axis_display_options
            if secondary_y_axis_label_options is not None:
                self._values["secondary_y_axis_label_options"] = secondary_y_axis_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def bar_data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            The data label options for a bar in a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-bardatalabels
            '''
            result = self._values.get("bar_data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def bars_arrangement(self) -> typing.Optional[builtins.str]:
            '''Determines the bar arrangement in a combo chart. The following are valid values in this structure:.

            - ``CLUSTERED`` : For clustered bar combo charts.
            - ``STACKED`` : For stacked bar combo charts.
            - ``STACKED_PERCENT`` : Do not use. If you use this value, the operation returns a validation error.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-barsarrangement
            '''
            result = self._values.get("bars_arrangement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The category axis of a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ComboChartFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ComboChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def line_data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            The data label options for a line in a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-linedatalabels
            '''
            result = self._values.get("line_data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineProperty"]]]]:
            '''The reference line setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineProperty"]]]], result)

        @builtins.property
        def secondary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-secondaryyaxisdisplayoptions
            '''
            result = self._values.get("secondary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def secondary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-secondaryyaxislabeloptions
            '''
            result = self._values.get("secondary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ComboChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``ComboChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ComboChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ComboChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "combo_chart_aggregated_field_wells": "comboChartAggregatedFieldWells",
        },
    )
    class ComboChartFieldWellsProperty:
        def __init__(
            self,
            *,
            combo_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ComboChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of the visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param combo_chart_aggregated_field_wells: The aggregated field wells of a combo chart. Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__750fddcd66a75ce8d856b0e7bd0d5297eae44b30206f4c923d0754bf3e356142)
                check_type(argname="argument combo_chart_aggregated_field_wells", value=combo_chart_aggregated_field_wells, expected_type=type_hints["combo_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if combo_chart_aggregated_field_wells is not None:
                self._values["combo_chart_aggregated_field_wells"] = combo_chart_aggregated_field_wells

        @builtins.property
        def combo_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ComboChartAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a combo chart.

            Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartfieldwells.html#cfn-quicksight-dashboard-combochartfieldwells-combochartaggregatedfieldwells
            '''
            result = self._values.get("combo_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ComboChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ComboChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
        },
    )
    class ComboChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``ComboChartVisual`` .

            :param category_items_limit: The item limit configuration for the category field well of a combo chart.
            :param category_sort: The sort configuration of the category field well in a combo chart.
            :param color_items_limit: The item limit configuration of the color field well in a combo chart.
            :param color_sort: The sort configuration of the color field well in a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                combo_chart_sort_configuration_property = quicksight.CfnDashboard.ComboChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e14489ee2ac7dda0e959d77faf1914af7855fdd711ea4bfae95df20f58bf5960)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The item limit configuration for the category field well of a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html#cfn-quicksight-dashboard-combochartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category field well in a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html#cfn-quicksight-dashboard-combochartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The item limit configuration of the color field well in a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html#cfn-quicksight-dashboard-combochartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the color field well in a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html#cfn-quicksight-dashboard-combochartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ComboChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class ComboChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ComboChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A combo chart.

            The ``ComboChartVisual`` includes stacked bar combo charts and clustered bar combo charts

            For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c56dc3108e3f8ec1fedb5f5c02e509a7604241deed933a5e46a9d86a8d190e71)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ComboChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ComboChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ComparisonConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "comparison_format": "comparisonFormat",
            "comparison_method": "comparisonMethod",
        },
    )
    class ComparisonConfigurationProperty:
        def __init__(
            self,
            *,
            comparison_format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ComparisonFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            comparison_method: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The comparison display configuration of a KPI or gauge chart.

            :param comparison_format: The format of the comparison.
            :param comparison_method: The method of the comparison. Choose from the following options:. - ``DIFFERENCE`` - ``PERCENT_DIFFERENCE`` - ``PERCENT``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                comparison_configuration_property = quicksight.CfnDashboard.ComparisonConfigurationProperty(
                    comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    ),
                    comparison_method="comparisonMethod"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b8e196894b8ac8b385cdaf8540ab8726ea2d1ab17972f01e9fad60382741eb32)
                check_type(argname="argument comparison_format", value=comparison_format, expected_type=type_hints["comparison_format"])
                check_type(argname="argument comparison_method", value=comparison_method, expected_type=type_hints["comparison_method"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if comparison_format is not None:
                self._values["comparison_format"] = comparison_format
            if comparison_method is not None:
                self._values["comparison_method"] = comparison_method

        @builtins.property
        def comparison_format(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ComparisonFormatConfigurationProperty"]]:
            '''The format of the comparison.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonconfiguration.html#cfn-quicksight-dashboard-comparisonconfiguration-comparisonformat
            '''
            result = self._values.get("comparison_format")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ComparisonFormatConfigurationProperty"]], result)

        @builtins.property
        def comparison_method(self) -> typing.Optional[builtins.str]:
            '''The method of the comparison. Choose from the following options:.

            - ``DIFFERENCE``
            - ``PERCENT_DIFFERENCE``
            - ``PERCENT``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonconfiguration.html#cfn-quicksight-dashboard-comparisonconfiguration-comparisonmethod
            '''
            result = self._values.get("comparison_method")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComparisonConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ComparisonFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "number_display_format_configuration": "numberDisplayFormatConfiguration",
            "percentage_display_format_configuration": "percentageDisplayFormatConfiguration",
        },
    )
    class ComparisonFormatConfigurationProperty:
        def __init__(
            self,
            *,
            number_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumberDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            percentage_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PercentageDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The format of the comparison.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param number_display_format_configuration: The number display format.
            :param percentage_display_format_configuration: The percentage display format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                comparison_format_configuration_property = quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    ),
                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        prefix="prefix",
                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0f59f1dd8d6d0e102801b593d59d5dace1c52310955f5ee932bd59dbe8ac4e24)
                check_type(argname="argument number_display_format_configuration", value=number_display_format_configuration, expected_type=type_hints["number_display_format_configuration"])
                check_type(argname="argument percentage_display_format_configuration", value=percentage_display_format_configuration, expected_type=type_hints["percentage_display_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if number_display_format_configuration is not None:
                self._values["number_display_format_configuration"] = number_display_format_configuration
            if percentage_display_format_configuration is not None:
                self._values["percentage_display_format_configuration"] = percentage_display_format_configuration

        @builtins.property
        def number_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumberDisplayFormatConfigurationProperty"]]:
            '''The number display format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonformatconfiguration.html#cfn-quicksight-dashboard-comparisonformatconfiguration-numberdisplayformatconfiguration
            '''
            result = self._values.get("number_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumberDisplayFormatConfigurationProperty"]], result)

        @builtins.property
        def percentage_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PercentageDisplayFormatConfigurationProperty"]]:
            '''The percentage display format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonformatconfiguration.html#cfn-quicksight-dashboard-comparisonformatconfiguration-percentagedisplayformatconfiguration
            '''
            result = self._values.get("percentage_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PercentageDisplayFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComparisonFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "forecast": "forecast",
            "growth_rate": "growthRate",
            "maximum_minimum": "maximumMinimum",
            "metric_comparison": "metricComparison",
            "period_over_period": "periodOverPeriod",
            "period_to_date": "periodToDate",
            "top_bottom_movers": "topBottomMovers",
            "top_bottom_ranked": "topBottomRanked",
            "total_aggregation": "totalAggregation",
            "unique_values": "uniqueValues",
        },
    )
    class ComputationProperty:
        def __init__(
            self,
            *,
            forecast: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ForecastComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            growth_rate: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GrowthRateComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            maximum_minimum: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MaximumMinimumComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            metric_comparison: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MetricComparisonComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            period_over_period: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PeriodOverPeriodComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            period_to_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PeriodToDateComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top_bottom_movers: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TopBottomMoversComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top_bottom_ranked: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TopBottomRankedComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            total_aggregation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TotalAggregationComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            unique_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.UniqueValuesComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The computation union that is used in an insight visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param forecast: The forecast computation configuration.
            :param growth_rate: The growth rate computation configuration.
            :param maximum_minimum: The maximum and minimum computation configuration.
            :param metric_comparison: The metric comparison computation configuration.
            :param period_over_period: The period over period computation configuration.
            :param period_to_date: The period to ``DataSetIdentifier`` computation configuration.
            :param top_bottom_movers: The top movers and bottom movers computation configuration.
            :param top_bottom_ranked: The top ranked and bottom ranked computation configuration.
            :param total_aggregation: The total aggregation computation configuration.
            :param unique_values: The unique values computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1c88e0fb81b82b5b5c849eba51d2c22b27aa4a826273a1235cf0706d2a766bed)
                check_type(argname="argument forecast", value=forecast, expected_type=type_hints["forecast"])
                check_type(argname="argument growth_rate", value=growth_rate, expected_type=type_hints["growth_rate"])
                check_type(argname="argument maximum_minimum", value=maximum_minimum, expected_type=type_hints["maximum_minimum"])
                check_type(argname="argument metric_comparison", value=metric_comparison, expected_type=type_hints["metric_comparison"])
                check_type(argname="argument period_over_period", value=period_over_period, expected_type=type_hints["period_over_period"])
                check_type(argname="argument period_to_date", value=period_to_date, expected_type=type_hints["period_to_date"])
                check_type(argname="argument top_bottom_movers", value=top_bottom_movers, expected_type=type_hints["top_bottom_movers"])
                check_type(argname="argument top_bottom_ranked", value=top_bottom_ranked, expected_type=type_hints["top_bottom_ranked"])
                check_type(argname="argument total_aggregation", value=total_aggregation, expected_type=type_hints["total_aggregation"])
                check_type(argname="argument unique_values", value=unique_values, expected_type=type_hints["unique_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if forecast is not None:
                self._values["forecast"] = forecast
            if growth_rate is not None:
                self._values["growth_rate"] = growth_rate
            if maximum_minimum is not None:
                self._values["maximum_minimum"] = maximum_minimum
            if metric_comparison is not None:
                self._values["metric_comparison"] = metric_comparison
            if period_over_period is not None:
                self._values["period_over_period"] = period_over_period
            if period_to_date is not None:
                self._values["period_to_date"] = period_to_date
            if top_bottom_movers is not None:
                self._values["top_bottom_movers"] = top_bottom_movers
            if top_bottom_ranked is not None:
                self._values["top_bottom_ranked"] = top_bottom_ranked
            if total_aggregation is not None:
                self._values["total_aggregation"] = total_aggregation
            if unique_values is not None:
                self._values["unique_values"] = unique_values

        @builtins.property
        def forecast(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ForecastComputationProperty"]]:
            '''The forecast computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-forecast
            '''
            result = self._values.get("forecast")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ForecastComputationProperty"]], result)

        @builtins.property
        def growth_rate(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GrowthRateComputationProperty"]]:
            '''The growth rate computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-growthrate
            '''
            result = self._values.get("growth_rate")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GrowthRateComputationProperty"]], result)

        @builtins.property
        def maximum_minimum(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MaximumMinimumComputationProperty"]]:
            '''The maximum and minimum computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-maximumminimum
            '''
            result = self._values.get("maximum_minimum")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MaximumMinimumComputationProperty"]], result)

        @builtins.property
        def metric_comparison(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MetricComparisonComputationProperty"]]:
            '''The metric comparison computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-metriccomparison
            '''
            result = self._values.get("metric_comparison")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MetricComparisonComputationProperty"]], result)

        @builtins.property
        def period_over_period(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PeriodOverPeriodComputationProperty"]]:
            '''The period over period computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-periodoverperiod
            '''
            result = self._values.get("period_over_period")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PeriodOverPeriodComputationProperty"]], result)

        @builtins.property
        def period_to_date(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PeriodToDateComputationProperty"]]:
            '''The period to ``DataSetIdentifier`` computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-periodtodate
            '''
            result = self._values.get("period_to_date")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PeriodToDateComputationProperty"]], result)

        @builtins.property
        def top_bottom_movers(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TopBottomMoversComputationProperty"]]:
            '''The top movers and bottom movers computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-topbottommovers
            '''
            result = self._values.get("top_bottom_movers")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TopBottomMoversComputationProperty"]], result)

        @builtins.property
        def top_bottom_ranked(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TopBottomRankedComputationProperty"]]:
            '''The top ranked and bottom ranked computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-topbottomranked
            '''
            result = self._values.get("top_bottom_ranked")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TopBottomRankedComputationProperty"]], result)

        @builtins.property
        def total_aggregation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TotalAggregationComputationProperty"]]:
            '''The total aggregation computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-totalaggregation
            '''
            result = self._values.get("total_aggregation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TotalAggregationComputationProperty"]], result)

        @builtins.property
        def unique_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.UniqueValuesComputationProperty"]]:
            '''The unique values computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-uniquevalues
            '''
            result = self._values.get("unique_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.UniqueValuesComputationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ConditionalFormattingColorProperty",
        jsii_struct_bases=[],
        name_mapping={"gradient": "gradient", "solid": "solid"},
    )
    class ConditionalFormattingColorProperty:
        def __init__(
            self,
            *,
            gradient: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingGradientColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            solid: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingSolidColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The formatting configuration for the color.

            :param gradient: Formatting configuration for gradient color.
            :param solid: Formatting configuration for solid color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_color_property = quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                        color=quicksight.CfnDashboard.GradientColorProperty(
                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                gradient_offset=123,
                
                                # the properties below are optional
                                color="color",
                                data_value=123
                            )]
                        ),
                        expression="expression"
                    ),
                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                        expression="expression",
                
                        # the properties below are optional
                        color="color"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__88a8387bfb2cbcecb9460319453a7db8b6a2c5f735ae4e8608a1d6b47037d026)
                check_type(argname="argument gradient", value=gradient, expected_type=type_hints["gradient"])
                check_type(argname="argument solid", value=solid, expected_type=type_hints["solid"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if gradient is not None:
                self._values["gradient"] = gradient
            if solid is not None:
                self._values["solid"] = solid

        @builtins.property
        def gradient(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingGradientColorProperty"]]:
            '''Formatting configuration for gradient color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcolor.html#cfn-quicksight-dashboard-conditionalformattingcolor-gradient
            '''
            result = self._values.get("gradient")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingGradientColorProperty"]], result)

        @builtins.property
        def solid(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingSolidColorProperty"]]:
            '''Formatting configuration for solid color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcolor.html#cfn-quicksight-dashboard-conditionalformattingcolor-solid
            '''
            result = self._values.get("solid")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingSolidColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "expression": "expression",
            "icon_options": "iconOptions",
            "color": "color",
            "display_configuration": "displayConfiguration",
        },
    )
    class ConditionalFormattingCustomIconConditionProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            icon_options: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingCustomIconOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
            color: typing.Optional[builtins.str] = None,
            display_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Determines the custom condition for an icon set.

            :param expression: The expression that determines the condition of the icon set.
            :param icon_options: Custom icon options for an icon set.
            :param color: Determines the color of the icon.
            :param display_configuration: Determines the icon display configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_custom_icon_condition_property = quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                    expression="expression",
                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                        icon="icon",
                        unicode_icon="unicodeIcon"
                    ),
                
                    # the properties below are optional
                    color="color",
                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                        icon_display_option="iconDisplayOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ed3cc39ecaf3fd90a69e4d089e00af009bc69b9e288971097164c04094802f4f)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument icon_options", value=icon_options, expected_type=type_hints["icon_options"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument display_configuration", value=display_configuration, expected_type=type_hints["display_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
                "icon_options": icon_options,
            }
            if color is not None:
                self._values["color"] = color
            if display_configuration is not None:
                self._values["display_configuration"] = display_configuration

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the condition of the icon set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html#cfn-quicksight-dashboard-conditionalformattingcustomiconcondition-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def icon_options(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingCustomIconOptionsProperty"]:
            '''Custom icon options for an icon set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html#cfn-quicksight-dashboard-conditionalformattingcustomiconcondition-iconoptions
            '''
            result = self._values.get("icon_options")
            assert result is not None, "Required property 'icon_options' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingCustomIconOptionsProperty"], result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html#cfn-quicksight-dashboard-conditionalformattingcustomiconcondition-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty"]]:
            '''Determines the icon display configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html#cfn-quicksight-dashboard-conditionalformattingcustomiconcondition-displayconfiguration
            '''
            result = self._values.get("display_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingCustomIconConditionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "unicode_icon": "unicodeIcon"},
    )
    class ConditionalFormattingCustomIconOptionsProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[builtins.str] = None,
            unicode_icon: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Custom icon options for an icon set.

            :param icon: Determines the type of icon.
            :param unicode_icon: Determines the Unicode icon type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_custom_icon_options_property = quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                    icon="icon",
                    unicode_icon="unicodeIcon"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ee2f39575eff053694b3d8008cdbd992af0fd6cf3fca2df85843e51416b61812)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument unicode_icon", value=unicode_icon, expected_type=type_hints["unicode_icon"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if unicode_icon is not None:
                self._values["unicode_icon"] = unicode_icon

        @builtins.property
        def icon(self) -> typing.Optional[builtins.str]:
            '''Determines the type of icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconoptions.html#cfn-quicksight-dashboard-conditionalformattingcustomiconoptions-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def unicode_icon(self) -> typing.Optional[builtins.str]:
            '''Determines the Unicode icon type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconoptions.html#cfn-quicksight-dashboard-conditionalformattingcustomiconoptions-unicodeicon
            '''
            result = self._values.get("unicode_icon")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingCustomIconOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "expression": "expression"},
    )
    class ConditionalFormattingGradientColorProperty:
        def __init__(
            self,
            *,
            color: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GradientColorProperty", typing.Dict[builtins.str, typing.Any]]],
            expression: builtins.str,
        ) -> None:
            '''Formatting configuration for gradient color.

            :param color: Determines the color.
            :param expression: The expression that determines the formatting configuration for gradient color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattinggradientcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_gradient_color_property = quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                    color=quicksight.CfnDashboard.GradientColorProperty(
                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                            gradient_offset=123,
                
                            # the properties below are optional
                            color="color",
                            data_value=123
                        )]
                    ),
                    expression="expression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2597a121e0ae9bb968ae505e70d399bf5ae60328f6d14047e43b01b88daa0a76)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
                "expression": expression,
            }

        @builtins.property
        def color(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.GradientColorProperty"]:
            '''Determines the color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattinggradientcolor.html#cfn-quicksight-dashboard-conditionalformattinggradientcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.GradientColorProperty"], result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for gradient color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattinggradientcolor.html#cfn-quicksight-dashboard-conditionalformattinggradientcolor-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingGradientColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"icon_display_option": "iconDisplayOption"},
    )
    class ConditionalFormattingIconDisplayConfigurationProperty:
        def __init__(
            self,
            *,
            icon_display_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the icon display configuration.

            :param icon_display_option: Determines the icon display configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicondisplayconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_icon_display_configuration_property = quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                    icon_display_option="iconDisplayOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fe4245d68dd9ae181a10d86eac3b16ff18b9d1a07aecd186d06803116461c310)
                check_type(argname="argument icon_display_option", value=icon_display_option, expected_type=type_hints["icon_display_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon_display_option is not None:
                self._values["icon_display_option"] = icon_display_option

        @builtins.property
        def icon_display_option(self) -> typing.Optional[builtins.str]:
            '''Determines the icon display configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicondisplayconfiguration.html#cfn-quicksight-dashboard-conditionalformattingicondisplayconfiguration-icondisplayoption
            '''
            result = self._values.get("icon_display_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconDisplayConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ConditionalFormattingIconProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_condition": "customCondition", "icon_set": "iconSet"},
    )
    class ConditionalFormattingIconProperty:
        def __init__(
            self,
            *,
            custom_condition: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingCustomIconConditionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            icon_set: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingIconSetProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The formatting configuration for the icon.

            :param custom_condition: Determines the custom condition for an icon set.
            :param icon_set: Formatting configuration for icon set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicon.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_icon_property = quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                    custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                        expression="expression",
                        icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                            icon="icon",
                            unicode_icon="unicodeIcon"
                        ),
                
                        # the properties below are optional
                        color="color",
                        display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                            icon_display_option="iconDisplayOption"
                        )
                    ),
                    icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                        expression="expression",
                
                        # the properties below are optional
                        icon_set_type="iconSetType"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__76b7c03283d97079c4d4bd096728b150b22eaeb518146d704b9a7aca34445ea5)
                check_type(argname="argument custom_condition", value=custom_condition, expected_type=type_hints["custom_condition"])
                check_type(argname="argument icon_set", value=icon_set, expected_type=type_hints["icon_set"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_condition is not None:
                self._values["custom_condition"] = custom_condition
            if icon_set is not None:
                self._values["icon_set"] = icon_set

        @builtins.property
        def custom_condition(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingCustomIconConditionProperty"]]:
            '''Determines the custom condition for an icon set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicon.html#cfn-quicksight-dashboard-conditionalformattingicon-customcondition
            '''
            result = self._values.get("custom_condition")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingCustomIconConditionProperty"]], result)

        @builtins.property
        def icon_set(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingIconSetProperty"]]:
            '''Formatting configuration for icon set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicon.html#cfn-quicksight-dashboard-conditionalformattingicon-iconset
            '''
            result = self._values.get("icon_set")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingIconSetProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ConditionalFormattingIconSetProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "icon_set_type": "iconSetType"},
    )
    class ConditionalFormattingIconSetProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            icon_set_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Formatting configuration for icon set.

            :param expression: The expression that determines the formatting configuration for the icon set.
            :param icon_set_type: Determines the icon set type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingiconset.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_icon_set_property = quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                    expression="expression",
                
                    # the properties below are optional
                    icon_set_type="iconSetType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bdb3a9d1c8c1ab25c7a5f72bc88b9738eba5d6bab1d5ca4d29bd0e4d42224e3f)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument icon_set_type", value=icon_set_type, expected_type=type_hints["icon_set_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if icon_set_type is not None:
                self._values["icon_set_type"] = icon_set_type

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for the icon set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingiconset.html#cfn-quicksight-dashboard-conditionalformattingiconset-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def icon_set_type(self) -> typing.Optional[builtins.str]:
            '''Determines the icon set type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingiconset.html#cfn-quicksight-dashboard-conditionalformattingiconset-iconsettype
            '''
            result = self._values.get("icon_set_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconSetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "color": "color"},
    )
    class ConditionalFormattingSolidColorProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            color: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Formatting configuration for solid color.

            :param expression: The expression that determines the formatting configuration for solid color.
            :param color: Determines the color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingsolidcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_solid_color_property = quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                    expression="expression",
                
                    # the properties below are optional
                    color="color"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__272578562644e2eb61241c8c390a9e6b789d45f67326ebbe68b342827bd61c44)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if color is not None:
                self._values["color"] = color

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for solid color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingsolidcolor.html#cfn-quicksight-dashboard-conditionalformattingsolidcolor-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingsolidcolor.html#cfn-quicksight-dashboard-conditionalformattingsolidcolor-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingSolidColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ContributionAnalysisDefaultProperty",
        jsii_struct_bases=[],
        name_mapping={
            "contributor_dimensions": "contributorDimensions",
            "measure_field_id": "measureFieldId",
        },
    )
    class ContributionAnalysisDefaultProperty:
        def __init__(
            self,
            *,
            contributor_dimensions: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]]],
            measure_field_id: builtins.str,
        ) -> None:
            '''The contribution analysis visual display for a line, pie, or bar chart.

            :param contributor_dimensions: The dimensions columns that are used in the contribution analysis, usually a list of ``ColumnIdentifiers`` .
            :param measure_field_id: The measure field that is used in the contribution analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-contributionanalysisdefault.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                contribution_analysis_default_property = quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                    contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    measure_field_id="measureFieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3e03029700976e5cffc01742a3eb8eb3645dac78c9ae9b02746e90c0a2455565)
                check_type(argname="argument contributor_dimensions", value=contributor_dimensions, expected_type=type_hints["contributor_dimensions"])
                check_type(argname="argument measure_field_id", value=measure_field_id, expected_type=type_hints["measure_field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "contributor_dimensions": contributor_dimensions,
                "measure_field_id": measure_field_id,
            }

        @builtins.property
        def contributor_dimensions(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]]]:
            '''The dimensions columns that are used in the contribution analysis, usually a list of ``ColumnIdentifiers`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-contributionanalysisdefault.html#cfn-quicksight-dashboard-contributionanalysisdefault-contributordimensions
            '''
            result = self._values.get("contributor_dimensions")
            assert result is not None, "Required property 'contributor_dimensions' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]]], result)

        @builtins.property
        def measure_field_id(self) -> builtins.str:
            '''The measure field that is used in the contribution analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-contributionanalysisdefault.html#cfn-quicksight-dashboard-contributionanalysisdefault-measurefieldid
            '''
            result = self._values.get("measure_field_id")
            assert result is not None, "Required property 'measure_field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ContributionAnalysisDefaultProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "number_scale": "numberScale",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
            "symbol": "symbol",
        },
    )
    class CurrencyDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            negative_value_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_scale: typing.Optional[builtins.str] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            suffix: typing.Optional[builtins.str] = None,
            symbol: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the currency display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param number_scale: Determines the number scale value for the currency format.
            :param prefix: Determines the prefix value of the currency format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the currency format.
            :param symbol: Determines the symbol for the currency format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                currency_display_format_configuration_property = quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    number_scale="numberScale",
                    prefix="prefix",
                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix",
                    symbol="symbol"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__235a95352eaac3f8dd43f46a556706a771a21cf49fe0fa4a1349fdfaff4de4bc)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument number_scale", value=number_scale, expected_type=type_hints["number_scale"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
                check_type(argname="argument symbol", value=symbol, expected_type=type_hints["symbol"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if number_scale is not None:
                self._values["number_scale"] = number_scale
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix
            if symbol is not None:
                self._values["symbol"] = symbol

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DecimalPlacesConfigurationProperty"]]:
            '''The option that determines the decimal places configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DecimalPlacesConfigurationProperty"]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NegativeValueConfigurationProperty"]]:
            '''The options that determine the negative value configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NegativeValueConfigurationProperty"]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def number_scale(self) -> typing.Optional[builtins.str]:
            '''Determines the number scale value for the currency format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-numberscale
            '''
            result = self._values.get("number_scale")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the currency format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericSeparatorConfigurationProperty"]]:
            '''The options that determine the numeric separator configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericSeparatorConfigurationProperty"]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the currency format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def symbol(self) -> typing.Optional[builtins.str]:
            '''Determines the symbol for the currency format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-symbol
            '''
            result = self._values.get("symbol")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CurrencyDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CustomActionFilterOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "selected_fields_configuration": "selectedFieldsConfiguration",
            "target_visuals_configuration": "targetVisualsConfiguration",
        },
    )
    class CustomActionFilterOperationProperty:
        def __init__(
            self,
            *,
            selected_fields_configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            target_visuals_configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilterOperationTargetVisualsConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The filter operation that filters data included in a visual or in an entire sheet.

            :param selected_fields_configuration: The configuration that chooses the fields to be filtered.
            :param target_visuals_configuration: The configuration that chooses the target visuals to be filtered.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionfilteroperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_action_filter_operation_property = quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                        selected_columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        selected_field_options="selectedFieldOptions",
                        selected_fields=["selectedFields"]
                    ),
                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                            target_visual_options="targetVisualOptions",
                            target_visuals=["targetVisuals"]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ca93d409bb0ca5acf790524575431726482f03d6f24a12edf6f6c380d27d8ae0)
                check_type(argname="argument selected_fields_configuration", value=selected_fields_configuration, expected_type=type_hints["selected_fields_configuration"])
                check_type(argname="argument target_visuals_configuration", value=target_visuals_configuration, expected_type=type_hints["target_visuals_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "selected_fields_configuration": selected_fields_configuration,
                "target_visuals_configuration": target_visuals_configuration,
            }

        @builtins.property
        def selected_fields_configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty"]:
            '''The configuration that chooses the fields to be filtered.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionfilteroperation.html#cfn-quicksight-dashboard-customactionfilteroperation-selectedfieldsconfiguration
            '''
            result = self._values.get("selected_fields_configuration")
            assert result is not None, "Required property 'selected_fields_configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty"], result)

        @builtins.property
        def target_visuals_configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterOperationTargetVisualsConfigurationProperty"]:
            '''The configuration that chooses the target visuals to be filtered.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionfilteroperation.html#cfn-quicksight-dashboard-customactionfilteroperation-targetvisualsconfiguration
            '''
            result = self._values.get("target_visuals_configuration")
            assert result is not None, "Required property 'target_visuals_configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterOperationTargetVisualsConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionFilterOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CustomActionNavigationOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "local_navigation_configuration": "localNavigationConfiguration",
        },
    )
    class CustomActionNavigationOperationProperty:
        def __init__(
            self,
            *,
            local_navigation_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LocalNavigationConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The navigation operation that navigates between different sheets in the same analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param local_navigation_configuration: The configuration that chooses the navigation target.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionnavigationoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_action_navigation_operation_property = quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                        target_sheet_id="targetSheetId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3492367ac39471d6d5e9f4bc6d5027d2a5b3ba696c04f259be40cccace6ba539)
                check_type(argname="argument local_navigation_configuration", value=local_navigation_configuration, expected_type=type_hints["local_navigation_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if local_navigation_configuration is not None:
                self._values["local_navigation_configuration"] = local_navigation_configuration

        @builtins.property
        def local_navigation_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LocalNavigationConfigurationProperty"]]:
            '''The configuration that chooses the navigation target.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionnavigationoperation.html#cfn-quicksight-dashboard-customactionnavigationoperation-localnavigationconfiguration
            '''
            result = self._values.get("local_navigation_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LocalNavigationConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionNavigationOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CustomActionSetParametersOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_value_configurations": "parameterValueConfigurations",
        },
    )
    class CustomActionSetParametersOperationProperty:
        def __init__(
            self,
            *,
            parameter_value_configurations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SetParameterValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The set parameter operation that sets parameters in custom action.

            :param parameter_value_configurations: The parameter that determines the value configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionsetparametersoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_action_set_parameters_operation_property = quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                        destination_parameter_name="destinationParameterName",
                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                    date_time_values=["dateTimeValues"],
                                    decimal_values=[123],
                                    integer_values=[123],
                                    string_values=["stringValues"]
                                ),
                
                                # the properties below are optional
                                include_null_value=False
                            ),
                            select_all_value_options="selectAllValueOptions",
                            source_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_field="sourceField",
                            source_parameter_name="sourceParameterName"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4ea98618066df7305ad3e0f620deeeffed1af87a2316908d6dd39be7650ec331)
                check_type(argname="argument parameter_value_configurations", value=parameter_value_configurations, expected_type=type_hints["parameter_value_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_value_configurations": parameter_value_configurations,
            }

        @builtins.property
        def parameter_value_configurations(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SetParameterValueConfigurationProperty"]]]:
            '''The parameter that determines the value configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionsetparametersoperation.html#cfn-quicksight-dashboard-customactionsetparametersoperation-parametervalueconfigurations
            '''
            result = self._values.get("parameter_value_configurations")
            assert result is not None, "Required property 'parameter_value_configurations' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SetParameterValueConfigurationProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionSetParametersOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CustomActionURLOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"url_target": "urlTarget", "url_template": "urlTemplate"},
    )
    class CustomActionURLOperationProperty:
        def __init__(
            self,
            *,
            url_target: builtins.str,
            url_template: builtins.str,
        ) -> None:
            '''The URL operation that opens a link to another webpage.

            :param url_target: The target of the ``CustomActionURLOperation`` . Valid values are defined as follows: - ``NEW_TAB`` : Opens the target URL in a new browser tab. - ``NEW_WINDOW`` : Opens the target URL in a new browser window. - ``SAME_TAB`` : Opens the target URL in the same browser tab.
            :param url_template: THe URL link of the ``CustomActionURLOperation`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionurloperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_action_uRLOperation_property = quicksight.CfnDashboard.CustomActionURLOperationProperty(
                    url_target="urlTarget",
                    url_template="urlTemplate"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0b831c7ba679c3665ff690d272674eaaa1db367da2162f5a4827cab1ae43ea72)
                check_type(argname="argument url_target", value=url_target, expected_type=type_hints["url_target"])
                check_type(argname="argument url_template", value=url_template, expected_type=type_hints["url_template"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "url_target": url_target,
                "url_template": url_template,
            }

        @builtins.property
        def url_target(self) -> builtins.str:
            '''The target of the ``CustomActionURLOperation`` .

            Valid values are defined as follows:

            - ``NEW_TAB`` : Opens the target URL in a new browser tab.
            - ``NEW_WINDOW`` : Opens the target URL in a new browser window.
            - ``SAME_TAB`` : Opens the target URL in the same browser tab.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionurloperation.html#cfn-quicksight-dashboard-customactionurloperation-urltarget
            '''
            result = self._values.get("url_target")
            assert result is not None, "Required property 'url_target' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def url_template(self) -> builtins.str:
            '''THe URL link of the ``CustomActionURLOperation`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionurloperation.html#cfn-quicksight-dashboard-customactionurloperation-urltemplate
            '''
            result = self._values.get("url_template")
            assert result is not None, "Required property 'url_template' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionURLOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CustomColorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color": "color",
            "field_value": "fieldValue",
            "special_value": "specialValue",
        },
    )
    class CustomColorProperty:
        def __init__(
            self,
            *,
            color: builtins.str,
            field_value: typing.Optional[builtins.str] = None,
            special_value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the color that's applied to a particular data value in a column.

            :param color: The color that is applied to the data value.
            :param field_value: The data value that the color is applied to.
            :param special_value: The value of a special data value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_color_property = quicksight.CfnDashboard.CustomColorProperty(
                    color="color",
                
                    # the properties below are optional
                    field_value="fieldValue",
                    special_value="specialValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7e9f957c9df98206ae11864f8584f7c563586a42c9db0556ecb3d00aa0c9f012)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument special_value", value=special_value, expected_type=type_hints["special_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
            }
            if field_value is not None:
                self._values["field_value"] = field_value
            if special_value is not None:
                self._values["special_value"] = special_value

        @builtins.property
        def color(self) -> builtins.str:
            '''The color that is applied to the data value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcolor.html#cfn-quicksight-dashboard-customcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The data value that the color is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcolor.html#cfn-quicksight-dashboard-customcolor-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def special_value(self) -> typing.Optional[builtins.str]:
            '''The value of a special data value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcolor.html#cfn-quicksight-dashboard-customcolor-specialvalue
            '''
            result = self._values.get("special_value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CustomContentConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "content_type": "contentType",
            "content_url": "contentUrl",
            "image_scaling": "imageScaling",
        },
    )
    class CustomContentConfigurationProperty:
        def __init__(
            self,
            *,
            content_type: typing.Optional[builtins.str] = None,
            content_url: typing.Optional[builtins.str] = None,
            image_scaling: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of a ``CustomContentVisual`` .

            :param content_type: The content type of the custom content visual. You can use this to have the visual render as an image.
            :param content_url: The input URL that links to the custom content that you want in the custom visual.
            :param image_scaling: The sizing options for the size of the custom content visual. This structure is required when the ``ContentType`` of the visual is ``'IMAGE'`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_content_configuration_property = quicksight.CfnDashboard.CustomContentConfigurationProperty(
                    content_type="contentType",
                    content_url="contentUrl",
                    image_scaling="imageScaling"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__64f037fd56898a28a550e2ed664bd5a58ddfca34ba1a572582230ffbe7b7bb1f)
                check_type(argname="argument content_type", value=content_type, expected_type=type_hints["content_type"])
                check_type(argname="argument content_url", value=content_url, expected_type=type_hints["content_url"])
                check_type(argname="argument image_scaling", value=image_scaling, expected_type=type_hints["image_scaling"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if content_type is not None:
                self._values["content_type"] = content_type
            if content_url is not None:
                self._values["content_url"] = content_url
            if image_scaling is not None:
                self._values["image_scaling"] = image_scaling

        @builtins.property
        def content_type(self) -> typing.Optional[builtins.str]:
            '''The content type of the custom content visual.

            You can use this to have the visual render as an image.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentconfiguration.html#cfn-quicksight-dashboard-customcontentconfiguration-contenttype
            '''
            result = self._values.get("content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def content_url(self) -> typing.Optional[builtins.str]:
            '''The input URL that links to the custom content that you want in the custom visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentconfiguration.html#cfn-quicksight-dashboard-customcontentconfiguration-contenturl
            '''
            result = self._values.get("content_url")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def image_scaling(self) -> typing.Optional[builtins.str]:
            '''The sizing options for the size of the custom content visual.

            This structure is required when the ``ContentType`` of the visual is ``'IMAGE'`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentconfiguration.html#cfn-quicksight-dashboard-customcontentconfiguration-imagescaling
            '''
            result = self._values.get("image_scaling")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomContentConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CustomContentVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class CustomContentVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CustomContentConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A visual that contains custom content.

            For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :param data_set_identifier: The dataset that is used to create the custom content visual. You can't create a visual without a dataset.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``CustomContentVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_content_visual_property = quicksight.CfnDashboard.CustomContentVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.CustomContentConfigurationProperty(
                        content_type="contentType",
                        content_url="contentUrl",
                        image_scaling="imageScaling"
                    ),
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__354d93a497099427a608068f40c1d32059de70bdd997fced2346f971a5114404)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The dataset that is used to create the custom content visual.

            You can't create a visual without a dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomContentConfigurationProperty"]]:
            '''The configuration of a ``CustomContentVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomContentConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomContentVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CustomFilterConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "category_value": "categoryValue",
            "parameter_name": "parameterName",
            "select_all_options": "selectAllOptions",
        },
    )
    class CustomFilterConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            null_option: builtins.str,
            category_value: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A custom filter that filters based on a single value.

            This filter can be partially matched.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param category_value: The category value for the filter. This field is mutually exclusive to ``ParameterName`` .
            :param parameter_name: The parameter whose value should be used for the filter value. This field is mutually exclusive to ``CategoryValue`` .
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_filter_configuration_property = quicksight.CfnDashboard.CustomFilterConfigurationProperty(
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    category_value="categoryValue",
                    parameter_name="parameterName",
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a321f2a48177fd94bc6c941da6234b88fa63b0c5a72a7a8debc04d6db62f368f)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument category_value", value=category_value, expected_type=type_hints["category_value"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if category_value is not None:
                self._values["category_value"] = category_value
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_value(self) -> typing.Optional[builtins.str]:
            '''The category value for the filter.

            This field is mutually exclusive to ``ParameterName`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-categoryvalue
            '''
            result = self._values.get("category_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            This field is mutually exclusive to ``CategoryValue`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomFilterConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CustomFilterListConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "category_values": "categoryValues",
            "select_all_options": "selectAllOptions",
        },
    )
    class CustomFilterListConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            null_option: builtins.str,
            category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A list of custom filter values.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param category_values: The list of category values for the filter.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_filter_list_configuration_property = quicksight.CfnDashboard.CustomFilterListConfigurationProperty(
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    category_values=["categoryValues"],
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__44b72029c0f8352cba8c7b55ff03212461cd317ede5e2c548ad957630eb7d9d5)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if category_values is not None:
                self._values["category_values"] = category_values
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html#cfn-quicksight-dashboard-customfilterlistconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html#cfn-quicksight-dashboard-customfilterlistconfiguration-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of category values for the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html#cfn-quicksight-dashboard-customfilterlistconfiguration-categoryvalues
            '''
            result = self._values.get("category_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html#cfn-quicksight-dashboard-customfilterlistconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomFilterListConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CustomNarrativeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"narrative": "narrative"},
    )
    class CustomNarrativeOptionsProperty:
        def __init__(self, *, narrative: builtins.str) -> None:
            '''The custom narrative options.

            :param narrative: The string input of custom narrative.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customnarrativeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_narrative_options_property = quicksight.CfnDashboard.CustomNarrativeOptionsProperty(
                    narrative="narrative"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c65e3cae33c0dc61d3615e127c179e32db1f7411cde8ad49580649d899f06c1b)
                check_type(argname="argument narrative", value=narrative, expected_type=type_hints["narrative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "narrative": narrative,
            }

        @builtins.property
        def narrative(self) -> builtins.str:
            '''The string input of custom narrative.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customnarrativeoptions.html#cfn-quicksight-dashboard-customnarrativeoptions-narrative
            '''
            result = self._values.get("narrative")
            assert result is not None, "Required property 'narrative' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomNarrativeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CustomParameterValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_values": "dateTimeValues",
            "decimal_values": "decimalValues",
            "integer_values": "integerValues",
            "string_values": "stringValues",
        },
    )
    class CustomParameterValuesProperty:
        def __init__(
            self,
            *,
            date_time_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            decimal_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
            integer_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
            string_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The customized parameter values.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_values: A list of datetime-type parameter values.
            :param decimal_values: A list of decimal-type parameter values.
            :param integer_values: A list of integer-type parameter values.
            :param string_values: A list of string-type parameter values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_parameter_values_property = quicksight.CfnDashboard.CustomParameterValuesProperty(
                    date_time_values=["dateTimeValues"],
                    decimal_values=[123],
                    integer_values=[123],
                    string_values=["stringValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__33466e20565e5347076222755427f3d07f86ba3912eac79845bebaa14b278bc4)
                check_type(argname="argument date_time_values", value=date_time_values, expected_type=type_hints["date_time_values"])
                check_type(argname="argument decimal_values", value=decimal_values, expected_type=type_hints["decimal_values"])
                check_type(argname="argument integer_values", value=integer_values, expected_type=type_hints["integer_values"])
                check_type(argname="argument string_values", value=string_values, expected_type=type_hints["string_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_values is not None:
                self._values["date_time_values"] = date_time_values
            if decimal_values is not None:
                self._values["decimal_values"] = decimal_values
            if integer_values is not None:
                self._values["integer_values"] = integer_values
            if string_values is not None:
                self._values["string_values"] = string_values

        @builtins.property
        def date_time_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of datetime-type parameter values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html#cfn-quicksight-dashboard-customparametervalues-datetimevalues
            '''
            result = self._values.get("date_time_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def decimal_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]]:
            '''A list of decimal-type parameter values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html#cfn-quicksight-dashboard-customparametervalues-decimalvalues
            '''
            result = self._values.get("decimal_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]], result)

        @builtins.property
        def integer_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]]:
            '''A list of integer-type parameter values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html#cfn-quicksight-dashboard-customparametervalues-integervalues
            '''
            result = self._values.get("integer_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]], result)

        @builtins.property
        def string_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of string-type parameter values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html#cfn-quicksight-dashboard-customparametervalues-stringvalues
            '''
            result = self._values.get("string_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomParameterValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.CustomValuesConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_values": "customValues",
            "include_null_value": "includeNullValue",
        },
    )
    class CustomValuesConfigurationProperty:
        def __init__(
            self,
            *,
            custom_values: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CustomParameterValuesProperty", typing.Dict[builtins.str, typing.Any]]],
            include_null_value: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
        ) -> None:
            '''The configuration of custom values for the destination parameter in ``DestinationParameterValueConfiguration`` .

            :param custom_values: 
            :param include_null_value: Includes the null value in custom action parameter values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customvaluesconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_values_configuration_property = quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                        date_time_values=["dateTimeValues"],
                        decimal_values=[123],
                        integer_values=[123],
                        string_values=["stringValues"]
                    ),
                
                    # the properties below are optional
                    include_null_value=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7fa24bde9f040db1bb0899a06916f6b95315c730d7af9ae814a68caba3800645)
                check_type(argname="argument custom_values", value=custom_values, expected_type=type_hints["custom_values"])
                check_type(argname="argument include_null_value", value=include_null_value, expected_type=type_hints["include_null_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "custom_values": custom_values,
            }
            if include_null_value is not None:
                self._values["include_null_value"] = include_null_value

        @builtins.property
        def custom_values(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomParameterValuesProperty"]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customvaluesconfiguration.html#cfn-quicksight-dashboard-customvaluesconfiguration-customvalues
            '''
            result = self._values.get("custom_values")
            assert result is not None, "Required property 'custom_values' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomParameterValuesProperty"], result)

        @builtins.property
        def include_null_value(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''Includes the null value in custom action parameter values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customvaluesconfiguration.html#cfn-quicksight-dashboard-customvaluesconfiguration-includenullvalue
            '''
            result = self._values.get("include_null_value")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomValuesConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DashboardErrorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "message": "message",
            "type": "type",
            "violated_entities": "violatedEntities",
        },
    )
    class DashboardErrorProperty:
        def __init__(
            self,
            *,
            message: typing.Optional[builtins.str] = None,
            type: typing.Optional[builtins.str] = None,
            violated_entities: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.EntityProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''Dashboard error.

            :param message: Message.
            :param type: Type.
            :param violated_entities: Lists the violated entities that caused the dashboard error.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboarderror.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                dashboard_error_property = quicksight.CfnDashboard.DashboardErrorProperty(
                    message="message",
                    type="type",
                    violated_entities=[quicksight.CfnDashboard.EntityProperty(
                        path="path"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__61c0c303f4ca0cb34d1d364e3a84603385cd100cd97983f58920860f89aef2a4)
                check_type(argname="argument message", value=message, expected_type=type_hints["message"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument violated_entities", value=violated_entities, expected_type=type_hints["violated_entities"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if message is not None:
                self._values["message"] = message
            if type is not None:
                self._values["type"] = type
            if violated_entities is not None:
                self._values["violated_entities"] = violated_entities

        @builtins.property
        def message(self) -> typing.Optional[builtins.str]:
            '''Message.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboarderror.html#cfn-quicksight-dashboard-dashboarderror-message
            '''
            result = self._values.get("message")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''Type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboarderror.html#cfn-quicksight-dashboard-dashboarderror-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def violated_entities(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.EntityProperty"]]]]:
            '''Lists the violated entities that caused the dashboard error.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboarderror.html#cfn-quicksight-dashboard-dashboarderror-violatedentities
            '''
            result = self._values.get("violated_entities")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.EntityProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DashboardErrorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DashboardPublishOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "ad_hoc_filtering_option": "adHocFilteringOption",
            "data_point_drill_up_down_option": "dataPointDrillUpDownOption",
            "data_point_menu_label_option": "dataPointMenuLabelOption",
            "data_point_tooltip_option": "dataPointTooltipOption",
            "export_to_csv_option": "exportToCsvOption",
            "export_with_hidden_fields_option": "exportWithHiddenFieldsOption",
            "sheet_controls_option": "sheetControlsOption",
            "sheet_layout_element_maximization_option": "sheetLayoutElementMaximizationOption",
            "visual_axis_sort_option": "visualAxisSortOption",
            "visual_menu_option": "visualMenuOption",
            "visual_publish_options": "visualPublishOptions",
        },
    )
    class DashboardPublishOptionsProperty:
        def __init__(
            self,
            *,
            ad_hoc_filtering_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AdHocFilteringOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_point_drill_up_down_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataPointDrillUpDownOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_point_menu_label_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataPointMenuLabelOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_point_tooltip_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataPointTooltipOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            export_to_csv_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ExportToCSVOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            export_with_hidden_fields_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ExportWithHiddenFieldsOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sheet_controls_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SheetControlsOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sheet_layout_element_maximization_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SheetLayoutElementMaximizationOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_axis_sort_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualAxisSortOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_menu_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualMenuOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_publish_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DashboardVisualPublishOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Dashboard publish options.

            :param ad_hoc_filtering_option: Ad hoc (one-time) filtering option.
            :param data_point_drill_up_down_option: The drill-down options of data points in a dashboard.
            :param data_point_menu_label_option: The data point menu label options of a dashboard.
            :param data_point_tooltip_option: The data point tool tip options of a dashboard.
            :param export_to_csv_option: Export to .csv option.
            :param export_with_hidden_fields_option: Determines if hidden fields are exported with a dashboard.
            :param sheet_controls_option: Sheet controls option.
            :param sheet_layout_element_maximization_option: The sheet layout maximization options of a dashbaord.
            :param visual_axis_sort_option: The axis sort options of a dashboard.
            :param visual_menu_option: The menu options of a visual in a dashboard.
            :param visual_publish_options: The visual publish options of a visual in a dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                dashboard_publish_options_property = quicksight.CfnDashboard.DashboardPublishOptionsProperty(
                    ad_hoc_filtering_option=quicksight.CfnDashboard.AdHocFilteringOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    data_point_drill_up_down_option=quicksight.CfnDashboard.DataPointDrillUpDownOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    data_point_menu_label_option=quicksight.CfnDashboard.DataPointMenuLabelOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    data_point_tooltip_option=quicksight.CfnDashboard.DataPointTooltipOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    export_to_csv_option=quicksight.CfnDashboard.ExportToCSVOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    export_with_hidden_fields_option=quicksight.CfnDashboard.ExportWithHiddenFieldsOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    sheet_controls_option=quicksight.CfnDashboard.SheetControlsOptionProperty(
                        visibility_state="visibilityState"
                    ),
                    sheet_layout_element_maximization_option=quicksight.CfnDashboard.SheetLayoutElementMaximizationOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    visual_axis_sort_option=quicksight.CfnDashboard.VisualAxisSortOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    visual_menu_option=quicksight.CfnDashboard.VisualMenuOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    visual_publish_options=quicksight.CfnDashboard.DashboardVisualPublishOptionsProperty(
                        export_hidden_fields_option=quicksight.CfnDashboard.ExportHiddenFieldsOptionProperty(
                            availability_status="availabilityStatus"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c9e09587ab720431f5373014612c24f6d414533d5702638a33a14c36c7d8f81a)
                check_type(argname="argument ad_hoc_filtering_option", value=ad_hoc_filtering_option, expected_type=type_hints["ad_hoc_filtering_option"])
                check_type(argname="argument data_point_drill_up_down_option", value=data_point_drill_up_down_option, expected_type=type_hints["data_point_drill_up_down_option"])
                check_type(argname="argument data_point_menu_label_option", value=data_point_menu_label_option, expected_type=type_hints["data_point_menu_label_option"])
                check_type(argname="argument data_point_tooltip_option", value=data_point_tooltip_option, expected_type=type_hints["data_point_tooltip_option"])
                check_type(argname="argument export_to_csv_option", value=export_to_csv_option, expected_type=type_hints["export_to_csv_option"])
                check_type(argname="argument export_with_hidden_fields_option", value=export_with_hidden_fields_option, expected_type=type_hints["export_with_hidden_fields_option"])
                check_type(argname="argument sheet_controls_option", value=sheet_controls_option, expected_type=type_hints["sheet_controls_option"])
                check_type(argname="argument sheet_layout_element_maximization_option", value=sheet_layout_element_maximization_option, expected_type=type_hints["sheet_layout_element_maximization_option"])
                check_type(argname="argument visual_axis_sort_option", value=visual_axis_sort_option, expected_type=type_hints["visual_axis_sort_option"])
                check_type(argname="argument visual_menu_option", value=visual_menu_option, expected_type=type_hints["visual_menu_option"])
                check_type(argname="argument visual_publish_options", value=visual_publish_options, expected_type=type_hints["visual_publish_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if ad_hoc_filtering_option is not None:
                self._values["ad_hoc_filtering_option"] = ad_hoc_filtering_option
            if data_point_drill_up_down_option is not None:
                self._values["data_point_drill_up_down_option"] = data_point_drill_up_down_option
            if data_point_menu_label_option is not None:
                self._values["data_point_menu_label_option"] = data_point_menu_label_option
            if data_point_tooltip_option is not None:
                self._values["data_point_tooltip_option"] = data_point_tooltip_option
            if export_to_csv_option is not None:
                self._values["export_to_csv_option"] = export_to_csv_option
            if export_with_hidden_fields_option is not None:
                self._values["export_with_hidden_fields_option"] = export_with_hidden_fields_option
            if sheet_controls_option is not None:
                self._values["sheet_controls_option"] = sheet_controls_option
            if sheet_layout_element_maximization_option is not None:
                self._values["sheet_layout_element_maximization_option"] = sheet_layout_element_maximization_option
            if visual_axis_sort_option is not None:
                self._values["visual_axis_sort_option"] = visual_axis_sort_option
            if visual_menu_option is not None:
                self._values["visual_menu_option"] = visual_menu_option
            if visual_publish_options is not None:
                self._values["visual_publish_options"] = visual_publish_options

        @builtins.property
        def ad_hoc_filtering_option(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AdHocFilteringOptionProperty"]]:
            '''Ad hoc (one-time) filtering option.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-adhocfilteringoption
            '''
            result = self._values.get("ad_hoc_filtering_option")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AdHocFilteringOptionProperty"]], result)

        @builtins.property
        def data_point_drill_up_down_option(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPointDrillUpDownOptionProperty"]]:
            '''The drill-down options of data points in a dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-datapointdrillupdownoption
            '''
            result = self._values.get("data_point_drill_up_down_option")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPointDrillUpDownOptionProperty"]], result)

        @builtins.property
        def data_point_menu_label_option(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPointMenuLabelOptionProperty"]]:
            '''The data point menu label options of a dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-datapointmenulabeloption
            '''
            result = self._values.get("data_point_menu_label_option")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPointMenuLabelOptionProperty"]], result)

        @builtins.property
        def data_point_tooltip_option(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPointTooltipOptionProperty"]]:
            '''The data point tool tip options of a dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-datapointtooltipoption
            '''
            result = self._values.get("data_point_tooltip_option")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPointTooltipOptionProperty"]], result)

        @builtins.property
        def export_to_csv_option(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ExportToCSVOptionProperty"]]:
            '''Export to .csv option.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-exporttocsvoption
            '''
            result = self._values.get("export_to_csv_option")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ExportToCSVOptionProperty"]], result)

        @builtins.property
        def export_with_hidden_fields_option(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ExportWithHiddenFieldsOptionProperty"]]:
            '''Determines if hidden fields are exported with a dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-exportwithhiddenfieldsoption
            '''
            result = self._values.get("export_with_hidden_fields_option")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ExportWithHiddenFieldsOptionProperty"]], result)

        @builtins.property
        def sheet_controls_option(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetControlsOptionProperty"]]:
            '''Sheet controls option.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-sheetcontrolsoption
            '''
            result = self._values.get("sheet_controls_option")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetControlsOptionProperty"]], result)

        @builtins.property
        def sheet_layout_element_maximization_option(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetLayoutElementMaximizationOptionProperty"]]:
            '''The sheet layout maximization options of a dashbaord.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-sheetlayoutelementmaximizationoption
            '''
            result = self._values.get("sheet_layout_element_maximization_option")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetLayoutElementMaximizationOptionProperty"]], result)

        @builtins.property
        def visual_axis_sort_option(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualAxisSortOptionProperty"]]:
            '''The axis sort options of a dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-visualaxissortoption
            '''
            result = self._values.get("visual_axis_sort_option")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualAxisSortOptionProperty"]], result)

        @builtins.property
        def visual_menu_option(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualMenuOptionProperty"]]:
            '''The menu options of a visual in a dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-visualmenuoption
            '''
            result = self._values.get("visual_menu_option")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualMenuOptionProperty"]], result)

        @builtins.property
        def visual_publish_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DashboardVisualPublishOptionsProperty"]]:
            '''The visual publish options of a visual in a dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-visualpublishoptions
            '''
            result = self._values.get("visual_publish_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DashboardVisualPublishOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DashboardPublishOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DashboardSourceEntityProperty",
        jsii_struct_bases=[],
        name_mapping={"source_template": "sourceTemplate"},
    )
    class DashboardSourceEntityProperty:
        def __init__(
            self,
            *,
            source_template: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DashboardSourceTemplateProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Dashboard source entity.

            :param source_template: Source template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourceentity.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                dashboard_source_entity_property = quicksight.CfnDashboard.DashboardSourceEntityProperty(
                    source_template=quicksight.CfnDashboard.DashboardSourceTemplateProperty(
                        arn="arn",
                        data_set_references=[quicksight.CfnDashboard.DataSetReferenceProperty(
                            data_set_arn="dataSetArn",
                            data_set_placeholder="dataSetPlaceholder"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8b22ad6b4df9586231a28572e714cb9eb5a398d4bdac27b13e2d1834997ec0d6)
                check_type(argname="argument source_template", value=source_template, expected_type=type_hints["source_template"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if source_template is not None:
                self._values["source_template"] = source_template

        @builtins.property
        def source_template(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DashboardSourceTemplateProperty"]]:
            '''Source template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourceentity.html#cfn-quicksight-dashboard-dashboardsourceentity-sourcetemplate
            '''
            result = self._values.get("source_template")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DashboardSourceTemplateProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DashboardSourceEntityProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DashboardSourceTemplateProperty",
        jsii_struct_bases=[],
        name_mapping={"arn": "arn", "data_set_references": "dataSetReferences"},
    )
    class DashboardSourceTemplateProperty:
        def __init__(
            self,
            *,
            arn: builtins.str,
            data_set_references: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataSetReferenceProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''Dashboard source template.

            :param arn: The Amazon Resource Name (ARN) of the resource.
            :param data_set_references: Dataset references.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourcetemplate.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                dashboard_source_template_property = quicksight.CfnDashboard.DashboardSourceTemplateProperty(
                    arn="arn",
                    data_set_references=[quicksight.CfnDashboard.DataSetReferenceProperty(
                        data_set_arn="dataSetArn",
                        data_set_placeholder="dataSetPlaceholder"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__95b9662dc196870a44ca7342023a1657b392214f06ee6115f1f9507f842aabf4)
                check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
                check_type(argname="argument data_set_references", value=data_set_references, expected_type=type_hints["data_set_references"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "arn": arn,
                "data_set_references": data_set_references,
            }

        @builtins.property
        def arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the resource.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourcetemplate.html#cfn-quicksight-dashboard-dashboardsourcetemplate-arn
            '''
            result = self._values.get("arn")
            assert result is not None, "Required property 'arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_references(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataSetReferenceProperty"]]]:
            '''Dataset references.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourcetemplate.html#cfn-quicksight-dashboard-dashboardsourcetemplate-datasetreferences
            '''
            result = self._values.get("data_set_references")
            assert result is not None, "Required property 'data_set_references' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataSetReferenceProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DashboardSourceTemplateProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DashboardVersionDefinitionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier_declarations": "dataSetIdentifierDeclarations",
            "analysis_defaults": "analysisDefaults",
            "calculated_fields": "calculatedFields",
            "column_configurations": "columnConfigurations",
            "filter_groups": "filterGroups",
            "options": "options",
            "parameter_declarations": "parameterDeclarations",
            "sheets": "sheets",
        },
    )
    class DashboardVersionDefinitionProperty:
        def __init__(
            self,
            *,
            data_set_identifier_declarations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataSetIdentifierDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AnalysisDefaultsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            calculated_fields: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CalculatedFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            column_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            filter_groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilterGroupProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AssetOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            parameter_declarations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sheets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SheetDefinitionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The contents of a dashboard.

            :param data_set_identifier_declarations: An array of dataset identifier declarations. With this mapping,you can use dataset identifiers instead of dataset Amazon Resource Names (ARNs) throughout the dashboard's sub-structures.
            :param analysis_defaults: 
            :param calculated_fields: An array of calculated field definitions for the dashboard.
            :param column_configurations: An array of dashboard-level column configurations. Column configurations are used to set the default formatting for a column that is used throughout a dashboard.
            :param filter_groups: The filter definitions for a dashboard. For more information, see `Filtering Data in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/adding-a-filter.html>`_ in the *Amazon QuickSight User Guide* .
            :param options: An array of option definitions for a dashboard.
            :param parameter_declarations: The parameter declarations for a dashboard. Parameters are named variables that can transfer a value for use by an action or an object. For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .
            :param sheets: An array of sheet definitions for a dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d1e773460c007615acde57e73c58a06ad78362ee67cca8db11e785b394622e44)
                check_type(argname="argument data_set_identifier_declarations", value=data_set_identifier_declarations, expected_type=type_hints["data_set_identifier_declarations"])
                check_type(argname="argument analysis_defaults", value=analysis_defaults, expected_type=type_hints["analysis_defaults"])
                check_type(argname="argument calculated_fields", value=calculated_fields, expected_type=type_hints["calculated_fields"])
                check_type(argname="argument column_configurations", value=column_configurations, expected_type=type_hints["column_configurations"])
                check_type(argname="argument filter_groups", value=filter_groups, expected_type=type_hints["filter_groups"])
                check_type(argname="argument options", value=options, expected_type=type_hints["options"])
                check_type(argname="argument parameter_declarations", value=parameter_declarations, expected_type=type_hints["parameter_declarations"])
                check_type(argname="argument sheets", value=sheets, expected_type=type_hints["sheets"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier_declarations": data_set_identifier_declarations,
            }
            if analysis_defaults is not None:
                self._values["analysis_defaults"] = analysis_defaults
            if calculated_fields is not None:
                self._values["calculated_fields"] = calculated_fields
            if column_configurations is not None:
                self._values["column_configurations"] = column_configurations
            if filter_groups is not None:
                self._values["filter_groups"] = filter_groups
            if options is not None:
                self._values["options"] = options
            if parameter_declarations is not None:
                self._values["parameter_declarations"] = parameter_declarations
            if sheets is not None:
                self._values["sheets"] = sheets

        @builtins.property
        def data_set_identifier_declarations(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataSetIdentifierDeclarationProperty"]]]:
            '''An array of dataset identifier declarations.

            With this mapping,you can use dataset identifiers instead of dataset Amazon Resource Names (ARNs) throughout the dashboard's sub-structures.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-datasetidentifierdeclarations
            '''
            result = self._values.get("data_set_identifier_declarations")
            assert result is not None, "Required property 'data_set_identifier_declarations' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataSetIdentifierDeclarationProperty"]]], result)

        @builtins.property
        def analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AnalysisDefaultsProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-analysisdefaults
            '''
            result = self._values.get("analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AnalysisDefaultsProperty"]], result)

        @builtins.property
        def calculated_fields(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CalculatedFieldProperty"]]]]:
            '''An array of calculated field definitions for the dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-calculatedfields
            '''
            result = self._values.get("calculated_fields")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CalculatedFieldProperty"]]]], result)

        @builtins.property
        def column_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnConfigurationProperty"]]]]:
            '''An array of dashboard-level column configurations.

            Column configurations are used to set the default formatting for a column that is used throughout a dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-columnconfigurations
            '''
            result = self._values.get("column_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnConfigurationProperty"]]]], result)

        @builtins.property
        def filter_groups(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterGroupProperty"]]]]:
            '''The filter definitions for a dashboard.

            For more information, see `Filtering Data in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/adding-a-filter.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-filtergroups
            '''
            result = self._values.get("filter_groups")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterGroupProperty"]]]], result)

        @builtins.property
        def options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AssetOptionsProperty"]]:
            '''An array of option definitions for a dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-options
            '''
            result = self._values.get("options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AssetOptionsProperty"]], result)

        @builtins.property
        def parameter_declarations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParameterDeclarationProperty"]]]]:
            '''The parameter declarations for a dashboard.

            Parameters are named variables that can transfer a value for use by an action or an object.

            For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-parameterdeclarations
            '''
            result = self._values.get("parameter_declarations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParameterDeclarationProperty"]]]], result)

        @builtins.property
        def sheets(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetDefinitionProperty"]]]]:
            '''An array of sheet definitions for a dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-sheets
            '''
            result = self._values.get("sheets")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetDefinitionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DashboardVersionDefinitionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DashboardVersionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arn": "arn",
            "created_time": "createdTime",
            "data_set_arns": "dataSetArns",
            "description": "description",
            "errors": "errors",
            "sheets": "sheets",
            "source_entity_arn": "sourceEntityArn",
            "status": "status",
            "theme_arn": "themeArn",
            "version_number": "versionNumber",
        },
    )
    class DashboardVersionProperty:
        def __init__(
            self,
            *,
            arn: typing.Optional[builtins.str] = None,
            created_time: typing.Optional[builtins.str] = None,
            data_set_arns: typing.Optional[typing.Sequence[builtins.str]] = None,
            description: typing.Optional[builtins.str] = None,
            errors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DashboardErrorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sheets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SheetProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            source_entity_arn: typing.Optional[builtins.str] = None,
            status: typing.Optional[builtins.str] = None,
            theme_arn: typing.Optional[builtins.str] = None,
            version_number: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''Dashboard version.

            :param arn: The Amazon Resource Name (ARN) of the resource.
            :param created_time: The time that this dashboard version was created.
            :param data_set_arns: The Amazon Resource Numbers (ARNs) for the datasets that are associated with this version of the dashboard.
            :param description: Description.
            :param errors: Errors associated with this dashboard version.
            :param sheets: A list of the associated sheets with the unique identifier and name of each sheet.
            :param source_entity_arn: Source entity ARN.
            :param status: The HTTP status of the request.
            :param theme_arn: The ARN of the theme associated with a version of the dashboard.
            :param version_number: Version number for this version of the dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                dashboard_version_property = quicksight.CfnDashboard.DashboardVersionProperty(
                    arn="arn",
                    created_time="createdTime",
                    data_set_arns=["dataSetArns"],
                    description="description",
                    errors=[quicksight.CfnDashboard.DashboardErrorProperty(
                        message="message",
                        type="type",
                        violated_entities=[quicksight.CfnDashboard.EntityProperty(
                            path="path"
                        )]
                    )],
                    sheets=[quicksight.CfnDashboard.SheetProperty(
                        name="name",
                        sheet_id="sheetId"
                    )],
                    source_entity_arn="sourceEntityArn",
                    status="status",
                    theme_arn="themeArn",
                    version_number=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__02747fd699d99b0ae57df7fb8479638c8d4ee9c3ac6b8674fad0ad725a1c466d)
                check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
                check_type(argname="argument created_time", value=created_time, expected_type=type_hints["created_time"])
                check_type(argname="argument data_set_arns", value=data_set_arns, expected_type=type_hints["data_set_arns"])
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
                check_type(argname="argument errors", value=errors, expected_type=type_hints["errors"])
                check_type(argname="argument sheets", value=sheets, expected_type=type_hints["sheets"])
                check_type(argname="argument source_entity_arn", value=source_entity_arn, expected_type=type_hints["source_entity_arn"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument theme_arn", value=theme_arn, expected_type=type_hints["theme_arn"])
                check_type(argname="argument version_number", value=version_number, expected_type=type_hints["version_number"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arn is not None:
                self._values["arn"] = arn
            if created_time is not None:
                self._values["created_time"] = created_time
            if data_set_arns is not None:
                self._values["data_set_arns"] = data_set_arns
            if description is not None:
                self._values["description"] = description
            if errors is not None:
                self._values["errors"] = errors
            if sheets is not None:
                self._values["sheets"] = sheets
            if source_entity_arn is not None:
                self._values["source_entity_arn"] = source_entity_arn
            if status is not None:
                self._values["status"] = status
            if theme_arn is not None:
                self._values["theme_arn"] = theme_arn
            if version_number is not None:
                self._values["version_number"] = version_number

        @builtins.property
        def arn(self) -> typing.Optional[builtins.str]:
            '''The Amazon Resource Name (ARN) of the resource.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-arn
            '''
            result = self._values.get("arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def created_time(self) -> typing.Optional[builtins.str]:
            '''The time that this dashboard version was created.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-createdtime
            '''
            result = self._values.get("created_time")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_set_arns(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The Amazon Resource Numbers (ARNs) for the datasets that are associated with this version of the dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-datasetarns
            '''
            result = self._values.get("data_set_arns")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''Description.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def errors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DashboardErrorProperty"]]]]:
            '''Errors associated with this dashboard version.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-errors
            '''
            result = self._values.get("errors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DashboardErrorProperty"]]]], result)

        @builtins.property
        def sheets(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetProperty"]]]]:
            '''A list of the associated sheets with the unique identifier and name of each sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-sheets
            '''
            result = self._values.get("sheets")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetProperty"]]]], result)

        @builtins.property
        def source_entity_arn(self) -> typing.Optional[builtins.str]:
            '''Source entity ARN.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-sourceentityarn
            '''
            result = self._values.get("source_entity_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The HTTP status of the request.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def theme_arn(self) -> typing.Optional[builtins.str]:
            '''The ARN of the theme associated with a version of the dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-themearn
            '''
            result = self._values.get("theme_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def version_number(self) -> typing.Optional[jsii.Number]:
            '''Version number for this version of the dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-versionnumber
            '''
            result = self._values.get("version_number")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DashboardVersionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DashboardVisualPublishOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"export_hidden_fields_option": "exportHiddenFieldsOption"},
    )
    class DashboardVisualPublishOptionsProperty:
        def __init__(
            self,
            *,
            export_hidden_fields_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ExportHiddenFieldsOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The visual publish options of a visual in a dashboard.

            :param export_hidden_fields_option: Determines if hidden fields are included in an exported dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardvisualpublishoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                dashboard_visual_publish_options_property = quicksight.CfnDashboard.DashboardVisualPublishOptionsProperty(
                    export_hidden_fields_option=quicksight.CfnDashboard.ExportHiddenFieldsOptionProperty(
                        availability_status="availabilityStatus"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__408958d561c48a3ffa2d0cb52dd8fc2ab0cb9121e11f9f6aa3bbd8e0fbe9780f)
                check_type(argname="argument export_hidden_fields_option", value=export_hidden_fields_option, expected_type=type_hints["export_hidden_fields_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if export_hidden_fields_option is not None:
                self._values["export_hidden_fields_option"] = export_hidden_fields_option

        @builtins.property
        def export_hidden_fields_option(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ExportHiddenFieldsOptionProperty"]]:
            '''Determines if hidden fields are included in an exported dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardvisualpublishoptions.html#cfn-quicksight-dashboard-dashboardvisualpublishoptions-exporthiddenfieldsoption
            '''
            result = self._values.get("export_hidden_fields_option")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ExportHiddenFieldsOptionProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DashboardVisualPublishOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DataBarsOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "negative_color": "negativeColor",
            "positive_color": "positiveColor",
        },
    )
    class DataBarsOptionsProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            negative_color: typing.Optional[builtins.str] = None,
            positive_color: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for data bars.

            :param field_id: The field ID for the data bars options.
            :param negative_color: The color of the negative data bar.
            :param positive_color: The color of the positive data bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-databarsoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_bars_options_property = quicksight.CfnDashboard.DataBarsOptionsProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    negative_color="negativeColor",
                    positive_color="positiveColor"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e762c8a306c685fc81eb9f9ac5fb29bad77d9a83bdfef9c21ef788c7eb6d2f11)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument negative_color", value=negative_color, expected_type=type_hints["negative_color"])
                check_type(argname="argument positive_color", value=positive_color, expected_type=type_hints["positive_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if negative_color is not None:
                self._values["negative_color"] = negative_color
            if positive_color is not None:
                self._values["positive_color"] = positive_color

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for the data bars options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-databarsoptions.html#cfn-quicksight-dashboard-databarsoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def negative_color(self) -> typing.Optional[builtins.str]:
            '''The color of the negative data bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-databarsoptions.html#cfn-quicksight-dashboard-databarsoptions-negativecolor
            '''
            result = self._values.get("negative_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def positive_color(self) -> typing.Optional[builtins.str]:
            '''The color of the positive data bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-databarsoptions.html#cfn-quicksight-dashboard-databarsoptions-positivecolor
            '''
            result = self._values.get("positive_color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataBarsOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DataColorProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "data_value": "dataValue"},
    )
    class DataColorProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            data_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''Determines the color that is applied to a particular data value.

            :param color: The color that is applied to the data value.
            :param data_value: The data value that the color is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datacolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_color_property = quicksight.CfnDashboard.DataColorProperty(
                    color="color",
                    data_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ff858a4698c777414bebc3e80e4b098f61cd252dc6c4039b7f6f2df9bc6b6b5b)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument data_value", value=data_value, expected_type=type_hints["data_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if data_value is not None:
                self._values["data_value"] = data_value

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color that is applied to the data value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datacolor.html#cfn-quicksight-dashboard-datacolor-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_value(self) -> typing.Optional[jsii.Number]:
            '''The data value that the color is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datacolor.html#cfn-quicksight-dashboard-datacolor-datavalue
            '''
            result = self._values.get("data_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DataFieldSeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "field_id": "fieldId",
            "field_value": "fieldValue",
            "settings": "settings",
        },
    )
    class DataFieldSeriesItemProperty:
        def __init__(
            self,
            *,
            axis_binding: builtins.str,
            field_id: builtins.str,
            field_value: typing.Optional[builtins.str] = None,
            settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LineChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The data field series item configuration of a line chart.

            :param axis_binding: The axis that you are binding the field to.
            :param field_id: The field ID of the field that you are setting the axis binding to.
            :param field_value: The field value of the field that you are setting the axis binding to.
            :param settings: The options that determine the presentation of line series associated to the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_field_series_item_property = quicksight.CfnDashboard.DataFieldSeriesItemProperty(
                    axis_binding="axisBinding",
                    field_id="fieldId",
                
                    # the properties below are optional
                    field_value="fieldValue",
                    settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                        line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6d13131552e8cba6227c967cc9c165670b2e73eb08f2baa34ef0de7f638ba9f1)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument settings", value=settings, expected_type=type_hints["settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "axis_binding": axis_binding,
                "field_id": field_id,
            }
            if field_value is not None:
                self._values["field_value"] = field_value
            if settings is not None:
                self._values["settings"] = settings

        @builtins.property
        def axis_binding(self) -> builtins.str:
            '''The axis that you are binding the field to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html#cfn-quicksight-dashboard-datafieldseriesitem-axisbinding
            '''
            result = self._values.get("axis_binding")
            assert result is not None, "Required property 'axis_binding' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field that you are setting the axis binding to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html#cfn-quicksight-dashboard-datafieldseriesitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The field value of the field that you are setting the axis binding to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html#cfn-quicksight-dashboard-datafieldseriesitem-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartSeriesSettingsProperty"]]:
            '''The options that determine the presentation of line series associated to the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html#cfn-quicksight-dashboard-datafieldseriesitem-settings
            '''
            result = self._values.get("settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartSeriesSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataFieldSeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DataLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_visibility": "categoryLabelVisibility",
            "data_label_types": "dataLabelTypes",
            "label_color": "labelColor",
            "label_content": "labelContent",
            "label_font_configuration": "labelFontConfiguration",
            "measure_label_visibility": "measureLabelVisibility",
            "overlap": "overlap",
            "position": "position",
            "totals_visibility": "totalsVisibility",
            "visibility": "visibility",
        },
    )
    class DataLabelOptionsProperty:
        def __init__(
            self,
            *,
            category_label_visibility: typing.Optional[builtins.str] = None,
            data_label_types: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            label_color: typing.Optional[builtins.str] = None,
            label_content: typing.Optional[builtins.str] = None,
            label_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            measure_label_visibility: typing.Optional[builtins.str] = None,
            overlap: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of the data labels.

            :param category_label_visibility: Determines the visibility of the category field labels.
            :param data_label_types: The option that determines the data label type.
            :param label_color: Determines the color of the data labels.
            :param label_content: Determines the content of the data labels.
            :param label_font_configuration: Determines the font configuration of the data labels.
            :param measure_label_visibility: Determines the visibility of the measure field labels.
            :param overlap: Determines whether overlap is enabled or disabled for the data labels.
            :param position: Determines the position of the data labels.
            :param totals_visibility: Determines the visibility of the total.
            :param visibility: Determines the visibility of the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_label_options_property = quicksight.CfnDashboard.DataLabelOptionsProperty(
                    category_label_visibility="categoryLabelVisibility",
                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                            field_id="fieldId",
                            field_value="fieldValue",
                            visibility="visibility"
                        ),
                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                            field_id="fieldId",
                            visibility="visibility"
                        ),
                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                            visibility="visibility"
                        ),
                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                            visibility="visibility"
                        ),
                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                            visibility="visibility"
                        )
                    )],
                    label_color="labelColor",
                    label_content="labelContent",
                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    measure_label_visibility="measureLabelVisibility",
                    overlap="overlap",
                    position="position",
                    totals_visibility="totalsVisibility",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f90116c0c378202ed19ef75ca4423f1481dfc4314406661e137ae66ce4ee2ef9)
                check_type(argname="argument category_label_visibility", value=category_label_visibility, expected_type=type_hints["category_label_visibility"])
                check_type(argname="argument data_label_types", value=data_label_types, expected_type=type_hints["data_label_types"])
                check_type(argname="argument label_color", value=label_color, expected_type=type_hints["label_color"])
                check_type(argname="argument label_content", value=label_content, expected_type=type_hints["label_content"])
                check_type(argname="argument label_font_configuration", value=label_font_configuration, expected_type=type_hints["label_font_configuration"])
                check_type(argname="argument measure_label_visibility", value=measure_label_visibility, expected_type=type_hints["measure_label_visibility"])
                check_type(argname="argument overlap", value=overlap, expected_type=type_hints["overlap"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_visibility is not None:
                self._values["category_label_visibility"] = category_label_visibility
            if data_label_types is not None:
                self._values["data_label_types"] = data_label_types
            if label_color is not None:
                self._values["label_color"] = label_color
            if label_content is not None:
                self._values["label_content"] = label_content
            if label_font_configuration is not None:
                self._values["label_font_configuration"] = label_font_configuration
            if measure_label_visibility is not None:
                self._values["measure_label_visibility"] = measure_label_visibility
            if overlap is not None:
                self._values["overlap"] = overlap
            if position is not None:
                self._values["position"] = position
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def category_label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the category field labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-categorylabelvisibility
            '''
            result = self._values.get("category_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_label_types(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelTypeProperty"]]]]:
            '''The option that determines the data label type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-datalabeltypes
            '''
            result = self._values.get("data_label_types")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelTypeProperty"]]]], result)

        @builtins.property
        def label_color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-labelcolor
            '''
            result = self._values.get("label_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_content(self) -> typing.Optional[builtins.str]:
            '''Determines the content of the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-labelcontent
            '''
            result = self._values.get("label_content")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"]]:
            '''Determines the font configuration of the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-labelfontconfiguration
            '''
            result = self._values.get("label_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"]], result)

        @builtins.property
        def measure_label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the measure field labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-measurelabelvisibility
            '''
            result = self._values.get("measure_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def overlap(self) -> typing.Optional[builtins.str]:
            '''Determines whether overlap is enabled or disabled for the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-overlap
            '''
            result = self._values.get("overlap")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''Determines the position of the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the total.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DataLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_path_label_type": "dataPathLabelType",
            "field_label_type": "fieldLabelType",
            "maximum_label_type": "maximumLabelType",
            "minimum_label_type": "minimumLabelType",
            "range_ends_label_type": "rangeEndsLabelType",
        },
    )
    class DataLabelTypeProperty:
        def __init__(
            self,
            *,
            data_path_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataPathLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            maximum_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MaximumLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            minimum_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MinimumLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            range_ends_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.RangeEndsLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The option that determines the data label type.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_path_label_type: The option that specifies individual data values for labels.
            :param field_label_type: Determines the label configuration for the entire field.
            :param maximum_label_type: Determines the label configuration for the maximum value in a visual.
            :param minimum_label_type: Determines the label configuration for the minimum value in a visual.
            :param range_ends_label_type: Determines the label configuration for range end value in a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_label_type_property = quicksight.CfnDashboard.DataLabelTypeProperty(
                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                        field_id="fieldId",
                        field_value="fieldValue",
                        visibility="visibility"
                    ),
                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                        field_id="fieldId",
                        visibility="visibility"
                    ),
                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                        visibility="visibility"
                    ),
                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                        visibility="visibility"
                    ),
                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1a3b2866435d1823bb1d6c4d241168cf11d7944c2c8af72f1491542605e626e9)
                check_type(argname="argument data_path_label_type", value=data_path_label_type, expected_type=type_hints["data_path_label_type"])
                check_type(argname="argument field_label_type", value=field_label_type, expected_type=type_hints["field_label_type"])
                check_type(argname="argument maximum_label_type", value=maximum_label_type, expected_type=type_hints["maximum_label_type"])
                check_type(argname="argument minimum_label_type", value=minimum_label_type, expected_type=type_hints["minimum_label_type"])
                check_type(argname="argument range_ends_label_type", value=range_ends_label_type, expected_type=type_hints["range_ends_label_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_path_label_type is not None:
                self._values["data_path_label_type"] = data_path_label_type
            if field_label_type is not None:
                self._values["field_label_type"] = field_label_type
            if maximum_label_type is not None:
                self._values["maximum_label_type"] = maximum_label_type
            if minimum_label_type is not None:
                self._values["minimum_label_type"] = minimum_label_type
            if range_ends_label_type is not None:
                self._values["range_ends_label_type"] = range_ends_label_type

        @builtins.property
        def data_path_label_type(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPathLabelTypeProperty"]]:
            '''The option that specifies individual data values for labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-datapathlabeltype
            '''
            result = self._values.get("data_path_label_type")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPathLabelTypeProperty"]], result)

        @builtins.property
        def field_label_type(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldLabelTypeProperty"]]:
            '''Determines the label configuration for the entire field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-fieldlabeltype
            '''
            result = self._values.get("field_label_type")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldLabelTypeProperty"]], result)

        @builtins.property
        def maximum_label_type(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MaximumLabelTypeProperty"]]:
            '''Determines the label configuration for the maximum value in a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-maximumlabeltype
            '''
            result = self._values.get("maximum_label_type")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MaximumLabelTypeProperty"]], result)

        @builtins.property
        def minimum_label_type(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MinimumLabelTypeProperty"]]:
            '''Determines the label configuration for the minimum value in a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-minimumlabeltype
            '''
            result = self._values.get("minimum_label_type")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MinimumLabelTypeProperty"]], result)

        @builtins.property
        def range_ends_label_type(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RangeEndsLabelTypeProperty"]]:
            '''Determines the label configuration for range end value in a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-rangeendslabeltype
            '''
            result = self._values.get("range_ends_label_type")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RangeEndsLabelTypeProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DataPathColorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color": "color",
            "element": "element",
            "time_granularity": "timeGranularity",
        },
    )
    class DataPathColorProperty:
        def __init__(
            self,
            *,
            color: builtins.str,
            element: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]]],
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The color map that determines the color options for a particular element.

            :param color: The color that needs to be applied to the element.
            :param element: The element that the color needs to be applied to.
            :param time_granularity: The time granularity of the field that the color needs to be applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_path_color_property = quicksight.CfnDashboard.DataPathColorProperty(
                    color="color",
                    element=quicksight.CfnDashboard.DataPathValueProperty(
                        data_path_type=quicksight.CfnDashboard.DataPathTypeProperty(
                            pivot_table_data_path_type="pivotTableDataPathType"
                        ),
                        field_id="fieldId",
                        field_value="fieldValue"
                    ),
                
                    # the properties below are optional
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__939a8b10369228e2d550044997e4717f7015bedb3638c36441ae5fa61abfeba8)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument element", value=element, expected_type=type_hints["element"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
                "element": element,
            }
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def color(self) -> builtins.str:
            '''The color that needs to be applied to the element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathcolor.html#cfn-quicksight-dashboard-datapathcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPathValueProperty"]:
            '''The element that the color needs to be applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathcolor.html#cfn-quicksight-dashboard-datapathcolor-element
            '''
            result = self._values.get("element")
            assert result is not None, "Required property 'element' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPathValueProperty"], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The time granularity of the field that the color needs to be applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathcolor.html#cfn-quicksight-dashboard-datapathcolor-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DataPathLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "field_value": "fieldValue",
            "visibility": "visibility",
        },
    )
    class DataPathLabelTypeProperty:
        def __init__(
            self,
            *,
            field_id: typing.Optional[builtins.str] = None,
            field_value: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The option that specifies individual data values for labels.

            :param field_id: The field ID of the field that the data label needs to be applied to.
            :param field_value: The actual value of the field that is labeled.
            :param visibility: The visibility of the data label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_path_label_type_property = quicksight.CfnDashboard.DataPathLabelTypeProperty(
                    field_id="fieldId",
                    field_value="fieldValue",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__20efdc01250971060f769b4d3d1d3683c4b2af4a4c62cbd865becb49dd1e80bf)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id
            if field_value is not None:
                self._values["field_value"] = field_value
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the field that the data label needs to be applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathlabeltype.html#cfn-quicksight-dashboard-datapathlabeltype-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The actual value of the field that is labeled.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathlabeltype.html#cfn-quicksight-dashboard-datapathlabeltype-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the data label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathlabeltype.html#cfn-quicksight-dashboard-datapathlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DataPathSortProperty",
        jsii_struct_bases=[],
        name_mapping={"direction": "direction", "sort_paths": "sortPaths"},
    )
    class DataPathSortProperty:
        def __init__(
            self,
            *,
            direction: builtins.str,
            sort_paths: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''Allows data paths to be sorted by a specific data value.

            :param direction: Determines the sort direction.
            :param sort_paths: The list of data paths that need to be sorted.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_path_sort_property = quicksight.CfnDashboard.DataPathSortProperty(
                    direction="direction",
                    sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                        data_path_type=quicksight.CfnDashboard.DataPathTypeProperty(
                            pivot_table_data_path_type="pivotTableDataPathType"
                        ),
                        field_id="fieldId",
                        field_value="fieldValue"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__86a2aa8b069cab21c5f19ed1464a235ba31dc5042b5ed2e0c7eaea1a9194b01f)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument sort_paths", value=sort_paths, expected_type=type_hints["sort_paths"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "sort_paths": sort_paths,
            }

        @builtins.property
        def direction(self) -> builtins.str:
            '''Determines the sort direction.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathsort.html#cfn-quicksight-dashboard-datapathsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_paths(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPathValueProperty"]]]:
            '''The list of data paths that need to be sorted.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathsort.html#cfn-quicksight-dashboard-datapathsort-sortpaths
            '''
            result = self._values.get("sort_paths")
            assert result is not None, "Required property 'sort_paths' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPathValueProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DataPathTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"pivot_table_data_path_type": "pivotTableDataPathType"},
    )
    class DataPathTypeProperty:
        def __init__(
            self,
            *,
            pivot_table_data_path_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The type of the data path value.

            :param pivot_table_data_path_type: The type of data path value utilized in a pivot table. Choose one of the following options:. - ``HIERARCHY_ROWS_LAYOUT_COLUMN`` - The type of data path for the rows layout column, when ``RowsLayout`` is set to ``HIERARCHY`` . - ``MULTIPLE_ROW_METRICS_COLUMN`` - The type of data path for the metric column when the row is set to Metric Placement. - ``EMPTY_COLUMN_HEADER`` - The type of data path for the column with empty column header, when there is no field in ``ColumnsFieldWell`` and the row is set to Metric Placement. - ``COUNT_METRIC_COLUMN`` - The type of data path for the column with ``COUNT`` as the metric, when there is no field in the ``ValuesFieldWell`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathtype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_path_type_property = quicksight.CfnDashboard.DataPathTypeProperty(
                    pivot_table_data_path_type="pivotTableDataPathType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__38b24f0de1a215ef94744ac397948cf3f58954b385a4af3005fb01fe6f9ca6e2)
                check_type(argname="argument pivot_table_data_path_type", value=pivot_table_data_path_type, expected_type=type_hints["pivot_table_data_path_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pivot_table_data_path_type is not None:
                self._values["pivot_table_data_path_type"] = pivot_table_data_path_type

        @builtins.property
        def pivot_table_data_path_type(self) -> typing.Optional[builtins.str]:
            '''The type of data path value utilized in a pivot table. Choose one of the following options:.

            - ``HIERARCHY_ROWS_LAYOUT_COLUMN`` - The type of data path for the rows layout column, when ``RowsLayout`` is set to ``HIERARCHY`` .
            - ``MULTIPLE_ROW_METRICS_COLUMN`` - The type of data path for the metric column when the row is set to Metric Placement.
            - ``EMPTY_COLUMN_HEADER`` - The type of data path for the column with empty column header, when there is no field in ``ColumnsFieldWell`` and the row is set to Metric Placement.
            - ``COUNT_METRIC_COLUMN`` - The type of data path for the column with ``COUNT`` as the metric, when there is no field in the ``ValuesFieldWell`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathtype.html#cfn-quicksight-dashboard-datapathtype-pivottabledatapathtype
            '''
            result = self._values.get("pivot_table_data_path_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DataPathValueProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_path_type": "dataPathType",
            "field_id": "fieldId",
            "field_value": "fieldValue",
        },
    )
    class DataPathValueProperty:
        def __init__(
            self,
            *,
            data_path_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataPathTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_id: typing.Optional[builtins.str] = None,
            field_value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The data path that needs to be sorted.

            :param data_path_type: The type configuration of the field.
            :param field_id: The field ID of the field that needs to be sorted.
            :param field_value: The actual value of the field that needs to be sorted.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathvalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_path_value_property = quicksight.CfnDashboard.DataPathValueProperty(
                    data_path_type=quicksight.CfnDashboard.DataPathTypeProperty(
                        pivot_table_data_path_type="pivotTableDataPathType"
                    ),
                    field_id="fieldId",
                    field_value="fieldValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__87f049f31df40ffc5c192a50ab46cff21e148d108d92cf10d0d9b6b6269d6371)
                check_type(argname="argument data_path_type", value=data_path_type, expected_type=type_hints["data_path_type"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_path_type is not None:
                self._values["data_path_type"] = data_path_type
            if field_id is not None:
                self._values["field_id"] = field_id
            if field_value is not None:
                self._values["field_value"] = field_value

        @builtins.property
        def data_path_type(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPathTypeProperty"]]:
            '''The type configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathvalue.html#cfn-quicksight-dashboard-datapathvalue-datapathtype
            '''
            result = self._values.get("data_path_type")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPathTypeProperty"]], result)

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the field that needs to be sorted.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathvalue.html#cfn-quicksight-dashboard-datapathvalue-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The actual value of the field that needs to be sorted.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathvalue.html#cfn-quicksight-dashboard-datapathvalue-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DataPointDrillUpDownOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class DataPointDrillUpDownOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The drill down options for data points in a dashbaord.

            :param availability_status: The status of the drill down options of data points.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointdrillupdownoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_point_drill_up_down_option_property = quicksight.CfnDashboard.DataPointDrillUpDownOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7171910ea4dde254edc15b1d1632dbb4e005794bd8989ea533a292e85c45061b)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The status of the drill down options of data points.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointdrillupdownoption.html#cfn-quicksight-dashboard-datapointdrillupdownoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPointDrillUpDownOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DataPointMenuLabelOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class DataPointMenuLabelOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The data point menu options of a dashboard.

            :param availability_status: The status of the data point menu options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointmenulabeloption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_point_menu_label_option_property = quicksight.CfnDashboard.DataPointMenuLabelOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__87cdfa681edcc17bb2bff1a0485212a0780e425b67f48ee06d44f67561cc4da4)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The status of the data point menu options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointmenulabeloption.html#cfn-quicksight-dashboard-datapointmenulabeloption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPointMenuLabelOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DataPointTooltipOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class DataPointTooltipOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The data point tooltip options.

            :param availability_status: The status of the data point tool tip options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointtooltipoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_point_tooltip_option_property = quicksight.CfnDashboard.DataPointTooltipOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__96c647bd5166be9e741815d6acf00a0fa2522e200ea452f9e7fe12d6073b6f52)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The status of the data point tool tip options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointtooltipoption.html#cfn-quicksight-dashboard-datapointtooltipoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPointTooltipOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DataSetIdentifierDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={"data_set_arn": "dataSetArn", "identifier": "identifier"},
    )
    class DataSetIdentifierDeclarationProperty:
        def __init__(
            self,
            *,
            data_set_arn: builtins.str,
            identifier: builtins.str,
        ) -> None:
            '''A data set.

            :param data_set_arn: The Amazon Resource Name (ARN) of the data set.
            :param identifier: The identifier of the data set, typically the data set's name.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetidentifierdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_set_identifier_declaration_property = quicksight.CfnDashboard.DataSetIdentifierDeclarationProperty(
                    data_set_arn="dataSetArn",
                    identifier="identifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7c2de2aa62a91bb21ddbfe6e508333eb0b4dd2396f8fd30f3899cda7426aaefe)
                check_type(argname="argument data_set_arn", value=data_set_arn, expected_type=type_hints["data_set_arn"])
                check_type(argname="argument identifier", value=identifier, expected_type=type_hints["identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_arn": data_set_arn,
                "identifier": identifier,
            }

        @builtins.property
        def data_set_arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the data set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetidentifierdeclaration.html#cfn-quicksight-dashboard-datasetidentifierdeclaration-datasetarn
            '''
            result = self._values.get("data_set_arn")
            assert result is not None, "Required property 'data_set_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def identifier(self) -> builtins.str:
            '''The identifier of the data set, typically the data set's name.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetidentifierdeclaration.html#cfn-quicksight-dashboard-datasetidentifierdeclaration-identifier
            '''
            result = self._values.get("identifier")
            assert result is not None, "Required property 'identifier' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetIdentifierDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DataSetReferenceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_arn": "dataSetArn",
            "data_set_placeholder": "dataSetPlaceholder",
        },
    )
    class DataSetReferenceProperty:
        def __init__(
            self,
            *,
            data_set_arn: builtins.str,
            data_set_placeholder: builtins.str,
        ) -> None:
            '''Dataset reference.

            :param data_set_arn: Dataset Amazon Resource Name (ARN).
            :param data_set_placeholder: Dataset placeholder.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetreference.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_set_reference_property = quicksight.CfnDashboard.DataSetReferenceProperty(
                    data_set_arn="dataSetArn",
                    data_set_placeholder="dataSetPlaceholder"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0f916781b7071e5a0e35e8dc0a8b9fae5ff8314c5baaeefb50c0769a3463a848)
                check_type(argname="argument data_set_arn", value=data_set_arn, expected_type=type_hints["data_set_arn"])
                check_type(argname="argument data_set_placeholder", value=data_set_placeholder, expected_type=type_hints["data_set_placeholder"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_arn": data_set_arn,
                "data_set_placeholder": data_set_placeholder,
            }

        @builtins.property
        def data_set_arn(self) -> builtins.str:
            '''Dataset Amazon Resource Name (ARN).

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetreference.html#cfn-quicksight-dashboard-datasetreference-datasetarn
            '''
            result = self._values.get("data_set_arn")
            assert result is not None, "Required property 'data_set_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_placeholder(self) -> builtins.str:
            '''Dataset placeholder.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetreference.html#cfn-quicksight-dashboard-datasetreference-datasetplaceholder
            '''
            result = self._values.get("data_set_placeholder")
            assert result is not None, "Required property 'data_set_placeholder' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetReferenceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DateAxisOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"missing_date_visibility": "missingDateVisibility"},
    )
    class DateAxisOptionsProperty:
        def __init__(
            self,
            *,
            missing_date_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine how a date axis is displayed.

            :param missing_date_visibility: Determines whether or not missing dates are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dateaxisoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_axis_options_property = quicksight.CfnDashboard.DateAxisOptionsProperty(
                    missing_date_visibility="missingDateVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7622ec7beb65b878ece677b0ae426935fe2a72a4581abc480e0157a7eab03a9a)
                check_type(argname="argument missing_date_visibility", value=missing_date_visibility, expected_type=type_hints["missing_date_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if missing_date_visibility is not None:
                self._values["missing_date_visibility"] = missing_date_visibility

        @builtins.property
        def missing_date_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not missing dates are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dateaxisoptions.html#cfn-quicksight-dashboard-dateaxisoptions-missingdatevisibility
            '''
            result = self._values.get("missing_date_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateAxisOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DateDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "date_granularity": "dateGranularity",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class DateDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            date_granularity: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with date type columns.

            :param column: The column that is used in the ``DateDimensionField`` .
            :param field_id: The custom field ID.
            :param date_granularity: The date granularity of the ``DateDimensionField`` . Choose one of the following options:. - ``YEAR`` - ``QUARTER`` - ``MONTH`` - ``WEEK`` - ``DAY`` - ``HOUR`` - ``MINUTE`` - ``SECOND`` - ``MILLISECOND``
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_dimension_field_property = quicksight.CfnDashboard.DateDimensionFieldProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    date_granularity="dateGranularity",
                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__65e6e13e88922fa8c8283b4c80a542fe26f5b4b1016bab559e96cbcf4af80735)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument date_granularity", value=date_granularity, expected_type=type_hints["date_granularity"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if date_granularity is not None:
                self._values["date_granularity"] = date_granularity
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that is used in the ``DateDimensionField`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def date_granularity(self) -> typing.Optional[builtins.str]:
            '''The date granularity of the ``DateDimensionField`` . Choose one of the following options:.

            - ``YEAR``
            - ``QUARTER``
            - ``MONTH``
            - ``WEEK``
            - ``DAY``
            - ``HOUR``
            - ``MINUTE``
            - ``SECOND``
            - ``MILLISECOND``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-dategranularity
            '''
            result = self._values.get("date_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateTimeFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateTimeFormatConfigurationProperty"]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DateMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class DateMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            aggregation_function: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure type field with date type columns.

            :param column: The column that is used in the ``DateMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_measure_field_property = quicksight.CfnDashboard.DateMeasureFieldProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function="aggregationFunction",
                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d2f2d0df47996350b04a49c28c7e4bfc9a2001cdabe2a4c3d1c11829ec2da577)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that is used in the ``DateMeasureField`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html#cfn-quicksight-dashboard-datemeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html#cfn-quicksight-dashboard-datemeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(self) -> typing.Optional[builtins.str]:
            '''The aggregation function of the measure field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html#cfn-quicksight-dashboard-datemeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateTimeFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html#cfn-quicksight-dashboard-datemeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateTimeFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DateTimeDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "rolling_date": "rollingDate",
            "static_values": "staticValues",
        },
    )
    class DateTimeDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rolling_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.RollingDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The default values of the ``DateTimeParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``DataTimeDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param rolling_date: The rolling date of the ``DataTimeDefaultValues`` . The date is determined from the dataset based on input expression.
            :param static_values: The static values of the ``DataTimeDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimedefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_default_values_property = quicksight.CfnDashboard.DateTimeDefaultValuesProperty(
                    dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                        expression="expression",
                
                        # the properties below are optional
                        data_set_identifier="dataSetIdentifier"
                    ),
                    static_values=["staticValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a322af65ddd2559f08ada6b32f3cedd34ba1e46f320f3322497e15adcf47fcff)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument rolling_date", value=rolling_date, expected_type=type_hints["rolling_date"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if rolling_date is not None:
                self._values["rolling_date"] = rolling_date
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``DataTimeDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimedefaultvalues.html#cfn-quicksight-dashboard-datetimedefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def rolling_date(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RollingDateConfigurationProperty"]]:
            '''The rolling date of the ``DataTimeDefaultValues`` .

            The date is determined from the dataset based on input expression.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimedefaultvalues.html#cfn-quicksight-dashboard-datetimedefaultvalues-rollingdate
            '''
            result = self._values.get("rolling_date")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RollingDateConfigurationProperty"]], result)

        @builtins.property
        def static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The static values of the ``DataTimeDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimedefaultvalues.html#cfn-quicksight-dashboard-datetimedefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DateTimeFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "numeric_format_configuration": "numericFormatConfiguration",
        },
    )
    class DateTimeFormatConfigurationProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Formatting configuration for ``DateTime`` fields.

            :param date_time_format: Determines the ``DateTime`` format.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param numeric_format_configuration: The formatting configuration for numeric ``DateTime`` fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_format_configuration_property = quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                    date_time_format="dateTimeFormat",
                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__927b666ae44de8c1741c7b79a487bc1e3521427748c18a164ff02d721b657be5)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument numeric_format_configuration", value=numeric_format_configuration, expected_type=type_hints["numeric_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if numeric_format_configuration is not None:
                self._values["numeric_format_configuration"] = numeric_format_configuration

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Determines the ``DateTime`` format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeformatconfiguration.html#cfn-quicksight-dashboard-datetimeformatconfiguration-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeformatconfiguration.html#cfn-quicksight-dashboard-datetimeformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def numeric_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericFormatConfigurationProperty"]]:
            '''The formatting configuration for numeric ``DateTime`` fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeformatconfiguration.html#cfn-quicksight-dashboard-datetimeformatconfiguration-numericformatconfiguration
            '''
            result = self._values.get("numeric_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DateTimeHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class DateTimeHierarchyProperty:
        def __init__(
            self,
            *,
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of any ``DateTime`` fields.

            :param hierarchy_id: The hierarchy ID of the ``DateTime`` hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the ``DateTime`` hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimehierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_hierarchy_property = quicksight.CfnDashboard.DateTimeHierarchyProperty(
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2d11b2f7a0e52f24fad6c7123e2bdd12b12d6ab1098bb93b4150bd7bd2b860de)
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the ``DateTime`` hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimehierarchy.html#cfn-quicksight-dashboard-datetimehierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DrillDownFilterProperty"]]]]:
            '''The option that determines the drill down filters for the ``DateTime`` hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimehierarchy.html#cfn-quicksight-dashboard-datetimehierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DrillDownFilterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DateTimeParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "time_granularity": "timeGranularity",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class DateTimeParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DateTimeDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
            value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``DateTime`` data type.

            :param name: The name of the parameter that is being declared.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: 
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param value_when_unset: The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_parameter_declaration_property = quicksight.CfnDashboard.DateTimeParameterDeclarationProperty(
                    name="name",
                
                    # the properties below are optional
                    default_values=quicksight.CfnDashboard.DateTimeDefaultValuesProperty(
                        dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_values=["staticValues"]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    time_granularity="timeGranularity",
                    value_when_unset=quicksight.CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty(
                        custom_value="customValue",
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__483baa308f6cfa1ba3f021837dce98bdb34180d183674301b2ed09410fd41568)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateTimeDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateTimeDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MappedDataSetParameterProperty"]]]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty"]]:
            '''The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DateTimeParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class DateTimeParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Sequence[builtins.str],
        ) -> None:
            '''A date-time parameter.

            :param name: A display name for the date-time parameter.
            :param values: The values for the date-time parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_parameter_property = quicksight.CfnDashboard.DateTimeParameterProperty(
                    name="name",
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5bb492b85dd26afa0e0a0a44d9b6d3e843e5ca7f2532e74369bc4fa81a47cd32)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for the date-time parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameter.html#cfn-quicksight-dashboard-datetimeparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(self) -> typing.List[builtins.str]:
            '''The values for the date-time parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameter.html#cfn-quicksight-dashboard-datetimeparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.List[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "info_icon_label_options": "infoIconLabelOptions",
            "title_options": "titleOptions",
        },
    )
    class DateTimePickerControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SheetControlInfoIconLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param date_time_format: Customize how dates are formatted in controls.
            :param info_icon_label_options: The configuration of info icon label options.
            :param title_options: The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimepickercontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_picker_control_display_options_property = quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                    date_time_format="dateTimeFormat",
                    info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                        info_icon_text="infoIconText",
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__90e69e789349808e2dd1f4e3618f32bb7adc79e96050c62b7bac8d4c93987833)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument info_icon_label_options", value=info_icon_label_options, expected_type=type_hints["info_icon_label_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if info_icon_label_options is not None:
                self._values["info_icon_label_options"] = info_icon_label_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Customize how dates are formatted in controls.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimepickercontroldisplayoptions.html#cfn-quicksight-dashboard-datetimepickercontroldisplayoptions-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def info_icon_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetControlInfoIconLabelOptionsProperty"]]:
            '''The configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimepickercontroldisplayoptions.html#cfn-quicksight-dashboard-datetimepickercontroldisplayoptions-infoiconlabeloptions
            '''
            result = self._values.get("info_icon_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetControlInfoIconLabelOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimepickercontroldisplayoptions.html#cfn-quicksight-dashboard-datetimepickercontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimePickerControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class DateTimeValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[builtins.str] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimevaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_value_when_unset_configuration_property = quicksight.CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty(
                    custom_value="customValue",
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d8c807c3455810693e49813aeed10819fe9aa62d8a125e2183604b02ed8fec45)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[builtins.str]:
            '''A custom value that's used when the value of a parameter isn't set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-datetimevaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-datetimevaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DecimalDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class DecimalDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
        ) -> None:
            '''The default values of the ``DecimalParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``DecimalDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``DecimalDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimaldefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                decimal_default_values_property = quicksight.CfnDashboard.DecimalDefaultValuesProperty(
                    dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__86abb8b5e2412c864c791e7d7d718932bf206adcc683c8eb64021cedef34bde6)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``DecimalDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimaldefaultvalues.html#cfn-quicksight-dashboard-decimaldefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def static_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]]:
            '''The static values of the ``DecimalDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimaldefaultvalues.html#cfn-quicksight-dashboard-decimaldefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DecimalParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class DecimalParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DecimalDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DecimalValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``Decimal`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: 
            :param value_when_unset: The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                decimal_parameter_declaration_property = quicksight.CfnDashboard.DecimalParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnDashboard.DecimalDefaultValuesProperty(
                        dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=[123]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnDashboard.DecimalValueWhenUnsetConfigurationProperty(
                        custom_value=123,
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__493cbc9becd13ff6e4b0932b7cfc11e2c50d6fe07cd083d18977551416b6ffa2)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DecimalDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DecimalDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MappedDataSetParameterProperty"]]]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DecimalValueWhenUnsetConfigurationProperty"]]:
            '''The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DecimalValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DecimalParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class DecimalParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]],
        ) -> None:
            '''A decimal parameter.

            :param name: A display name for the decimal parameter.
            :param values: The values for the decimal parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                decimal_parameter_property = quicksight.CfnDashboard.DecimalParameterProperty(
                    name="name",
                    values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0374f299306ea49d96a80a06e399d71cf788801ce5ead0d587a2c27b0519b2a3)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for the decimal parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameter.html#cfn-quicksight-dashboard-decimalparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]:
            '''The values for the decimal parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameter.html#cfn-quicksight-dashboard-decimalparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DecimalPlacesConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"decimal_places": "decimalPlaces"},
    )
    class DecimalPlacesConfigurationProperty:
        def __init__(self, *, decimal_places: jsii.Number) -> None:
            '''The option that determines the decimal places configuration.

            :param decimal_places: The values of the decimal places.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalplacesconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                decimal_places_configuration_property = quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                    decimal_places=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__810f14e63dfcfe16d8a2f1cd7186b1bb7852edc493057b58a2a2a94e35f1c855)
                check_type(argname="argument decimal_places", value=decimal_places, expected_type=type_hints["decimal_places"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "decimal_places": decimal_places,
            }

        @builtins.property
        def decimal_places(self) -> jsii.Number:
            '''The values of the decimal places.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalplacesconfiguration.html#cfn-quicksight-dashboard-decimalplacesconfiguration-decimalplaces
            '''
            result = self._values.get("decimal_places")
            assert result is not None, "Required property 'decimal_places' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalPlacesConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DecimalValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class DecimalValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[jsii.Number] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalvaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                decimal_value_when_unset_configuration_property = quicksight.CfnDashboard.DecimalValueWhenUnsetConfigurationProperty(
                    custom_value=123,
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ffc6e7c59e3e07f6b1ec5099c92200960ba85988e1b545901df9e24c7b4d244f)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[jsii.Number]:
            '''A custom value that's used when the value of a parameter isn't set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-decimalvaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-decimalvaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DefaultFreeFormLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultFreeFormLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The options that determine the default settings of a free-form layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultfreeformlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                default_free_form_layout_configuration_property = quicksight.CfnDashboard.DefaultFreeFormLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d39e97411686f88df1ab9f7b1a77ffcca0bd59ae74b683d51772f2f2b82efb9a)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty"]:
            '''Determines the screen canvas size options for a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultfreeformlayoutconfiguration.html#cfn-quicksight-dashboard-defaultfreeformlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultFreeFormLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DefaultGridLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultGridLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GridLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The options that determine the default settings for a grid layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a grid layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultgridlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                default_grid_layout_configuration_property = quicksight.CfnDashboard.DefaultGridLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                            resize_option="resizeOption",
                
                            # the properties below are optional
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__38ff44a7d24b9c7656d9f3eda759ad3d180955f180dc852ec17bc66f6f6ec722)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.GridLayoutCanvasSizeOptionsProperty"]:
            '''Determines the screen canvas size options for a grid layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultgridlayoutconfiguration.html#cfn-quicksight-dashboard-defaultgridlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.GridLayoutCanvasSizeOptionsProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultGridLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DefaultInteractiveLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"free_form": "freeForm", "grid": "grid"},
    )
    class DefaultInteractiveLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DefaultFreeFormLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            grid: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DefaultGridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the default settings for interactive layout configuration.

            :param free_form: The options that determine the default settings of a free-form layout configuration.
            :param grid: The options that determine the default settings for a grid layout configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultinteractivelayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                default_interactive_layout_configuration_property = quicksight.CfnDashboard.DefaultInteractiveLayoutConfigurationProperty(
                    free_form=quicksight.CfnDashboard.DefaultFreeFormLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    grid=quicksight.CfnDashboard.DefaultGridLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ea14aeb09317551633f58ca2d3bc4e54974792dbd1ed21854e72d32d1ba80ee8)
                check_type(argname="argument free_form", value=free_form, expected_type=type_hints["free_form"])
                check_type(argname="argument grid", value=grid, expected_type=type_hints["grid"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if free_form is not None:
                self._values["free_form"] = free_form
            if grid is not None:
                self._values["grid"] = grid

        @builtins.property
        def free_form(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DefaultFreeFormLayoutConfigurationProperty"]]:
            '''The options that determine the default settings of a free-form layout configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultinteractivelayoutconfiguration.html#cfn-quicksight-dashboard-defaultinteractivelayoutconfiguration-freeform
            '''
            result = self._values.get("free_form")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DefaultFreeFormLayoutConfigurationProperty"]], result)

        @builtins.property
        def grid(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DefaultGridLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for a grid layout configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultinteractivelayoutconfiguration.html#cfn-quicksight-dashboard-defaultinteractivelayoutconfiguration-grid
            '''
            result = self._values.get("grid")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DefaultGridLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultInteractiveLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DefaultNewSheetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "interactive_layout_configuration": "interactiveLayoutConfiguration",
            "paginated_layout_configuration": "paginatedLayoutConfiguration",
            "sheet_content_type": "sheetContentType",
        },
    )
    class DefaultNewSheetConfigurationProperty:
        def __init__(
            self,
            *,
            interactive_layout_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DefaultInteractiveLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paginated_layout_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DefaultPaginatedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sheet_content_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration for default new sheet settings.

            :param interactive_layout_configuration: The options that determine the default settings for interactive layout configuration.
            :param paginated_layout_configuration: The options that determine the default settings for a paginated layout configuration.
            :param sheet_content_type: The option that determines the sheet content type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultnewsheetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                default_new_sheet_configuration_property = quicksight.CfnDashboard.DefaultNewSheetConfigurationProperty(
                    interactive_layout_configuration=quicksight.CfnDashboard.DefaultInteractiveLayoutConfigurationProperty(
                        free_form=quicksight.CfnDashboard.DefaultFreeFormLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        grid=quicksight.CfnDashboard.DefaultGridLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        )
                    ),
                    paginated_layout_configuration=quicksight.CfnDashboard.DefaultPaginatedLayoutConfigurationProperty(
                        section_based=quicksight.CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                    paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    ),
                                    paper_orientation="paperOrientation",
                                    paper_size="paperSize"
                                )
                            )
                        )
                    ),
                    sheet_content_type="sheetContentType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__56eea1585b07f7f2c3a40432abd531967f87d24eed0fda5a6e2be08d6417b73e)
                check_type(argname="argument interactive_layout_configuration", value=interactive_layout_configuration, expected_type=type_hints["interactive_layout_configuration"])
                check_type(argname="argument paginated_layout_configuration", value=paginated_layout_configuration, expected_type=type_hints["paginated_layout_configuration"])
                check_type(argname="argument sheet_content_type", value=sheet_content_type, expected_type=type_hints["sheet_content_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if interactive_layout_configuration is not None:
                self._values["interactive_layout_configuration"] = interactive_layout_configuration
            if paginated_layout_configuration is not None:
                self._values["paginated_layout_configuration"] = paginated_layout_configuration
            if sheet_content_type is not None:
                self._values["sheet_content_type"] = sheet_content_type

        @builtins.property
        def interactive_layout_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DefaultInteractiveLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for interactive layout configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultnewsheetconfiguration.html#cfn-quicksight-dashboard-defaultnewsheetconfiguration-interactivelayoutconfiguration
            '''
            result = self._values.get("interactive_layout_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DefaultInteractiveLayoutConfigurationProperty"]], result)

        @builtins.property
        def paginated_layout_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DefaultPaginatedLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for a paginated layout configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultnewsheetconfiguration.html#cfn-quicksight-dashboard-defaultnewsheetconfiguration-paginatedlayoutconfiguration
            '''
            result = self._values.get("paginated_layout_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DefaultPaginatedLayoutConfigurationProperty"]], result)

        @builtins.property
        def sheet_content_type(self) -> typing.Optional[builtins.str]:
            '''The option that determines the sheet content type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultnewsheetconfiguration.html#cfn-quicksight-dashboard-defaultnewsheetconfiguration-sheetcontenttype
            '''
            result = self._values.get("sheet_content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultNewSheetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DefaultPaginatedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"section_based": "sectionBased"},
    )
    class DefaultPaginatedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            section_based: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the default settings for a paginated layout configuration.

            :param section_based: The options that determine the default settings for a section-based layout configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultpaginatedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                default_paginated_layout_configuration_property = quicksight.CfnDashboard.DefaultPaginatedLayoutConfigurationProperty(
                    section_based=quicksight.CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                            paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                ),
                                paper_orientation="paperOrientation",
                                paper_size="paperSize"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dbf88a4accfa6c839334fbab2361d44b01977cd33f36f5d92413f3ad23056102)
                check_type(argname="argument section_based", value=section_based, expected_type=type_hints["section_based"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if section_based is not None:
                self._values["section_based"] = section_based

        @builtins.property
        def section_based(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for a section-based layout configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultpaginatedlayoutconfiguration.html#cfn-quicksight-dashboard-defaultpaginatedlayoutconfiguration-sectionbased
            '''
            result = self._values.get("section_based")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultPaginatedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultSectionBasedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The options that determine the default settings for a section-based layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a section-based layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultsectionbasedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                default_section_based_layout_configuration_property = quicksight.CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                        paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                            paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            ),
                            paper_orientation="paperOrientation",
                            paper_size="paperSize"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2de36f258c529330394e6e04556e307357bccc72c2039ee1fd796872f1e73748)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty"]:
            '''Determines the screen canvas size options for a section-based layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultsectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-defaultsectionbasedlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultSectionBasedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_values_configuration": "customValuesConfiguration",
            "select_all_value_options": "selectAllValueOptions",
            "source_column": "sourceColumn",
            "source_field": "sourceField",
            "source_parameter_name": "sourceParameterName",
        },
    )
    class DestinationParameterValueConfigurationProperty:
        def __init__(
            self,
            *,
            custom_values_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CustomValuesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            select_all_value_options: typing.Optional[builtins.str] = None,
            source_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            source_field: typing.Optional[builtins.str] = None,
            source_parameter_name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of destination parameter values.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_values_configuration: The configuration of custom values for destination parameter in ``DestinationParameterValueConfiguration`` .
            :param select_all_value_options: The configuration that selects all options.
            :param source_column: 
            :param source_field: The source field ID of the destination parameter.
            :param source_parameter_name: The source parameter name of the destination parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                destination_parameter_value_configuration_property = quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                            date_time_values=["dateTimeValues"],
                            decimal_values=[123],
                            integer_values=[123],
                            string_values=["stringValues"]
                        ),
                
                        # the properties below are optional
                        include_null_value=False
                    ),
                    select_all_value_options="selectAllValueOptions",
                    source_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    source_field="sourceField",
                    source_parameter_name="sourceParameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2967c2f7f112aa455423258fd03cbd20b6108b6d170855e75a5fb046fd75ff43)
                check_type(argname="argument custom_values_configuration", value=custom_values_configuration, expected_type=type_hints["custom_values_configuration"])
                check_type(argname="argument select_all_value_options", value=select_all_value_options, expected_type=type_hints["select_all_value_options"])
                check_type(argname="argument source_column", value=source_column, expected_type=type_hints["source_column"])
                check_type(argname="argument source_field", value=source_field, expected_type=type_hints["source_field"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_values_configuration is not None:
                self._values["custom_values_configuration"] = custom_values_configuration
            if select_all_value_options is not None:
                self._values["select_all_value_options"] = select_all_value_options
            if source_column is not None:
                self._values["source_column"] = source_column
            if source_field is not None:
                self._values["source_field"] = source_field
            if source_parameter_name is not None:
                self._values["source_parameter_name"] = source_parameter_name

        @builtins.property
        def custom_values_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomValuesConfigurationProperty"]]:
            '''The configuration of custom values for destination parameter in ``DestinationParameterValueConfiguration`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-customvaluesconfiguration
            '''
            result = self._values.get("custom_values_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomValuesConfigurationProperty"]], result)

        @builtins.property
        def select_all_value_options(self) -> typing.Optional[builtins.str]:
            '''The configuration that selects all options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-selectallvalueoptions
            '''
            result = self._values.get("select_all_value_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def source_column(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-sourcecolumn
            '''
            result = self._values.get("source_column")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]], result)

        @builtins.property
        def source_field(self) -> typing.Optional[builtins.str]:
            '''The source field ID of the destination parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-sourcefield
            '''
            result = self._values.get("source_field")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def source_parameter_name(self) -> typing.Optional[builtins.str]:
            '''The source parameter name of the destination parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DestinationParameterValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "categorical_dimension_field": "categoricalDimensionField",
            "date_dimension_field": "dateDimensionField",
            "numerical_dimension_field": "numericalDimensionField",
        },
    )
    class DimensionFieldProperty:
        def __init__(
            self,
            *,
            categorical_dimension_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CategoricalDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            date_dimension_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DateDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numerical_dimension_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumericalDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The dimension type field.

            :param categorical_dimension_field: The dimension type field with categorical type columns.
            :param date_dimension_field: The dimension type field with date type columns.
            :param numerical_dimension_field: The dimension type field with numerical type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                dimension_field_property = quicksight.CfnDashboard.DimensionFieldProperty(
                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    ),
                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        date_granularity="dateGranularity",
                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    ),
                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f13427962c0b6c9aa8bb064ca5ebe13bded7171a506ce55828534c5acb7af781)
                check_type(argname="argument categorical_dimension_field", value=categorical_dimension_field, expected_type=type_hints["categorical_dimension_field"])
                check_type(argname="argument date_dimension_field", value=date_dimension_field, expected_type=type_hints["date_dimension_field"])
                check_type(argname="argument numerical_dimension_field", value=numerical_dimension_field, expected_type=type_hints["numerical_dimension_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if categorical_dimension_field is not None:
                self._values["categorical_dimension_field"] = categorical_dimension_field
            if date_dimension_field is not None:
                self._values["date_dimension_field"] = date_dimension_field
            if numerical_dimension_field is not None:
                self._values["numerical_dimension_field"] = numerical_dimension_field

        @builtins.property
        def categorical_dimension_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CategoricalDimensionFieldProperty"]]:
            '''The dimension type field with categorical type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dimensionfield.html#cfn-quicksight-dashboard-dimensionfield-categoricaldimensionfield
            '''
            result = self._values.get("categorical_dimension_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CategoricalDimensionFieldProperty"]], result)

        @builtins.property
        def date_dimension_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateDimensionFieldProperty"]]:
            '''The dimension type field with date type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dimensionfield.html#cfn-quicksight-dashboard-dimensionfield-datedimensionfield
            '''
            result = self._values.get("date_dimension_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateDimensionFieldProperty"]], result)

        @builtins.property
        def numerical_dimension_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericalDimensionFieldProperty"]]:
            '''The dimension type field with numerical type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dimensionfield.html#cfn-quicksight-dashboard-dimensionfield-numericaldimensionfield
            '''
            result = self._values.get("numerical_dimension_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericalDimensionFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DonutCenterOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"label_visibility": "labelVisibility"},
    )
    class DonutCenterOptionsProperty:
        def __init__(
            self,
            *,
            label_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label options of the label that is displayed in the center of a donut chart.

            This option isn't available for pie charts.

            :param label_visibility: Determines the visibility of the label in a donut chart. In the Amazon QuickSight console, this option is called ``'Show total'`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutcenteroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                donut_center_options_property = quicksight.CfnDashboard.DonutCenterOptionsProperty(
                    label_visibility="labelVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aff1e2eb9a1c2600f67efc0797fe03c739576b352bb30d9cb902503991e4a538)
                check_type(argname="argument label_visibility", value=label_visibility, expected_type=type_hints["label_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if label_visibility is not None:
                self._values["label_visibility"] = label_visibility

        @builtins.property
        def label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the label in a donut chart.

            In the Amazon QuickSight console, this option is called ``'Show total'`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutcenteroptions.html#cfn-quicksight-dashboard-donutcenteroptions-labelvisibility
            '''
            result = self._values.get("label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DonutCenterOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DonutOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arc_options": "arcOptions",
            "donut_center_options": "donutCenterOptions",
        },
    )
    class DonutOptionsProperty:
        def __init__(
            self,
            *,
            arc_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ArcOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            donut_center_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DonutCenterOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options for configuring a donut chart or pie chart.

            :param arc_options: The option for define the arc of the chart shape. Valid values are as follows:. - ``WHOLE`` - A pie chart - ``SMALL`` - A small-sized donut chart - ``MEDIUM`` - A medium-sized donut chart - ``LARGE`` - A large-sized donut chart
            :param donut_center_options: The label options of the label that is displayed in the center of a donut chart. This option isn't available for pie charts.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                donut_options_property = quicksight.CfnDashboard.DonutOptionsProperty(
                    arc_options=quicksight.CfnDashboard.ArcOptionsProperty(
                        arc_thickness="arcThickness"
                    ),
                    donut_center_options=quicksight.CfnDashboard.DonutCenterOptionsProperty(
                        label_visibility="labelVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__204d9f4c3acc927e3a4fb916dab8ae30a397452434329da28d3f42677909fa90)
                check_type(argname="argument arc_options", value=arc_options, expected_type=type_hints["arc_options"])
                check_type(argname="argument donut_center_options", value=donut_center_options, expected_type=type_hints["donut_center_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_options is not None:
                self._values["arc_options"] = arc_options
            if donut_center_options is not None:
                self._values["donut_center_options"] = donut_center_options

        @builtins.property
        def arc_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ArcOptionsProperty"]]:
            '''The option for define the arc of the chart shape. Valid values are as follows:.

            - ``WHOLE`` - A pie chart
            - ``SMALL`` - A small-sized donut chart
            - ``MEDIUM`` - A medium-sized donut chart
            - ``LARGE`` - A large-sized donut chart

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutoptions.html#cfn-quicksight-dashboard-donutoptions-arcoptions
            '''
            result = self._values.get("arc_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ArcOptionsProperty"]], result)

        @builtins.property
        def donut_center_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DonutCenterOptionsProperty"]]:
            '''The label options of the label that is displayed in the center of a donut chart.

            This option isn't available for pie charts.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutoptions.html#cfn-quicksight-dashboard-donutoptions-donutcenteroptions
            '''
            result = self._values.get("donut_center_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DonutCenterOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DonutOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_filter": "categoryFilter",
            "numeric_equality_filter": "numericEqualityFilter",
            "time_range_filter": "timeRangeFilter",
        },
    )
    class DrillDownFilterProperty:
        def __init__(
            self,
            *,
            category_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CategoryDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_equality_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumericEqualityDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TimeRangeDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The drill down filter for the column hierarchies.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param category_filter: The category type drill down filter. This filter is used for string type columns.
            :param numeric_equality_filter: The numeric equality type drill down filter. This filter is used for number type columns.
            :param time_range_filter: The time range drill down filter. This filter is used for date time columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-drilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                drill_down_filter_property = quicksight.CfnDashboard.DrillDownFilterProperty(
                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                        category_values=["categoryValues"],
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        value=123
                    ),
                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        range_maximum="rangeMaximum",
                        range_minimum="rangeMinimum",
                        time_granularity="timeGranularity"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6a57b90130b9805eb215653ca43c03a593f7cd11bc59cbc7b53ee3e0c571bacf)
                check_type(argname="argument category_filter", value=category_filter, expected_type=type_hints["category_filter"])
                check_type(argname="argument numeric_equality_filter", value=numeric_equality_filter, expected_type=type_hints["numeric_equality_filter"])
                check_type(argname="argument time_range_filter", value=time_range_filter, expected_type=type_hints["time_range_filter"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_filter is not None:
                self._values["category_filter"] = category_filter
            if numeric_equality_filter is not None:
                self._values["numeric_equality_filter"] = numeric_equality_filter
            if time_range_filter is not None:
                self._values["time_range_filter"] = time_range_filter

        @builtins.property
        def category_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CategoryDrillDownFilterProperty"]]:
            '''The category type drill down filter.

            This filter is used for string type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-drilldownfilter.html#cfn-quicksight-dashboard-drilldownfilter-categoryfilter
            '''
            result = self._values.get("category_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CategoryDrillDownFilterProperty"]], result)

        @builtins.property
        def numeric_equality_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericEqualityDrillDownFilterProperty"]]:
            '''The numeric equality type drill down filter.

            This filter is used for number type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-drilldownfilter.html#cfn-quicksight-dashboard-drilldownfilter-numericequalityfilter
            '''
            result = self._values.get("numeric_equality_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericEqualityDrillDownFilterProperty"]], result)

        @builtins.property
        def time_range_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TimeRangeDrillDownFilterProperty"]]:
            '''The time range drill down filter.

            This filter is used for date time columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-drilldownfilter.html#cfn-quicksight-dashboard-drilldownfilter-timerangefilter
            '''
            result = self._values.get("time_range_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TimeRangeDrillDownFilterProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "info_icon_label_options": "infoIconLabelOptions",
            "select_all_options": "selectAllOptions",
            "title_options": "titleOptions",
        },
    )
    class DropDownControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SheetControlInfoIconLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            select_all_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ListControlSelectAllOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param info_icon_label_options: The configuration of info icon label options.
            :param select_all_options: The configuration of the ``Select all`` options in a dropdown control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dropdowncontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                drop_down_control_display_options_property = quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                    info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                        info_icon_text="infoIconText",
                        visibility="visibility"
                    ),
                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__355aeea49a7fad6b4a1a346bd823cda58b43b32bec7044ac9122977e1c23714e)
                check_type(argname="argument info_icon_label_options", value=info_icon_label_options, expected_type=type_hints["info_icon_label_options"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if info_icon_label_options is not None:
                self._values["info_icon_label_options"] = info_icon_label_options
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def info_icon_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetControlInfoIconLabelOptionsProperty"]]:
            '''The configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dropdowncontroldisplayoptions.html#cfn-quicksight-dashboard-dropdowncontroldisplayoptions-infoiconlabeloptions
            '''
            result = self._values.get("info_icon_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetControlInfoIconLabelOptionsProperty"]], result)

        @builtins.property
        def select_all_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ListControlSelectAllOptionsProperty"]]:
            '''The configuration of the ``Select all`` options in a dropdown control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dropdowncontroldisplayoptions.html#cfn-quicksight-dashboard-dropdowncontroldisplayoptions-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ListControlSelectAllOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dropdowncontroldisplayoptions.html#cfn-quicksight-dashboard-dropdowncontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DropDownControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.DynamicDefaultValueProperty",
        jsii_struct_bases=[],
        name_mapping={
            "default_value_column": "defaultValueColumn",
            "group_name_column": "groupNameColumn",
            "user_name_column": "userNameColumn",
        },
    )
    class DynamicDefaultValueProperty:
        def __init__(
            self,
            *,
            default_value_column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            group_name_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            user_name_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Defines different defaults to the users or groups based on mapping.

            :param default_value_column: The column that contains the default value of each user or group.
            :param group_name_column: The column that contains the group name.
            :param user_name_column: The column that contains the username.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dynamicdefaultvalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                dynamic_default_value_property = quicksight.CfnDashboard.DynamicDefaultValueProperty(
                    default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0d675ac8a86048db958c90c51de98db3c58d4ffcbe17e8397f30ee68e31d74c6)
                check_type(argname="argument default_value_column", value=default_value_column, expected_type=type_hints["default_value_column"])
                check_type(argname="argument group_name_column", value=group_name_column, expected_type=type_hints["group_name_column"])
                check_type(argname="argument user_name_column", value=user_name_column, expected_type=type_hints["user_name_column"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "default_value_column": default_value_column,
            }
            if group_name_column is not None:
                self._values["group_name_column"] = group_name_column
            if user_name_column is not None:
                self._values["user_name_column"] = user_name_column

        @builtins.property
        def default_value_column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that contains the default value of each user or group.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dynamicdefaultvalue.html#cfn-quicksight-dashboard-dynamicdefaultvalue-defaultvaluecolumn
            '''
            result = self._values.get("default_value_column")
            assert result is not None, "Required property 'default_value_column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def group_name_column(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]]:
            '''The column that contains the group name.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dynamicdefaultvalue.html#cfn-quicksight-dashboard-dynamicdefaultvalue-groupnamecolumn
            '''
            result = self._values.get("group_name_column")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]], result)

        @builtins.property
        def user_name_column(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]]:
            '''The column that contains the username.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dynamicdefaultvalue.html#cfn-quicksight-dashboard-dynamicdefaultvalue-usernamecolumn
            '''
            result = self._values.get("user_name_column")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DynamicDefaultValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.EmptyVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
        },
    )
    class EmptyVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''An empty visual.

            Empty visuals are used in layouts but have not been configured to show any data. A new visual created in the Amazon QuickSight console is considered an ``EmptyVisual`` until a visual type is selected.

            :param data_set_identifier: The data set that is used in the empty visual. Every visual requires a dataset to render.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-emptyvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                empty_visual_property = quicksight.CfnDashboard.EmptyVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__604dd475dca9ac1a9cec890c4ca9cbaa82fc5789da3dd6746e358d9712a56c8a)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that is used in the empty visual.

            Every visual requires a dataset to render.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-emptyvisual.html#cfn-quicksight-dashboard-emptyvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-emptyvisual.html#cfn-quicksight-dashboard-emptyvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-emptyvisual.html#cfn-quicksight-dashboard-emptyvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "EmptyVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.EntityProperty",
        jsii_struct_bases=[],
        name_mapping={"path": "path"},
    )
    class EntityProperty:
        def __init__(self, *, path: typing.Optional[builtins.str] = None) -> None:
            '''An object, structure, or sub-structure of an analysis, template, or dashboard.

            :param path: The hierarchical path of the entity within the analysis, template, or dashboard definition tree.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-entity.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                entity_property = quicksight.CfnDashboard.EntityProperty(
                    path="path"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a6cf24f107ec2fd6520772b006c6a35713e11f36165ea69f4ecbfe2522465cf3)
                check_type(argname="argument path", value=path, expected_type=type_hints["path"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if path is not None:
                self._values["path"] = path

        @builtins.property
        def path(self) -> typing.Optional[builtins.str]:
            '''The hierarchical path of the entity within the analysis, template, or dashboard definition tree.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-entity.html#cfn-quicksight-dashboard-entity-path
            '''
            result = self._values.get("path")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "EntityProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ExcludePeriodConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "amount": "amount",
            "granularity": "granularity",
            "status": "status",
        },
    )
    class ExcludePeriodConfigurationProperty:
        def __init__(
            self,
            *,
            amount: jsii.Number,
            granularity: builtins.str,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The exclude period of ``TimeRangeFilter`` or ``RelativeDatesFilter`` .

            :param amount: The amount or number of the exclude period.
            :param granularity: The granularity or unit (day, month, year) of the exclude period.
            :param status: The status of the exclude period. Choose from the following options:. - ``ENABLED`` - ``DISABLED``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-excludeperiodconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                exclude_period_configuration_property = quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                    amount=123,
                    granularity="granularity",
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__315a64b5a54ec0e4314b4e2461ac459b120f16876aff5304c7d486848069ad67)
                check_type(argname="argument amount", value=amount, expected_type=type_hints["amount"])
                check_type(argname="argument granularity", value=granularity, expected_type=type_hints["granularity"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "amount": amount,
                "granularity": granularity,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def amount(self) -> jsii.Number:
            '''The amount or number of the exclude period.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-excludeperiodconfiguration.html#cfn-quicksight-dashboard-excludeperiodconfiguration-amount
            '''
            result = self._values.get("amount")
            assert result is not None, "Required property 'amount' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def granularity(self) -> builtins.str:
            '''The granularity or unit (day, month, year) of the exclude period.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-excludeperiodconfiguration.html#cfn-quicksight-dashboard-excludeperiodconfiguration-granularity
            '''
            result = self._values.get("granularity")
            assert result is not None, "Required property 'granularity' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the exclude period. Choose from the following options:.

            - ``ENABLED``
            - ``DISABLED``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-excludeperiodconfiguration.html#cfn-quicksight-dashboard-excludeperiodconfiguration-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExcludePeriodConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ExplicitHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class ExplicitHierarchyProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]]],
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields that are built within a visual's field wells.

            These fields can't be duplicated to other visuals.

            :param columns: The list of columns that define the explicit hierarchy.
            :param hierarchy_id: The hierarchy ID of the explicit hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the explicit hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-explicithierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                explicit_hierarchy_property = quicksight.CfnDashboard.ExplicitHierarchyProperty(
                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a917725d612aafa12d8d0c1a105a2d73f203127b6a08252afd54f0488fcee902)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]]]:
            '''The list of columns that define the explicit hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-explicithierarchy.html#cfn-quicksight-dashboard-explicithierarchy-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]]], result)

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the explicit hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-explicithierarchy.html#cfn-quicksight-dashboard-explicithierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DrillDownFilterProperty"]]]]:
            '''The option that determines the drill down filters for the explicit hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-explicithierarchy.html#cfn-quicksight-dashboard-explicithierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DrillDownFilterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExplicitHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ExportHiddenFieldsOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class ExportHiddenFieldsOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines if hidden fields are included in an exported dashboard.

            :param availability_status: The status of the export hidden fields options of a dashbaord.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exporthiddenfieldsoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                export_hidden_fields_option_property = quicksight.CfnDashboard.ExportHiddenFieldsOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ccc7b7919fe9bff8b58d9914e3408ddc601f119bb566a521c9ba330108021166)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The status of the export hidden fields options of a dashbaord.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exporthiddenfieldsoption.html#cfn-quicksight-dashboard-exporthiddenfieldsoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExportHiddenFieldsOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ExportToCSVOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class ExportToCSVOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Export to .csv option.

            :param availability_status: Availability status.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exporttocsvoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                export_to_cSVOption_property = quicksight.CfnDashboard.ExportToCSVOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c1b31bc0e0d8ecfdfaa4ea2ea823bb9e0f3b9b39115478ab8d612a79942da86c)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''Availability status.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exporttocsvoption.html#cfn-quicksight-dashboard-exporttocsvoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExportToCSVOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ExportWithHiddenFieldsOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class ExportWithHiddenFieldsOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines whether or not hidden fields are visible on exported dashbaords.

            :param availability_status: The status of the export with hidden fields options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exportwithhiddenfieldsoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                export_with_hidden_fields_option_property = quicksight.CfnDashboard.ExportWithHiddenFieldsOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__951b93a6bd5a29ecd51b86f3f98148422298ea3c1ff8545e6e22e166a7e05335)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The status of the export with hidden fields options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exportwithhiddenfieldsoption.html#cfn-quicksight-dashboard-exportwithhiddenfieldsoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExportWithHiddenFieldsOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FieldBasedTooltipProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_visibility": "aggregationVisibility",
            "tooltip_fields": "tooltipFields",
            "tooltip_title_type": "tooltipTitleType",
        },
    )
    class FieldBasedTooltipProperty:
        def __init__(
            self,
            *,
            aggregation_visibility: typing.Optional[builtins.str] = None,
            tooltip_fields: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TooltipItemProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            tooltip_title_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The setup for the detailed tooltip.

            :param aggregation_visibility: The visibility of ``Show aggregations`` .
            :param tooltip_fields: The fields configuration in the tooltip.
            :param tooltip_title_type: The type for the >tooltip title. Choose one of the following options:. - ``NONE`` : Doesn't use the primary value as the title. - ``PRIMARY_VALUE`` : Uses primary value as the title.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldbasedtooltip.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                field_based_tooltip_property = quicksight.CfnDashboard.FieldBasedTooltipProperty(
                    aggregation_visibility="aggregationVisibility",
                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            label="label",
                            visibility="visibility"
                        ),
                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            label="label",
                            visibility="visibility"
                        )
                    )],
                    tooltip_title_type="tooltipTitleType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1f95445a18533857ef283056719d18541fe202fa20c0a5eaec800a7f2fd74847)
                check_type(argname="argument aggregation_visibility", value=aggregation_visibility, expected_type=type_hints["aggregation_visibility"])
                check_type(argname="argument tooltip_fields", value=tooltip_fields, expected_type=type_hints["tooltip_fields"])
                check_type(argname="argument tooltip_title_type", value=tooltip_title_type, expected_type=type_hints["tooltip_title_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if aggregation_visibility is not None:
                self._values["aggregation_visibility"] = aggregation_visibility
            if tooltip_fields is not None:
                self._values["tooltip_fields"] = tooltip_fields
            if tooltip_title_type is not None:
                self._values["tooltip_title_type"] = tooltip_title_type

        @builtins.property
        def aggregation_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of ``Show aggregations`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldbasedtooltip.html#cfn-quicksight-dashboard-fieldbasedtooltip-aggregationvisibility
            '''
            result = self._values.get("aggregation_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tooltip_fields(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipItemProperty"]]]]:
            '''The fields configuration in the tooltip.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldbasedtooltip.html#cfn-quicksight-dashboard-fieldbasedtooltip-tooltipfields
            '''
            result = self._values.get("tooltip_fields")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipItemProperty"]]]], result)

        @builtins.property
        def tooltip_title_type(self) -> typing.Optional[builtins.str]:
            '''The type for the >tooltip title. Choose one of the following options:.

            - ``NONE`` : Doesn't use the primary value as the title.
            - ``PRIMARY_VALUE`` : Uses primary value as the title.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldbasedtooltip.html#cfn-quicksight-dashboard-fieldbasedtooltip-tooltiptitletype
            '''
            result = self._values.get("tooltip_title_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldBasedTooltipProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FieldLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "visibility": "visibility"},
    )
    class FieldLabelTypeProperty:
        def __init__(
            self,
            *,
            field_id: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The field label type.

            :param field_id: Indicates the field that is targeted by the field label.
            :param visibility: The visibility of the field label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                field_label_type_property = quicksight.CfnDashboard.FieldLabelTypeProperty(
                    field_id="fieldId",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d73962d6db6d9d7d01e259ac5c319f46d5598e0facaf47cc82082c11c21d6574)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''Indicates the field that is targeted by the field label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldlabeltype.html#cfn-quicksight-dashboard-fieldlabeltype-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the field label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldlabeltype.html#cfn-quicksight-dashboard-fieldlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FieldSeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "field_id": "fieldId",
            "settings": "settings",
        },
    )
    class FieldSeriesItemProperty:
        def __init__(
            self,
            *,
            axis_binding: builtins.str,
            field_id: builtins.str,
            settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LineChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field series item configuration of a line chart.

            :param axis_binding: The axis that you are binding the field to.
            :param field_id: The field ID of the field for which you are setting the axis binding.
            :param settings: The options that determine the presentation of line series associated to the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldseriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                field_series_item_property = quicksight.CfnDashboard.FieldSeriesItemProperty(
                    axis_binding="axisBinding",
                    field_id="fieldId",
                
                    # the properties below are optional
                    settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                        line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6de4ea2be24b42686f57223b63c6775199dac756d45769f5a0fda1a7d55b426b)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument settings", value=settings, expected_type=type_hints["settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "axis_binding": axis_binding,
                "field_id": field_id,
            }
            if settings is not None:
                self._values["settings"] = settings

        @builtins.property
        def axis_binding(self) -> builtins.str:
            '''The axis that you are binding the field to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldseriesitem.html#cfn-quicksight-dashboard-fieldseriesitem-axisbinding
            '''
            result = self._values.get("axis_binding")
            assert result is not None, "Required property 'axis_binding' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field for which you are setting the axis binding.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldseriesitem.html#cfn-quicksight-dashboard-fieldseriesitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartSeriesSettingsProperty"]]:
            '''The options that determine the presentation of line series associated to the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldseriesitem.html#cfn-quicksight-dashboard-fieldseriesitem-settings
            '''
            result = self._values.get("settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartSeriesSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FieldSortOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"column_sort": "columnSort", "field_sort": "fieldSort"},
    )
    class FieldSortOptionsProperty:
        def __init__(
            self,
            *,
            column_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field sort options in a chart configuration.

            :param column_sort: The sort configuration for a column that is not used in a field well.
            :param field_sort: The sort configuration for a field in a field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsortoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                field_sort_options_property = quicksight.CfnDashboard.FieldSortOptionsProperty(
                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                        direction="direction",
                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                            attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                simple_attribute_aggregation="simpleAttributeAggregation",
                                value_for_multiple_values="valueForMultipleValues"
                            ),
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                        direction="direction",
                        field_id="fieldId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__703c022d70e47dc536d3b84b0fab66de512a3d2f42b5806c2030ea4aa9dbbf15)
                check_type(argname="argument column_sort", value=column_sort, expected_type=type_hints["column_sort"])
                check_type(argname="argument field_sort", value=field_sort, expected_type=type_hints["field_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_sort is not None:
                self._values["column_sort"] = column_sort
            if field_sort is not None:
                self._values["field_sort"] = field_sort

        @builtins.property
        def column_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnSortProperty"]]:
            '''The sort configuration for a column that is not used in a field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsortoptions.html#cfn-quicksight-dashboard-fieldsortoptions-columnsort
            '''
            result = self._values.get("column_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnSortProperty"]], result)

        @builtins.property
        def field_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortProperty"]]:
            '''The sort configuration for a field in a field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsortoptions.html#cfn-quicksight-dashboard-fieldsortoptions-fieldsort
            '''
            result = self._values.get("field_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSortOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FieldSortProperty",
        jsii_struct_bases=[],
        name_mapping={"direction": "direction", "field_id": "fieldId"},
    )
    class FieldSortProperty:
        def __init__(self, *, direction: builtins.str, field_id: builtins.str) -> None:
            '''The sort configuration for a field in a field well.

            :param direction: The sort direction. Choose one of the following options:. - ``ASC`` : Ascending - ``DESC`` : Descending
            :param field_id: The sort configuration target field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                field_sort_property = quicksight.CfnDashboard.FieldSortProperty(
                    direction="direction",
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7d96dac125009282df2800c265b69ee315d440a1ebe6cb4c048fa9cea413603b)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "field_id": field_id,
            }

        @builtins.property
        def direction(self) -> builtins.str:
            '''The sort direction. Choose one of the following options:.

            - ``ASC`` : Ascending
            - ``DESC`` : Descending

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsort.html#cfn-quicksight-dashboard-fieldsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The sort configuration target field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsort.html#cfn-quicksight-dashboard-fieldsort-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FieldTooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "label": "label",
            "visibility": "visibility",
        },
    )
    class FieldTooltipItemProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The tooltip item for the fields.

            :param field_id: The unique ID of the field that is targeted by the tooltip.
            :param label: The label of the tooltip item.
            :param visibility: The visibility of the tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldtooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                field_tooltip_item_property = quicksight.CfnDashboard.FieldTooltipItemProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    label="label",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2b39cb7f5cb9b4fe2e4a6850ae1e2aebcadcb37b16fbc7431330772f250faf46)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if label is not None:
                self._values["label"] = label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The unique ID of the field that is targeted by the tooltip.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldtooltipitem.html#cfn-quicksight-dashboard-fieldtooltipitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def label(self) -> typing.Optional[builtins.str]:
            '''The label of the tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldtooltipitem.html#cfn-quicksight-dashboard-fieldtooltipitem-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldtooltipitem.html#cfn-quicksight-dashboard-fieldtooltipitem-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldTooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"geospatial": "geospatial", "values": "values"},
    )
    class FilledMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            geospatial: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well of the filled map.

            :param geospatial: The aggregated location field well of the filled map. Values are grouped by location fields.
            :param values: The aggregated color field well of a filled map. Values are aggregated based on location fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filled_map_aggregated_field_wells_property = quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty(
                    geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__560833d96ba2f94dae161fd8edc6f1d6cb9e0e3abd174bb20b4ff8d4525a225f)
                check_type(argname="argument geospatial", value=geospatial, expected_type=type_hints["geospatial"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if geospatial is not None:
                self._values["geospatial"] = geospatial
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def geospatial(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The aggregated location field well of the filled map.

            Values are grouped by location fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapaggregatedfieldwells.html#cfn-quicksight-dashboard-filledmapaggregatedfieldwells-geospatial
            '''
            result = self._values.get("geospatial")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The aggregated color field well of a filled map.

            Values are aggregated based on location fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapaggregatedfieldwells.html#cfn-quicksight-dashboard-filledmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilledMapConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"shape": "shape"},
    )
    class FilledMapConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            shape: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilledMapShapeConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''Conditional formatting options of a ``FilledMapVisual`` .

            :param shape: The conditional formatting that determines the shape of the filled map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filled_map_conditional_formatting_option_property = quicksight.CfnDashboard.FilledMapConditionalFormattingOptionProperty(
                    shape=quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        format=quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__92568506a0b7eac5da521ce1e8fb0bce5258abc90c6a94838dffd0a03b214ea1)
                check_type(argname="argument shape", value=shape, expected_type=type_hints["shape"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "shape": shape,
            }

        @builtins.property
        def shape(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilledMapShapeConditionalFormattingProperty"]:
            '''The conditional formatting that determines the shape of the filled map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconditionalformattingoption.html#cfn-quicksight-dashboard-filledmapconditionalformattingoption-shape
            '''
            result = self._values.get("shape")
            assert result is not None, "Required property 'shape' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilledMapShapeConditionalFormattingProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilledMapConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class FilledMapConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilledMapConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The conditional formatting of a ``FilledMapVisual`` .

            :param conditional_formatting_options: Conditional formatting options of a ``FilledMapVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filled_map_conditional_formatting_property = quicksight.CfnDashboard.FilledMapConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnDashboard.FilledMapConditionalFormattingOptionProperty(
                        shape=quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            format=quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d6dd37dbac75444f21387e81f2a86a710e907c622778879fcb0f11925af1f290)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "conditional_formatting_options": conditional_formatting_options,
            }

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilledMapConditionalFormattingOptionProperty"]]]:
            '''Conditional formatting options of a ``FilledMapVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconditionalformatting.html#cfn-quicksight-dashboard-filledmapconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            assert result is not None, "Required property 'conditional_formatting_options' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilledMapConditionalFormattingOptionProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilledMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "legend": "legend",
            "map_style_options": "mapStyleOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "window_options": "windowOptions",
        },
    )
    class FilledMapConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilledMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            map_style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GeospatialMapStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilledMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            window_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GeospatialWindowOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``FilledMapVisual`` .

            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param map_style_options: The map style options of the filled map visual.
            :param sort_configuration: The sort configuration of a ``FilledMapVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param window_options: The window options of the filled map visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dfbb3e48b89cd28bbd6e8c24af60f9d5fee5663d3154f1c7e83f8dfaa588562a)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument map_style_options", value=map_style_options, expected_type=type_hints["map_style_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument window_options", value=window_options, expected_type=type_hints["window_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if map_style_options is not None:
                self._values["map_style_options"] = map_style_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if window_options is not None:
                self._values["window_options"] = window_options

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilledMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilledMapFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def map_style_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialMapStyleOptionsProperty"]]:
            '''The map style options of the filled map visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-mapstyleoptions
            '''
            result = self._values.get("map_style_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialMapStyleOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilledMapSortConfigurationProperty"]]:
            '''The sort configuration of a ``FilledMapVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilledMapSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def window_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialWindowOptionsProperty"]]:
            '''The window options of the filled map visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-windowoptions
            '''
            result = self._values.get("window_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialWindowOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilledMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filled_map_aggregated_field_wells": "filledMapAggregatedFieldWells",
        },
    )
    class FilledMapFieldWellsProperty:
        def __init__(
            self,
            *,
            filled_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilledMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``FilledMapVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param filled_map_aggregated_field_wells: The aggregated field well of the filled map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filled_map_field_wells_property = quicksight.CfnDashboard.FilledMapFieldWellsProperty(
                    filled_map_aggregated_field_wells=quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty(
                        geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a7d475d5525d818bb42442611b254c215fe179788b82491e663964db4a9face4)
                check_type(argname="argument filled_map_aggregated_field_wells", value=filled_map_aggregated_field_wells, expected_type=type_hints["filled_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if filled_map_aggregated_field_wells is not None:
                self._values["filled_map_aggregated_field_wells"] = filled_map_aggregated_field_wells

        @builtins.property
        def filled_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilledMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field well of the filled map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapfieldwells.html#cfn-quicksight-dashboard-filledmapfieldwells-filledmapaggregatedfieldwells
            '''
            result = self._values.get("filled_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilledMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "format": "format"},
    )
    class FilledMapShapeConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ShapeConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting that determines the shape of the filled map.

            :param field_id: The field ID of the filled map shape.
            :param format: The conditional formatting that determines the background color of a filled map's shape.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapshapeconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filled_map_shape_conditional_formatting_property = quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    format=quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__41738324d641a58ffbaaee8a6fe4b354222a034d4d72aad36feeec5ed6b5aa19)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format", value=format, expected_type=type_hints["format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if format is not None:
                self._values["format"] = format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the filled map shape.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapshapeconditionalformatting.html#cfn-quicksight-dashboard-filledmapshapeconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ShapeConditionalFormatProperty"]]:
            '''The conditional formatting that determines the background color of a filled map's shape.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapshapeconditionalformatting.html#cfn-quicksight-dashboard-filledmapshapeconditionalformatting-format
            '''
            result = self._values.get("format")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ShapeConditionalFormatProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapShapeConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilledMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"category_sort": "categorySort"},
    )
    class FilledMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``FilledMapVisual`` .

            :param category_sort: The sort configuration of the location fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filled_map_sort_configuration_property = quicksight.CfnDashboard.FilledMapSortConfigurationProperty(
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__82e3253f6e68896072aac3be7604bbf0741c45a93bb52513b47daca075a7c043)
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the location fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapsortconfiguration.html#cfn-quicksight-dashboard-filledmapsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilledMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class FilledMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilledMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilledMapConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A filled map.

            For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param conditional_formatting: The conditional formatting of a ``FilledMapVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__368d66b0d5e169afda9cf70e70a66d450d0559e333ac6b4f67fca18f415bcdc2)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilledMapConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilledMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilledMapConditionalFormattingProperty"]]:
            '''The conditional formatting of a ``FilledMapVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilledMapConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilterControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_picker": "dateTimePicker",
            "dropdown": "dropdown",
            "list": "list",
            "relative_date_time": "relativeDateTime",
            "slider": "slider",
            "text_area": "textArea",
            "text_field": "textField",
        },
    )
    class FilterControlProperty:
        def __init__(
            self,
            *,
            date_time_picker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilterDateTimePickerControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            dropdown: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilterDropDownControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            list: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilterListControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relative_date_time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilterRelativeDateTimeControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            slider: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilterSliderControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_area: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilterTextAreaControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilterTextFieldControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The control of a filter that is used to interact with a dashboard or an analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_picker: A control from a date filter that is used to specify date and time.
            :param dropdown: A control to display a dropdown list with buttons that are used to select a single value.
            :param list: A control to display a list of buttons or boxes. This is used to select either a single value or multiple values.
            :param relative_date_time: A control from a date filter that is used to specify the relative date.
            :param slider: A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
            :param text_area: A control to display a text box that is used to enter multiple entries.
            :param text_field: A control to display a text box that is used to enter a single entry.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_control_property = quicksight.CfnDashboard.FilterControlProperty(
                    date_time_picker=quicksight.CfnDashboard.FilterDateTimePickerControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        type="type"
                    ),
                    dropdown=quicksight.CfnDashboard.FilterDropDownControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                            values=["values"]
                        ),
                        type="type"
                    ),
                    list=quicksight.CfnDashboard.FilterListControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                            values=["values"]
                        ),
                        type="type"
                    ),
                    relative_date_time=quicksight.CfnDashboard.FilterRelativeDateTimeControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    slider=quicksight.CfnDashboard.FilterSliderControlProperty(
                        filter_control_id="filterControlId",
                        maximum_value=123,
                        minimum_value=123,
                        source_filter_id="sourceFilterId",
                        step_size=123,
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        type="type"
                    ),
                    text_area=quicksight.CfnDashboard.FilterTextAreaControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        delimiter="delimiter",
                        display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_field=quicksight.CfnDashboard.FilterTextFieldControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3de36a833439e9279b496af4596b88285b5a80e52020a02cc1d918bc3caf8a63)
                check_type(argname="argument date_time_picker", value=date_time_picker, expected_type=type_hints["date_time_picker"])
                check_type(argname="argument dropdown", value=dropdown, expected_type=type_hints["dropdown"])
                check_type(argname="argument list", value=list, expected_type=type_hints["list"])
                check_type(argname="argument relative_date_time", value=relative_date_time, expected_type=type_hints["relative_date_time"])
                check_type(argname="argument slider", value=slider, expected_type=type_hints["slider"])
                check_type(argname="argument text_area", value=text_area, expected_type=type_hints["text_area"])
                check_type(argname="argument text_field", value=text_field, expected_type=type_hints["text_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_picker is not None:
                self._values["date_time_picker"] = date_time_picker
            if dropdown is not None:
                self._values["dropdown"] = dropdown
            if list is not None:
                self._values["list"] = list
            if relative_date_time is not None:
                self._values["relative_date_time"] = relative_date_time
            if slider is not None:
                self._values["slider"] = slider
            if text_area is not None:
                self._values["text_area"] = text_area
            if text_field is not None:
                self._values["text_field"] = text_field

        @builtins.property
        def date_time_picker(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterDateTimePickerControlProperty"]]:
            '''A control from a date filter that is used to specify date and time.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-datetimepicker
            '''
            result = self._values.get("date_time_picker")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterDateTimePickerControlProperty"]], result)

        @builtins.property
        def dropdown(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterDropDownControlProperty"]]:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-dropdown
            '''
            result = self._values.get("dropdown")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterDropDownControlProperty"]], result)

        @builtins.property
        def list(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterListControlProperty"]]:
            '''A control to display a list of buttons or boxes.

            This is used to select either a single value or multiple values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-list
            '''
            result = self._values.get("list")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterListControlProperty"]], result)

        @builtins.property
        def relative_date_time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterRelativeDateTimeControlProperty"]]:
            '''A control from a date filter that is used to specify the relative date.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-relativedatetime
            '''
            result = self._values.get("relative_date_time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterRelativeDateTimeControlProperty"]], result)

        @builtins.property
        def slider(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterSliderControlProperty"]]:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-slider
            '''
            result = self._values.get("slider")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterSliderControlProperty"]], result)

        @builtins.property
        def text_area(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterTextAreaControlProperty"]]:
            '''A control to display a text box that is used to enter multiple entries.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-textarea
            '''
            result = self._values.get("text_area")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterTextAreaControlProperty"]], result)

        @builtins.property
        def text_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterTextFieldControlProperty"]]:
            '''A control to display a text box that is used to enter a single entry.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-textfield
            '''
            result = self._values.get("text_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterTextFieldControlProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilterDateTimePickerControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
            "type": "type",
        },
    )
    class FilterDateTimePickerControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DateTimePickerControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control from a date filter that is used to specify date and time.

            :param filter_control_id: The ID of the ``FilterDateTimePickerControl`` .
            :param source_filter_id: The source filter ID of the ``FilterDateTimePickerControl`` .
            :param title: The title of the ``FilterDateTimePickerControl`` .
            :param display_options: The display options of a control.
            :param type: The date time picker type of a ``FilterDateTimePickerControl`` . Choose one of the following options:. - ``SINGLE_VALUED`` : The filter condition is a fixed date. - ``DATE_RANGE`` : The filter condition is a date time range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_date_time_picker_control_property = quicksight.CfnDashboard.FilterDateTimePickerControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2d4dc823ed0b42bce5fa5201fff6d7738b35fe75bcd098d2d11ab7106684e6db)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterDateTimePickerControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterDateTimePickerControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterDateTimePickerControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateTimePickerControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateTimePickerControlDisplayOptionsProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The date time picker type of a ``FilterDateTimePickerControl`` . Choose one of the following options:.

            - ``SINGLE_VALUED`` : The filter condition is a fixed date.
            - ``DATE_RANGE`` : The filter condition is a date time range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterDateTimePickerControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilterDropDownControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class FilterDropDownControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DropDownControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :param filter_control_id: The ID of the ``FilterDropDownControl`` .
            :param source_filter_id: The source filter ID of the ``FilterDropDownControl`` .
            :param title: The title of the ``FilterDropDownControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of the ``FilterDropDownControl`` .
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of the ``FilterDropDownControl`` . Choose one of the following options:. - ``MULTI_SELECT`` : The user can select multiple entries from a dropdown menu. - ``SINGLE_SELECT`` : The user can select a single entry from a dropdown menu.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_drop_down_control_property = quicksight.CfnDashboard.FilterDropDownControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c1266fccd2cb683bbf30033038fd0b67f0c8037ac8dd77a92a464511099766b1)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DropDownControlDisplayOptionsProperty"]]:
            '''The display options of the ``FilterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DropDownControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of the ``FilterDropDownControl`` . Choose one of the following options:.

            - ``MULTI_SELECT`` : The user can select multiple entries from a dropdown menu.
            - ``SINGLE_SELECT`` : The user can select a single entry from a dropdown menu.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterDropDownControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilterGroupProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cross_dataset": "crossDataset",
            "filter_group_id": "filterGroupId",
            "filters": "filters",
            "scope_configuration": "scopeConfiguration",
            "status": "status",
        },
    )
    class FilterGroupProperty:
        def __init__(
            self,
            *,
            cross_dataset: builtins.str,
            filter_group_id: builtins.str,
            filters: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilterProperty", typing.Dict[builtins.str, typing.Any]]]]],
            scope_configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilterScopeConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A grouping of individual filters. Filter groups are applied to the same group of visuals.

            For more information, see `Adding filter conditions (group filters) with AND and OR operators <https://docs.aws.amazon.com/quicksight/latest/user/add-a-compound-filter.html>`_ in the *Amazon QuickSight User Guide* .

            :param cross_dataset: The filter new feature which can apply filter group to all data sets. Choose one of the following options:. - ``ALL_DATASETS`` - ``SINGLE_DATASET``
            :param filter_group_id: The value that uniquely identifies a ``FilterGroup`` within a dashboard, template, or analysis.
            :param filters: The list of filters that are present in a ``FilterGroup`` .
            :param scope_configuration: The configuration that specifies what scope to apply to a ``FilterGroup`` . This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
            :param status: The status of the ``FilterGroup`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # all_sheets: Any
                
                filter_group_property = quicksight.CfnDashboard.FilterGroupProperty(
                    cross_dataset="crossDataset",
                    filter_group_id="filterGroupId",
                    filters=[quicksight.CfnDashboard.FilterProperty(
                        category_filter=quicksight.CfnDashboard.CategoryFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            configuration=quicksight.CfnDashboard.CategoryFilterConfigurationProperty(
                                custom_filter_configuration=quicksight.CfnDashboard.CustomFilterConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
                
                                    # the properties below are optional
                                    category_value="categoryValue",
                                    parameter_name="parameterName",
                                    select_all_options="selectAllOptions"
                                ),
                                custom_filter_list_configuration=quicksight.CfnDashboard.CustomFilterListConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
                
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                ),
                                filter_list_configuration=quicksight.CfnDashboard.FilterListConfigurationProperty(
                                    match_operator="matchOperator",
                
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    null_option="nullOption",
                                    select_all_options="selectAllOptions"
                                )
                            ),
                            filter_id="filterId"
                        ),
                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions",
                            value=123
                        ),
                        numeric_range_filter=quicksight.CfnDashboard.NumericRangeFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            range_minimum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            select_all_options="selectAllOptions"
                        ),
                        relative_dates_filter=quicksight.CfnDashboard.RelativeDatesFilterProperty(
                            anchor_date_configuration=quicksight.CfnDashboard.AnchorDateConfigurationProperty(
                                anchor_option="anchorOption",
                                parameter_name="parameterName"
                            ),
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                            relative_date_type="relativeDateType",
                            time_granularity="timeGranularity",
                
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
                
                                # the properties below are optional
                                status="status"
                            ),
                            minimum_granularity="minimumGranularity",
                            parameter_name="parameterName",
                            relative_date_value=123
                        ),
                        time_equality_filter=quicksight.CfnDashboard.TimeEqualityFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                
                            # the properties below are optional
                            parameter_name="parameterName",
                            rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            time_granularity="timeGranularity",
                            value="value"
                        ),
                        time_range_filter=quicksight.CfnDashboard.TimeRangeFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
                
                                # the properties below are optional
                                status="status"
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            range_minimum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            time_granularity="timeGranularity"
                        ),
                        top_bottom_filter=quicksight.CfnDashboard.TopBottomFilterProperty(
                            aggregation_sort_configurations=[quicksight.CfnDashboard.AggregationSortConfigurationProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                sort_direction="sortDirection",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                        simple_attribute_aggregation="simpleAttributeAggregation",
                                        value_for_multiple_values="valueForMultipleValues"
                                    ),
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            )],
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                
                            # the properties below are optional
                            limit=123,
                            parameter_name="parameterName",
                            time_granularity="timeGranularity"
                        )
                    )],
                    scope_configuration=quicksight.CfnDashboard.FilterScopeConfigurationProperty(
                        all_sheets=all_sheets,
                        selected_sheets=quicksight.CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty(
                            sheet_visual_scoping_configurations=[quicksight.CfnDashboard.SheetVisualScopingConfigurationProperty(
                                scope="scope",
                                sheet_id="sheetId",
                
                                # the properties below are optional
                                visual_ids=["visualIds"]
                            )]
                        )
                    ),
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ce4cf47935a3ae4c473d594d89b4d8807ac704b2960631354034ef58f07b298f)
                check_type(argname="argument cross_dataset", value=cross_dataset, expected_type=type_hints["cross_dataset"])
                check_type(argname="argument filter_group_id", value=filter_group_id, expected_type=type_hints["filter_group_id"])
                check_type(argname="argument filters", value=filters, expected_type=type_hints["filters"])
                check_type(argname="argument scope_configuration", value=scope_configuration, expected_type=type_hints["scope_configuration"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "cross_dataset": cross_dataset,
                "filter_group_id": filter_group_id,
                "filters": filters,
                "scope_configuration": scope_configuration,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def cross_dataset(self) -> builtins.str:
            '''The filter new feature which can apply filter group to all data sets. Choose one of the following options:.

            - ``ALL_DATASETS``
            - ``SINGLE_DATASET``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-crossdataset
            '''
            result = self._values.get("cross_dataset")
            assert result is not None, "Required property 'cross_dataset' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def filter_group_id(self) -> builtins.str:
            '''The value that uniquely identifies a ``FilterGroup`` within a dashboard, template, or analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-filtergroupid
            '''
            result = self._values.get("filter_group_id")
            assert result is not None, "Required property 'filter_group_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def filters(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterProperty"]]]:
            '''The list of filters that are present in a ``FilterGroup`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-filters
            '''
            result = self._values.get("filters")
            assert result is not None, "Required property 'filters' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterProperty"]]], result)

        @builtins.property
        def scope_configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterScopeConfigurationProperty"]:
            '''The configuration that specifies what scope to apply to a ``FilterGroup`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-scopeconfiguration
            '''
            result = self._values.get("scope_configuration")
            assert result is not None, "Required property 'scope_configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterScopeConfigurationProperty"], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the ``FilterGroup`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterGroupProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilterListConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "category_values": "categoryValues",
            "null_option": "nullOption",
            "select_all_options": "selectAllOptions",
        },
    )
    class FilterListConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            null_option: typing.Optional[builtins.str] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A list of filter configurations.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param category_values: The list of category values for the filter.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_list_configuration_property = quicksight.CfnDashboard.FilterListConfigurationProperty(
                    match_operator="matchOperator",
                
                    # the properties below are optional
                    category_values=["categoryValues"],
                    null_option="nullOption",
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fd1881e6a42963794726bb270a28ec83d9d6eadb7785c1bf6cc95443879be88a)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
            }
            if category_values is not None:
                self._values["category_values"] = category_values
            if null_option is not None:
                self._values["null_option"] = null_option
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html#cfn-quicksight-dashboard-filterlistconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of category values for the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html#cfn-quicksight-dashboard-filterlistconfiguration-categoryvalues
            '''
            result = self._values.get("category_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def null_option(self) -> typing.Optional[builtins.str]:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html#cfn-quicksight-dashboard-filterlistconfiguration-nulloption
            '''
            result = self._values.get("null_option")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html#cfn-quicksight-dashboard-filterlistconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterListConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilterListControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class FilterListControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ListControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a list of buttons or boxes.

            This is used to select either a single value or multiple values.

            :param filter_control_id: The ID of the ``FilterListControl`` .
            :param source_filter_id: The source filter ID of the ``FilterListControl`` .
            :param title: The title of the ``FilterListControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of ``FilterListControl`` . Choose one of the following options:. - ``MULTI_SELECT`` : The user can select multiple entries from the list. - ``SINGLE_SELECT`` : The user can select a single entry from the list.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_list_control_property = quicksight.CfnDashboard.FilterListControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__403b2a94ff321ce0bd8b6439dab935c45cb3a984d7342cc0bfc042fb89f91f5d)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ListControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ListControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``FilterListControl`` . Choose one of the following options:.

            - ``MULTI_SELECT`` : The user can select multiple entries from the list.
            - ``SINGLE_SELECT`` : The user can select a single entry from the list.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterListControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "selected_columns": "selectedColumns",
            "selected_field_options": "selectedFieldOptions",
            "selected_fields": "selectedFields",
        },
    )
    class FilterOperationSelectedFieldsConfigurationProperty:
        def __init__(
            self,
            *,
            selected_columns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            selected_field_options: typing.Optional[builtins.str] = None,
            selected_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The configuration of selected fields in the ``CustomActionFilterOperation`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param selected_columns: The selected columns of a dataset.
            :param selected_field_options: A structure that contains the options that choose which fields are filtered in the ``CustomActionFilterOperation`` . Valid values are defined as follows: - ``ALL_FIELDS`` : Applies the filter operation to all fields.
            :param selected_fields: Chooses the fields that are filtered in ``CustomActionFilterOperation`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationselectedfieldsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_operation_selected_fields_configuration_property = quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                    selected_columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    selected_field_options="selectedFieldOptions",
                    selected_fields=["selectedFields"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b5b5e5d482610e8b383a02eabcbfd4bc9f65085804d9c1c745d051f3ddf4947b)
                check_type(argname="argument selected_columns", value=selected_columns, expected_type=type_hints["selected_columns"])
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
                check_type(argname="argument selected_fields", value=selected_fields, expected_type=type_hints["selected_fields"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if selected_columns is not None:
                self._values["selected_columns"] = selected_columns
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options
            if selected_fields is not None:
                self._values["selected_fields"] = selected_fields

        @builtins.property
        def selected_columns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]]]]:
            '''The selected columns of a dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-dashboard-filteroperationselectedfieldsconfiguration-selectedcolumns
            '''
            result = self._values.get("selected_columns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]]]], result)

        @builtins.property
        def selected_field_options(self) -> typing.Optional[builtins.str]:
            '''A structure that contains the options that choose which fields are filtered in the ``CustomActionFilterOperation`` .

            Valid values are defined as follows:

            - ``ALL_FIELDS`` : Applies the filter operation to all fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-dashboard-filteroperationselectedfieldsconfiguration-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def selected_fields(self) -> typing.Optional[typing.List[builtins.str]]:
            '''Chooses the fields that are filtered in ``CustomActionFilterOperation`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-dashboard-filteroperationselectedfieldsconfiguration-selectedfields
            '''
            result = self._values.get("selected_fields")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterOperationSelectedFieldsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "same_sheet_target_visual_configuration": "sameSheetTargetVisualConfiguration",
        },
    )
    class FilterOperationTargetVisualsConfigurationProperty:
        def __init__(
            self,
            *,
            same_sheet_target_visual_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SameSheetTargetVisualConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of target visuals that you want to be filtered.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param same_sheet_target_visual_configuration: The configuration of the same-sheet target visuals that you want to be filtered.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationtargetvisualsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_operation_target_visuals_configuration_property = quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                        target_visual_options="targetVisualOptions",
                        target_visuals=["targetVisuals"]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__413ed1cbfd1047c2147c27cfc0b0ae60bc33e6bae22446da36a79d3fdc277ab4)
                check_type(argname="argument same_sheet_target_visual_configuration", value=same_sheet_target_visual_configuration, expected_type=type_hints["same_sheet_target_visual_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if same_sheet_target_visual_configuration is not None:
                self._values["same_sheet_target_visual_configuration"] = same_sheet_target_visual_configuration

        @builtins.property
        def same_sheet_target_visual_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SameSheetTargetVisualConfigurationProperty"]]:
            '''The configuration of the same-sheet target visuals that you want to be filtered.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationtargetvisualsconfiguration.html#cfn-quicksight-dashboard-filteroperationtargetvisualsconfiguration-samesheettargetvisualconfiguration
            '''
            result = self._values.get("same_sheet_target_visual_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SameSheetTargetVisualConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterOperationTargetVisualsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_filter": "categoryFilter",
            "numeric_equality_filter": "numericEqualityFilter",
            "numeric_range_filter": "numericRangeFilter",
            "relative_dates_filter": "relativeDatesFilter",
            "time_equality_filter": "timeEqualityFilter",
            "time_range_filter": "timeRangeFilter",
            "top_bottom_filter": "topBottomFilter",
        },
    )
    class FilterProperty:
        def __init__(
            self,
            *,
            category_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CategoryFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_equality_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumericEqualityFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumericRangeFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relative_dates_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.RelativeDatesFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_equality_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TimeEqualityFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TimeRangeFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top_bottom_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TopBottomFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''With a ``Filter`` , you can remove portions of data from a particular visual or view.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param category_filter: A ``CategoryFilter`` filters text values. For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .
            :param numeric_equality_filter: A ``NumericEqualityFilter`` filters numeric values that equal or do not equal a given numeric value.
            :param numeric_range_filter: A ``NumericRangeFilter`` filters numeric values that are either inside or outside a given numeric range.
            :param relative_dates_filter: A ``RelativeDatesFilter`` filters date values that are relative to a given date.
            :param time_equality_filter: A ``TimeEqualityFilter`` filters date-time values that equal or do not equal a given date/time value.
            :param time_range_filter: A ``TimeRangeFilter`` filters date-time values that are either inside or outside a given date/time range.
            :param top_bottom_filter: A ``TopBottomFilter`` filters data to the top or bottom values for a given column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_property = quicksight.CfnDashboard.FilterProperty(
                    category_filter=quicksight.CfnDashboard.CategoryFilterProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        configuration=quicksight.CfnDashboard.CategoryFilterConfigurationProperty(
                            custom_filter_configuration=quicksight.CfnDashboard.CustomFilterConfigurationProperty(
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                category_value="categoryValue",
                                parameter_name="parameterName",
                                select_all_options="selectAllOptions"
                            ),
                            custom_filter_list_configuration=quicksight.CfnDashboard.CustomFilterListConfigurationProperty(
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                category_values=["categoryValues"],
                                select_all_options="selectAllOptions"
                            ),
                            filter_list_configuration=quicksight.CfnDashboard.FilterListConfigurationProperty(
                                match_operator="matchOperator",
                
                                # the properties below are optional
                                category_values=["categoryValues"],
                                null_option="nullOption",
                                select_all_options="selectAllOptions"
                            )
                        ),
                        filter_id="filterId"
                    ),
                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityFilterProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                            attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                simple_attribute_aggregation="simpleAttributeAggregation",
                                value_for_multiple_values="valueForMultipleValues"
                            ),
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        parameter_name="parameterName",
                        select_all_options="selectAllOptions",
                        value=123
                    ),
                    numeric_range_filter=quicksight.CfnDashboard.NumericRangeFilterProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                            attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                simple_attribute_aggregation="simpleAttributeAggregation",
                                value_for_multiple_values="valueForMultipleValues"
                            ),
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        include_maximum=False,
                        include_minimum=False,
                        range_maximum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                            parameter="parameter",
                            static_value=123
                        ),
                        range_minimum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                            parameter="parameter",
                            static_value=123
                        ),
                        select_all_options="selectAllOptions"
                    ),
                    relative_dates_filter=quicksight.CfnDashboard.RelativeDatesFilterProperty(
                        anchor_date_configuration=quicksight.CfnDashboard.AnchorDateConfigurationProperty(
                            anchor_option="anchorOption",
                            parameter_name="parameterName"
                        ),
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                        relative_date_type="relativeDateType",
                        time_granularity="timeGranularity",
                
                        # the properties below are optional
                        exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                            amount=123,
                            granularity="granularity",
                
                            # the properties below are optional
                            status="status"
                        ),
                        minimum_granularity="minimumGranularity",
                        parameter_name="parameterName",
                        relative_date_value=123
                    ),
                    time_equality_filter=quicksight.CfnDashboard.TimeEqualityFilterProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                
                        # the properties below are optional
                        parameter_name="parameterName",
                        rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        time_granularity="timeGranularity",
                        value="value"
                    ),
                    time_range_filter=quicksight.CfnDashboard.TimeRangeFilterProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                
                        # the properties below are optional
                        exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                            amount=123,
                            granularity="granularity",
                
                            # the properties below are optional
                            status="status"
                        ),
                        include_maximum=False,
                        include_minimum=False,
                        range_maximum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                            parameter="parameter",
                            rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_value="staticValue"
                        ),
                        range_minimum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                            parameter="parameter",
                            rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_value="staticValue"
                        ),
                        time_granularity="timeGranularity"
                    ),
                    top_bottom_filter=quicksight.CfnDashboard.TopBottomFilterProperty(
                        aggregation_sort_configurations=[quicksight.CfnDashboard.AggregationSortConfigurationProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            sort_direction="sortDirection",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        )],
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                
                        # the properties below are optional
                        limit=123,
                        parameter_name="parameterName",
                        time_granularity="timeGranularity"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__409a9ada70537b5b198a9297213605c443d07089acc597a347aed1b89af1fd00)
                check_type(argname="argument category_filter", value=category_filter, expected_type=type_hints["category_filter"])
                check_type(argname="argument numeric_equality_filter", value=numeric_equality_filter, expected_type=type_hints["numeric_equality_filter"])
                check_type(argname="argument numeric_range_filter", value=numeric_range_filter, expected_type=type_hints["numeric_range_filter"])
                check_type(argname="argument relative_dates_filter", value=relative_dates_filter, expected_type=type_hints["relative_dates_filter"])
                check_type(argname="argument time_equality_filter", value=time_equality_filter, expected_type=type_hints["time_equality_filter"])
                check_type(argname="argument time_range_filter", value=time_range_filter, expected_type=type_hints["time_range_filter"])
                check_type(argname="argument top_bottom_filter", value=top_bottom_filter, expected_type=type_hints["top_bottom_filter"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_filter is not None:
                self._values["category_filter"] = category_filter
            if numeric_equality_filter is not None:
                self._values["numeric_equality_filter"] = numeric_equality_filter
            if numeric_range_filter is not None:
                self._values["numeric_range_filter"] = numeric_range_filter
            if relative_dates_filter is not None:
                self._values["relative_dates_filter"] = relative_dates_filter
            if time_equality_filter is not None:
                self._values["time_equality_filter"] = time_equality_filter
            if time_range_filter is not None:
                self._values["time_range_filter"] = time_range_filter
            if top_bottom_filter is not None:
                self._values["top_bottom_filter"] = top_bottom_filter

        @builtins.property
        def category_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CategoryFilterProperty"]]:
            '''A ``CategoryFilter`` filters text values.

            For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-categoryfilter
            '''
            result = self._values.get("category_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CategoryFilterProperty"]], result)

        @builtins.property
        def numeric_equality_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericEqualityFilterProperty"]]:
            '''A ``NumericEqualityFilter`` filters numeric values that equal or do not equal a given numeric value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-numericequalityfilter
            '''
            result = self._values.get("numeric_equality_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericEqualityFilterProperty"]], result)

        @builtins.property
        def numeric_range_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericRangeFilterProperty"]]:
            '''A ``NumericRangeFilter`` filters numeric values that are either inside or outside a given numeric range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-numericrangefilter
            '''
            result = self._values.get("numeric_range_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericRangeFilterProperty"]], result)

        @builtins.property
        def relative_dates_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RelativeDatesFilterProperty"]]:
            '''A ``RelativeDatesFilter`` filters date values that are relative to a given date.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-relativedatesfilter
            '''
            result = self._values.get("relative_dates_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RelativeDatesFilterProperty"]], result)

        @builtins.property
        def time_equality_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TimeEqualityFilterProperty"]]:
            '''A ``TimeEqualityFilter`` filters date-time values that equal or do not equal a given date/time value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-timeequalityfilter
            '''
            result = self._values.get("time_equality_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TimeEqualityFilterProperty"]], result)

        @builtins.property
        def time_range_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TimeRangeFilterProperty"]]:
            '''A ``TimeRangeFilter`` filters date-time values that are either inside or outside a given date/time range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-timerangefilter
            '''
            result = self._values.get("time_range_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TimeRangeFilterProperty"]], result)

        @builtins.property
        def top_bottom_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TopBottomFilterProperty"]]:
            '''A ``TopBottomFilter`` filters data to the top or bottom values for a given column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-topbottomfilter
            '''
            result = self._values.get("top_bottom_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TopBottomFilterProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilterRelativeDateTimeControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class FilterRelativeDateTimeControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control from a date filter that is used to specify the relative date.

            :param filter_control_id: The ID of the ``FilterTextAreaControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextAreaControl`` .
            :param title: The title of the ``FilterTextAreaControl`` .
            :param display_options: The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_relative_date_time_control_property = quicksight.CfnDashboard.FilterRelativeDateTimeControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fe7bdb0ee36689d0f3888592fe2c5e415e7128d38d6bc414f6b5e8f15996dc4e)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html#cfn-quicksight-dashboard-filterrelativedatetimecontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html#cfn-quicksight-dashboard-filterrelativedatetimecontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html#cfn-quicksight-dashboard-filterrelativedatetimecontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html#cfn-quicksight-dashboard-filterrelativedatetimecontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterRelativeDateTimeControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilterScopeConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"all_sheets": "allSheets", "selected_sheets": "selectedSheets"},
    )
    class FilterScopeConfigurationProperty:
        def __init__(
            self,
            *,
            all_sheets: typing.Any = None,
            selected_sheets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The scope configuration for a ``FilterGroup`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param all_sheets: The configuration for applying a filter to all sheets.
            :param selected_sheets: The configuration for applying a filter to specific sheets.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterscopeconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # all_sheets: Any
                
                filter_scope_configuration_property = quicksight.CfnDashboard.FilterScopeConfigurationProperty(
                    all_sheets=all_sheets,
                    selected_sheets=quicksight.CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty(
                        sheet_visual_scoping_configurations=[quicksight.CfnDashboard.SheetVisualScopingConfigurationProperty(
                            scope="scope",
                            sheet_id="sheetId",
                
                            # the properties below are optional
                            visual_ids=["visualIds"]
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__efb1f0d726575795de7c1bc1743a357d70f197f085d1b1a859344beaf57af343)
                check_type(argname="argument all_sheets", value=all_sheets, expected_type=type_hints["all_sheets"])
                check_type(argname="argument selected_sheets", value=selected_sheets, expected_type=type_hints["selected_sheets"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if all_sheets is not None:
                self._values["all_sheets"] = all_sheets
            if selected_sheets is not None:
                self._values["selected_sheets"] = selected_sheets

        @builtins.property
        def all_sheets(self) -> typing.Any:
            '''The configuration for applying a filter to all sheets.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterscopeconfiguration.html#cfn-quicksight-dashboard-filterscopeconfiguration-allsheets
            '''
            result = self._values.get("all_sheets")
            return typing.cast(typing.Any, result)

        @builtins.property
        def selected_sheets(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty"]]:
            '''The configuration for applying a filter to specific sheets.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterscopeconfiguration.html#cfn-quicksight-dashboard-filterscopeconfiguration-selectedsheets
            '''
            result = self._values.get("selected_sheets")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterScopeConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilterSelectableValuesProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class FilterSelectableValuesProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A list of selectable values that are used in a control.

            :param values: The values that are used in the ``FilterSelectableValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterselectablevalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_selectable_values_property = quicksight.CfnDashboard.FilterSelectableValuesProperty(
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bf3a69b2044179c514a37eb8de1bf2d7c8863ea4288b0fbea70e60407873a3af)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The values that are used in the ``FilterSelectableValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterselectablevalues.html#cfn-quicksight-dashboard-filterselectablevalues-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterSelectableValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilterSliderControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "maximum_value": "maximumValue",
            "minimum_value": "minimumValue",
            "source_filter_id": "sourceFilterId",
            "step_size": "stepSize",
            "title": "title",
            "display_options": "displayOptions",
            "type": "type",
        },
    )
    class FilterSliderControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            maximum_value: jsii.Number,
            minimum_value: jsii.Number,
            source_filter_id: builtins.str,
            step_size: jsii.Number,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SliderControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :param filter_control_id: The ID of the ``FilterSliderControl`` .
            :param maximum_value: The smaller value that is displayed at the left of the slider. Default: - 0
            :param minimum_value: The larger value that is displayed at the right of the slider. Default: - 0
            :param source_filter_id: The source filter ID of the ``FilterSliderControl`` .
            :param step_size: The number of increments that the slider bar is divided into. Default: - 0
            :param title: The title of the ``FilterSliderControl`` .
            :param display_options: The display options of a control.
            :param type: The type of ``FilterSliderControl`` . Choose one of the following options:. - ``SINGLE_POINT`` : Filter against(equals) a single data point. - ``RANGE`` : Filter data that is in a specified range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_slider_control_property = quicksight.CfnDashboard.FilterSliderControlProperty(
                    filter_control_id="filterControlId",
                    maximum_value=123,
                    minimum_value=123,
                    source_filter_id="sourceFilterId",
                    step_size=123,
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e33f693f0cd3872c53b5519898c8c1204c4e5b7949e6651059ef65d15ef1ea62)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument maximum_value", value=maximum_value, expected_type=type_hints["maximum_value"])
                check_type(argname="argument minimum_value", value=minimum_value, expected_type=type_hints["minimum_value"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "maximum_value": maximum_value,
                "minimum_value": minimum_value,
                "source_filter_id": source_filter_id,
                "step_size": step_size,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterSliderControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def maximum_value(self) -> jsii.Number:
            '''The smaller value that is displayed at the left of the slider.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-maximumvalue
            '''
            result = self._values.get("maximum_value")
            assert result is not None, "Required property 'maximum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def minimum_value(self) -> jsii.Number:
            '''The larger value that is displayed at the right of the slider.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-minimumvalue
            '''
            result = self._values.get("minimum_value")
            assert result is not None, "Required property 'minimum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterSliderControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def step_size(self) -> jsii.Number:
            '''The number of increments that the slider bar is divided into.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-stepsize
            '''
            result = self._values.get("step_size")
            assert result is not None, "Required property 'step_size' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterSliderControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SliderControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SliderControlDisplayOptionsProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``FilterSliderControl`` . Choose one of the following options:.

            - ``SINGLE_POINT`` : Filter against(equals) a single data point.
            - ``RANGE`` : Filter data that is in a specified range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterSliderControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilterTextAreaControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "delimiter": "delimiter",
            "display_options": "displayOptions",
        },
    )
    class FilterTextAreaControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            delimiter: typing.Optional[builtins.str] = None,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TextAreaControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter multiple entries.

            :param filter_control_id: The ID of the ``FilterTextAreaControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextAreaControl`` .
            :param title: The title of the ``FilterTextAreaControl`` .
            :param delimiter: The delimiter that is used to separate the lines in text.
            :param display_options: The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_text_area_control_property = quicksight.CfnDashboard.FilterTextAreaControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    delimiter="delimiter",
                    display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aff6992b42407f813dd49b07602424a15f4a5bd9dcfb70625da0055df7195ed0)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument delimiter", value=delimiter, expected_type=type_hints["delimiter"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if delimiter is not None:
                self._values["delimiter"] = delimiter
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def delimiter(self) -> typing.Optional[builtins.str]:
            '''The delimiter that is used to separate the lines in text.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-delimiter
            '''
            result = self._values.get("delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TextAreaControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TextAreaControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterTextAreaControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FilterTextFieldControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class FilterTextFieldControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TextFieldControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter a single entry.

            :param filter_control_id: The ID of the ``FilterTextFieldControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextFieldControl`` .
            :param title: The title of the ``FilterTextFieldControl`` .
            :param display_options: The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_text_field_control_property = quicksight.CfnDashboard.FilterTextFieldControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__07b6a627f5bf3da40af7a2bd33995eaebca4bc7d53a56462a0d40b6e1f8c711d)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextFieldControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html#cfn-quicksight-dashboard-filtertextfieldcontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextFieldControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html#cfn-quicksight-dashboard-filtertextfieldcontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextFieldControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html#cfn-quicksight-dashboard-filtertextfieldcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TextFieldControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html#cfn-quicksight-dashboard-filtertextfieldcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TextFieldControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterTextFieldControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FontConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "font_color": "fontColor",
            "font_decoration": "fontDecoration",
            "font_size": "fontSize",
            "font_style": "fontStyle",
            "font_weight": "fontWeight",
        },
    )
    class FontConfigurationProperty:
        def __init__(
            self,
            *,
            font_color: typing.Optional[builtins.str] = None,
            font_decoration: typing.Optional[builtins.str] = None,
            font_size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FontSizeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            font_style: typing.Optional[builtins.str] = None,
            font_weight: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FontWeightProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Configures the display properties of the given text.

            :param font_color: Determines the color of the text.
            :param font_decoration: Determines the appearance of decorative lines on the text.
            :param font_size: The option that determines the text display size.
            :param font_style: Determines the text display face that is inherited by the given font family.
            :param font_weight: The option that determines the text display weight, or boldness.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                font_configuration_property = quicksight.CfnDashboard.FontConfigurationProperty(
                    font_color="fontColor",
                    font_decoration="fontDecoration",
                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                        relative="relative"
                    ),
                    font_style="fontStyle",
                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                        name="name"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b48855a807262480043342a23f56c41acad1677b4c6bc1911063c9f4033d5eb7)
                check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
                check_type(argname="argument font_decoration", value=font_decoration, expected_type=type_hints["font_decoration"])
                check_type(argname="argument font_size", value=font_size, expected_type=type_hints["font_size"])
                check_type(argname="argument font_style", value=font_style, expected_type=type_hints["font_style"])
                check_type(argname="argument font_weight", value=font_weight, expected_type=type_hints["font_weight"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_color is not None:
                self._values["font_color"] = font_color
            if font_decoration is not None:
                self._values["font_decoration"] = font_decoration
            if font_size is not None:
                self._values["font_size"] = font_size
            if font_style is not None:
                self._values["font_style"] = font_style
            if font_weight is not None:
                self._values["font_weight"] = font_weight

        @builtins.property
        def font_color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the text.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontcolor
            '''
            result = self._values.get("font_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_decoration(self) -> typing.Optional[builtins.str]:
            '''Determines the appearance of decorative lines on the text.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontdecoration
            '''
            result = self._values.get("font_decoration")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_size(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontSizeProperty"]]:
            '''The option that determines the text display size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontsize
            '''
            result = self._values.get("font_size")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontSizeProperty"]], result)

        @builtins.property
        def font_style(self) -> typing.Optional[builtins.str]:
            '''Determines the text display face that is inherited by the given font family.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontstyle
            '''
            result = self._values.get("font_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_weight(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontWeightProperty"]]:
            '''The option that determines the text display weight, or boldness.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontweight
            '''
            result = self._values.get("font_weight")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontWeightProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FontSizeProperty",
        jsii_struct_bases=[],
        name_mapping={"relative": "relative"},
    )
    class FontSizeProperty:
        def __init__(self, *, relative: typing.Optional[builtins.str] = None) -> None:
            '''The option that determines the text display size.

            :param relative: The lexical name for the text size, proportional to its surrounding context.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontsize.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                font_size_property = quicksight.CfnDashboard.FontSizeProperty(
                    relative="relative"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__87370eaa416d91722053871ba89812b2d930c3fa9cd16a54352a4cf9c36d9c24)
                check_type(argname="argument relative", value=relative, expected_type=type_hints["relative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if relative is not None:
                self._values["relative"] = relative

        @builtins.property
        def relative(self) -> typing.Optional[builtins.str]:
            '''The lexical name for the text size, proportional to its surrounding context.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontsize.html#cfn-quicksight-dashboard-fontsize-relative
            '''
            result = self._values.get("relative")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontSizeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FontWeightProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name"},
    )
    class FontWeightProperty:
        def __init__(self, *, name: typing.Optional[builtins.str] = None) -> None:
            '''The option that determines the text display weight, or boldness.

            :param name: The lexical name for the level of boldness of the text display.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontweight.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                font_weight_property = quicksight.CfnDashboard.FontWeightProperty(
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cb1820b444eb7285c5d903348397d79b1b218ecd395042fecf1881a3cfb07656)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The lexical name for the level of boldness of the text display.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontweight.html#cfn-quicksight-dashboard-fontweight-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontWeightProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ForecastComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "custom_seasonality_value": "customSeasonalityValue",
            "lower_boundary": "lowerBoundary",
            "name": "name",
            "periods_backward": "periodsBackward",
            "periods_forward": "periodsForward",
            "prediction_interval": "predictionInterval",
            "seasonality": "seasonality",
            "time": "time",
            "upper_boundary": "upperBoundary",
            "value": "value",
        },
    )
    class ForecastComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            custom_seasonality_value: typing.Optional[jsii.Number] = None,
            lower_boundary: typing.Optional[jsii.Number] = None,
            name: typing.Optional[builtins.str] = None,
            periods_backward: typing.Optional[jsii.Number] = None,
            periods_forward: typing.Optional[jsii.Number] = None,
            prediction_interval: typing.Optional[jsii.Number] = None,
            seasonality: typing.Optional[builtins.str] = None,
            time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            upper_boundary: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The forecast computation configuration.

            :param computation_id: The ID for a computation.
            :param custom_seasonality_value: The custom seasonality value setup of a forecast computation.
            :param lower_boundary: The lower boundary setup of a forecast computation.
            :param name: The name of a computation.
            :param periods_backward: The periods backward setup of a forecast computation.
            :param periods_forward: The periods forward setup of a forecast computation.
            :param prediction_interval: The prediction interval setup of a forecast computation.
            :param seasonality: The seasonality setup of a forecast computation. Choose one of the following options:. - ``AUTOMATIC`` - ``CUSTOM`` : Checks the custom seasonality value.
            :param time: The time field that is used in a computation.
            :param upper_boundary: The upper boundary setup of a forecast computation.
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f91e691a746e8b818f00f28461113260257720e2f02fcbf51c4f79d80e4d9638)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument custom_seasonality_value", value=custom_seasonality_value, expected_type=type_hints["custom_seasonality_value"])
                check_type(argname="argument lower_boundary", value=lower_boundary, expected_type=type_hints["lower_boundary"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument periods_backward", value=periods_backward, expected_type=type_hints["periods_backward"])
                check_type(argname="argument periods_forward", value=periods_forward, expected_type=type_hints["periods_forward"])
                check_type(argname="argument prediction_interval", value=prediction_interval, expected_type=type_hints["prediction_interval"])
                check_type(argname="argument seasonality", value=seasonality, expected_type=type_hints["seasonality"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument upper_boundary", value=upper_boundary, expected_type=type_hints["upper_boundary"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
            }
            if custom_seasonality_value is not None:
                self._values["custom_seasonality_value"] = custom_seasonality_value
            if lower_boundary is not None:
                self._values["lower_boundary"] = lower_boundary
            if name is not None:
                self._values["name"] = name
            if periods_backward is not None:
                self._values["periods_backward"] = periods_backward
            if periods_forward is not None:
                self._values["periods_forward"] = periods_forward
            if prediction_interval is not None:
                self._values["prediction_interval"] = prediction_interval
            if seasonality is not None:
                self._values["seasonality"] = seasonality
            if time is not None:
                self._values["time"] = time
            if upper_boundary is not None:
                self._values["upper_boundary"] = upper_boundary
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def custom_seasonality_value(self) -> typing.Optional[jsii.Number]:
            '''The custom seasonality value setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-customseasonalityvalue
            '''
            result = self._values.get("custom_seasonality_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def lower_boundary(self) -> typing.Optional[jsii.Number]:
            '''The lower boundary setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-lowerboundary
            '''
            result = self._values.get("lower_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def periods_backward(self) -> typing.Optional[jsii.Number]:
            '''The periods backward setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-periodsbackward
            '''
            result = self._values.get("periods_backward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_forward(self) -> typing.Optional[jsii.Number]:
            '''The periods forward setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-periodsforward
            '''
            result = self._values.get("periods_forward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def prediction_interval(self) -> typing.Optional[jsii.Number]:
            '''The prediction interval setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-predictioninterval
            '''
            result = self._values.get("prediction_interval")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def seasonality(self) -> typing.Optional[builtins.str]:
            '''The seasonality setup of a forecast computation. Choose one of the following options:.

            - ``AUTOMATIC``
            - ``CUSTOM`` : Checks the custom seasonality value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-seasonality
            '''
            result = self._values.get("seasonality")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]:
            '''The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-time
            '''
            result = self._values.get("time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]], result)

        @builtins.property
        def upper_boundary(self) -> typing.Optional[jsii.Number]:
            '''The upper boundary setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-upperboundary
            '''
            result = self._values.get("upper_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ForecastConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "forecast_properties": "forecastProperties",
            "scenario": "scenario",
        },
    )
    class ForecastConfigurationProperty:
        def __init__(
            self,
            *,
            forecast_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TimeBasedForecastPropertiesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scenario: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ForecastScenarioProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The forecast configuration that is used in a line chart's display properties.

            :param forecast_properties: The forecast properties setup of a forecast in the line chart.
            :param scenario: The forecast scenario of a forecast in the line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                forecast_configuration_property = quicksight.CfnDashboard.ForecastConfigurationProperty(
                    forecast_properties=quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty(
                        lower_boundary=123,
                        periods_backward=123,
                        periods_forward=123,
                        prediction_interval=123,
                        seasonality=123,
                        upper_boundary=123
                    ),
                    scenario=quicksight.CfnDashboard.ForecastScenarioProperty(
                        what_if_point_scenario=quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                            date="date",
                            value=123
                        ),
                        what_if_range_scenario=quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                            end_date="endDate",
                            start_date="startDate",
                            value=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c3dc530549bc6019bca764db8795b5e3acd8f88a710e7e98e121c2bcc2f9a812)
                check_type(argname="argument forecast_properties", value=forecast_properties, expected_type=type_hints["forecast_properties"])
                check_type(argname="argument scenario", value=scenario, expected_type=type_hints["scenario"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if forecast_properties is not None:
                self._values["forecast_properties"] = forecast_properties
            if scenario is not None:
                self._values["scenario"] = scenario

        @builtins.property
        def forecast_properties(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TimeBasedForecastPropertiesProperty"]]:
            '''The forecast properties setup of a forecast in the line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastconfiguration.html#cfn-quicksight-dashboard-forecastconfiguration-forecastproperties
            '''
            result = self._values.get("forecast_properties")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TimeBasedForecastPropertiesProperty"]], result)

        @builtins.property
        def scenario(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ForecastScenarioProperty"]]:
            '''The forecast scenario of a forecast in the line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastconfiguration.html#cfn-quicksight-dashboard-forecastconfiguration-scenario
            '''
            result = self._values.get("scenario")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ForecastScenarioProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ForecastScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={
            "what_if_point_scenario": "whatIfPointScenario",
            "what_if_range_scenario": "whatIfRangeScenario",
        },
    )
    class ForecastScenarioProperty:
        def __init__(
            self,
            *,
            what_if_point_scenario: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.WhatIfPointScenarioProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            what_if_range_scenario: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.WhatIfRangeScenarioProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The forecast scenario of a forecast in the line chart.

            :param what_if_point_scenario: The what-if analysis forecast setup with the target date.
            :param what_if_range_scenario: The what-if analysis forecast setup with the date range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastscenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                forecast_scenario_property = quicksight.CfnDashboard.ForecastScenarioProperty(
                    what_if_point_scenario=quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                        date="date",
                        value=123
                    ),
                    what_if_range_scenario=quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                        end_date="endDate",
                        start_date="startDate",
                        value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__829e76534c57a3e2f285027a428362cc8dc3cee7af117c595ada8b70012df488)
                check_type(argname="argument what_if_point_scenario", value=what_if_point_scenario, expected_type=type_hints["what_if_point_scenario"])
                check_type(argname="argument what_if_range_scenario", value=what_if_range_scenario, expected_type=type_hints["what_if_range_scenario"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if what_if_point_scenario is not None:
                self._values["what_if_point_scenario"] = what_if_point_scenario
            if what_if_range_scenario is not None:
                self._values["what_if_range_scenario"] = what_if_range_scenario

        @builtins.property
        def what_if_point_scenario(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WhatIfPointScenarioProperty"]]:
            '''The what-if analysis forecast setup with the target date.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastscenario.html#cfn-quicksight-dashboard-forecastscenario-whatifpointscenario
            '''
            result = self._values.get("what_if_point_scenario")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WhatIfPointScenarioProperty"]], result)

        @builtins.property
        def what_if_range_scenario(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WhatIfRangeScenarioProperty"]]:
            '''The what-if analysis forecast setup with the date range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastscenario.html#cfn-quicksight-dashboard-forecastscenario-whatifrangescenario
            '''
            result = self._values.get("what_if_range_scenario")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WhatIfRangeScenarioProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format_configuration": "dateTimeFormatConfiguration",
            "number_format_configuration": "numberFormatConfiguration",
            "string_format_configuration": "stringFormatConfiguration",
        },
    )
    class FormatConfigurationProperty:
        def __init__(
            self,
            *,
            date_time_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            string_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The formatting configuration for all types of field.

            :param date_time_format_configuration: Formatting configuration for ``DateTime`` fields.
            :param number_format_configuration: Formatting configuration for number fields.
            :param string_format_configuration: Formatting configuration for string fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-formatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                format_configuration_property = quicksight.CfnDashboard.FormatConfigurationProperty(
                    date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__90959d3e0ee71e29b41c19db0cd1f5b51611a3b9af7d2bb83eeca51b89d68780)
                check_type(argname="argument date_time_format_configuration", value=date_time_format_configuration, expected_type=type_hints["date_time_format_configuration"])
                check_type(argname="argument number_format_configuration", value=number_format_configuration, expected_type=type_hints["number_format_configuration"])
                check_type(argname="argument string_format_configuration", value=string_format_configuration, expected_type=type_hints["string_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format_configuration is not None:
                self._values["date_time_format_configuration"] = date_time_format_configuration
            if number_format_configuration is not None:
                self._values["number_format_configuration"] = number_format_configuration
            if string_format_configuration is not None:
                self._values["string_format_configuration"] = string_format_configuration

        @builtins.property
        def date_time_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateTimeFormatConfigurationProperty"]]:
            '''Formatting configuration for ``DateTime`` fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-formatconfiguration.html#cfn-quicksight-dashboard-formatconfiguration-datetimeformatconfiguration
            '''
            result = self._values.get("date_time_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateTimeFormatConfigurationProperty"]], result)

        @builtins.property
        def number_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumberFormatConfigurationProperty"]]:
            '''Formatting configuration for number fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-formatconfiguration.html#cfn-quicksight-dashboard-formatconfiguration-numberformatconfiguration
            '''
            result = self._values.get("number_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumberFormatConfigurationProperty"]], result)

        @builtins.property
        def string_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.StringFormatConfigurationProperty"]]:
            '''Formatting configuration for string fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-formatconfiguration.html#cfn-quicksight-dashboard-formatconfiguration-stringformatconfiguration
            '''
            result = self._values.get("string_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.StringFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"screen_canvas_size_options": "screenCanvasSizeOptions"},
    )
    class FreeFormLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            screen_canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Configuration options for the canvas of a free-form layout.

            :param screen_canvas_size_options: The options that determine the sizing of the canvas used in a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                free_form_layout_canvas_size_options_property = quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                    screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                        optimized_view_port_width="optimizedViewPortWidth"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6f481aadfa74edce1b66d1816988d464c1f72af28e18dccbc2c01c0121f1dfdf)
                check_type(argname="argument screen_canvas_size_options", value=screen_canvas_size_options, expected_type=type_hints["screen_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if screen_canvas_size_options is not None:
                self._values["screen_canvas_size_options"] = screen_canvas_size_options

        @builtins.property
        def screen_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty"]]:
            '''The options that determine the sizing of the canvas used in a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutcanvassizeoptions.html#cfn-quicksight-dashboard-freeformlayoutcanvassizeoptions-screencanvassizeoptions
            '''
            result = self._values.get("screen_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FreeFormLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "elements": "elements",
            "canvas_size_options": "canvasSizeOptions",
        },
    )
    class FreeFormLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FreeFormLayoutElementProperty", typing.Dict[builtins.str, typing.Any]]]]],
            canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a free-form layout.

            :param elements: The elements that are included in a free-form layout.
            :param canvas_size_options: 

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                free_form_layout_configuration_property = quicksight.CfnDashboard.FreeFormLayoutConfigurationProperty(
                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                        element_id="elementId",
                        element_type="elementType",
                        height="height",
                        width="width",
                        x_axis_location="xAxisLocation",
                        y_axis_location="yAxisLocation",
                
                        # the properties below are optional
                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                            visibility="visibility"
                        ),
                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                visibility="visibility"
                            ),
                            expression="expression"
                        )],
                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        visibility="visibility"
                    )],
                
                    # the properties below are optional
                    canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__07bbe87652872f78234fbeb060e181f658867cedffb02337adc12cbf96d13de3)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }
            if canvas_size_options is not None:
                self._values["canvas_size_options"] = canvas_size_options

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FreeFormLayoutElementProperty"]]]:
            '''The elements that are included in a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutconfiguration.html#cfn-quicksight-dashboard-freeformlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FreeFormLayoutElementProperty"]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutconfiguration.html#cfn-quicksight-dashboard-freeformlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "visibility": "visibility"},
    )
    class FreeFormLayoutElementBackgroundStyleProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The background style configuration of a free-form layout element.

            :param color: The background color of a free-form layout element.
            :param visibility: The background visibility of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementbackgroundstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                free_form_layout_element_background_style_property = quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                    color="color",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8a972e6dc4bf756339d7c3a8094ff7c1248e0e85efb004f5fdd1bdf23b0ac329)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The background color of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-dashboard-freeformlayoutelementbackgroundstyle-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The background visibility of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-dashboard-freeformlayoutelementbackgroundstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementBackgroundStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "visibility": "visibility"},
    )
    class FreeFormLayoutElementBorderStyleProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The background style configuration of a free-form layout element.

            :param color: The border color of a free-form layout element.
            :param visibility: The border visibility of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementborderstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                free_form_layout_element_border_style_property = quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                    color="color",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b1efb68c56f7c19acb251fb30163e7ac379fcc6b5040fb694928a8d86ad08666)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The border color of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementborderstyle.html#cfn-quicksight-dashboard-freeformlayoutelementborderstyle-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The border visibility of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementborderstyle.html#cfn-quicksight-dashboard-freeformlayoutelementborderstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementBorderStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FreeFormLayoutElementProperty",
        jsii_struct_bases=[],
        name_mapping={
            "element_id": "elementId",
            "element_type": "elementType",
            "height": "height",
            "width": "width",
            "x_axis_location": "xAxisLocation",
            "y_axis_location": "yAxisLocation",
            "background_style": "backgroundStyle",
            "border_style": "borderStyle",
            "loading_animation": "loadingAnimation",
            "rendering_rules": "renderingRules",
            "selected_border_style": "selectedBorderStyle",
            "visibility": "visibility",
        },
    )
    class FreeFormLayoutElementProperty:
        def __init__(
            self,
            *,
            element_id: builtins.str,
            element_type: builtins.str,
            height: builtins.str,
            width: builtins.str,
            x_axis_location: builtins.str,
            y_axis_location: builtins.str,
            background_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            border_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FreeFormLayoutElementBorderStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            loading_animation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LoadingAnimationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rendering_rules: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SheetElementRenderingRuleProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            selected_border_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FreeFormLayoutElementBorderStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''An element within a free-form layout.

            :param element_id: A unique identifier for an element within a free-form layout.
            :param element_type: The type of element.
            :param height: The height of an element within a free-form layout.
            :param width: The width of an element within a free-form layout.
            :param x_axis_location: The x-axis coordinate of the element.
            :param y_axis_location: The y-axis coordinate of the element.
            :param background_style: The background style configuration of a free-form layout element.
            :param border_style: The border style configuration of a free-form layout element.
            :param loading_animation: The loading animation configuration of a free-form layout element.
            :param rendering_rules: The rendering rules that determine when an element should be displayed within a free-form layout.
            :param selected_border_style: The border style configuration of a free-form layout element. This border style is used when the element is selected.
            :param visibility: The visibility of an element within a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                free_form_layout_element_property = quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                    element_id="elementId",
                    element_type="elementType",
                    height="height",
                    width="width",
                    x_axis_location="xAxisLocation",
                    y_axis_location="yAxisLocation",
                
                    # the properties below are optional
                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                        visibility="visibility"
                    ),
                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                            visibility="visibility"
                        ),
                        expression="expression"
                    )],
                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2cb05e72a9acce67f4442e314c4130c787e3a61f511d8475ed2c9e323d816338)
                check_type(argname="argument element_id", value=element_id, expected_type=type_hints["element_id"])
                check_type(argname="argument element_type", value=element_type, expected_type=type_hints["element_type"])
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
                check_type(argname="argument x_axis_location", value=x_axis_location, expected_type=type_hints["x_axis_location"])
                check_type(argname="argument y_axis_location", value=y_axis_location, expected_type=type_hints["y_axis_location"])
                check_type(argname="argument background_style", value=background_style, expected_type=type_hints["background_style"])
                check_type(argname="argument border_style", value=border_style, expected_type=type_hints["border_style"])
                check_type(argname="argument loading_animation", value=loading_animation, expected_type=type_hints["loading_animation"])
                check_type(argname="argument rendering_rules", value=rendering_rules, expected_type=type_hints["rendering_rules"])
                check_type(argname="argument selected_border_style", value=selected_border_style, expected_type=type_hints["selected_border_style"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "element_id": element_id,
                "element_type": element_type,
                "height": height,
                "width": width,
                "x_axis_location": x_axis_location,
                "y_axis_location": y_axis_location,
            }
            if background_style is not None:
                self._values["background_style"] = background_style
            if border_style is not None:
                self._values["border_style"] = border_style
            if loading_animation is not None:
                self._values["loading_animation"] = loading_animation
            if rendering_rules is not None:
                self._values["rendering_rules"] = rendering_rules
            if selected_border_style is not None:
                self._values["selected_border_style"] = selected_border_style
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def element_id(self) -> builtins.str:
            '''A unique identifier for an element within a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-elementid
            '''
            result = self._values.get("element_id")
            assert result is not None, "Required property 'element_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element_type(self) -> builtins.str:
            '''The type of element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-elementtype
            '''
            result = self._values.get("element_type")
            assert result is not None, "Required property 'element_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def height(self) -> builtins.str:
            '''The height of an element within a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-height
            '''
            result = self._values.get("height")
            assert result is not None, "Required property 'height' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def width(self) -> builtins.str:
            '''The width of an element within a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-width
            '''
            result = self._values.get("width")
            assert result is not None, "Required property 'width' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def x_axis_location(self) -> builtins.str:
            '''The x-axis coordinate of the element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-xaxislocation
            '''
            result = self._values.get("x_axis_location")
            assert result is not None, "Required property 'x_axis_location' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def y_axis_location(self) -> builtins.str:
            '''The y-axis coordinate of the element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-yaxislocation
            '''
            result = self._values.get("y_axis_location")
            assert result is not None, "Required property 'y_axis_location' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def background_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty"]]:
            '''The background style configuration of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-backgroundstyle
            '''
            result = self._values.get("background_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty"]], result)

        @builtins.property
        def border_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FreeFormLayoutElementBorderStyleProperty"]]:
            '''The border style configuration of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-borderstyle
            '''
            result = self._values.get("border_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FreeFormLayoutElementBorderStyleProperty"]], result)

        @builtins.property
        def loading_animation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LoadingAnimationProperty"]]:
            '''The loading animation configuration of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-loadinganimation
            '''
            result = self._values.get("loading_animation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LoadingAnimationProperty"]], result)

        @builtins.property
        def rendering_rules(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetElementRenderingRuleProperty"]]]]:
            '''The rendering rules that determine when an element should be displayed within a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-renderingrules
            '''
            result = self._values.get("rendering_rules")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetElementRenderingRuleProperty"]]]], result)

        @builtins.property
        def selected_border_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FreeFormLayoutElementBorderStyleProperty"]]:
            '''The border style configuration of a free-form layout element.

            This border style is used when the element is selected.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-selectedborderstyle
            '''
            result = self._values.get("selected_border_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FreeFormLayoutElementBorderStyleProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of an element within a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"optimized_view_port_width": "optimizedViewPortWidth"},
    )
    class FreeFormLayoutScreenCanvasSizeOptionsProperty:
        def __init__(self, *, optimized_view_port_width: builtins.str) -> None:
            '''The options that determine the sizing of the canvas used in a free-form layout.

            :param optimized_view_port_width: The width that the view port will be optimized for when the layout renders.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutscreencanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                free_form_layout_screen_canvas_size_options_property = quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                    optimized_view_port_width="optimizedViewPortWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__70f5968d224145b77864fe3e212a23fefddd12d98d4f16ad65f82862d26c4118)
                check_type(argname="argument optimized_view_port_width", value=optimized_view_port_width, expected_type=type_hints["optimized_view_port_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "optimized_view_port_width": optimized_view_port_width,
            }

        @builtins.property
        def optimized_view_port_width(self) -> builtins.str:
            '''The width that the view port will be optimized for when the layout renders.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutscreencanvassizeoptions.html#cfn-quicksight-dashboard-freeformlayoutscreencanvassizeoptions-optimizedviewportwidth
            '''
            result = self._values.get("optimized_view_port_width")
            assert result is not None, "Required property 'optimized_view_port_width' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutScreenCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"elements": "elements"},
    )
    class FreeFormSectionLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FreeFormLayoutElementProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The free-form layout configuration of a section.

            :param elements: The elements that are included in the free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformsectionlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                free_form_section_layout_configuration_property = quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                        element_id="elementId",
                        element_type="elementType",
                        height="height",
                        width="width",
                        x_axis_location="xAxisLocation",
                        y_axis_location="yAxisLocation",
                
                        # the properties below are optional
                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                            visibility="visibility"
                        ),
                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                visibility="visibility"
                            ),
                            expression="expression"
                        )],
                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        visibility="visibility"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__05b8ccdd5307faf5a757a70e1b706a486b996457d2b944a58a72c592ecf00ba1)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FreeFormLayoutElementProperty"]]]:
            '''The elements that are included in the free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformsectionlayoutconfiguration.html#cfn-quicksight-dashboard-freeformsectionlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FreeFormLayoutElementProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormSectionLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"category": "category", "values": "values"},
    )
    class FunnelChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :param category: The category field wells of a funnel chart. Values are grouped by category fields.
            :param values: The value field wells of a funnel chart. Values are aggregated based on categories.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                funnel_chart_aggregated_field_wells_property = quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aace408b5c9a77434abc078712f8b959e3ece3f10cc2292577592c845a953a54)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The category field wells of a funnel chart.

            Values are grouped by category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartaggregatedfieldwells.html#cfn-quicksight-dashboard-funnelchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The value field wells of a funnel chart.

            Values are aggregated based on categories.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartaggregatedfieldwells.html#cfn-quicksight-dashboard-funnelchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FunnelChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "data_label_options": "dataLabelOptions",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class FunnelChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FunnelChartDataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FunnelChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FunnelChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``FunnelChartVisual`` .

            :param category_label_options: The label options of the categories that are displayed in a ``FunnelChartVisual`` .
            :param data_label_options: The options that determine the presentation of the data labels.
            :param field_wells: The field well configuration of a ``FunnelChartVisual`` .
            :param sort_configuration: The sort configuration of a ``FunnelChartVisual`` .
            :param tooltip: The tooltip configuration of a ``FunnelChartVisual`` .
            :param value_label_options: The label options for the values that are displayed in a ``FunnelChartVisual`` .
            :param visual_palette: The visual palette configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a56fa8bef7c45a37b0f6d57489f85aa4bcf476e3005e754a161693aa18450109)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument data_label_options", value=data_label_options, expected_type=type_hints["data_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if data_label_options is not None:
                self._values["data_label_options"] = data_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the categories that are displayed in a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def data_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FunnelChartDataLabelOptionsProperty"]]:
            '''The options that determine the presentation of the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-datalabeloptions
            '''
            result = self._values.get("data_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FunnelChartDataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FunnelChartFieldWellsProperty"]]:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FunnelChartFieldWellsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FunnelChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FunnelChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options for the values that are displayed in a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]]:
            '''The visual palette configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FunnelChartDataLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_visibility": "categoryLabelVisibility",
            "label_color": "labelColor",
            "label_font_configuration": "labelFontConfiguration",
            "measure_data_label_style": "measureDataLabelStyle",
            "measure_label_visibility": "measureLabelVisibility",
            "position": "position",
            "visibility": "visibility",
        },
    )
    class FunnelChartDataLabelOptionsProperty:
        def __init__(
            self,
            *,
            category_label_visibility: typing.Optional[builtins.str] = None,
            label_color: typing.Optional[builtins.str] = None,
            label_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            measure_data_label_style: typing.Optional[builtins.str] = None,
            measure_label_visibility: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of the data labels.

            :param category_label_visibility: The visibility of the category labels within the data labels.
            :param label_color: The color of the data label text.
            :param label_font_configuration: The font configuration for the data labels. Only the ``FontSize`` attribute of the font configuration is used for data labels.
            :param measure_data_label_style: Determines the style of the metric labels.
            :param measure_label_visibility: The visibility of the measure labels within the data labels.
            :param position: Determines the positioning of the data label relative to a section of the funnel.
            :param visibility: The visibility option that determines if data labels are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                funnel_chart_data_label_options_property = quicksight.CfnDashboard.FunnelChartDataLabelOptionsProperty(
                    category_label_visibility="categoryLabelVisibility",
                    label_color="labelColor",
                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    measure_data_label_style="measureDataLabelStyle",
                    measure_label_visibility="measureLabelVisibility",
                    position="position",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b5bacc08479d189c88550d455b346769521b7ce35e9d537b88edd8f0592b7e4c)
                check_type(argname="argument category_label_visibility", value=category_label_visibility, expected_type=type_hints["category_label_visibility"])
                check_type(argname="argument label_color", value=label_color, expected_type=type_hints["label_color"])
                check_type(argname="argument label_font_configuration", value=label_font_configuration, expected_type=type_hints["label_font_configuration"])
                check_type(argname="argument measure_data_label_style", value=measure_data_label_style, expected_type=type_hints["measure_data_label_style"])
                check_type(argname="argument measure_label_visibility", value=measure_label_visibility, expected_type=type_hints["measure_label_visibility"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_visibility is not None:
                self._values["category_label_visibility"] = category_label_visibility
            if label_color is not None:
                self._values["label_color"] = label_color
            if label_font_configuration is not None:
                self._values["label_font_configuration"] = label_font_configuration
            if measure_data_label_style is not None:
                self._values["measure_data_label_style"] = measure_data_label_style
            if measure_label_visibility is not None:
                self._values["measure_label_visibility"] = measure_label_visibility
            if position is not None:
                self._values["position"] = position
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def category_label_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the category labels within the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-categorylabelvisibility
            '''
            result = self._values.get("category_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_color(self) -> typing.Optional[builtins.str]:
            '''The color of the data label text.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-labelcolor
            '''
            result = self._values.get("label_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"]]:
            '''The font configuration for the data labels.

            Only the ``FontSize`` attribute of the font configuration is used for data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-labelfontconfiguration
            '''
            result = self._values.get("label_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"]], result)

        @builtins.property
        def measure_data_label_style(self) -> typing.Optional[builtins.str]:
            '''Determines the style of the metric labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-measuredatalabelstyle
            '''
            result = self._values.get("measure_data_label_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def measure_label_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the measure labels within the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-measurelabelvisibility
            '''
            result = self._values.get("measure_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''Determines the positioning of the data label relative to a section of the funnel.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility option that determines if data labels are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartDataLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FunnelChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "funnel_chart_aggregated_field_wells": "funnelChartAggregatedFieldWells",
        },
    )
    class FunnelChartFieldWellsProperty:
        def __init__(
            self,
            *,
            funnel_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FunnelChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a ``FunnelChartVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param funnel_chart_aggregated_field_wells: The field well configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                funnel_chart_field_wells_property = quicksight.CfnDashboard.FunnelChartFieldWellsProperty(
                    funnel_chart_aggregated_field_wells=quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__427263f05cdce6f497bd2cc0818ec31767bf2aec215e5c863da0dabe71eeb941)
                check_type(argname="argument funnel_chart_aggregated_field_wells", value=funnel_chart_aggregated_field_wells, expected_type=type_hints["funnel_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if funnel_chart_aggregated_field_wells is not None:
                self._values["funnel_chart_aggregated_field_wells"] = funnel_chart_aggregated_field_wells

        @builtins.property
        def funnel_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FunnelChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartfieldwells.html#cfn-quicksight-dashboard-funnelchartfieldwells-funnelchartaggregatedfieldwells
            '''
            result = self._values.get("funnel_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FunnelChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FunnelChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class FunnelChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``FunnelChartVisual`` .

            :param category_items_limit: The limit on the number of categories displayed.
            :param category_sort: The sort configuration of the category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                funnel_chart_sort_configuration_property = quicksight.CfnDashboard.FunnelChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__63de974df528ed8a6f65f8a7861a94176c8253fcf631e2e94eb458a6da15efda)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartsortconfiguration.html#cfn-quicksight-dashboard-funnelchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartsortconfiguration.html#cfn-quicksight-dashboard-funnelchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.FunnelChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class FunnelChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FunnelChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A funnel chart.

            For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``FunnelChartVisual`` .
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__11eb4360e3908a74c4d1c2eac25bd4c2f3fb92610f398c4d029394d82c94a674)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FunnelChartConfigurationProperty"]]:
            '''The configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FunnelChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"foreground_color": "foregroundColor"},
    )
    class GaugeChartArcConditionalFormattingProperty:
        def __init__(
            self,
            *,
            foreground_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of the arc of a ``GaugeChartVisual`` .

            :param foreground_color: The conditional formatting of the arc foreground color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartarcconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gauge_chart_arc_conditional_formatting_property = quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty(
                    foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3193770941793ac48d16e4b4cdbeb6e3d875cbfeb9cdc14d327d05694ea1a6b1)
                check_type(argname="argument foreground_color", value=foreground_color, expected_type=type_hints["foreground_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if foreground_color is not None:
                self._values["foreground_color"] = foreground_color

        @builtins.property
        def foreground_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the arc foreground color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartarcconditionalformatting.html#cfn-quicksight-dashboard-gaugechartarcconditionalformatting-foregroundcolor
            '''
            result = self._values.get("foreground_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartArcConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GaugeChartConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"arc": "arc", "primary_value": "primaryValue"},
    )
    class GaugeChartConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            arc: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GaugeChartArcConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Conditional formatting options of a ``GaugeChartVisual`` .

            :param arc: The options that determine the presentation of the arc of a ``GaugeChartVisual`` .
            :param primary_value: The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gauge_chart_conditional_formatting_option_property = quicksight.CfnDashboard.GaugeChartConditionalFormattingOptionProperty(
                    arc=quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty(
                        foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    primary_value=quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty(
                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ee3c24d3e86ef2aeb08344f18648d5ff677d0cc9da4dca46857b7f2b5d1ec2a7)
                check_type(argname="argument arc", value=arc, expected_type=type_hints["arc"])
                check_type(argname="argument primary_value", value=primary_value, expected_type=type_hints["primary_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc is not None:
                self._values["arc"] = arc
            if primary_value is not None:
                self._values["primary_value"] = primary_value

        @builtins.property
        def arc(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GaugeChartArcConditionalFormattingProperty"]]:
            '''The options that determine the presentation of the arc of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformattingoption.html#cfn-quicksight-dashboard-gaugechartconditionalformattingoption-arc
            '''
            result = self._values.get("arc")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GaugeChartArcConditionalFormattingProperty"]], result)

        @builtins.property
        def primary_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty"]]:
            '''The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformattingoption.html#cfn-quicksight-dashboard-gaugechartconditionalformattingoption-primaryvalue
            '''
            result = self._values.get("primary_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GaugeChartConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class GaugeChartConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GaugeChartConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting of a ``GaugeChartVisual`` .

            :param conditional_formatting_options: Conditional formatting options of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gauge_chart_conditional_formatting_property = quicksight.CfnDashboard.GaugeChartConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnDashboard.GaugeChartConditionalFormattingOptionProperty(
                        arc=quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty(
                            foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        primary_value=quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty(
                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__db3bb7f458c5bb03088ea72306d6b41fdaa355726755bafc8674afec9c715eb0)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GaugeChartConditionalFormattingOptionProperty"]]]]:
            '''Conditional formatting options of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformatting.html#cfn-quicksight-dashboard-gaugechartconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GaugeChartConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GaugeChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "gauge_chart_options": "gaugeChartOptions",
            "tooltip_options": "tooltipOptions",
            "visual_palette": "visualPalette",
        },
    )
    class GaugeChartConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GaugeChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            gauge_chart_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GaugeChartOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``GaugeChartVisual`` .

            :param data_labels: The data label configuration of a ``GaugeChartVisual`` .
            :param field_wells: The field well configuration of a ``GaugeChartVisual`` .
            :param gauge_chart_options: The options that determine the presentation of the ``GaugeChartVisual`` .
            :param tooltip_options: The tooltip configuration of a ``GaugeChartVisual`` .
            :param visual_palette: The visual palette configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fea0ba99ad1b3d15526d38a27c8008590d5844786e9587800c5a8514183744c3)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument gauge_chart_options", value=gauge_chart_options, expected_type=type_hints["gauge_chart_options"])
                check_type(argname="argument tooltip_options", value=tooltip_options, expected_type=type_hints["tooltip_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if gauge_chart_options is not None:
                self._values["gauge_chart_options"] = gauge_chart_options
            if tooltip_options is not None:
                self._values["tooltip_options"] = tooltip_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The data label configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GaugeChartFieldWellsProperty"]]:
            '''The field well configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GaugeChartFieldWellsProperty"]], result)

        @builtins.property
        def gauge_chart_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GaugeChartOptionsProperty"]]:
            '''The options that determine the presentation of the ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-gaugechartoptions
            '''
            result = self._values.get("gauge_chart_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GaugeChartOptionsProperty"]], result)

        @builtins.property
        def tooltip_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-tooltipoptions
            '''
            result = self._values.get("tooltip_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]]:
            '''The visual palette configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GaugeChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"target_values": "targetValues", "values": "values"},
    )
    class GaugeChartFieldWellsProperty:
        def __init__(
            self,
            *,
            target_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a ``GaugeChartVisual`` .

            :param target_values: The target value field wells of a ``GaugeChartVisual`` .
            :param values: The value field wells of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__daf0ee523aee63965b511d70b72de53c3390d01f1816827484208a8f970682ee)
                check_type(argname="argument target_values", value=target_values, expected_type=type_hints["target_values"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_values is not None:
                self._values["target_values"] = target_values
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def target_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The target value field wells of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartfieldwells.html#cfn-quicksight-dashboard-gaugechartfieldwells-targetvalues
            '''
            result = self._values.get("target_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The value field wells of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartfieldwells.html#cfn-quicksight-dashboard-gaugechartfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GaugeChartOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arc": "arc",
            "arc_axis": "arcAxis",
            "comparison": "comparison",
            "primary_value_display_type": "primaryValueDisplayType",
            "primary_value_font_configuration": "primaryValueFontConfiguration",
        },
    )
    class GaugeChartOptionsProperty:
        def __init__(
            self,
            *,
            arc: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ArcConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            arc_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ArcAxisConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            comparison: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ComparisonConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_value_display_type: typing.Optional[builtins.str] = None,
            primary_value_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of the ``GaugeChartVisual`` .

            :param arc: The arc configuration of a ``GaugeChartVisual`` .
            :param arc_axis: The arc axis configuration of a ``GaugeChartVisual`` .
            :param comparison: The comparison configuration of a ``GaugeChartVisual`` .
            :param primary_value_display_type: The options that determine the primary value display type.
            :param primary_value_font_configuration: The options that determine the primary value font configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gauge_chart_options_property = quicksight.CfnDashboard.GaugeChartOptionsProperty(
                    arc=quicksight.CfnDashboard.ArcConfigurationProperty(
                        arc_angle=123,
                        arc_thickness="arcThickness"
                    ),
                    arc_axis=quicksight.CfnDashboard.ArcAxisConfigurationProperty(
                        range=quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                            max=123,
                            min=123
                        ),
                        reserve_range=123
                    ),
                    comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                        comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        comparison_method="comparisonMethod"
                    ),
                    primary_value_display_type="primaryValueDisplayType",
                    primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b8c17bdd93f0eec1fe081eb70a918a76490915edf0849cc6e373f3433517057f)
                check_type(argname="argument arc", value=arc, expected_type=type_hints["arc"])
                check_type(argname="argument arc_axis", value=arc_axis, expected_type=type_hints["arc_axis"])
                check_type(argname="argument comparison", value=comparison, expected_type=type_hints["comparison"])
                check_type(argname="argument primary_value_display_type", value=primary_value_display_type, expected_type=type_hints["primary_value_display_type"])
                check_type(argname="argument primary_value_font_configuration", value=primary_value_font_configuration, expected_type=type_hints["primary_value_font_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc is not None:
                self._values["arc"] = arc
            if arc_axis is not None:
                self._values["arc_axis"] = arc_axis
            if comparison is not None:
                self._values["comparison"] = comparison
            if primary_value_display_type is not None:
                self._values["primary_value_display_type"] = primary_value_display_type
            if primary_value_font_configuration is not None:
                self._values["primary_value_font_configuration"] = primary_value_font_configuration

        @builtins.property
        def arc(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ArcConfigurationProperty"]]:
            '''The arc configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-arc
            '''
            result = self._values.get("arc")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ArcConfigurationProperty"]], result)

        @builtins.property
        def arc_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ArcAxisConfigurationProperty"]]:
            '''The arc axis configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-arcaxis
            '''
            result = self._values.get("arc_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ArcAxisConfigurationProperty"]], result)

        @builtins.property
        def comparison(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ComparisonConfigurationProperty"]]:
            '''The comparison configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-comparison
            '''
            result = self._values.get("comparison")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ComparisonConfigurationProperty"]], result)

        @builtins.property
        def primary_value_display_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the primary value display type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-primaryvaluedisplaytype
            '''
            result = self._values.get("primary_value_display_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"]]:
            '''The options that determine the primary value font configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-primaryvaluefontconfiguration
            '''
            result = self._values.get("primary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class GaugeChartPrimaryValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :param icon: The conditional formatting of the primary value icon.
            :param text_color: The conditional formatting of the primary value text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gauge_chart_primary_value_conditional_formatting_property = quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty(
                    icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4325066aeedbf8956d0d2df46ce10a24eb071592875bd468395073a06d5d39ba)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting of the primary value icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the primary value text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartPrimaryValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GaugeChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class GaugeChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GaugeChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GaugeChartConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A gauge chart.

            For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``GaugeChartVisual`` .
            :param conditional_formatting: The conditional formatting of a ``GaugeChartVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7b9f11cfc17a7b5c10021167342d4df018195c51992933bcc7ad4f3960ab0664)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GaugeChartConfigurationProperty"]]:
            '''The configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GaugeChartConfigurationProperty"]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GaugeChartConditionalFormattingProperty"]]:
            '''The conditional formatting of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GaugeChartConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "east": "east",
            "north": "north",
            "south": "south",
            "west": "west",
        },
    )
    class GeospatialCoordinateBoundsProperty:
        def __init__(
            self,
            *,
            east: jsii.Number,
            north: jsii.Number,
            south: jsii.Number,
            west: jsii.Number,
        ) -> None:
            '''The bound options (north, south, west, east) of the geospatial window options.

            :param east: The longitude of the east bound of the geospatial coordinate bounds.
            :param north: The latitude of the north bound of the geospatial coordinate bounds.
            :param south: The latitude of the south bound of the geospatial coordinate bounds.
            :param west: The longitude of the west bound of the geospatial coordinate bounds.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geospatial_coordinate_bounds_property = quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                    east=123,
                    north=123,
                    south=123,
                    west=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7515d114e0451a7d5606e6a7f4a3dd9e88dcef9e1fe68358e144d6827cbb91dd)
                check_type(argname="argument east", value=east, expected_type=type_hints["east"])
                check_type(argname="argument north", value=north, expected_type=type_hints["north"])
                check_type(argname="argument south", value=south, expected_type=type_hints["south"])
                check_type(argname="argument west", value=west, expected_type=type_hints["west"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "east": east,
                "north": north,
                "south": south,
                "west": west,
            }

        @builtins.property
        def east(self) -> jsii.Number:
            '''The longitude of the east bound of the geospatial coordinate bounds.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html#cfn-quicksight-dashboard-geospatialcoordinatebounds-east
            '''
            result = self._values.get("east")
            assert result is not None, "Required property 'east' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def north(self) -> jsii.Number:
            '''The latitude of the north bound of the geospatial coordinate bounds.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html#cfn-quicksight-dashboard-geospatialcoordinatebounds-north
            '''
            result = self._values.get("north")
            assert result is not None, "Required property 'north' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def south(self) -> jsii.Number:
            '''The latitude of the south bound of the geospatial coordinate bounds.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html#cfn-quicksight-dashboard-geospatialcoordinatebounds-south
            '''
            result = self._values.get("south")
            assert result is not None, "Required property 'south' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def west(self) -> jsii.Number:
            '''The longitude of the west bound of the geospatial coordinate bounds.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html#cfn-quicksight-dashboard-geospatialcoordinatebounds-west
            '''
            result = self._values.get("west")
            assert result is not None, "Required property 'west' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialCoordinateBoundsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GeospatialHeatmapColorScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"colors": "colors"},
    )
    class GeospatialHeatmapColorScaleProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GeospatialHeatmapDataColorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The color scale specification for the heatmap point style.

            :param colors: The list of colors to be used in heatmap point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialheatmapcolorscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geospatial_heatmap_color_scale_property = quicksight.CfnDashboard.GeospatialHeatmapColorScaleProperty(
                    colors=[quicksight.CfnDashboard.GeospatialHeatmapDataColorProperty(
                        color="color"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f01ffbeb07e8e6645fd7010279d5161810dda96eefaeff99b6feb9773e8467ce)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialHeatmapDataColorProperty"]]]]:
            '''The list of colors to be used in heatmap point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialheatmapcolorscale.html#cfn-quicksight-dashboard-geospatialheatmapcolorscale-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialHeatmapDataColorProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialHeatmapColorScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GeospatialHeatmapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"heatmap_color": "heatmapColor"},
    )
    class GeospatialHeatmapConfigurationProperty:
        def __init__(
            self,
            *,
            heatmap_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GeospatialHeatmapColorScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The heatmap configuration of the geospatial point style.

            :param heatmap_color: The color scale specification for the heatmap point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialheatmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geospatial_heatmap_configuration_property = quicksight.CfnDashboard.GeospatialHeatmapConfigurationProperty(
                    heatmap_color=quicksight.CfnDashboard.GeospatialHeatmapColorScaleProperty(
                        colors=[quicksight.CfnDashboard.GeospatialHeatmapDataColorProperty(
                            color="color"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ade06e39a7c8f7181d2a5baf6246bee04dd897bf4e00d308088a09a7d7b2773e)
                check_type(argname="argument heatmap_color", value=heatmap_color, expected_type=type_hints["heatmap_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if heatmap_color is not None:
                self._values["heatmap_color"] = heatmap_color

        @builtins.property
        def heatmap_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialHeatmapColorScaleProperty"]]:
            '''The color scale specification for the heatmap point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialheatmapconfiguration.html#cfn-quicksight-dashboard-geospatialheatmapconfiguration-heatmapcolor
            '''
            result = self._values.get("heatmap_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialHeatmapColorScaleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialHeatmapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GeospatialHeatmapDataColorProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color"},
    )
    class GeospatialHeatmapDataColorProperty:
        def __init__(self, *, color: builtins.str) -> None:
            '''The color to be used in the heatmap point style.

            :param color: The hex color to be used in the heatmap point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialheatmapdatacolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geospatial_heatmap_data_color_property = quicksight.CfnDashboard.GeospatialHeatmapDataColorProperty(
                    color="color"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7765677970819760ce3a84b37a74b17865bae3f99d6d12d36f844713ba72f805)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
            }

        @builtins.property
        def color(self) -> builtins.str:
            '''The hex color to be used in the heatmap point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialheatmapdatacolor.html#cfn-quicksight-dashboard-geospatialheatmapdatacolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialHeatmapDataColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GeospatialMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "colors": "colors",
            "geospatial": "geospatial",
            "values": "values",
        },
    )
    class GeospatialMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            geospatial: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells for a geospatial map.

            :param colors: The color field wells of a geospatial map.
            :param geospatial: The geospatial field wells of a geospatial map. Values are grouped by geospatial fields.
            :param values: The size field wells of a geospatial map. Values are aggregated based on geospatial fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0081ce6bc2bc7286f3c3dde4cef1576fa5ec0d3d81d922acd1160502c6acaee3)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument geospatial", value=geospatial, expected_type=type_hints["geospatial"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors
            if geospatial is not None:
                self._values["geospatial"] = geospatial
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The color field wells of a geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapaggregatedfieldwells.html#cfn-quicksight-dashboard-geospatialmapaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def geospatial(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The geospatial field wells of a geospatial map.

            Values are grouped by geospatial fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapaggregatedfieldwells.html#cfn-quicksight-dashboard-geospatialmapaggregatedfieldwells-geospatial
            '''
            result = self._values.get("geospatial")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The size field wells of a geospatial map.

            Values are aggregated based on geospatial fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapaggregatedfieldwells.html#cfn-quicksight-dashboard-geospatialmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GeospatialMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "legend": "legend",
            "map_style_options": "mapStyleOptions",
            "point_style_options": "pointStyleOptions",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "window_options": "windowOptions",
        },
    )
    class GeospatialMapConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GeospatialMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            map_style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GeospatialMapStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            point_style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GeospatialPointStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            window_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GeospatialWindowOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``GeospatialMapVisual`` .

            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param map_style_options: The map style options of the geospatial map.
            :param point_style_options: The point style options of the geospatial map.
            :param tooltip: The tooltip display setup of the visual.
            :param visual_palette: 
            :param window_options: The window options of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7c94bbf4d0514fb89546f03bc3d9bba05117b5d6eb67cec997161c719fc3064c)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument map_style_options", value=map_style_options, expected_type=type_hints["map_style_options"])
                check_type(argname="argument point_style_options", value=point_style_options, expected_type=type_hints["point_style_options"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument window_options", value=window_options, expected_type=type_hints["window_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if map_style_options is not None:
                self._values["map_style_options"] = map_style_options
            if point_style_options is not None:
                self._values["point_style_options"] = point_style_options
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if window_options is not None:
                self._values["window_options"] = window_options

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialMapFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def map_style_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialMapStyleOptionsProperty"]]:
            '''The map style options of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-mapstyleoptions
            '''
            result = self._values.get("map_style_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialMapStyleOptionsProperty"]], result)

        @builtins.property
        def point_style_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialPointStyleOptionsProperty"]]:
            '''The point style options of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-pointstyleoptions
            '''
            result = self._values.get("point_style_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialPointStyleOptionsProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]], result)

        @builtins.property
        def window_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialWindowOptionsProperty"]]:
            '''The window options of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-windowoptions
            '''
            result = self._values.get("window_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialWindowOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GeospatialMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "geospatial_map_aggregated_field_wells": "geospatialMapAggregatedFieldWells",
        },
    )
    class GeospatialMapFieldWellsProperty:
        def __init__(
            self,
            *,
            geospatial_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GeospatialMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``GeospatialMapVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param geospatial_map_aggregated_field_wells: The aggregated field well for a geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f24adf7d5f2edab16a8d998d8e290c3075ae0fc4687dee027bb9f43024f4e3a4)
                check_type(argname="argument geospatial_map_aggregated_field_wells", value=geospatial_map_aggregated_field_wells, expected_type=type_hints["geospatial_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if geospatial_map_aggregated_field_wells is not None:
                self._values["geospatial_map_aggregated_field_wells"] = geospatial_map_aggregated_field_wells

        @builtins.property
        def geospatial_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field well for a geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapfieldwells.html#cfn-quicksight-dashboard-geospatialmapfieldwells-geospatialmapaggregatedfieldwells
            '''
            result = self._values.get("geospatial_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"base_map_style": "baseMapStyle"},
    )
    class GeospatialMapStyleOptionsProperty:
        def __init__(
            self,
            *,
            base_map_style: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The map style options of the geospatial map.

            :param base_map_style: The base map style of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geospatial_map_style_options_property = quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                    base_map_style="baseMapStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f0bf9a88bcd93f122219813203be22ab19e3bd2409bc9c15271ad6b318d1b86b)
                check_type(argname="argument base_map_style", value=base_map_style, expected_type=type_hints["base_map_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if base_map_style is not None:
                self._values["base_map_style"] = base_map_style

        @builtins.property
        def base_map_style(self) -> typing.Optional[builtins.str]:
            '''The base map style of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapstyleoptions.html#cfn-quicksight-dashboard-geospatialmapstyleoptions-basemapstyle
            '''
            result = self._values.get("base_map_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GeospatialMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class GeospatialMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GeospatialMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A geospatial map or a points on map visual.

            For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4a9dbd6ba6cceac988fa2dc9fbbd35f1368447584a2e2700e6fdde8e9a9d8d10)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialMapConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GeospatialPointStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cluster_marker_configuration": "clusterMarkerConfiguration",
            "heatmap_configuration": "heatmapConfiguration",
            "selected_point_style": "selectedPointStyle",
        },
    )
    class GeospatialPointStyleOptionsProperty:
        def __init__(
            self,
            *,
            cluster_marker_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ClusterMarkerConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            heatmap_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GeospatialHeatmapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selected_point_style: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The point style of the geospatial map.

            :param cluster_marker_configuration: The cluster marker configuration of the geospatial point style.
            :param heatmap_configuration: The heatmap configuration of the geospatial point style.
            :param selected_point_style: The selected point styles (point, cluster) of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialpointstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geospatial_point_style_options_property = quicksight.CfnDashboard.GeospatialPointStyleOptionsProperty(
                    cluster_marker_configuration=quicksight.CfnDashboard.ClusterMarkerConfigurationProperty(
                        cluster_marker=quicksight.CfnDashboard.ClusterMarkerProperty(
                            simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                                color="color"
                            )
                        )
                    ),
                    heatmap_configuration=quicksight.CfnDashboard.GeospatialHeatmapConfigurationProperty(
                        heatmap_color=quicksight.CfnDashboard.GeospatialHeatmapColorScaleProperty(
                            colors=[quicksight.CfnDashboard.GeospatialHeatmapDataColorProperty(
                                color="color"
                            )]
                        )
                    ),
                    selected_point_style="selectedPointStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8d4508d35d96aec21a12e6d288ad6950dbed353a7024772ea7842902a22015cf)
                check_type(argname="argument cluster_marker_configuration", value=cluster_marker_configuration, expected_type=type_hints["cluster_marker_configuration"])
                check_type(argname="argument heatmap_configuration", value=heatmap_configuration, expected_type=type_hints["heatmap_configuration"])
                check_type(argname="argument selected_point_style", value=selected_point_style, expected_type=type_hints["selected_point_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cluster_marker_configuration is not None:
                self._values["cluster_marker_configuration"] = cluster_marker_configuration
            if heatmap_configuration is not None:
                self._values["heatmap_configuration"] = heatmap_configuration
            if selected_point_style is not None:
                self._values["selected_point_style"] = selected_point_style

        @builtins.property
        def cluster_marker_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ClusterMarkerConfigurationProperty"]]:
            '''The cluster marker configuration of the geospatial point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialpointstyleoptions.html#cfn-quicksight-dashboard-geospatialpointstyleoptions-clustermarkerconfiguration
            '''
            result = self._values.get("cluster_marker_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ClusterMarkerConfigurationProperty"]], result)

        @builtins.property
        def heatmap_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialHeatmapConfigurationProperty"]]:
            '''The heatmap configuration of the geospatial point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialpointstyleoptions.html#cfn-quicksight-dashboard-geospatialpointstyleoptions-heatmapconfiguration
            '''
            result = self._values.get("heatmap_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialHeatmapConfigurationProperty"]], result)

        @builtins.property
        def selected_point_style(self) -> typing.Optional[builtins.str]:
            '''The selected point styles (point, cluster) of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialpointstyleoptions.html#cfn-quicksight-dashboard-geospatialpointstyleoptions-selectedpointstyle
            '''
            result = self._values.get("selected_point_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialPointStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GeospatialWindowOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"bounds": "bounds", "map_zoom_mode": "mapZoomMode"},
    )
    class GeospatialWindowOptionsProperty:
        def __init__(
            self,
            *,
            bounds: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GeospatialCoordinateBoundsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            map_zoom_mode: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The window options of the geospatial map visual.

            :param bounds: The bounds options (north, south, west, east) of the geospatial window options.
            :param map_zoom_mode: The map zoom modes (manual, auto) of the geospatial window options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialwindowoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geospatial_window_options_property = quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                    bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                        east=123,
                        north=123,
                        south=123,
                        west=123
                    ),
                    map_zoom_mode="mapZoomMode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bc7f40fe34a00233ceecbc2e3c35e5dcee432a6d0db96de1cb0c58c0ae1776cb)
                check_type(argname="argument bounds", value=bounds, expected_type=type_hints["bounds"])
                check_type(argname="argument map_zoom_mode", value=map_zoom_mode, expected_type=type_hints["map_zoom_mode"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bounds is not None:
                self._values["bounds"] = bounds
            if map_zoom_mode is not None:
                self._values["map_zoom_mode"] = map_zoom_mode

        @builtins.property
        def bounds(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialCoordinateBoundsProperty"]]:
            '''The bounds options (north, south, west, east) of the geospatial window options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialwindowoptions.html#cfn-quicksight-dashboard-geospatialwindowoptions-bounds
            '''
            result = self._values.get("bounds")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialCoordinateBoundsProperty"]], result)

        @builtins.property
        def map_zoom_mode(self) -> typing.Optional[builtins.str]:
            '''The map zoom modes (manual, auto) of the geospatial window options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialwindowoptions.html#cfn-quicksight-dashboard-geospatialwindowoptions-mapzoommode
            '''
            result = self._values.get("map_zoom_mode")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialWindowOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GlobalTableBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "side_specific_border": "sideSpecificBorder",
            "uniform_border": "uniformBorder",
        },
    )
    class GlobalTableBorderOptionsProperty:
        def __init__(
            self,
            *,
            side_specific_border: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableSideBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            uniform_border: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Determines the border options for a table visual.

            :param side_specific_border: Determines the options for side specific border.
            :param uniform_border: Determines the options for uniform border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-globaltableborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                global_table_border_options_property = quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        )
                    ),
                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__27a7446208bfe67d687aee519cbaaed4ac8efa54c443cbbdf9708bd6c305a776)
                check_type(argname="argument side_specific_border", value=side_specific_border, expected_type=type_hints["side_specific_border"])
                check_type(argname="argument uniform_border", value=uniform_border, expected_type=type_hints["uniform_border"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if side_specific_border is not None:
                self._values["side_specific_border"] = side_specific_border
            if uniform_border is not None:
                self._values["uniform_border"] = uniform_border

        @builtins.property
        def side_specific_border(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableSideBorderOptionsProperty"]]:
            '''Determines the options for side specific border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-globaltableborderoptions.html#cfn-quicksight-dashboard-globaltableborderoptions-sidespecificborder
            '''
            result = self._values.get("side_specific_border")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableSideBorderOptionsProperty"]], result)

        @builtins.property
        def uniform_border(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableBorderOptionsProperty"]]:
            '''Determines the options for uniform border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-globaltableborderoptions.html#cfn-quicksight-dashboard-globaltableborderoptions-uniformborder
            '''
            result = self._values.get("uniform_border")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableBorderOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GlobalTableBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GradientColorProperty",
        jsii_struct_bases=[],
        name_mapping={"stops": "stops"},
    )
    class GradientColorProperty:
        def __init__(
            self,
            *,
            stops: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GradientStopProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''Determines the gradient color settings.

            :param stops: The list of gradient color stops.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gradient_color_property = quicksight.CfnDashboard.GradientColorProperty(
                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                        gradient_offset=123,
                
                        # the properties below are optional
                        color="color",
                        data_value=123
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5cb0751a4418198f0765973b54a98a09757aa3ce4e3e4922b434672e646f8b33)
                check_type(argname="argument stops", value=stops, expected_type=type_hints["stops"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if stops is not None:
                self._values["stops"] = stops

        @builtins.property
        def stops(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GradientStopProperty"]]]]:
            '''The list of gradient color stops.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientcolor.html#cfn-quicksight-dashboard-gradientcolor-stops
            '''
            result = self._values.get("stops")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GradientStopProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GradientColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GradientStopProperty",
        jsii_struct_bases=[],
        name_mapping={
            "gradient_offset": "gradientOffset",
            "color": "color",
            "data_value": "dataValue",
        },
    )
    class GradientStopProperty:
        def __init__(
            self,
            *,
            gradient_offset: jsii.Number,
            color: typing.Optional[builtins.str] = None,
            data_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''Determines the gradient stop configuration.

            :param gradient_offset: Determines gradient offset value. Default: - 0
            :param color: Determines the color.
            :param data_value: Determines the data value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientstop.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gradient_stop_property = quicksight.CfnDashboard.GradientStopProperty(
                    gradient_offset=123,
                
                    # the properties below are optional
                    color="color",
                    data_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9785be233d22cda38939c462a2167fdb51a9701bb2ef9909bdfad544a88e5c60)
                check_type(argname="argument gradient_offset", value=gradient_offset, expected_type=type_hints["gradient_offset"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument data_value", value=data_value, expected_type=type_hints["data_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "gradient_offset": gradient_offset,
            }
            if color is not None:
                self._values["color"] = color
            if data_value is not None:
                self._values["data_value"] = data_value

        @builtins.property
        def gradient_offset(self) -> jsii.Number:
            '''Determines gradient offset value.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientstop.html#cfn-quicksight-dashboard-gradientstop-gradientoffset
            '''
            result = self._values.get("gradient_offset")
            assert result is not None, "Required property 'gradient_offset' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientstop.html#cfn-quicksight-dashboard-gradientstop-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_value(self) -> typing.Optional[jsii.Number]:
            '''Determines the data value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientstop.html#cfn-quicksight-dashboard-gradientstop-datavalue
            '''
            result = self._values.get("data_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GradientStopProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"screen_canvas_size_options": "screenCanvasSizeOptions"},
    )
    class GridLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            screen_canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Configuration options for the canvas of a grid layout.

            :param screen_canvas_size_options: The options that determine the sizing of the canvas used in a grid layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                grid_layout_canvas_size_options_property = quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                    screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                        resize_option="resizeOption",
                
                        # the properties below are optional
                        optimized_view_port_width="optimizedViewPortWidth"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5f5628cde5e59ad163ad239a741d0284d2880b8d85b6b9f2cc881247a1867701)
                check_type(argname="argument screen_canvas_size_options", value=screen_canvas_size_options, expected_type=type_hints["screen_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if screen_canvas_size_options is not None:
                self._values["screen_canvas_size_options"] = screen_canvas_size_options

        @builtins.property
        def screen_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty"]]:
            '''The options that determine the sizing of the canvas used in a grid layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutcanvassizeoptions.html#cfn-quicksight-dashboard-gridlayoutcanvassizeoptions-screencanvassizeoptions
            '''
            result = self._values.get("screen_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GridLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "elements": "elements",
            "canvas_size_options": "canvasSizeOptions",
        },
    )
    class GridLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GridLayoutElementProperty", typing.Dict[builtins.str, typing.Any]]]]],
            canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GridLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a grid layout. Also called a tiled layout.

            Visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size.

            :param elements: The elements that are included in a grid layout.
            :param canvas_size_options: 

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                grid_layout_configuration_property = quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                    elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                        column_span=123,
                        element_id="elementId",
                        element_type="elementType",
                        row_span=123,
                
                        # the properties below are optional
                        column_index=123,
                        row_index=123
                    )],
                
                    # the properties below are optional
                    canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                            resize_option="resizeOption",
                
                            # the properties below are optional
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__07ddf3867d702eb7d8212af0e65e1a706db30e2f3da951b94d6da034d2a13a04)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }
            if canvas_size_options is not None:
                self._values["canvas_size_options"] = canvas_size_options

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GridLayoutElementProperty"]]]:
            '''The elements that are included in a grid layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutconfiguration.html#cfn-quicksight-dashboard-gridlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GridLayoutElementProperty"]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GridLayoutCanvasSizeOptionsProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutconfiguration.html#cfn-quicksight-dashboard-gridlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GridLayoutCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GridLayoutElementProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_span": "columnSpan",
            "element_id": "elementId",
            "element_type": "elementType",
            "row_span": "rowSpan",
            "column_index": "columnIndex",
            "row_index": "rowIndex",
        },
    )
    class GridLayoutElementProperty:
        def __init__(
            self,
            *,
            column_span: jsii.Number,
            element_id: builtins.str,
            element_type: builtins.str,
            row_span: jsii.Number,
            column_index: typing.Optional[jsii.Number] = None,
            row_index: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''An element within a grid layout.

            :param column_span: The width of a grid element expressed as a number of grid columns.
            :param element_id: A unique identifier for an element within a grid layout.
            :param element_type: The type of element.
            :param row_span: The height of a grid element expressed as a number of grid rows.
            :param column_index: The column index for the upper left corner of an element.
            :param row_index: The row index for the upper left corner of an element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                grid_layout_element_property = quicksight.CfnDashboard.GridLayoutElementProperty(
                    column_span=123,
                    element_id="elementId",
                    element_type="elementType",
                    row_span=123,
                
                    # the properties below are optional
                    column_index=123,
                    row_index=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d41dff837bdfa0fda2ee1f5027f9ae683257cd1c33a07f86e7756bc5de4be6ec)
                check_type(argname="argument column_span", value=column_span, expected_type=type_hints["column_span"])
                check_type(argname="argument element_id", value=element_id, expected_type=type_hints["element_id"])
                check_type(argname="argument element_type", value=element_type, expected_type=type_hints["element_type"])
                check_type(argname="argument row_span", value=row_span, expected_type=type_hints["row_span"])
                check_type(argname="argument column_index", value=column_index, expected_type=type_hints["column_index"])
                check_type(argname="argument row_index", value=row_index, expected_type=type_hints["row_index"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_span": column_span,
                "element_id": element_id,
                "element_type": element_type,
                "row_span": row_span,
            }
            if column_index is not None:
                self._values["column_index"] = column_index
            if row_index is not None:
                self._values["row_index"] = row_index

        @builtins.property
        def column_span(self) -> jsii.Number:
            '''The width of a grid element expressed as a number of grid columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-columnspan
            '''
            result = self._values.get("column_span")
            assert result is not None, "Required property 'column_span' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def element_id(self) -> builtins.str:
            '''A unique identifier for an element within a grid layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-elementid
            '''
            result = self._values.get("element_id")
            assert result is not None, "Required property 'element_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element_type(self) -> builtins.str:
            '''The type of element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-elementtype
            '''
            result = self._values.get("element_type")
            assert result is not None, "Required property 'element_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def row_span(self) -> jsii.Number:
            '''The height of a grid element expressed as a number of grid rows.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-rowspan
            '''
            result = self._values.get("row_span")
            assert result is not None, "Required property 'row_span' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def column_index(self) -> typing.Optional[jsii.Number]:
            '''The column index for the upper left corner of an element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-columnindex
            '''
            result = self._values.get("column_index")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def row_index(self) -> typing.Optional[jsii.Number]:
            '''The row index for the upper left corner of an element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-rowindex
            '''
            result = self._values.get("row_index")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutElementProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "resize_option": "resizeOption",
            "optimized_view_port_width": "optimizedViewPortWidth",
        },
    )
    class GridLayoutScreenCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            resize_option: builtins.str,
            optimized_view_port_width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the sizing of the canvas used in a grid layout.

            :param resize_option: This value determines the layout behavior when the viewport is resized. - ``FIXED`` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called ``Classic`` . - ``RESPONSIVE`` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called ``Tiled`` .
            :param optimized_view_port_width: The width that the view port will be optimized for when the layout renders.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutscreencanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                grid_layout_screen_canvas_size_options_property = quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                    resize_option="resizeOption",
                
                    # the properties below are optional
                    optimized_view_port_width="optimizedViewPortWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0762b2492578471646a9ea2bd2aa6807395415b286cfd01b979f4c772217c915)
                check_type(argname="argument resize_option", value=resize_option, expected_type=type_hints["resize_option"])
                check_type(argname="argument optimized_view_port_width", value=optimized_view_port_width, expected_type=type_hints["optimized_view_port_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "resize_option": resize_option,
            }
            if optimized_view_port_width is not None:
                self._values["optimized_view_port_width"] = optimized_view_port_width

        @builtins.property
        def resize_option(self) -> builtins.str:
            '''This value determines the layout behavior when the viewport is resized.

            - ``FIXED`` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called ``Classic`` .
            - ``RESPONSIVE`` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called ``Tiled`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-dashboard-gridlayoutscreencanvassizeoptions-resizeoption
            '''
            result = self._values.get("resize_option")
            assert result is not None, "Required property 'resize_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def optimized_view_port_width(self) -> typing.Optional[builtins.str]:
            '''The width that the view port will be optimized for when the layout renders.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-dashboard-gridlayoutscreencanvassizeoptions-optimizedviewportwidth
            '''
            result = self._values.get("optimized_view_port_width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutScreenCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.GrowthRateComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "name": "name",
            "period_size": "periodSize",
            "time": "time",
            "value": "value",
        },
    )
    class GrowthRateComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            name: typing.Optional[builtins.str] = None,
            period_size: typing.Optional[jsii.Number] = None,
            time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The growth rate computation configuration.

            :param computation_id: The ID for a computation.
            :param name: The name of a computation.
            :param period_size: The period size setup of a growth rate computation. Default: - 0
            :param time: The time field that is used in a computation.
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                growth_rate_computation_property = quicksight.CfnDashboard.GrowthRateComputationProperty(
                    computation_id="computationId",
                
                    # the properties below are optional
                    name="name",
                    period_size=123,
                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__89d788cd539eba2c8371dacb20e21bc3c5f714c002dad436e7d9ea1854c0224c)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument period_size", value=period_size, expected_type=type_hints["period_size"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
            }
            if name is not None:
                self._values["name"] = name
            if period_size is not None:
                self._values["period_size"] = period_size
            if time is not None:
                self._values["time"] = time
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def period_size(self) -> typing.Optional[jsii.Number]:
            '''The period size setup of a growth rate computation.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-periodsize
            '''
            result = self._values.get("period_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]:
            '''The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-time
            '''
            result = self._values.get("time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GrowthRateComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"layout": "layout", "section_id": "sectionId", "style": "style"},
    )
    class HeaderFooterSectionConfigurationProperty:
        def __init__(
            self,
            *,
            layout: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            section_id: builtins.str,
            style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SectionStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a header or footer section.

            :param layout: The layout configuration of the header or footer section.
            :param section_id: The unique identifier of the header or footer section.
            :param style: The style options of a header or footer section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-headerfootersectionconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                header_footer_section_configuration_property = quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                    layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                            elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )]
                        )
                    ),
                    section_id="sectionId",
                
                    # the properties below are optional
                    style=quicksight.CfnDashboard.SectionStyleProperty(
                        height="height",
                        padding=quicksight.CfnDashboard.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f55e9b5efe8317be49ec8dd44c387505ab557653b7fa784a61182a8e083c31f2)
                check_type(argname="argument layout", value=layout, expected_type=type_hints["layout"])
                check_type(argname="argument section_id", value=section_id, expected_type=type_hints["section_id"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "layout": layout,
                "section_id": section_id,
            }
            if style is not None:
                self._values["style"] = style

        @builtins.property
        def layout(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.SectionLayoutConfigurationProperty"]:
            '''The layout configuration of the header or footer section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-headerfootersectionconfiguration.html#cfn-quicksight-dashboard-headerfootersectionconfiguration-layout
            '''
            result = self._values.get("layout")
            assert result is not None, "Required property 'layout' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.SectionLayoutConfigurationProperty"], result)

        @builtins.property
        def section_id(self) -> builtins.str:
            '''The unique identifier of the header or footer section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-headerfootersectionconfiguration.html#cfn-quicksight-dashboard-headerfootersectionconfiguration-sectionid
            '''
            result = self._values.get("section_id")
            assert result is not None, "Required property 'section_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SectionStyleProperty"]]:
            '''The style options of a header or footer section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-headerfootersectionconfiguration.html#cfn-quicksight-dashboard-headerfootersectionconfiguration-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SectionStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeaderFooterSectionConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.HeatMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns", "rows": "rows", "values": "values"},
    )
    class HeatMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            columns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            rows: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a heat map.

            :param columns: The columns field well of a heat map.
            :param rows: The rows field well of a heat map.
            :param values: The values field well of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2aebeb90e30c4dc284a705b12b49faa78a3788d9d66c42ea86e49230ee6efd16)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument rows", value=rows, expected_type=type_hints["rows"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if columns is not None:
                self._values["columns"] = columns
            if rows is not None:
                self._values["rows"] = rows
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def columns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The columns field well of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapaggregatedfieldwells.html#cfn-quicksight-dashboard-heatmapaggregatedfieldwells-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def rows(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The rows field well of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapaggregatedfieldwells.html#cfn-quicksight-dashboard-heatmapaggregatedfieldwells-rows
            '''
            result = self._values.get("rows")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The values field well of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapaggregatedfieldwells.html#cfn-quicksight-dashboard-heatmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.HeatMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_scale": "colorScale",
            "column_label_options": "columnLabelOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "row_label_options": "rowLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
        },
    )
    class HeatMapConfigurationProperty:
        def __init__(
            self,
            *,
            color_scale: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColorScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.HeatMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.HeatMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a heat map.

            :param color_scale: The color options (gradient color, point of divergence) in a heat map.
            :param column_label_options: The label options of the column that is displayed in a heat map.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param row_label_options: The label options of the row that is displayed in a ``heat map`` .
            :param sort_configuration: The sort configuration of a heat map.
            :param tooltip: The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__33b2cc83619b5207a3569782ee4e7ca1b05e84142345469cadcd0df6113dfe0c)
                check_type(argname="argument color_scale", value=color_scale, expected_type=type_hints["color_scale"])
                check_type(argname="argument column_label_options", value=column_label_options, expected_type=type_hints["column_label_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument row_label_options", value=row_label_options, expected_type=type_hints["row_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color_scale is not None:
                self._values["color_scale"] = color_scale
            if column_label_options is not None:
                self._values["column_label_options"] = column_label_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if row_label_options is not None:
                self._values["row_label_options"] = row_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip

        @builtins.property
        def color_scale(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColorScaleProperty"]]:
            '''The color options (gradient color, point of divergence) in a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-colorscale
            '''
            result = self._values.get("color_scale")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColorScaleProperty"]], result)

        @builtins.property
        def column_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the column that is displayed in a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-columnlabeloptions
            '''
            result = self._values.get("column_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HeatMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HeatMapFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def row_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the row that is displayed in a ``heat map`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-rowlabeloptions
            '''
            result = self._values.get("row_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HeatMapSortConfigurationProperty"]]:
            '''The sort configuration of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HeatMapSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.HeatMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "heat_map_aggregated_field_wells": "heatMapAggregatedFieldWells",
        },
    )
    class HeatMapFieldWellsProperty:
        def __init__(
            self,
            *,
            heat_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.HeatMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a heat map.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param heat_map_aggregated_field_wells: The aggregated field wells of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__46d251a3808c6dbd9def272fd8f48092651d1d5f20cb52799c4e6be95a10435e)
                check_type(argname="argument heat_map_aggregated_field_wells", value=heat_map_aggregated_field_wells, expected_type=type_hints["heat_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if heat_map_aggregated_field_wells is not None:
                self._values["heat_map_aggregated_field_wells"] = heat_map_aggregated_field_wells

        @builtins.property
        def heat_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HeatMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapfieldwells.html#cfn-quicksight-dashboard-heatmapfieldwells-heatmapaggregatedfieldwells
            '''
            result = self._values.get("heat_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HeatMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.HeatMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "heat_map_column_items_limit_configuration": "heatMapColumnItemsLimitConfiguration",
            "heat_map_column_sort": "heatMapColumnSort",
            "heat_map_row_items_limit_configuration": "heatMapRowItemsLimitConfiguration",
            "heat_map_row_sort": "heatMapRowSort",
        },
    )
    class HeatMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            heat_map_column_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            heat_map_column_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            heat_map_row_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            heat_map_row_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a heat map.

            :param heat_map_column_items_limit_configuration: The limit on the number of columns that are displayed in a heat map.
            :param heat_map_column_sort: The column sort configuration for heat map for columns that aren't a part of a field well.
            :param heat_map_row_items_limit_configuration: The limit on the number of rows that are displayed in a heat map.
            :param heat_map_row_sort: The field sort configuration of the rows fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                heat_map_sort_configuration_property = quicksight.CfnDashboard.HeatMapSortConfigurationProperty(
                    heat_map_column_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    heat_map_column_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    heat_map_row_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    heat_map_row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__97e7e218c841d1919af9453d3724140467e7d3a37e0ccb3c7c54738c6f7e5131)
                check_type(argname="argument heat_map_column_items_limit_configuration", value=heat_map_column_items_limit_configuration, expected_type=type_hints["heat_map_column_items_limit_configuration"])
                check_type(argname="argument heat_map_column_sort", value=heat_map_column_sort, expected_type=type_hints["heat_map_column_sort"])
                check_type(argname="argument heat_map_row_items_limit_configuration", value=heat_map_row_items_limit_configuration, expected_type=type_hints["heat_map_row_items_limit_configuration"])
                check_type(argname="argument heat_map_row_sort", value=heat_map_row_sort, expected_type=type_hints["heat_map_row_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if heat_map_column_items_limit_configuration is not None:
                self._values["heat_map_column_items_limit_configuration"] = heat_map_column_items_limit_configuration
            if heat_map_column_sort is not None:
                self._values["heat_map_column_sort"] = heat_map_column_sort
            if heat_map_row_items_limit_configuration is not None:
                self._values["heat_map_row_items_limit_configuration"] = heat_map_row_items_limit_configuration
            if heat_map_row_sort is not None:
                self._values["heat_map_row_sort"] = heat_map_row_sort

        @builtins.property
        def heat_map_column_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of columns that are displayed in a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html#cfn-quicksight-dashboard-heatmapsortconfiguration-heatmapcolumnitemslimitconfiguration
            '''
            result = self._values.get("heat_map_column_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def heat_map_column_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The column sort configuration for heat map for columns that aren't a part of a field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html#cfn-quicksight-dashboard-heatmapsortconfiguration-heatmapcolumnsort
            '''
            result = self._values.get("heat_map_column_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def heat_map_row_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of rows that are displayed in a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html#cfn-quicksight-dashboard-heatmapsortconfiguration-heatmaprowitemslimitconfiguration
            '''
            result = self._values.get("heat_map_row_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def heat_map_row_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The field sort configuration of the rows fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html#cfn-quicksight-dashboard-heatmapsortconfiguration-heatmaprowsort
            '''
            result = self._values.get("heat_map_row_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.HeatMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class HeatMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.HeatMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A heat map.

            For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a heat map.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ce1d7823e45e9c769613b464cbdd93ab8f7a04d1f4bb2683dd1879f3167929b1)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HeatMapConfigurationProperty"]]:
            '''The configuration of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HeatMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class HistogramAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a histogram.

            :param values: The value field wells of a histogram. Values are aggregated by ``COUNT`` or ``DISTINCT_COUNT`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                histogram_aggregated_field_wells_property = quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty(
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__55f052416da79b3a6acdb5f9c369802d9f69e969829c042b9d8fa3ab6411af37)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The value field wells of a histogram.

            Values are aggregated by ``COUNT`` or ``DISTINCT_COUNT`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramaggregatedfieldwells.html#cfn-quicksight-dashboard-histogramaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.HistogramBinOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bin_count": "binCount",
            "bin_width": "binWidth",
            "selected_bin_type": "selectedBinType",
            "start_value": "startValue",
        },
    )
    class HistogramBinOptionsProperty:
        def __init__(
            self,
            *,
            bin_count: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.BinCountOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            bin_width: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.BinWidthOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selected_bin_type: typing.Optional[builtins.str] = None,
            start_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The options that determine the presentation of histogram bins.

            :param bin_count: The options that determine the bin count of a histogram.
            :param bin_width: The options that determine the bin width of a histogram.
            :param selected_bin_type: The options that determine the selected bin type.
            :param start_value: The options that determine the bin start value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                histogram_bin_options_property = quicksight.CfnDashboard.HistogramBinOptionsProperty(
                    bin_count=quicksight.CfnDashboard.BinCountOptionsProperty(
                        value=123
                    ),
                    bin_width=quicksight.CfnDashboard.BinWidthOptionsProperty(
                        bin_count_limit=123,
                        value=123
                    ),
                    selected_bin_type="selectedBinType",
                    start_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b6561e35b100703863a6577e11984bcc9c29eeb96e642b079f44894e6be5ac19)
                check_type(argname="argument bin_count", value=bin_count, expected_type=type_hints["bin_count"])
                check_type(argname="argument bin_width", value=bin_width, expected_type=type_hints["bin_width"])
                check_type(argname="argument selected_bin_type", value=selected_bin_type, expected_type=type_hints["selected_bin_type"])
                check_type(argname="argument start_value", value=start_value, expected_type=type_hints["start_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_count is not None:
                self._values["bin_count"] = bin_count
            if bin_width is not None:
                self._values["bin_width"] = bin_width
            if selected_bin_type is not None:
                self._values["selected_bin_type"] = selected_bin_type
            if start_value is not None:
                self._values["start_value"] = start_value

        @builtins.property
        def bin_count(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BinCountOptionsProperty"]]:
            '''The options that determine the bin count of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html#cfn-quicksight-dashboard-histogrambinoptions-bincount
            '''
            result = self._values.get("bin_count")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BinCountOptionsProperty"]], result)

        @builtins.property
        def bin_width(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BinWidthOptionsProperty"]]:
            '''The options that determine the bin width of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html#cfn-quicksight-dashboard-histogrambinoptions-binwidth
            '''
            result = self._values.get("bin_width")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BinWidthOptionsProperty"]], result)

        @builtins.property
        def selected_bin_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the selected bin type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html#cfn-quicksight-dashboard-histogrambinoptions-selectedbintype
            '''
            result = self._values.get("selected_bin_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def start_value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin start value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html#cfn-quicksight-dashboard-histogrambinoptions-startvalue
            '''
            result = self._values.get("start_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramBinOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.HistogramConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bin_options": "binOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
            "y_axis_display_options": "yAxisDisplayOptions",
        },
    )
    class HistogramConfigurationProperty:
        def __init__(
            self,
            *,
            bin_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.HistogramBinOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.HistogramFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``HistogramVisual`` .

            :param bin_options: The options that determine the presentation of histogram bins.
            :param data_labels: The data label configuration of a histogram.
            :param field_wells: The field well configuration of a histogram.
            :param tooltip: The tooltip configuration of a histogram.
            :param visual_palette: The visual palette configuration of a histogram.
            :param x_axis_display_options: The options that determine the presentation of the x-axis.
            :param x_axis_label_options: The options that determine the presentation of the x-axis label.
            :param y_axis_display_options: The options that determine the presentation of the y-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__55fb22b8f131ca0355cf2363ede9227a9566eaf41711d6e583a7548354ee63e7)
                check_type(argname="argument bin_options", value=bin_options, expected_type=type_hints["bin_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
                check_type(argname="argument y_axis_display_options", value=y_axis_display_options, expected_type=type_hints["y_axis_display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_options is not None:
                self._values["bin_options"] = bin_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options
            if y_axis_display_options is not None:
                self._values["y_axis_display_options"] = y_axis_display_options

        @builtins.property
        def bin_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HistogramBinOptionsProperty"]]:
            '''The options that determine the presentation of histogram bins.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-binoptions
            '''
            result = self._values.get("bin_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HistogramBinOptionsProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The data label configuration of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HistogramFieldWellsProperty"]]:
            '''The field well configuration of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HistogramFieldWellsProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]]:
            '''The visual palette configuration of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-yaxisdisplayoptions
            '''
            result = self._values.get("y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.HistogramFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "histogram_aggregated_field_wells": "histogramAggregatedFieldWells",
        },
    )
    class HistogramFieldWellsProperty:
        def __init__(
            self,
            *,
            histogram_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.HistogramAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a histogram.

            :param histogram_aggregated_field_wells: The field well configuration of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                histogram_field_wells_property = quicksight.CfnDashboard.HistogramFieldWellsProperty(
                    histogram_aggregated_field_wells=quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty(
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a57245b80f90a48fe9bc98fd8ba608c332cd9005ea0a92838c1e75a7714eff68)
                check_type(argname="argument histogram_aggregated_field_wells", value=histogram_aggregated_field_wells, expected_type=type_hints["histogram_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if histogram_aggregated_field_wells is not None:
                self._values["histogram_aggregated_field_wells"] = histogram_aggregated_field_wells

        @builtins.property
        def histogram_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HistogramAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramfieldwells.html#cfn-quicksight-dashboard-histogramfieldwells-histogramaggregatedfieldwells
            '''
            result = self._values.get("histogram_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HistogramAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.HistogramVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class HistogramVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.HistogramConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A histogram.

            For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration for a ``HistogramVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__78952f3cbccea943cf440ea987f75700f709d9dd4fc6a9dac06b7492108a6a11)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HistogramConfigurationProperty"]]:
            '''The configuration for a ``HistogramVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HistogramConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.InsightConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computations": "computations",
            "custom_narrative": "customNarrative",
        },
    )
    class InsightConfigurationProperty:
        def __init__(
            self,
            *,
            computations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ComputationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            custom_narrative: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CustomNarrativeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of an insight visual.

            :param computations: The computations configurations of the insight visual.
            :param custom_narrative: The custom narrative of the insight visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8235743ecc0286b79753dfcdda1de4970acead6aaa3259160c576abc6de630fc)
                check_type(argname="argument computations", value=computations, expected_type=type_hints["computations"])
                check_type(argname="argument custom_narrative", value=custom_narrative, expected_type=type_hints["custom_narrative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if computations is not None:
                self._values["computations"] = computations
            if custom_narrative is not None:
                self._values["custom_narrative"] = custom_narrative

        @builtins.property
        def computations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ComputationProperty"]]]]:
            '''The computations configurations of the insight visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightconfiguration.html#cfn-quicksight-dashboard-insightconfiguration-computations
            '''
            result = self._values.get("computations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ComputationProperty"]]]], result)

        @builtins.property
        def custom_narrative(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomNarrativeOptionsProperty"]]:
            '''The custom narrative of the insight visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightconfiguration.html#cfn-quicksight-dashboard-insightconfiguration-customnarrative
            '''
            result = self._values.get("custom_narrative")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomNarrativeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "InsightConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.InsightVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
            "insight_configuration": "insightConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class InsightVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            insight_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.InsightConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''An insight visual.

            For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .

            :param data_set_identifier: The dataset that is used in the insight visual.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param insight_configuration: The configuration of an insight visual.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b6a7019df5bf36ddbab4f46b699320b02f7a35b0bbc6000e7642677af41bbe97)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument insight_configuration", value=insight_configuration, expected_type=type_hints["insight_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if insight_configuration is not None:
                self._values["insight_configuration"] = insight_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The dataset that is used in the insight visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def insight_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.InsightConfigurationProperty"]]:
            '''The configuration of an insight visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-insightconfiguration
            '''
            result = self._values.get("insight_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.InsightConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "InsightVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.IntegerDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class IntegerDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
        ) -> None:
            '''The default values of the ``IntegerParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``IntegerDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``IntegerDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                integer_default_values_property = quicksight.CfnDashboard.IntegerDefaultValuesProperty(
                    dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ccb4695c74fd56c3b39e1050d3ae136fcdcaf4af35bc03fed020ce96607802bb)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``IntegerDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerdefaultvalues.html#cfn-quicksight-dashboard-integerdefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def static_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]]:
            '''The static values of the ``IntegerDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerdefaultvalues.html#cfn-quicksight-dashboard-integerdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.IntegerParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class IntegerParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.IntegerDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.IntegerValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``Integer`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: 
            :param value_when_unset: A parameter declaration for the ``Integer`` data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                integer_parameter_declaration_property = quicksight.CfnDashboard.IntegerParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnDashboard.IntegerDefaultValuesProperty(
                        dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=[123]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnDashboard.IntegerValueWhenUnsetConfigurationProperty(
                        custom_value=123,
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bf138192dc9283275cb3acece8f0b5e40e3ab00313635a18480433bb8a70c44b)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.IntegerDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.IntegerDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MappedDataSetParameterProperty"]]]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.IntegerValueWhenUnsetConfigurationProperty"]]:
            '''A parameter declaration for the ``Integer`` data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.IntegerValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.IntegerParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class IntegerParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]],
        ) -> None:
            '''An integer parameter.

            :param name: The name of the integer parameter.
            :param values: The values for the integer parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                integer_parameter_property = quicksight.CfnDashboard.IntegerParameterProperty(
                    name="name",
                    values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ddb7a0b570f94a09892a440b237a12441b8b493eb0917532a86339b9a5651ff4)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the integer parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameter.html#cfn-quicksight-dashboard-integerparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]:
            '''The values for the integer parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameter.html#cfn-quicksight-dashboard-integerparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.IntegerValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class IntegerValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[jsii.Number] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A parameter declaration for the ``Integer`` data type.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integervaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                integer_value_when_unset_configuration_property = quicksight.CfnDashboard.IntegerValueWhenUnsetConfigurationProperty(
                    custom_value=123,
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5d720c615e5ea3ac62477a614355b7d8007940696895b128072d21154ae8a95c)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[jsii.Number]:
            '''A custom value that's used when the value of a parameter isn't set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integervaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-integervaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integervaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-integervaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ItemsLimitConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "items_limit": "itemsLimit",
            "other_categories": "otherCategories",
        },
    )
    class ItemsLimitConfigurationProperty:
        def __init__(
            self,
            *,
            items_limit: typing.Optional[jsii.Number] = None,
            other_categories: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The limit configuration of the visual display for an axis.

            :param items_limit: The limit on how many items of a field are showed in the chart. For example, the number of slices that are displayed in a pie chart.
            :param other_categories: The ``Show other`` of an axis in the chart. Choose one of the following options:. - ``INCLUDE`` - ``EXCLUDE``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-itemslimitconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                items_limit_configuration_property = quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                    items_limit=123,
                    other_categories="otherCategories"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__62652aaab644d6381c34df14cdb253620c9017787c2daa67a97c79a88afda818)
                check_type(argname="argument items_limit", value=items_limit, expected_type=type_hints["items_limit"])
                check_type(argname="argument other_categories", value=other_categories, expected_type=type_hints["other_categories"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if items_limit is not None:
                self._values["items_limit"] = items_limit
            if other_categories is not None:
                self._values["other_categories"] = other_categories

        @builtins.property
        def items_limit(self) -> typing.Optional[jsii.Number]:
            '''The limit on how many items of a field are showed in the chart.

            For example, the number of slices that are displayed in a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-itemslimitconfiguration.html#cfn-quicksight-dashboard-itemslimitconfiguration-itemslimit
            '''
            result = self._values.get("items_limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def other_categories(self) -> typing.Optional[builtins.str]:
            '''The ``Show other`` of an axis in the chart. Choose one of the following options:.

            - ``INCLUDE``
            - ``EXCLUDE``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-itemslimitconfiguration.html#cfn-quicksight-dashboard-itemslimitconfiguration-othercategories
            '''
            result = self._values.get("other_categories")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ItemsLimitConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.KPIActualValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class KPIActualValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the actual value of a KPI visual.

            :param icon: The conditional formatting of the actual value's icon.
            :param text_color: The conditional formatting of the actual value's text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiactualvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIActual_value_conditional_formatting_property = quicksight.CfnDashboard.KPIActualValueConditionalFormattingProperty(
                    icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__919a286d11388cef9537fdc99786898889b85fc6f3875b56f0e6305dfa083ae9)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting of the actual value's icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiactualvalueconditionalformatting.html#cfn-quicksight-dashboard-kpiactualvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the actual value's text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiactualvalueconditionalformatting.html#cfn-quicksight-dashboard-kpiactualvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIActualValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.KPIComparisonValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class KPIComparisonValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the comparison value of a KPI visual.

            :param icon: The conditional formatting of the comparison value's icon.
            :param text_color: The conditional formatting of the comparison value's text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpicomparisonvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIComparison_value_conditional_formatting_property = quicksight.CfnDashboard.KPIComparisonValueConditionalFormattingProperty(
                    icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3c10a5ebe510e02cb10399ecb639ce46b626d86fb5843157da57238e274fc67f)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting of the comparison value's icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpicomparisonvalueconditionalformatting.html#cfn-quicksight-dashboard-kpicomparisonvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the comparison value's text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpicomparisonvalueconditionalformatting.html#cfn-quicksight-dashboard-kpicomparisonvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIComparisonValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.KPIConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "actual_value": "actualValue",
            "comparison_value": "comparisonValue",
            "primary_value": "primaryValue",
            "progress_bar": "progressBar",
        },
    )
    class KPIConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            actual_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.KPIActualValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            comparison_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.KPIComparisonValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.KPIPrimaryValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            progress_bar: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.KPIProgressBarConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting options of a KPI visual.

            :param actual_value: The conditional formatting for the actual value of a KPI visual.
            :param comparison_value: The conditional formatting for the comparison value of a KPI visual.
            :param primary_value: The conditional formatting for the primary value of a KPI visual.
            :param progress_bar: The conditional formatting for the progress bar of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIConditional_formatting_option_property = quicksight.CfnDashboard.KPIConditionalFormattingOptionProperty(
                    actual_value=quicksight.CfnDashboard.KPIActualValueConditionalFormattingProperty(
                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    comparison_value=quicksight.CfnDashboard.KPIComparisonValueConditionalFormattingProperty(
                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    primary_value=quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty(
                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    progress_bar=quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty(
                        foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__054ca1d8afce6838bbd147fe7ef428987b8990694493d50a2c27acfa33440267)
                check_type(argname="argument actual_value", value=actual_value, expected_type=type_hints["actual_value"])
                check_type(argname="argument comparison_value", value=comparison_value, expected_type=type_hints["comparison_value"])
                check_type(argname="argument primary_value", value=primary_value, expected_type=type_hints["primary_value"])
                check_type(argname="argument progress_bar", value=progress_bar, expected_type=type_hints["progress_bar"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if actual_value is not None:
                self._values["actual_value"] = actual_value
            if comparison_value is not None:
                self._values["comparison_value"] = comparison_value
            if primary_value is not None:
                self._values["primary_value"] = primary_value
            if progress_bar is not None:
                self._values["progress_bar"] = progress_bar

        @builtins.property
        def actual_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIActualValueConditionalFormattingProperty"]]:
            '''The conditional formatting for the actual value of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformattingoption.html#cfn-quicksight-dashboard-kpiconditionalformattingoption-actualvalue
            '''
            result = self._values.get("actual_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIActualValueConditionalFormattingProperty"]], result)

        @builtins.property
        def comparison_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIComparisonValueConditionalFormattingProperty"]]:
            '''The conditional formatting for the comparison value of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformattingoption.html#cfn-quicksight-dashboard-kpiconditionalformattingoption-comparisonvalue
            '''
            result = self._values.get("comparison_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIComparisonValueConditionalFormattingProperty"]], result)

        @builtins.property
        def primary_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIPrimaryValueConditionalFormattingProperty"]]:
            '''The conditional formatting for the primary value of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformattingoption.html#cfn-quicksight-dashboard-kpiconditionalformattingoption-primaryvalue
            '''
            result = self._values.get("primary_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIPrimaryValueConditionalFormattingProperty"]], result)

        @builtins.property
        def progress_bar(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIProgressBarConditionalFormattingProperty"]]:
            '''The conditional formatting for the progress bar of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformattingoption.html#cfn-quicksight-dashboard-kpiconditionalformattingoption-progressbar
            '''
            result = self._values.get("progress_bar")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIProgressBarConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.KPIConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class KPIConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.KPIConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting of a KPI visual.

            :param conditional_formatting_options: The conditional formatting options of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIConditional_formatting_property = quicksight.CfnDashboard.KPIConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnDashboard.KPIConditionalFormattingOptionProperty(
                        actual_value=quicksight.CfnDashboard.KPIActualValueConditionalFormattingProperty(
                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        comparison_value=quicksight.CfnDashboard.KPIComparisonValueConditionalFormattingProperty(
                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        primary_value=quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty(
                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        progress_bar=quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty(
                            foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d09139b8ba0d36404275bbaaa9d5c0754a9a5d5d6e7f73f9aad683dcef24dfd3)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIConditionalFormattingOptionProperty"]]]]:
            '''The conditional formatting options of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformatting.html#cfn-quicksight-dashboard-kpiconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.KPIConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "kpi_options": "kpiOptions",
            "sort_configuration": "sortConfiguration",
        },
    )
    class KPIConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.KPIFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            kpi_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.KPIOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.KPISortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a KPI visual.

            :param field_wells: The field well configuration of a KPI visual.
            :param kpi_options: The options that determine the presentation of a KPI visual.
            :param sort_configuration: The sort configuration of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9159fd9adf82ef769630d8281064cd20f26eb2741b067214d01dcf1dc1516e8f)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument kpi_options", value=kpi_options, expected_type=type_hints["kpi_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if kpi_options is not None:
                self._values["kpi_options"] = kpi_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIFieldWellsProperty"]]:
            '''The field well configuration of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconfiguration.html#cfn-quicksight-dashboard-kpiconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIFieldWellsProperty"]], result)

        @builtins.property
        def kpi_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIOptionsProperty"]]:
            '''The options that determine the presentation of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconfiguration.html#cfn-quicksight-dashboard-kpiconfiguration-kpioptions
            '''
            result = self._values.get("kpi_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPISortConfigurationProperty"]]:
            '''The sort configuration of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconfiguration.html#cfn-quicksight-dashboard-kpiconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPISortConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.KPIFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "target_values": "targetValues",
            "trend_groups": "trendGroups",
            "values": "values",
        },
    )
    class KPIFieldWellsProperty:
        def __init__(
            self,
            *,
            target_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            trend_groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a KPI visual.

            :param target_values: The target value field wells of a KPI visual.
            :param trend_groups: The trend group field wells of a KPI visual.
            :param values: The value field wells of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpifieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__28b222716791c98b68a10fdc386c86011553fce98c9bcf9f05df0a77ebd3c794)
                check_type(argname="argument target_values", value=target_values, expected_type=type_hints["target_values"])
                check_type(argname="argument trend_groups", value=trend_groups, expected_type=type_hints["trend_groups"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_values is not None:
                self._values["target_values"] = target_values
            if trend_groups is not None:
                self._values["trend_groups"] = trend_groups
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def target_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The target value field wells of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpifieldwells.html#cfn-quicksight-dashboard-kpifieldwells-targetvalues
            '''
            result = self._values.get("target_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        @builtins.property
        def trend_groups(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The trend group field wells of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpifieldwells.html#cfn-quicksight-dashboard-kpifieldwells-trendgroups
            '''
            result = self._values.get("trend_groups")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The value field wells of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpifieldwells.html#cfn-quicksight-dashboard-kpifieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.KPIOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "comparison": "comparison",
            "primary_value_display_type": "primaryValueDisplayType",
            "primary_value_font_configuration": "primaryValueFontConfiguration",
            "progress_bar": "progressBar",
            "secondary_value": "secondaryValue",
            "secondary_value_font_configuration": "secondaryValueFontConfiguration",
            "sparkline": "sparkline",
            "trend_arrows": "trendArrows",
            "visual_layout_options": "visualLayoutOptions",
        },
    )
    class KPIOptionsProperty:
        def __init__(
            self,
            *,
            comparison: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ComparisonConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_value_display_type: typing.Optional[builtins.str] = None,
            primary_value_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            progress_bar: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ProgressBarOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SecondaryValueOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_value_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sparkline: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.KPISparklineOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            trend_arrows: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TrendArrowOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_layout_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.KPIVisualLayoutOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of a KPI visual.

            :param comparison: The comparison configuration of a KPI visual.
            :param primary_value_display_type: The options that determine the primary value display type.
            :param primary_value_font_configuration: The options that determine the primary value font configuration.
            :param progress_bar: The options that determine the presentation of the progress bar of a KPI visual.
            :param secondary_value: The options that determine the presentation of the secondary value of a KPI visual.
            :param secondary_value_font_configuration: The options that determine the secondary value font configuration.
            :param sparkline: The options that determine the visibility, color, type, and tooltip visibility of the sparkline of a KPI visual.
            :param trend_arrows: The options that determine the presentation of trend arrows in a KPI visual.
            :param visual_layout_options: The options that determine the layout a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIOptions_property = quicksight.CfnDashboard.KPIOptionsProperty(
                    comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                        comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        comparison_method="comparisonMethod"
                    ),
                    primary_value_display_type="primaryValueDisplayType",
                    primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    progress_bar=quicksight.CfnDashboard.ProgressBarOptionsProperty(
                        visibility="visibility"
                    ),
                    secondary_value=quicksight.CfnDashboard.SecondaryValueOptionsProperty(
                        visibility="visibility"
                    ),
                    secondary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    sparkline=quicksight.CfnDashboard.KPISparklineOptionsProperty(
                        type="type",
                
                        # the properties below are optional
                        color="color",
                        tooltip_visibility="tooltipVisibility",
                        visibility="visibility"
                    ),
                    trend_arrows=quicksight.CfnDashboard.TrendArrowOptionsProperty(
                        visibility="visibility"
                    ),
                    visual_layout_options=quicksight.CfnDashboard.KPIVisualLayoutOptionsProperty(
                        standard_layout=quicksight.CfnDashboard.KPIVisualStandardLayoutProperty(
                            type="type"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__59853c403e669ab17e13d6f88be86de38bedce05a11c9ccf87f43262aaa7e8d8)
                check_type(argname="argument comparison", value=comparison, expected_type=type_hints["comparison"])
                check_type(argname="argument primary_value_display_type", value=primary_value_display_type, expected_type=type_hints["primary_value_display_type"])
                check_type(argname="argument primary_value_font_configuration", value=primary_value_font_configuration, expected_type=type_hints["primary_value_font_configuration"])
                check_type(argname="argument progress_bar", value=progress_bar, expected_type=type_hints["progress_bar"])
                check_type(argname="argument secondary_value", value=secondary_value, expected_type=type_hints["secondary_value"])
                check_type(argname="argument secondary_value_font_configuration", value=secondary_value_font_configuration, expected_type=type_hints["secondary_value_font_configuration"])
                check_type(argname="argument sparkline", value=sparkline, expected_type=type_hints["sparkline"])
                check_type(argname="argument trend_arrows", value=trend_arrows, expected_type=type_hints["trend_arrows"])
                check_type(argname="argument visual_layout_options", value=visual_layout_options, expected_type=type_hints["visual_layout_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if comparison is not None:
                self._values["comparison"] = comparison
            if primary_value_display_type is not None:
                self._values["primary_value_display_type"] = primary_value_display_type
            if primary_value_font_configuration is not None:
                self._values["primary_value_font_configuration"] = primary_value_font_configuration
            if progress_bar is not None:
                self._values["progress_bar"] = progress_bar
            if secondary_value is not None:
                self._values["secondary_value"] = secondary_value
            if secondary_value_font_configuration is not None:
                self._values["secondary_value_font_configuration"] = secondary_value_font_configuration
            if sparkline is not None:
                self._values["sparkline"] = sparkline
            if trend_arrows is not None:
                self._values["trend_arrows"] = trend_arrows
            if visual_layout_options is not None:
                self._values["visual_layout_options"] = visual_layout_options

        @builtins.property
        def comparison(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ComparisonConfigurationProperty"]]:
            '''The comparison configuration of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-comparison
            '''
            result = self._values.get("comparison")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ComparisonConfigurationProperty"]], result)

        @builtins.property
        def primary_value_display_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the primary value display type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-primaryvaluedisplaytype
            '''
            result = self._values.get("primary_value_display_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"]]:
            '''The options that determine the primary value font configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-primaryvaluefontconfiguration
            '''
            result = self._values.get("primary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"]], result)

        @builtins.property
        def progress_bar(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ProgressBarOptionsProperty"]]:
            '''The options that determine the presentation of the progress bar of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-progressbar
            '''
            result = self._values.get("progress_bar")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ProgressBarOptionsProperty"]], result)

        @builtins.property
        def secondary_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SecondaryValueOptionsProperty"]]:
            '''The options that determine the presentation of the secondary value of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-secondaryvalue
            '''
            result = self._values.get("secondary_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SecondaryValueOptionsProperty"]], result)

        @builtins.property
        def secondary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"]]:
            '''The options that determine the secondary value font configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-secondaryvaluefontconfiguration
            '''
            result = self._values.get("secondary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"]], result)

        @builtins.property
        def sparkline(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPISparklineOptionsProperty"]]:
            '''The options that determine the visibility, color, type, and tooltip visibility of the sparkline of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-sparkline
            '''
            result = self._values.get("sparkline")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPISparklineOptionsProperty"]], result)

        @builtins.property
        def trend_arrows(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TrendArrowOptionsProperty"]]:
            '''The options that determine the presentation of trend arrows in a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-trendarrows
            '''
            result = self._values.get("trend_arrows")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TrendArrowOptionsProperty"]], result)

        @builtins.property
        def visual_layout_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIVisualLayoutOptionsProperty"]]:
            '''The options that determine the layout a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-visuallayoutoptions
            '''
            result = self._values.get("visual_layout_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIVisualLayoutOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class KPIPrimaryValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the primary value of a KPI visual.

            :param icon: The conditional formatting of the primary value's icon.
            :param text_color: The conditional formatting of the primary value's text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprimaryvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIPrimary_value_conditional_formatting_property = quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty(
                    icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b7f3446d8e2592c7e0ebc309a027eb735d94e3c3d6e90d988c2627118831e564)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting of the primary value's icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-dashboard-kpiprimaryvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the primary value's text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-dashboard-kpiprimaryvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIPrimaryValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"foreground_color": "foregroundColor"},
    )
    class KPIProgressBarConditionalFormattingProperty:
        def __init__(
            self,
            *,
            foreground_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the progress bar of a KPI visual.

            :param foreground_color: The conditional formatting of the progress bar's foreground color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprogressbarconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIProgress_bar_conditional_formatting_property = quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty(
                    foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__00958e997d3d3d1685c892bb73fd4e9829d963d1d7d3960a66b1dbb4e4c97cb5)
                check_type(argname="argument foreground_color", value=foreground_color, expected_type=type_hints["foreground_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if foreground_color is not None:
                self._values["foreground_color"] = foreground_color

        @builtins.property
        def foreground_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the progress bar's foreground color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprogressbarconditionalformatting.html#cfn-quicksight-dashboard-kpiprogressbarconditionalformatting-foregroundcolor
            '''
            result = self._values.get("foreground_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIProgressBarConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.KPISortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"trend_group_sort": "trendGroupSort"},
    )
    class KPISortConfigurationProperty:
        def __init__(
            self,
            *,
            trend_group_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a KPI visual.

            :param trend_group_sort: The sort configuration of the trend group fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpisortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pISort_configuration_property = quicksight.CfnDashboard.KPISortConfigurationProperty(
                    trend_group_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__830e3123ef066906448dfaa37c5cc66f39a978b0ec1a8616349a89766eb2d1db)
                check_type(argname="argument trend_group_sort", value=trend_group_sort, expected_type=type_hints["trend_group_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if trend_group_sort is not None:
                self._values["trend_group_sort"] = trend_group_sort

        @builtins.property
        def trend_group_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the trend group fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpisortconfiguration.html#cfn-quicksight-dashboard-kpisortconfiguration-trendgroupsort
            '''
            result = self._values.get("trend_group_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPISortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.KPISparklineOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "type": "type",
            "color": "color",
            "tooltip_visibility": "tooltipVisibility",
            "visibility": "visibility",
        },
    )
    class KPISparklineOptionsProperty:
        def __init__(
            self,
            *,
            type: builtins.str,
            color: typing.Optional[builtins.str] = None,
            tooltip_visibility: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the visibility, color, type, and tooltip visibility of the sparkline of a KPI visual.

            :param type: The type of the sparkline.
            :param color: The color of the sparkline.
            :param tooltip_visibility: The tooltip visibility of the sparkline.
            :param visibility: The visibility of the sparkline.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpisparklineoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pISparkline_options_property = quicksight.CfnDashboard.KPISparklineOptionsProperty(
                    type="type",
                
                    # the properties below are optional
                    color="color",
                    tooltip_visibility="tooltipVisibility",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__663aba93d0b6c71a0c5ce59ead14a6dc298172e3c9f326b0ffda40298b8980bf)
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument tooltip_visibility", value=tooltip_visibility, expected_type=type_hints["tooltip_visibility"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "type": type,
            }
            if color is not None:
                self._values["color"] = color
            if tooltip_visibility is not None:
                self._values["tooltip_visibility"] = tooltip_visibility
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def type(self) -> builtins.str:
            '''The type of the sparkline.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpisparklineoptions.html#cfn-quicksight-dashboard-kpisparklineoptions-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color of the sparkline.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpisparklineoptions.html#cfn-quicksight-dashboard-kpisparklineoptions-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tooltip_visibility(self) -> typing.Optional[builtins.str]:
            '''The tooltip visibility of the sparkline.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpisparklineoptions.html#cfn-quicksight-dashboard-kpisparklineoptions-tooltipvisibility
            '''
            result = self._values.get("tooltip_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the sparkline.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpisparklineoptions.html#cfn-quicksight-dashboard-kpisparklineoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPISparklineOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.KPIVisualLayoutOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"standard_layout": "standardLayout"},
    )
    class KPIVisualLayoutOptionsProperty:
        def __init__(
            self,
            *,
            standard_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.KPIVisualStandardLayoutProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the layout a KPI visual.

            :param standard_layout: The standard layout of the KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisuallayoutoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIVisual_layout_options_property = quicksight.CfnDashboard.KPIVisualLayoutOptionsProperty(
                    standard_layout=quicksight.CfnDashboard.KPIVisualStandardLayoutProperty(
                        type="type"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b3863a82f0561bdb9b66f36a181b4bf3558c5e1d26ac7d046102aa3cf6a4b22a)
                check_type(argname="argument standard_layout", value=standard_layout, expected_type=type_hints["standard_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if standard_layout is not None:
                self._values["standard_layout"] = standard_layout

        @builtins.property
        def standard_layout(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIVisualStandardLayoutProperty"]]:
            '''The standard layout of the KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisuallayoutoptions.html#cfn-quicksight-dashboard-kpivisuallayoutoptions-standardlayout
            '''
            result = self._values.get("standard_layout")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIVisualStandardLayoutProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIVisualLayoutOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.KPIVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class KPIVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.KPIConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.KPIConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A key performance indicator (KPI).

            For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a KPI visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param conditional_formatting: The conditional formatting of a KPI visual.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e7b926a06aee010f1ae9cc3385634ef06b770bfdeb88431b5e104610f5aac99d)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIConfigurationProperty"]]:
            '''The configuration of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIConditionalFormattingProperty"]]:
            '''The conditional formatting of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.KPIVisualStandardLayoutProperty",
        jsii_struct_bases=[],
        name_mapping={"type": "type"},
    )
    class KPIVisualStandardLayoutProperty:
        def __init__(self, *, type: builtins.str) -> None:
            '''The standard layout of the KPI visual.

            :param type: The standard layout type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisualstandardlayout.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIVisual_standard_layout_property = quicksight.CfnDashboard.KPIVisualStandardLayoutProperty(
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f172711b23d093cf923c9ef61a740b893f564403053d124223b83bab08c6723f)
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "type": type,
            }

        @builtins.property
        def type(self) -> builtins.str:
            '''The standard layout type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisualstandardlayout.html#cfn-quicksight-dashboard-kpivisualstandardlayout-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIVisualStandardLayoutProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.LabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "font_configuration": "fontConfiguration",
            "visibility": "visibility",
        },
    )
    class LabelOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The share label options for the labels.

            :param custom_label: The text for the label.
            :param font_configuration: The font configuration of the label.
            :param visibility: Determines whether or not the label is visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-labeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                label_options_property = quicksight.CfnDashboard.LabelOptionsProperty(
                    custom_label="customLabel",
                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ed3aea282a5c2eb2cd77ddf8885ac91a026dcc243dc633f7e35b5b626157d81a)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The text for the label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-labeloptions.html#cfn-quicksight-dashboard-labeloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"]]:
            '''The font configuration of the label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-labeloptions.html#cfn-quicksight-dashboard-labeloptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the label is visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-labeloptions.html#cfn-quicksight-dashboard-labeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.LayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "free_form_layout": "freeFormLayout",
            "grid_layout": "gridLayout",
            "section_based_layout": "sectionBasedLayout",
        },
    )
    class LayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FreeFormLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            grid_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            section_based_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SectionBasedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration that determines what the type of layout will be used on a sheet.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param free_form_layout: A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.
            :param grid_layout: A type of layout that can be used on a sheet. In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: ``FIXED`` or ``RESPONSIVE`` .
            :param section_based_layout: A section based layout organizes visuals into multiple sections and has customized header, footer and page break.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                layout_configuration_property = quicksight.CfnDashboard.LayoutConfigurationProperty(
                    free_form_layout=quicksight.CfnDashboard.FreeFormLayoutConfigurationProperty(
                        elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                            element_id="elementId",
                            element_type="elementType",
                            height="height",
                            width="width",
                            x_axis_location="xAxisLocation",
                            y_axis_location="yAxisLocation",
                
                            # the properties below are optional
                            background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                visibility="visibility"
                            ),
                            rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                    visibility="visibility"
                                ),
                                expression="expression"
                            )],
                            selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            visibility="visibility"
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                        elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                            column_span=123,
                            element_id="elementId",
                            element_type="elementType",
                            row_span=123,
                
                            # the properties below are optional
                            column_index=123,
                            row_index=123
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    section_based_layout=quicksight.CfnDashboard.SectionBasedLayoutConfigurationProperty(
                        body_sections=[quicksight.CfnDashboard.BodySectionConfigurationProperty(
                            content=quicksight.CfnDashboard.BodySectionContentProperty(
                                layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            page_break_configuration=quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                                after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                                    status="status"
                                )
                            ),
                            style=quicksight.CfnDashboard.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnDashboard.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )],
                        canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                            paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                ),
                                paper_orientation="paperOrientation",
                                paper_size="paperSize"
                            )
                        ),
                        footer_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                            layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            style=quicksight.CfnDashboard.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnDashboard.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )],
                        header_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                            layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            style=quicksight.CfnDashboard.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnDashboard.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__41d36737cec4c19d32ca9ef9050db8ac9846f44bf5cd395414df4eda7b29b2d1)
                check_type(argname="argument free_form_layout", value=free_form_layout, expected_type=type_hints["free_form_layout"])
                check_type(argname="argument grid_layout", value=grid_layout, expected_type=type_hints["grid_layout"])
                check_type(argname="argument section_based_layout", value=section_based_layout, expected_type=type_hints["section_based_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if free_form_layout is not None:
                self._values["free_form_layout"] = free_form_layout
            if grid_layout is not None:
                self._values["grid_layout"] = grid_layout
            if section_based_layout is not None:
                self._values["section_based_layout"] = section_based_layout

        @builtins.property
        def free_form_layout(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FreeFormLayoutConfigurationProperty"]]:
            '''A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layoutconfiguration.html#cfn-quicksight-dashboard-layoutconfiguration-freeformlayout
            '''
            result = self._values.get("free_form_layout")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FreeFormLayoutConfigurationProperty"]], result)

        @builtins.property
        def grid_layout(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GridLayoutConfigurationProperty"]]:
            '''A type of layout that can be used on a sheet.

            In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: ``FIXED`` or ``RESPONSIVE`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layoutconfiguration.html#cfn-quicksight-dashboard-layoutconfiguration-gridlayout
            '''
            result = self._values.get("grid_layout")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GridLayoutConfigurationProperty"]], result)

        @builtins.property
        def section_based_layout(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SectionBasedLayoutConfigurationProperty"]]:
            '''A section based layout organizes visuals into multiple sections and has customized header, footer and page break.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layoutconfiguration.html#cfn-quicksight-dashboard-layoutconfiguration-sectionbasedlayout
            '''
            result = self._values.get("section_based_layout")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SectionBasedLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.LayoutProperty",
        jsii_struct_bases=[],
        name_mapping={"configuration": "configuration"},
    )
    class LayoutProperty:
        def __init__(
            self,
            *,
            configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''A ``Layout`` defines the placement of elements within a sheet.

            For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param configuration: The configuration that determines what the type of layout for a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layout.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                layout_property = quicksight.CfnDashboard.LayoutProperty(
                    configuration=quicksight.CfnDashboard.LayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnDashboard.FreeFormLayoutConfigurationProperty(
                            elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                            elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                column_span=123,
                                element_id="elementId",
                                element_type="elementType",
                                row_span=123,
                
                                # the properties below are optional
                                column_index=123,
                                row_index=123
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        section_based_layout=quicksight.CfnDashboard.SectionBasedLayoutConfigurationProperty(
                            body_sections=[quicksight.CfnDashboard.BodySectionConfigurationProperty(
                                content=quicksight.CfnDashboard.BodySectionContentProperty(
                                    layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
                
                                                # the properties below are optional
                                                background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                page_break_configuration=quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                                    after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                                        status="status"
                                    )
                                ),
                                style=quicksight.CfnDashboard.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnDashboard.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )],
                            canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                    paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    ),
                                    paper_orientation="paperOrientation",
                                    paper_size="paperSize"
                                )
                            ),
                            footer_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                style=quicksight.CfnDashboard.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnDashboard.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )],
                            header_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                style=quicksight.CfnDashboard.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnDashboard.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1e55b9832974289c97fcd95560d0704a4b3f8f52a5d295492fe6420a37a16789)
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration": configuration,
            }

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.LayoutConfigurationProperty"]:
            '''The configuration that determines what the type of layout for a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layout.html#cfn-quicksight-dashboard-layout-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.LayoutConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LayoutProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.LegendOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "height": "height",
            "position": "position",
            "title": "title",
            "visibility": "visibility",
            "width": "width",
        },
    )
    class LegendOptionsProperty:
        def __init__(
            self,
            *,
            height: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for the legend setup of a visual.

            :param height: The height of the legend. If this value is omitted, a default height is used when rendering.
            :param position: The positions for the legend. Choose one of the following options:. - ``AUTO`` - ``RIGHT`` - ``BOTTOM`` - ``LEFT``
            :param title: The custom title for the legend.
            :param visibility: Determines whether or not the legend is visible.
            :param width: The width of the legend. If this value is omitted, a default width is used when rendering.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                legend_options_property = quicksight.CfnDashboard.LegendOptionsProperty(
                    height="height",
                    position="position",
                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    ),
                    visibility="visibility",
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8e82b7d2caeb5e63fcc81af6545407f35a2d85c92fe4afa322baa617613486b6)
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if height is not None:
                self._values["height"] = height
            if position is not None:
                self._values["position"] = position
            if title is not None:
                self._values["title"] = title
            if visibility is not None:
                self._values["visibility"] = visibility
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def height(self) -> typing.Optional[builtins.str]:
            '''The height of the legend.

            If this value is omitted, a default height is used when rendering.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''The positions for the legend. Choose one of the following options:.

            - ``AUTO``
            - ``RIGHT``
            - ``BOTTOM``
            - ``LEFT``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LabelOptionsProperty"]]:
            '''The custom title for the legend.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LabelOptionsProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the legend is visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width of the legend.

            If this value is omitted, a default width is used when rendering.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LegendOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.LineChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "colors": "colors",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class LineChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a line chart.

            :param category: The category field wells of a line chart. Values are grouped by category fields.
            :param colors: The color field wells of a line chart. Values are grouped by category fields.
            :param small_multiples: The small multiples field well of a line chart.
            :param values: The value field wells of a line chart. Values are aggregated based on categories.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3eb579202bb305cf3c724f33e50675ec7fc5dc6959c987e3851d5837f580e609)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The category field wells of a line chart.

            Values are grouped by category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html#cfn-quicksight-dashboard-linechartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The color field wells of a line chart.

            Values are grouped by category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html#cfn-quicksight-dashboard-linechartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The small multiples field well of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html#cfn-quicksight-dashboard-linechartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The value field wells of a line chart.

            Values are aggregated based on categories.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html#cfn-quicksight-dashboard-linechartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.LineChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "default_series_settings": "defaultSeriesSettings",
            "field_wells": "fieldWells",
            "forecast_configurations": "forecastConfigurations",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "secondary_y_axis_display_options": "secondaryYAxisDisplayOptions",
            "secondary_y_axis_label_options": "secondaryYAxisLabelOptions",
            "series": "series",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "type": "type",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
        },
    )
    class LineChartConfigurationProperty:
        def __init__(
            self,
            *,
            contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            default_series_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LineChartDefaultSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LineChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            forecast_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ForecastConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LineSeriesAxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            secondary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LineSeriesAxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            series: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SeriesItemProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LineChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a line chart.

            :param contribution_analysis_defaults: The default configuration of a line chart's contribution analysis.
            :param data_labels: The data label configuration of a line chart.
            :param default_series_settings: The options that determine the default presentation of all line series in ``LineChartVisual`` .
            :param field_wells: The field well configuration of a line chart.
            :param forecast_configurations: The forecast configuration of a line chart.
            :param legend: The legend configuration of a line chart.
            :param primary_y_axis_display_options: The series axis configuration of a line chart.
            :param primary_y_axis_label_options: The options that determine the presentation of the y-axis label.
            :param reference_lines: The reference lines configuration of a line chart.
            :param secondary_y_axis_display_options: The series axis configuration of a line chart.
            :param secondary_y_axis_label_options: The options that determine the presentation of the secondary y-axis label.
            :param series: The series item configuration of a line chart.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a line chart.
            :param tooltip: The tooltip configuration of a line chart.
            :param type: Determines the type of the line chart.
            :param visual_palette: The visual palette configuration of a line chart.
            :param x_axis_display_options: The options that determine the presentation of the x-axis.
            :param x_axis_label_options: The options that determine the presentation of the x-axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__325e94055957a7a4fa28fbb3ed26c873db36927077f3686d2bb2a695a498a6f2)
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument default_series_settings", value=default_series_settings, expected_type=type_hints["default_series_settings"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument forecast_configurations", value=forecast_configurations, expected_type=type_hints["forecast_configurations"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument secondary_y_axis_display_options", value=secondary_y_axis_display_options, expected_type=type_hints["secondary_y_axis_display_options"])
                check_type(argname="argument secondary_y_axis_label_options", value=secondary_y_axis_label_options, expected_type=type_hints["secondary_y_axis_label_options"])
                check_type(argname="argument series", value=series, expected_type=type_hints["series"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if default_series_settings is not None:
                self._values["default_series_settings"] = default_series_settings
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if forecast_configurations is not None:
                self._values["forecast_configurations"] = forecast_configurations
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if secondary_y_axis_display_options is not None:
                self._values["secondary_y_axis_display_options"] = secondary_y_axis_display_options
            if secondary_y_axis_label_options is not None:
                self._values["secondary_y_axis_label_options"] = secondary_y_axis_label_options
            if series is not None:
                self._values["series"] = series
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if type is not None:
                self._values["type"] = type
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ContributionAnalysisDefaultProperty"]]]]:
            '''The default configuration of a line chart's contribution analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ContributionAnalysisDefaultProperty"]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The data label configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def default_series_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartDefaultSeriesSettingsProperty"]]:
            '''The options that determine the default presentation of all line series in ``LineChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-defaultseriessettings
            '''
            result = self._values.get("default_series_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartDefaultSeriesSettingsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartFieldWellsProperty"]]:
            '''The field well configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartFieldWellsProperty"]], result)

        @builtins.property
        def forecast_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ForecastConfigurationProperty"]]]]:
            '''The forecast configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-forecastconfigurations
            '''
            result = self._values.get("forecast_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ForecastConfigurationProperty"]]]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineSeriesAxisDisplayOptionsProperty"]]:
            '''The series axis configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineSeriesAxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineProperty"]]]]:
            '''The reference lines configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineProperty"]]]], result)

        @builtins.property
        def secondary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineSeriesAxisDisplayOptionsProperty"]]:
            '''The series axis configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-secondaryyaxisdisplayoptions
            '''
            result = self._values.get("secondary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineSeriesAxisDisplayOptionsProperty"]], result)

        @builtins.property
        def secondary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the secondary y-axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-secondaryyaxislabeloptions
            '''
            result = self._values.get("secondary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def series(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SeriesItemProperty"]]]]:
            '''The series item configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-series
            '''
            result = self._values.get("series")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SeriesItemProperty"]]]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SmallMultiplesOptionsProperty"]]:
            '''The small multiples setup for the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SmallMultiplesOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartSortConfigurationProperty"]]:
            '''The sort configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''Determines the type of the line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]]:
            '''The visual palette configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.LineChartDefaultSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "line_style_settings": "lineStyleSettings",
            "marker_style_settings": "markerStyleSettings",
        },
    )
    class LineChartDefaultSeriesSettingsProperty:
        def __init__(
            self,
            *,
            axis_binding: typing.Optional[builtins.str] = None,
            line_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LineChartLineStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            marker_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LineChartMarkerStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the default presentation of all line series in ``LineChartVisual`` .

            :param axis_binding: The axis to which you are binding all line series to.
            :param line_style_settings: Line styles options for all line series in the visual.
            :param marker_style_settings: Marker styles options for all line series in the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartdefaultseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                line_chart_default_series_settings_property = quicksight.CfnDashboard.LineChartDefaultSeriesSettingsProperty(
                    axis_binding="axisBinding",
                    line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                        line_interpolation="lineInterpolation",
                        line_style="lineStyle",
                        line_visibility="lineVisibility",
                        line_width="lineWidth"
                    ),
                    marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                        marker_color="markerColor",
                        marker_shape="markerShape",
                        marker_size="markerSize",
                        marker_visibility="markerVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3cd4b39bb4a67901a51b3654698af1994671e560594c357fb303db580274922f)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument line_style_settings", value=line_style_settings, expected_type=type_hints["line_style_settings"])
                check_type(argname="argument marker_style_settings", value=marker_style_settings, expected_type=type_hints["marker_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_binding is not None:
                self._values["axis_binding"] = axis_binding
            if line_style_settings is not None:
                self._values["line_style_settings"] = line_style_settings
            if marker_style_settings is not None:
                self._values["marker_style_settings"] = marker_style_settings

        @builtins.property
        def axis_binding(self) -> typing.Optional[builtins.str]:
            '''The axis to which you are binding all line series to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartdefaultseriessettings.html#cfn-quicksight-dashboard-linechartdefaultseriessettings-axisbinding
            '''
            result = self._values.get("axis_binding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartLineStyleSettingsProperty"]]:
            '''Line styles options for all line series in the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartdefaultseriessettings.html#cfn-quicksight-dashboard-linechartdefaultseriessettings-linestylesettings
            '''
            result = self._values.get("line_style_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartLineStyleSettingsProperty"]], result)

        @builtins.property
        def marker_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartMarkerStyleSettingsProperty"]]:
            '''Marker styles options for all line series in the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartdefaultseriessettings.html#cfn-quicksight-dashboard-linechartdefaultseriessettings-markerstylesettings
            '''
            result = self._values.get("marker_style_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartMarkerStyleSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartDefaultSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.LineChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_chart_aggregated_field_wells": "lineChartAggregatedFieldWells",
        },
    )
    class LineChartFieldWellsProperty:
        def __init__(
            self,
            *,
            line_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LineChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a line chart.

            :param line_chart_aggregated_field_wells: The field well configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__23c446a0a24491ea27ce9de9e6f8399830bdcd50e00cf3bf9a24d2ada71a484d)
                check_type(argname="argument line_chart_aggregated_field_wells", value=line_chart_aggregated_field_wells, expected_type=type_hints["line_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_chart_aggregated_field_wells is not None:
                self._values["line_chart_aggregated_field_wells"] = line_chart_aggregated_field_wells

        @builtins.property
        def line_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartfieldwells.html#cfn-quicksight-dashboard-linechartfieldwells-linechartaggregatedfieldwells
            '''
            result = self._values.get("line_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.LineChartLineStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_interpolation": "lineInterpolation",
            "line_style": "lineStyle",
            "line_visibility": "lineVisibility",
            "line_width": "lineWidth",
        },
    )
    class LineChartLineStyleSettingsProperty:
        def __init__(
            self,
            *,
            line_interpolation: typing.Optional[builtins.str] = None,
            line_style: typing.Optional[builtins.str] = None,
            line_visibility: typing.Optional[builtins.str] = None,
            line_width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Line styles options for a line series in ``LineChartVisual`` .

            :param line_interpolation: Interpolation style for line series. - ``LINEAR`` : Show as default, linear style. - ``SMOOTH`` : Show as a smooth curve. - ``STEPPED`` : Show steps in line.
            :param line_style: Line style for line series. - ``SOLID`` : Show as a solid line. - ``DOTTED`` : Show as a dotted line. - ``DASHED`` : Show as a dashed line.
            :param line_visibility: Configuration option that determines whether to show the line for the series.
            :param line_width: Width that determines the line thickness.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                line_chart_line_style_settings_property = quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                    line_interpolation="lineInterpolation",
                    line_style="lineStyle",
                    line_visibility="lineVisibility",
                    line_width="lineWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__80f5ae999d7ee0c6716e616c20a253a968cf221318d4f99c2dc28b18c626a598)
                check_type(argname="argument line_interpolation", value=line_interpolation, expected_type=type_hints["line_interpolation"])
                check_type(argname="argument line_style", value=line_style, expected_type=type_hints["line_style"])
                check_type(argname="argument line_visibility", value=line_visibility, expected_type=type_hints["line_visibility"])
                check_type(argname="argument line_width", value=line_width, expected_type=type_hints["line_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_interpolation is not None:
                self._values["line_interpolation"] = line_interpolation
            if line_style is not None:
                self._values["line_style"] = line_style
            if line_visibility is not None:
                self._values["line_visibility"] = line_visibility
            if line_width is not None:
                self._values["line_width"] = line_width

        @builtins.property
        def line_interpolation(self) -> typing.Optional[builtins.str]:
            '''Interpolation style for line series.

            - ``LINEAR`` : Show as default, linear style.
            - ``SMOOTH`` : Show as a smooth curve.
            - ``STEPPED`` : Show steps in line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html#cfn-quicksight-dashboard-linechartlinestylesettings-lineinterpolation
            '''
            result = self._values.get("line_interpolation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_style(self) -> typing.Optional[builtins.str]:
            '''Line style for line series.

            - ``SOLID`` : Show as a solid line.
            - ``DOTTED`` : Show as a dotted line.
            - ``DASHED`` : Show as a dashed line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html#cfn-quicksight-dashboard-linechartlinestylesettings-linestyle
            '''
            result = self._values.get("line_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_visibility(self) -> typing.Optional[builtins.str]:
            '''Configuration option that determines whether to show the line for the series.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html#cfn-quicksight-dashboard-linechartlinestylesettings-linevisibility
            '''
            result = self._values.get("line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_width(self) -> typing.Optional[builtins.str]:
            '''Width that determines the line thickness.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html#cfn-quicksight-dashboard-linechartlinestylesettings-linewidth
            '''
            result = self._values.get("line_width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartLineStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "marker_color": "markerColor",
            "marker_shape": "markerShape",
            "marker_size": "markerSize",
            "marker_visibility": "markerVisibility",
        },
    )
    class LineChartMarkerStyleSettingsProperty:
        def __init__(
            self,
            *,
            marker_color: typing.Optional[builtins.str] = None,
            marker_shape: typing.Optional[builtins.str] = None,
            marker_size: typing.Optional[builtins.str] = None,
            marker_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Marker styles options for a line series in ``LineChartVisual`` .

            :param marker_color: Color of marker in the series.
            :param marker_shape: Shape option for markers in the series. - ``CIRCLE`` : Show marker as a circle. - ``TRIANGLE`` : Show marker as a triangle. - ``SQUARE`` : Show marker as a square. - ``DIAMOND`` : Show marker as a diamond. - ``ROUNDED_SQUARE`` : Show marker as a rounded square.
            :param marker_size: Size of marker in the series.
            :param marker_visibility: Configuration option that determines whether to show the markers in the series.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                line_chart_marker_style_settings_property = quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                    marker_color="markerColor",
                    marker_shape="markerShape",
                    marker_size="markerSize",
                    marker_visibility="markerVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8b8ee22ce77e49d5edfba08634bd4e383f230c469aba781ae7dc3648b0e8f7da)
                check_type(argname="argument marker_color", value=marker_color, expected_type=type_hints["marker_color"])
                check_type(argname="argument marker_shape", value=marker_shape, expected_type=type_hints["marker_shape"])
                check_type(argname="argument marker_size", value=marker_size, expected_type=type_hints["marker_size"])
                check_type(argname="argument marker_visibility", value=marker_visibility, expected_type=type_hints["marker_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if marker_color is not None:
                self._values["marker_color"] = marker_color
            if marker_shape is not None:
                self._values["marker_shape"] = marker_shape
            if marker_size is not None:
                self._values["marker_size"] = marker_size
            if marker_visibility is not None:
                self._values["marker_visibility"] = marker_visibility

        @builtins.property
        def marker_color(self) -> typing.Optional[builtins.str]:
            '''Color of marker in the series.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html#cfn-quicksight-dashboard-linechartmarkerstylesettings-markercolor
            '''
            result = self._values.get("marker_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_shape(self) -> typing.Optional[builtins.str]:
            '''Shape option for markers in the series.

            - ``CIRCLE`` : Show marker as a circle.
            - ``TRIANGLE`` : Show marker as a triangle.
            - ``SQUARE`` : Show marker as a square.
            - ``DIAMOND`` : Show marker as a diamond.
            - ``ROUNDED_SQUARE`` : Show marker as a rounded square.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html#cfn-quicksight-dashboard-linechartmarkerstylesettings-markershape
            '''
            result = self._values.get("marker_shape")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_size(self) -> typing.Optional[builtins.str]:
            '''Size of marker in the series.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html#cfn-quicksight-dashboard-linechartmarkerstylesettings-markersize
            '''
            result = self._values.get("marker_size")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_visibility(self) -> typing.Optional[builtins.str]:
            '''Configuration option that determines whether to show the markers in the series.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html#cfn-quicksight-dashboard-linechartmarkerstylesettings-markervisibility
            '''
            result = self._values.get("marker_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartMarkerStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.LineChartSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_style_settings": "lineStyleSettings",
            "marker_style_settings": "markerStyleSettings",
        },
    )
    class LineChartSeriesSettingsProperty:
        def __init__(
            self,
            *,
            line_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LineChartLineStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            marker_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LineChartMarkerStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of a line series in the visual.

            :param line_style_settings: Line styles options for a line series in ``LineChartVisual`` .
            :param marker_style_settings: Marker styles options for a line series in ``LineChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                line_chart_series_settings_property = quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                    line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                        line_interpolation="lineInterpolation",
                        line_style="lineStyle",
                        line_visibility="lineVisibility",
                        line_width="lineWidth"
                    ),
                    marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                        marker_color="markerColor",
                        marker_shape="markerShape",
                        marker_size="markerSize",
                        marker_visibility="markerVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__45ca02cd5ccaf4e3acd3f5e37dd78686d05d152a7cb398b4e8b93370fcf39fd2)
                check_type(argname="argument line_style_settings", value=line_style_settings, expected_type=type_hints["line_style_settings"])
                check_type(argname="argument marker_style_settings", value=marker_style_settings, expected_type=type_hints["marker_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_style_settings is not None:
                self._values["line_style_settings"] = line_style_settings
            if marker_style_settings is not None:
                self._values["marker_style_settings"] = marker_style_settings

        @builtins.property
        def line_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartLineStyleSettingsProperty"]]:
            '''Line styles options for a line series in ``LineChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartseriessettings.html#cfn-quicksight-dashboard-linechartseriessettings-linestylesettings
            '''
            result = self._values.get("line_style_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartLineStyleSettingsProperty"]], result)

        @builtins.property
        def marker_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartMarkerStyleSettingsProperty"]]:
            '''Marker styles options for a line series in ``LineChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartseriessettings.html#cfn-quicksight-dashboard-linechartseriessettings-markerstylesettings
            '''
            result = self._values.get("marker_style_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartMarkerStyleSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.LineChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit_configuration": "categoryItemsLimitConfiguration",
            "category_sort": "categorySort",
            "color_items_limit_configuration": "colorItemsLimitConfiguration",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class LineChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a line chart.

            :param category_items_limit_configuration: The limit on the number of categories that are displayed in a line chart.
            :param category_sort: The sort configuration of the category fields.
            :param color_items_limit_configuration: The limit on the number of lines that are displayed in a line chart.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                line_chart_sort_configuration_property = quicksight.CfnDashboard.LineChartSortConfigurationProperty(
                    category_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f72384473101adc505fee80a396d4ef68c8f333e0d08de6f8265233017598f3a)
                check_type(argname="argument category_items_limit_configuration", value=category_items_limit_configuration, expected_type=type_hints["category_items_limit_configuration"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit_configuration", value=color_items_limit_configuration, expected_type=type_hints["color_items_limit_configuration"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit_configuration is not None:
                self._values["category_items_limit_configuration"] = category_items_limit_configuration
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit_configuration is not None:
                self._values["color_items_limit_configuration"] = color_items_limit_configuration
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories that are displayed in a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-categoryitemslimitconfiguration
            '''
            result = self._values.get("category_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of lines that are displayed in a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-coloritemslimitconfiguration
            '''
            result = self._values.get("color_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of small multiples panels that are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the small multiples field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.LineChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class LineChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LineChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A line chart.

            For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a line chart.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2a17c46da1e334e21bb122680b41efbece4e896f58e9aa984f17c1c3e0e88d35)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartConfigurationProperty"]]:
            '''The configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_options": "axisOptions",
            "missing_data_configurations": "missingDataConfigurations",
        },
    )
    class LineSeriesAxisDisplayOptionsProperty:
        def __init__(
            self,
            *,
            axis_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            missing_data_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MissingDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The series axis configuration of a line chart.

            :param axis_options: The options that determine the presentation of the line series axis.
            :param missing_data_configurations: The configuration options that determine how missing data is treated during the rendering of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-lineseriesaxisdisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                line_series_axis_display_options_property = quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                    axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                        treatment_option="treatmentOption"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fa43b755d3e8cd729f0c22230227242df86ac6b0ae3c511bdaac2765b9959692)
                check_type(argname="argument axis_options", value=axis_options, expected_type=type_hints["axis_options"])
                check_type(argname="argument missing_data_configurations", value=missing_data_configurations, expected_type=type_hints["missing_data_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_options is not None:
                self._values["axis_options"] = axis_options
            if missing_data_configurations is not None:
                self._values["missing_data_configurations"] = missing_data_configurations

        @builtins.property
        def axis_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the line series axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-lineseriesaxisdisplayoptions.html#cfn-quicksight-dashboard-lineseriesaxisdisplayoptions-axisoptions
            '''
            result = self._values.get("axis_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def missing_data_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MissingDataConfigurationProperty"]]]]:
            '''The configuration options that determine how missing data is treated during the rendering of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-lineseriesaxisdisplayoptions.html#cfn-quicksight-dashboard-lineseriesaxisdisplayoptions-missingdataconfigurations
            '''
            result = self._values.get("missing_data_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MissingDataConfigurationProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineSeriesAxisDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.LinkSharingConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"permissions": "permissions"},
    )
    class LinkSharingConfigurationProperty:
        def __init__(
            self,
            *,
            permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ResourcePermissionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''A structure that contains the configuration of a shareable link to the dashboard.

            :param permissions: A structure that contains the permissions of a shareable link.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linksharingconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                link_sharing_configuration_property = quicksight.CfnDashboard.LinkSharingConfigurationProperty(
                    permissions=[quicksight.CfnDashboard.ResourcePermissionProperty(
                        actions=["actions"],
                        principal="principal",
                
                        # the properties below are optional
                        resource="resource"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__77e811ecdbaede7841b1061f8849cf7f395967476f906911777c1594226fea98)
                check_type(argname="argument permissions", value=permissions, expected_type=type_hints["permissions"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if permissions is not None:
                self._values["permissions"] = permissions

        @builtins.property
        def permissions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ResourcePermissionProperty"]]]]:
            '''A structure that contains the permissions of a shareable link.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linksharingconfiguration.html#cfn-quicksight-dashboard-linksharingconfiguration-permissions
            '''
            result = self._values.get("permissions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ResourcePermissionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LinkSharingConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ListControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "info_icon_label_options": "infoIconLabelOptions",
            "search_options": "searchOptions",
            "select_all_options": "selectAllOptions",
            "title_options": "titleOptions",
        },
    )
    class ListControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SheetControlInfoIconLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            search_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ListControlSearchOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            select_all_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ListControlSelectAllOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param info_icon_label_options: The configuration of info icon label options.
            :param search_options: The configuration of the search options in a list control.
            :param select_all_options: The configuration of the ``Select all`` options in a list control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                list_control_display_options_property = quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                    info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                        info_icon_text="infoIconText",
                        visibility="visibility"
                    ),
                    search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                        visibility="visibility"
                    ),
                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b5febadad439ef006025d123dc685e375e9130f929ac04be04802492a54f216c)
                check_type(argname="argument info_icon_label_options", value=info_icon_label_options, expected_type=type_hints["info_icon_label_options"])
                check_type(argname="argument search_options", value=search_options, expected_type=type_hints["search_options"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if info_icon_label_options is not None:
                self._values["info_icon_label_options"] = info_icon_label_options
            if search_options is not None:
                self._values["search_options"] = search_options
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def info_icon_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetControlInfoIconLabelOptionsProperty"]]:
            '''The configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html#cfn-quicksight-dashboard-listcontroldisplayoptions-infoiconlabeloptions
            '''
            result = self._values.get("info_icon_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetControlInfoIconLabelOptionsProperty"]], result)

        @builtins.property
        def search_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ListControlSearchOptionsProperty"]]:
            '''The configuration of the search options in a list control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html#cfn-quicksight-dashboard-listcontroldisplayoptions-searchoptions
            '''
            result = self._values.get("search_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ListControlSearchOptionsProperty"]], result)

        @builtins.property
        def select_all_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ListControlSelectAllOptionsProperty"]]:
            '''The configuration of the ``Select all`` options in a list control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html#cfn-quicksight-dashboard-listcontroldisplayoptions-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ListControlSelectAllOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html#cfn-quicksight-dashboard-listcontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ListControlSearchOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ListControlSearchOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the search options in a list control.

            :param visibility: The visibility configuration of the search options in a list control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontrolsearchoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                list_control_search_options_property = quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0f2bfe88b96feac05893272a6933f32c0cbb36085d7a87747d54d2134855d4d4)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the search options in a list control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontrolsearchoptions.html#cfn-quicksight-dashboard-listcontrolsearchoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlSearchOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ListControlSelectAllOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ListControlSelectAllOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the ``Select all`` options in a list control.

            :param visibility: The visibility configuration of the ``Select all`` options in a list control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontrolselectalloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                list_control_select_all_options_property = quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e342c52e23ca2e5cf5121b6c99dfe2ee42d9d8523d26c51bf160ba3d6cee1218)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the ``Select all`` options in a list control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontrolselectalloptions.html#cfn-quicksight-dashboard-listcontrolselectalloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlSelectAllOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.LoadingAnimationProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class LoadingAnimationProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of loading animation in free-form layout.

            :param visibility: The visibility configuration of ``LoadingAnimation`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-loadinganimation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                loading_animation_property = quicksight.CfnDashboard.LoadingAnimationProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ea6969bd08c6863508c0b35f70105fdb7d54dd6d741313463507879699d9f231)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of ``LoadingAnimation`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-loadinganimation.html#cfn-quicksight-dashboard-loadinganimation-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LoadingAnimationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.LocalNavigationConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"target_sheet_id": "targetSheetId"},
    )
    class LocalNavigationConfigurationProperty:
        def __init__(self, *, target_sheet_id: builtins.str) -> None:
            '''The navigation configuration for ``CustomActionNavigationOperation`` .

            :param target_sheet_id: The sheet that is targeted for navigation in the same analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-localnavigationconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                local_navigation_configuration_property = quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                    target_sheet_id="targetSheetId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1e727b4e5afe9dcf7ee17567cbece49b8405a4d61ff102fda4699ca24813e33b)
                check_type(argname="argument target_sheet_id", value=target_sheet_id, expected_type=type_hints["target_sheet_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "target_sheet_id": target_sheet_id,
            }

        @builtins.property
        def target_sheet_id(self) -> builtins.str:
            '''The sheet that is targeted for navigation in the same analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-localnavigationconfiguration.html#cfn-quicksight-dashboard-localnavigationconfiguration-targetsheetid
            '''
            result = self._values.get("target_sheet_id")
            assert result is not None, "Required property 'target_sheet_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LocalNavigationConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.LongFormatTextProperty",
        jsii_struct_bases=[],
        name_mapping={"plain_text": "plainText", "rich_text": "richText"},
    )
    class LongFormatTextProperty:
        def __init__(
            self,
            *,
            plain_text: typing.Optional[builtins.str] = None,
            rich_text: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The text format for a subtitle.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param plain_text: Plain text format.
            :param rich_text: Rich text. Examples of rich text include bold, underline, and italics.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-longformattext.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                long_format_text_property = quicksight.CfnDashboard.LongFormatTextProperty(
                    plain_text="plainText",
                    rich_text="richText"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f8c82e7585849d11a8eb98093cf1ec0ed05a67b818e40cfb8125e131200fd6a0)
                check_type(argname="argument plain_text", value=plain_text, expected_type=type_hints["plain_text"])
                check_type(argname="argument rich_text", value=rich_text, expected_type=type_hints["rich_text"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if plain_text is not None:
                self._values["plain_text"] = plain_text
            if rich_text is not None:
                self._values["rich_text"] = rich_text

        @builtins.property
        def plain_text(self) -> typing.Optional[builtins.str]:
            '''Plain text format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-longformattext.html#cfn-quicksight-dashboard-longformattext-plaintext
            '''
            result = self._values.get("plain_text")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rich_text(self) -> typing.Optional[builtins.str]:
            '''Rich text.

            Examples of rich text include bold, underline, and italics.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-longformattext.html#cfn-quicksight-dashboard-longformattext-richtext
            '''
            result = self._values.get("rich_text")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LongFormatTextProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.MappedDataSetParameterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "data_set_parameter_name": "dataSetParameterName",
        },
    )
    class MappedDataSetParameterProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            data_set_parameter_name: builtins.str,
        ) -> None:
            '''A dataset parameter that is mapped to an analysis parameter.

            :param data_set_identifier: A unique name that identifies a dataset within the analysis or dashboard.
            :param data_set_parameter_name: The name of the dataset parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-mappeddatasetparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                mapped_data_set_parameter_property = quicksight.CfnDashboard.MappedDataSetParameterProperty(
                    data_set_identifier="dataSetIdentifier",
                    data_set_parameter_name="dataSetParameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9f9c65987afa3e8ecb810a48c09d13991a4e50e35d888cff0de15d2f81c4ac78)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument data_set_parameter_name", value=data_set_parameter_name, expected_type=type_hints["data_set_parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "data_set_parameter_name": data_set_parameter_name,
            }

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''A unique name that identifies a dataset within the analysis or dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-mappeddatasetparameter.html#cfn-quicksight-dashboard-mappeddatasetparameter-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_parameter_name(self) -> builtins.str:
            '''The name of the dataset parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-mappeddatasetparameter.html#cfn-quicksight-dashboard-mappeddatasetparameter-datasetparametername
            '''
            result = self._values.get("data_set_parameter_name")
            assert result is not None, "Required property 'data_set_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MappedDataSetParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.MaximumLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class MaximumLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The maximum label of a data path label.

            :param visibility: The visibility of the maximum label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                maximum_label_type_property = quicksight.CfnDashboard.MaximumLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7eba20f4560008a2bd679cb6c33f50b8f1d0ff2085b15f74a56aa9e9b27cb548)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the maximum label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumlabeltype.html#cfn-quicksight-dashboard-maximumlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MaximumLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.MaximumMinimumComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "type": "type",
            "name": "name",
            "time": "time",
            "value": "value",
        },
    )
    class MaximumMinimumComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            type: builtins.str,
            name: typing.Optional[builtins.str] = None,
            time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The maximum and minimum computation configuration.

            :param computation_id: The ID for a computation.
            :param type: The type of computation. Choose one of the following options:. - MAXIMUM: A maximum computation. - MINIMUM: A minimum computation.
            :param name: The name of a computation.
            :param time: The time field that is used in a computation.
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                maximum_minimum_computation_property = quicksight.CfnDashboard.MaximumMinimumComputationProperty(
                    computation_id="computationId",
                    type="type",
                
                    # the properties below are optional
                    name="name",
                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d6b3c965bc0f32ee00be3157ab64b431f4d8304cd8016a419e48638795caccad)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "type": type,
            }
            if name is not None:
                self._values["name"] = name
            if time is not None:
                self._values["time"] = time
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The type of computation. Choose one of the following options:.

            - MAXIMUM: A maximum computation.
            - MINIMUM: A minimum computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]:
            '''The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-time
            '''
            result = self._values.get("time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MaximumMinimumComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.MeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "calculated_measure_field": "calculatedMeasureField",
            "categorical_measure_field": "categoricalMeasureField",
            "date_measure_field": "dateMeasureField",
            "numerical_measure_field": "numericalMeasureField",
        },
    )
    class MeasureFieldProperty:
        def __init__(
            self,
            *,
            calculated_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CalculatedMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            categorical_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CategoricalMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            date_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DateMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numerical_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumericalMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure (metric) type field.

            :param calculated_measure_field: The calculated measure field only used in pivot tables.
            :param categorical_measure_field: The measure type field with categorical type columns.
            :param date_measure_field: The measure type field with date type columns.
            :param numerical_measure_field: The measure type field with numerical type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                measure_field_property = quicksight.CfnDashboard.MeasureFieldProperty(
                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                        expression="expression",
                        field_id="fieldId"
                    ),
                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function="aggregationFunction",
                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function="aggregationFunction",
                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        ),
                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7bda39b861408c2eb1e8cfa89817d96de06554de544f2e1c091d4672bf14619e)
                check_type(argname="argument calculated_measure_field", value=calculated_measure_field, expected_type=type_hints["calculated_measure_field"])
                check_type(argname="argument categorical_measure_field", value=categorical_measure_field, expected_type=type_hints["categorical_measure_field"])
                check_type(argname="argument date_measure_field", value=date_measure_field, expected_type=type_hints["date_measure_field"])
                check_type(argname="argument numerical_measure_field", value=numerical_measure_field, expected_type=type_hints["numerical_measure_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if calculated_measure_field is not None:
                self._values["calculated_measure_field"] = calculated_measure_field
            if categorical_measure_field is not None:
                self._values["categorical_measure_field"] = categorical_measure_field
            if date_measure_field is not None:
                self._values["date_measure_field"] = date_measure_field
            if numerical_measure_field is not None:
                self._values["numerical_measure_field"] = numerical_measure_field

        @builtins.property
        def calculated_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CalculatedMeasureFieldProperty"]]:
            '''The calculated measure field only used in pivot tables.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html#cfn-quicksight-dashboard-measurefield-calculatedmeasurefield
            '''
            result = self._values.get("calculated_measure_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CalculatedMeasureFieldProperty"]], result)

        @builtins.property
        def categorical_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CategoricalMeasureFieldProperty"]]:
            '''The measure type field with categorical type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html#cfn-quicksight-dashboard-measurefield-categoricalmeasurefield
            '''
            result = self._values.get("categorical_measure_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CategoricalMeasureFieldProperty"]], result)

        @builtins.property
        def date_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateMeasureFieldProperty"]]:
            '''The measure type field with date type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html#cfn-quicksight-dashboard-measurefield-datemeasurefield
            '''
            result = self._values.get("date_measure_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateMeasureFieldProperty"]], result)

        @builtins.property
        def numerical_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericalMeasureFieldProperty"]]:
            '''The measure type field with numerical type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html#cfn-quicksight-dashboard-measurefield-numericalmeasurefield
            '''
            result = self._values.get("numerical_measure_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericalMeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.MetricComparisonComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "from_value": "fromValue",
            "name": "name",
            "target_value": "targetValue",
            "time": "time",
        },
    )
    class MetricComparisonComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            from_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            name: typing.Optional[builtins.str] = None,
            target_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The metric comparison computation configuration.

            :param computation_id: The ID for a computation.
            :param from_value: The field that is used in a metric comparison from value setup.
            :param name: The name of a computation.
            :param target_value: The field that is used in a metric comparison to value setup.
            :param time: The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__63e8a49c397729aa75566f224e0d131f29ebf8029dcc57744bb63bb5568aa2ae)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument from_value", value=from_value, expected_type=type_hints["from_value"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument target_value", value=target_value, expected_type=type_hints["target_value"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
            }
            if from_value is not None:
                self._values["from_value"] = from_value
            if name is not None:
                self._values["name"] = name
            if target_value is not None:
                self._values["target_value"] = target_value
            if time is not None:
                self._values["time"] = time

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def from_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]:
            '''The field that is used in a metric comparison from value setup.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-fromvalue
            '''
            result = self._values.get("from_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def target_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]:
            '''The field that is used in a metric comparison to value setup.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-targetvalue
            '''
            result = self._values.get("target_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]:
            '''The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-time
            '''
            result = self._values.get("time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MetricComparisonComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.MinimumLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class MinimumLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The minimum label of a data path label.

            :param visibility: The visibility of the minimum label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-minimumlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                minimum_label_type_property = quicksight.CfnDashboard.MinimumLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2dd6328c694c87ce7bc8e71398688e001f3b30fc6be372cf80de64f3ee2948ba)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the minimum label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-minimumlabeltype.html#cfn-quicksight-dashboard-minimumlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MinimumLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.MissingDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"treatment_option": "treatmentOption"},
    )
    class MissingDataConfigurationProperty:
        def __init__(
            self,
            *,
            treatment_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration options that determine how missing data is treated during the rendering of a line chart.

            :param treatment_option: The treatment option that determines how missing data should be rendered. Choose from the following options:. - ``INTERPOLATE`` : Interpolate missing values between the prior and the next known value. - ``SHOW_AS_ZERO`` : Show missing values as the value ``0`` . - ``SHOW_AS_BLANK`` : Display a blank space when rendering missing data.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-missingdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                missing_data_configuration_property = quicksight.CfnDashboard.MissingDataConfigurationProperty(
                    treatment_option="treatmentOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6e3f6e47ae79491a472a008f3e692fb130c1355a3131b42ea8b4113d051cf300)
                check_type(argname="argument treatment_option", value=treatment_option, expected_type=type_hints["treatment_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if treatment_option is not None:
                self._values["treatment_option"] = treatment_option

        @builtins.property
        def treatment_option(self) -> typing.Optional[builtins.str]:
            '''The treatment option that determines how missing data should be rendered. Choose from the following options:.

            - ``INTERPOLATE`` : Interpolate missing values between the prior and the next known value.
            - ``SHOW_AS_ZERO`` : Show missing values as the value ``0`` .
            - ``SHOW_AS_BLANK`` : Display a blank space when rendering missing data.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-missingdataconfiguration.html#cfn-quicksight-dashboard-missingdataconfiguration-treatmentoption
            '''
            result = self._values.get("treatment_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MissingDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.NegativeValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"display_mode": "displayMode"},
    )
    class NegativeValueConfigurationProperty:
        def __init__(self, *, display_mode: builtins.str) -> None:
            '''The options that determine the negative value configuration.

            :param display_mode: Determines the display mode of the negative value configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-negativevalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                negative_value_configuration_property = quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                    display_mode="displayMode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__25a251d32a4f0c00a9eef760d498031f541fc3c71caf4c3ee65823d077b187f9)
                check_type(argname="argument display_mode", value=display_mode, expected_type=type_hints["display_mode"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "display_mode": display_mode,
            }

        @builtins.property
        def display_mode(self) -> builtins.str:
            '''Determines the display mode of the negative value configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-negativevalueconfiguration.html#cfn-quicksight-dashboard-negativevalueconfiguration-displaymode
            '''
            result = self._values.get("display_mode")
            assert result is not None, "Required property 'display_mode' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NegativeValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.NullValueFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"null_string": "nullString"},
    )
    class NullValueFormatConfigurationProperty:
        def __init__(self, *, null_string: builtins.str) -> None:
            '''The options that determine the null value format configuration.

            :param null_string: Determines the null string of null values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-nullvalueformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                null_value_format_configuration_property = quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                    null_string="nullString"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7f51b09eae900dd10cd29e9f1885f421f017f3caf1e8e21b09b84868e7a5f8ba)
                check_type(argname="argument null_string", value=null_string, expected_type=type_hints["null_string"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "null_string": null_string,
            }

        @builtins.property
        def null_string(self) -> builtins.str:
            '''Determines the null string of null values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-nullvalueformatconfiguration.html#cfn-quicksight-dashboard-nullvalueformatconfiguration-nullstring
            '''
            result = self._values.get("null_string")
            assert result is not None, "Required property 'null_string' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NullValueFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "number_scale": "numberScale",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
        },
    )
    class NumberDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            negative_value_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_scale: typing.Optional[builtins.str] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            suffix: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the number display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param number_scale: Determines the number scale value of the number format.
            :param prefix: Determines the prefix value of the number format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the number format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                number_display_format_configuration_property = quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    number_scale="numberScale",
                    prefix="prefix",
                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6a96d7074de53c21a8e539d6cb48e65c7e85d1cbf67eca4ca61b9b1473906ed7)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument number_scale", value=number_scale, expected_type=type_hints["number_scale"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if number_scale is not None:
                self._values["number_scale"] = number_scale
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DecimalPlacesConfigurationProperty"]]:
            '''The option that determines the decimal places configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DecimalPlacesConfigurationProperty"]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NegativeValueConfigurationProperty"]]:
            '''The options that determine the negative value configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NegativeValueConfigurationProperty"]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def number_scale(self) -> typing.Optional[builtins.str]:
            '''Determines the number scale value of the number format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-numberscale
            '''
            result = self._values.get("number_scale")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the number format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericSeparatorConfigurationProperty"]]:
            '''The options that determine the numeric separator configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericSeparatorConfigurationProperty"]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the number format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumberDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.NumberFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"format_configuration": "formatConfiguration"},
    )
    class NumberFormatConfigurationProperty:
        def __init__(
            self,
            *,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Formatting configuration for number fields.

            :param format_configuration: The options that determine the numeric format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                number_format_configuration_property = quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6fb36f5050e3d16814ea7055ce44e84526b9fbf9a283f7f6f42b4dd802161c40)
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericFormatConfigurationProperty"]]:
            '''The options that determine the numeric format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberformatconfiguration.html#cfn-quicksight-dashboard-numberformatconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumberFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.NumericAxisOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"range": "range", "scale": "scale"},
    )
    class NumericAxisOptionsProperty:
        def __init__(
            self,
            *,
            range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisDisplayRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scale: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options for an axis with a numeric field.

            :param range: The range setup of a numeric axis.
            :param scale: The scale setup of a numeric axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaxisoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                numeric_axis_options_property = quicksight.CfnDashboard.NumericAxisOptionsProperty(
                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                        data_driven=data_driven,
                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                            maximum=123,
                            minimum=123
                        )
                    ),
                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                            step_count=123,
                            step_size=123
                        ),
                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                            base=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__96ee0575ac0d4099f362576200d818e04a24f0fdce06d4c3533b75aca6cb247e)
                check_type(argname="argument range", value=range, expected_type=type_hints["range"])
                check_type(argname="argument scale", value=scale, expected_type=type_hints["scale"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if range is not None:
                self._values["range"] = range
            if scale is not None:
                self._values["scale"] = scale

        @builtins.property
        def range(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayRangeProperty"]]:
            '''The range setup of a numeric axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaxisoptions.html#cfn-quicksight-dashboard-numericaxisoptions-range
            '''
            result = self._values.get("range")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayRangeProperty"]], result)

        @builtins.property
        def scale(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisScaleProperty"]]:
            '''The scale setup of a numeric axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaxisoptions.html#cfn-quicksight-dashboard-numericaxisoptions-scale
            '''
            result = self._values.get("scale")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisScaleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericAxisOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "value": "value"},
    )
    class NumericEqualityDrillDownFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            value: jsii.Number,
        ) -> None:
            '''The category drill down filter.

            :param column: The column that the filter is applied to.
            :param value: The value of the double input numeric drill down filter. Default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalitydrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numeric_equality_drill_down_filter_property = quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a73d37b65e8c2f2d75e447208c2ed3a35accf3a4673c415bb91faf8a8fcc2e68)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "value": value,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalitydrilldownfilter.html#cfn-quicksight-dashboard-numericequalitydrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The value of the double input numeric drill down filter.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalitydrilldownfilter.html#cfn-quicksight-dashboard-numericequalitydrilldownfilter-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericEqualityDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.NumericEqualityFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "aggregation_function": "aggregationFunction",
            "parameter_name": "parameterName",
            "select_all_options": "selectAllOptions",
            "value": "value",
        },
    )
    class NumericEqualityFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            match_operator: builtins.str,
            null_option: builtins.str,
            aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            select_all_options: typing.Optional[builtins.str] = None,
            value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A ``NumericEqualityFilter`` filters values that are equal to the specified value.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param aggregation_function: The aggregation function of the filter.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``
            :param value: The input value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numeric_equality_filter_property = quicksight.CfnDashboard.NumericEqualityFilterProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                        attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                            simple_attribute_aggregation="simpleAttributeAggregation",
                            value_for_multiple_values="valueForMultipleValues"
                        ),
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    parameter_name="parameterName",
                    select_all_options="selectAllOptions",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__33c1d8a8b144259cd2333132730c2b585497c63f012cc936b5a58dcdc1660291)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AggregationFunctionProperty"]]:
            '''The aggregation function of the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AggregationFunctionProperty"]], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The input value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericEqualityFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.NumericFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "currency_display_format_configuration": "currencyDisplayFormatConfiguration",
            "number_display_format_configuration": "numberDisplayFormatConfiguration",
            "percentage_display_format_configuration": "percentageDisplayFormatConfiguration",
        },
    )
    class NumericFormatConfigurationProperty:
        def __init__(
            self,
            *,
            currency_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CurrencyDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumberDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            percentage_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PercentageDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the numeric format configuration.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param currency_display_format_configuration: The options that determine the currency display format configuration.
            :param number_display_format_configuration: The options that determine the number display format configuration.
            :param percentage_display_format_configuration: The options that determine the percentage display format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numeric_format_configuration_property = quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix",
                        symbol="symbol"
                    ),
                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    ),
                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        prefix="prefix",
                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ef98e28d628760cd44e353d86bb69f21ec9fcd73daede27f00c572f318a86c5b)
                check_type(argname="argument currency_display_format_configuration", value=currency_display_format_configuration, expected_type=type_hints["currency_display_format_configuration"])
                check_type(argname="argument number_display_format_configuration", value=number_display_format_configuration, expected_type=type_hints["number_display_format_configuration"])
                check_type(argname="argument percentage_display_format_configuration", value=percentage_display_format_configuration, expected_type=type_hints["percentage_display_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if currency_display_format_configuration is not None:
                self._values["currency_display_format_configuration"] = currency_display_format_configuration
            if number_display_format_configuration is not None:
                self._values["number_display_format_configuration"] = number_display_format_configuration
            if percentage_display_format_configuration is not None:
                self._values["percentage_display_format_configuration"] = percentage_display_format_configuration

        @builtins.property
        def currency_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CurrencyDisplayFormatConfigurationProperty"]]:
            '''The options that determine the currency display format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericformatconfiguration.html#cfn-quicksight-dashboard-numericformatconfiguration-currencydisplayformatconfiguration
            '''
            result = self._values.get("currency_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CurrencyDisplayFormatConfigurationProperty"]], result)

        @builtins.property
        def number_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumberDisplayFormatConfigurationProperty"]]:
            '''The options that determine the number display format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericformatconfiguration.html#cfn-quicksight-dashboard-numericformatconfiguration-numberdisplayformatconfiguration
            '''
            result = self._values.get("number_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumberDisplayFormatConfigurationProperty"]], result)

        @builtins.property
        def percentage_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PercentageDisplayFormatConfigurationProperty"]]:
            '''The options that determine the percentage display format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericformatconfiguration.html#cfn-quicksight-dashboard-numericformatconfiguration-percentagedisplayformatconfiguration
            '''
            result = self._values.get("percentage_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PercentageDisplayFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.NumericRangeFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "aggregation_function": "aggregationFunction",
            "include_maximum": "includeMaximum",
            "include_minimum": "includeMinimum",
            "range_maximum": "rangeMaximum",
            "range_minimum": "rangeMinimum",
            "select_all_options": "selectAllOptions",
        },
    )
    class NumericRangeFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            null_option: builtins.str,
            aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
            include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
            range_maximum: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumericRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            range_minimum: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumericRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``NumericRangeFilter`` filters values that are within the value range.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param aggregation_function: The aggregation function of the filter.
            :param include_maximum: Determines whether the maximum value in the filter value range should be included in the filtered results.
            :param include_minimum: Determines whether the minimum value in the filter value range should be included in the filtered results.
            :param range_maximum: The maximum value for the filter value range.
            :param range_minimum: The minimum value for the filter value range.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numeric_range_filter_property = quicksight.CfnDashboard.NumericRangeFilterProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                        attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                            simple_attribute_aggregation="simpleAttributeAggregation",
                            value_for_multiple_values="valueForMultipleValues"
                        ),
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    include_maximum=False,
                    include_minimum=False,
                    range_maximum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                        parameter="parameter",
                        static_value=123
                    ),
                    range_minimum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                        parameter="parameter",
                        static_value=123
                    ),
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9c681777f29fc0374af076bf89718e3e161e2ca13842f8fb6844762b9658ae3a)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument include_maximum", value=include_maximum, expected_type=type_hints["include_maximum"])
                check_type(argname="argument include_minimum", value=include_minimum, expected_type=type_hints["include_minimum"])
                check_type(argname="argument range_maximum", value=range_maximum, expected_type=type_hints["range_maximum"])
                check_type(argname="argument range_minimum", value=range_minimum, expected_type=type_hints["range_minimum"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if include_maximum is not None:
                self._values["include_maximum"] = include_maximum
            if include_minimum is not None:
                self._values["include_minimum"] = include_minimum
            if range_maximum is not None:
                self._values["range_maximum"] = range_maximum
            if range_minimum is not None:
                self._values["range_minimum"] = range_minimum
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AggregationFunctionProperty"]]:
            '''The aggregation function of the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AggregationFunctionProperty"]], result)

        @builtins.property
        def include_maximum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''Determines whether the maximum value in the filter value range should be included in the filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-includemaximum
            '''
            result = self._values.get("include_maximum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        @builtins.property
        def include_minimum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''Determines whether the minimum value in the filter value range should be included in the filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-includeminimum
            '''
            result = self._values.get("include_minimum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        @builtins.property
        def range_maximum(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericRangeFilterValueProperty"]]:
            '''The maximum value for the filter value range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-rangemaximum
            '''
            result = self._values.get("range_maximum")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericRangeFilterValueProperty"]], result)

        @builtins.property
        def range_minimum(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericRangeFilterValueProperty"]]:
            '''The minimum value for the filter value range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-rangeminimum
            '''
            result = self._values.get("range_minimum")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericRangeFilterValueProperty"]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericRangeFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.NumericRangeFilterValueProperty",
        jsii_struct_bases=[],
        name_mapping={"parameter": "parameter", "static_value": "staticValue"},
    )
    class NumericRangeFilterValueProperty:
        def __init__(
            self,
            *,
            parameter: typing.Optional[builtins.str] = None,
            static_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The value input pf the numeric range filter.

            :param parameter: The parameter that is used in the numeric range.
            :param static_value: The static value of the numeric range filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefiltervalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numeric_range_filter_value_property = quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                    parameter="parameter",
                    static_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c7aab34efaf66b9df9b735b4608cdf96bb949e3ba505714bc8eff4ed94daaa2a)
                check_type(argname="argument parameter", value=parameter, expected_type=type_hints["parameter"])
                check_type(argname="argument static_value", value=static_value, expected_type=type_hints["static_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if parameter is not None:
                self._values["parameter"] = parameter
            if static_value is not None:
                self._values["static_value"] = static_value

        @builtins.property
        def parameter(self) -> typing.Optional[builtins.str]:
            '''The parameter that is used in the numeric range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefiltervalue.html#cfn-quicksight-dashboard-numericrangefiltervalue-parameter
            '''
            result = self._values.get("parameter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def static_value(self) -> typing.Optional[jsii.Number]:
            '''The static value of the numeric range filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefiltervalue.html#cfn-quicksight-dashboard-numericrangefiltervalue-staticvalue
            '''
            result = self._values.get("static_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericRangeFilterValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.NumericSeparatorConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_separator": "decimalSeparator",
            "thousands_separator": "thousandsSeparator",
        },
    )
    class NumericSeparatorConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_separator: typing.Optional[builtins.str] = None,
            thousands_separator: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ThousandSeparatorOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the numeric separator configuration.

            :param decimal_separator: Determines the decimal separator.
            :param thousands_separator: The options that determine the thousands separator configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericseparatorconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numeric_separator_configuration_property = quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                    decimal_separator="decimalSeparator",
                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                        symbol="symbol",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5dea558533477bbcc10607d4b35c93f02497d7e0f1260540b9949fdcd953df29)
                check_type(argname="argument decimal_separator", value=decimal_separator, expected_type=type_hints["decimal_separator"])
                check_type(argname="argument thousands_separator", value=thousands_separator, expected_type=type_hints["thousands_separator"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_separator is not None:
                self._values["decimal_separator"] = decimal_separator
            if thousands_separator is not None:
                self._values["thousands_separator"] = thousands_separator

        @builtins.property
        def decimal_separator(self) -> typing.Optional[builtins.str]:
            '''Determines the decimal separator.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericseparatorconfiguration.html#cfn-quicksight-dashboard-numericseparatorconfiguration-decimalseparator
            '''
            result = self._values.get("decimal_separator")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def thousands_separator(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ThousandSeparatorOptionsProperty"]]:
            '''The options that determine the thousands separator configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericseparatorconfiguration.html#cfn-quicksight-dashboard-numericseparatorconfiguration-thousandsseparator
            '''
            result = self._values.get("thousands_separator")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ThousandSeparatorOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericSeparatorConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.NumericalAggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "percentile_aggregation": "percentileAggregation",
            "simple_numerical_aggregation": "simpleNumericalAggregation",
        },
    )
    class NumericalAggregationFunctionProperty:
        def __init__(
            self,
            *,
            percentile_aggregation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PercentileAggregationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            simple_numerical_aggregation: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Aggregation for numerical values.

            :param percentile_aggregation: An aggregation based on the percentile of values in a dimension or measure.
            :param simple_numerical_aggregation: Built-in aggregation functions for numerical values. - ``SUM`` : The sum of a dimension or measure. - ``AVERAGE`` : The average of a dimension or measure. - ``MIN`` : The minimum value of a dimension or measure. - ``MAX`` : The maximum value of a dimension or measure. - ``COUNT`` : The count of a dimension or measure. - ``DISTINCT_COUNT`` : The count of distinct values in a dimension or measure. - ``VAR`` : The variance of a dimension or measure. - ``VARP`` : The partitioned variance of a dimension or measure. - ``STDEV`` : The standard deviation of a dimension or measure. - ``STDEVP`` : The partitioned standard deviation of a dimension or measure. - ``MEDIAN`` : The median value of a dimension or measure.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalaggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numerical_aggregation_function_property = quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                        percentile_value=123
                    ),
                    simple_numerical_aggregation="simpleNumericalAggregation"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a031996b9f7bbdd777729799f7e91919f186288677074ff2f3027c84d552d263)
                check_type(argname="argument percentile_aggregation", value=percentile_aggregation, expected_type=type_hints["percentile_aggregation"])
                check_type(argname="argument simple_numerical_aggregation", value=simple_numerical_aggregation, expected_type=type_hints["simple_numerical_aggregation"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percentile_aggregation is not None:
                self._values["percentile_aggregation"] = percentile_aggregation
            if simple_numerical_aggregation is not None:
                self._values["simple_numerical_aggregation"] = simple_numerical_aggregation

        @builtins.property
        def percentile_aggregation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PercentileAggregationProperty"]]:
            '''An aggregation based on the percentile of values in a dimension or measure.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalaggregationfunction.html#cfn-quicksight-dashboard-numericalaggregationfunction-percentileaggregation
            '''
            result = self._values.get("percentile_aggregation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PercentileAggregationProperty"]], result)

        @builtins.property
        def simple_numerical_aggregation(self) -> typing.Optional[builtins.str]:
            '''Built-in aggregation functions for numerical values.

            - ``SUM`` : The sum of a dimension or measure.
            - ``AVERAGE`` : The average of a dimension or measure.
            - ``MIN`` : The minimum value of a dimension or measure.
            - ``MAX`` : The maximum value of a dimension or measure.
            - ``COUNT`` : The count of a dimension or measure.
            - ``DISTINCT_COUNT`` : The count of distinct values in a dimension or measure.
            - ``VAR`` : The variance of a dimension or measure.
            - ``VARP`` : The partitioned variance of a dimension or measure.
            - ``STDEV`` : The standard deviation of a dimension or measure.
            - ``STDEVP`` : The partitioned standard deviation of a dimension or measure.
            - ``MEDIAN`` : The median value of a dimension or measure.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalaggregationfunction.html#cfn-quicksight-dashboard-numericalaggregationfunction-simplenumericalaggregation
            '''
            result = self._values.get("simple_numerical_aggregation")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalAggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.NumericalDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class NumericalDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with numerical type columns.

            :param column: The column that is used in the ``NumericalDimensionField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numerical_dimension_field_property = quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2d76f073619eb37e9e71fbf3ebf78782331b851f2ab756ee9131116d2fef3143)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that is used in the ``NumericalDimensionField`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html#cfn-quicksight-dashboard-numericaldimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html#cfn-quicksight-dashboard-numericaldimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumberFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html#cfn-quicksight-dashboard-numericaldimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumberFormatConfigurationProperty"]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html#cfn-quicksight-dashboard-numericaldimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.NumericalMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class NumericalMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure type field with numerical type columns.

            :param column: The column that is used in the ``NumericalMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numerical_measure_field_property = quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    ),
                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__329f754bdd9a2bf2422eda37f6a20073d93e96fcf8bf689ccd957aa8ecce472d)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that is used in the ``NumericalMeasureField`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html#cfn-quicksight-dashboard-numericalmeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html#cfn-quicksight-dashboard-numericalmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericalAggregationFunctionProperty"]]:
            '''The aggregation function of the measure field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html#cfn-quicksight-dashboard-numericalmeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericalAggregationFunctionProperty"]], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumberFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html#cfn-quicksight-dashboard-numericalmeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumberFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PaginationConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"page_number": "pageNumber", "page_size": "pageSize"},
    )
    class PaginationConfigurationProperty:
        def __init__(self, *, page_number: jsii.Number, page_size: jsii.Number) -> None:
            '''The pagination configuration for a table visual or boxplot.

            :param page_number: Indicates the page number.
            :param page_size: Indicates how many items render in one page.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paginationconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pagination_configuration_property = quicksight.CfnDashboard.PaginationConfigurationProperty(
                    page_number=123,
                    page_size=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__310fcb29ab91bd65346b543d1d0297b090a7bc9447cf55751a416392d9d18835)
                check_type(argname="argument page_number", value=page_number, expected_type=type_hints["page_number"])
                check_type(argname="argument page_size", value=page_size, expected_type=type_hints["page_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "page_number": page_number,
                "page_size": page_size,
            }

        @builtins.property
        def page_number(self) -> jsii.Number:
            '''Indicates the page number.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paginationconfiguration.html#cfn-quicksight-dashboard-paginationconfiguration-pagenumber
            '''
            result = self._values.get("page_number")
            assert result is not None, "Required property 'page_number' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def page_size(self) -> jsii.Number:
            '''Indicates how many items render in one page.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paginationconfiguration.html#cfn-quicksight-dashboard-paginationconfiguration-pagesize
            '''
            result = self._values.get("page_size")
            assert result is not None, "Required property 'page_size' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PaginationConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PanelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "background_visibility": "backgroundVisibility",
            "border_color": "borderColor",
            "border_style": "borderStyle",
            "border_thickness": "borderThickness",
            "border_visibility": "borderVisibility",
            "gutter_spacing": "gutterSpacing",
            "gutter_visibility": "gutterVisibility",
            "title": "title",
        },
    )
    class PanelConfigurationProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[builtins.str] = None,
            background_visibility: typing.Optional[builtins.str] = None,
            border_color: typing.Optional[builtins.str] = None,
            border_style: typing.Optional[builtins.str] = None,
            border_thickness: typing.Optional[builtins.str] = None,
            border_visibility: typing.Optional[builtins.str] = None,
            gutter_spacing: typing.Optional[builtins.str] = None,
            gutter_visibility: typing.Optional[builtins.str] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PanelTitleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A collection of options that configure how each panel displays in a small multiples chart.

            :param background_color: Sets the background color for each panel.
            :param background_visibility: Determines whether or not a background for each small multiples panel is rendered.
            :param border_color: Sets the line color of panel borders.
            :param border_style: Sets the line style of panel borders.
            :param border_thickness: Sets the line thickness of panel borders.
            :param border_visibility: Determines whether or not each panel displays a border.
            :param gutter_spacing: Sets the total amount of negative space to display between sibling panels.
            :param gutter_visibility: Determines whether or not negative space between sibling panels is rendered.
            :param title: Configures the title display within each small multiples panel.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                panel_configuration_property = quicksight.CfnDashboard.PanelConfigurationProperty(
                    background_color="backgroundColor",
                    background_visibility="backgroundVisibility",
                    border_color="borderColor",
                    border_style="borderStyle",
                    border_thickness="borderThickness",
                    border_visibility="borderVisibility",
                    gutter_spacing="gutterSpacing",
                    gutter_visibility="gutterVisibility",
                    title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        horizontal_text_alignment="horizontalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__faa7c6a00adee9dc4ba6f91728f5ce014b59bcc63fb564cd2d34d597a6c68ece)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument background_visibility", value=background_visibility, expected_type=type_hints["background_visibility"])
                check_type(argname="argument border_color", value=border_color, expected_type=type_hints["border_color"])
                check_type(argname="argument border_style", value=border_style, expected_type=type_hints["border_style"])
                check_type(argname="argument border_thickness", value=border_thickness, expected_type=type_hints["border_thickness"])
                check_type(argname="argument border_visibility", value=border_visibility, expected_type=type_hints["border_visibility"])
                check_type(argname="argument gutter_spacing", value=gutter_spacing, expected_type=type_hints["gutter_spacing"])
                check_type(argname="argument gutter_visibility", value=gutter_visibility, expected_type=type_hints["gutter_visibility"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if background_visibility is not None:
                self._values["background_visibility"] = background_visibility
            if border_color is not None:
                self._values["border_color"] = border_color
            if border_style is not None:
                self._values["border_style"] = border_style
            if border_thickness is not None:
                self._values["border_thickness"] = border_thickness
            if border_visibility is not None:
                self._values["border_visibility"] = border_visibility
            if gutter_spacing is not None:
                self._values["gutter_spacing"] = gutter_spacing
            if gutter_visibility is not None:
                self._values["gutter_visibility"] = gutter_visibility
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def background_color(self) -> typing.Optional[builtins.str]:
            '''Sets the background color for each panel.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def background_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not a background for each small multiples panel is rendered.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-backgroundvisibility
            '''
            result = self._values.get("background_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_color(self) -> typing.Optional[builtins.str]:
            '''Sets the line color of panel borders.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-bordercolor
            '''
            result = self._values.get("border_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_style(self) -> typing.Optional[builtins.str]:
            '''Sets the line style of panel borders.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-borderstyle
            '''
            result = self._values.get("border_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_thickness(self) -> typing.Optional[builtins.str]:
            '''Sets the line thickness of panel borders.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-borderthickness
            '''
            result = self._values.get("border_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not each panel displays a border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-bordervisibility
            '''
            result = self._values.get("border_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def gutter_spacing(self) -> typing.Optional[builtins.str]:
            '''Sets the total amount of negative space to display between sibling panels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-gutterspacing
            '''
            result = self._values.get("gutter_spacing")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def gutter_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not negative space between sibling panels is rendered.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-guttervisibility
            '''
            result = self._values.get("gutter_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PanelTitleOptionsProperty"]]:
            '''Configures the title display within each small multiples panel.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PanelTitleOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PanelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PanelTitleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "font_configuration": "fontConfiguration",
            "horizontal_text_alignment": "horizontalTextAlignment",
            "visibility": "visibility",
        },
    )
    class PanelTitleOptionsProperty:
        def __init__(
            self,
            *,
            font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            horizontal_text_alignment: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the title styles for each small multiples panel.

            :param font_configuration: 
            :param horizontal_text_alignment: Sets the horizontal text alignment of the title within each panel.
            :param visibility: Determines whether or not panel titles are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paneltitleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                panel_title_options_property = quicksight.CfnDashboard.PanelTitleOptionsProperty(
                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    horizontal_text_alignment="horizontalTextAlignment",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5de53ca22e1a3fe648e6b4daf781a351c3cb42a2fb15908472df8d6009793d64)
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument horizontal_text_alignment", value=horizontal_text_alignment, expected_type=type_hints["horizontal_text_alignment"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if horizontal_text_alignment is not None:
                self._values["horizontal_text_alignment"] = horizontal_text_alignment
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paneltitleoptions.html#cfn-quicksight-dashboard-paneltitleoptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"]], result)

        @builtins.property
        def horizontal_text_alignment(self) -> typing.Optional[builtins.str]:
            '''Sets the horizontal text alignment of the title within each panel.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paneltitleoptions.html#cfn-quicksight-dashboard-paneltitleoptions-horizontaltextalignment
            '''
            result = self._values.get("horizontal_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not panel titles are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paneltitleoptions.html#cfn-quicksight-dashboard-paneltitleoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PanelTitleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ParameterControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_picker": "dateTimePicker",
            "dropdown": "dropdown",
            "list": "list",
            "slider": "slider",
            "text_area": "textArea",
            "text_field": "textField",
        },
    )
    class ParameterControlProperty:
        def __init__(
            self,
            *,
            date_time_picker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ParameterDateTimePickerControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            dropdown: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ParameterDropDownControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            list: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ParameterListControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            slider: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ParameterSliderControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_area: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ParameterTextAreaControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ParameterTextFieldControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The control of a parameter that users can interact with in a dashboard or an analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_picker: A control from a date parameter that specifies date and time.
            :param dropdown: A control to display a dropdown list with buttons that are used to select a single value.
            :param list: A control to display a list with buttons or boxes that are used to select either a single value or multiple values.
            :param slider: A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
            :param text_area: A control to display a text box that is used to enter multiple entries.
            :param text_field: A control to display a text box that is used to enter a single entry.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_control_property = quicksight.CfnDashboard.ParameterControlProperty(
                    date_time_picker=quicksight.CfnDashboard.ParameterDateTimePickerControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    dropdown=quicksight.CfnDashboard.ParameterDropDownControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                            link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            values=["values"]
                        ),
                        type="type"
                    ),
                    list=quicksight.CfnDashboard.ParameterListControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                            link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            values=["values"]
                        ),
                        type="type"
                    ),
                    slider=quicksight.CfnDashboard.ParameterSliderControlProperty(
                        maximum_value=123,
                        minimum_value=123,
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        step_size=123,
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_area=quicksight.CfnDashboard.ParameterTextAreaControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        delimiter="delimiter",
                        display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_field=quicksight.CfnDashboard.ParameterTextFieldControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a9ccbef0e5e038633af739accbfa89308dadbb10cadb53ba45143c546424ab8d)
                check_type(argname="argument date_time_picker", value=date_time_picker, expected_type=type_hints["date_time_picker"])
                check_type(argname="argument dropdown", value=dropdown, expected_type=type_hints["dropdown"])
                check_type(argname="argument list", value=list, expected_type=type_hints["list"])
                check_type(argname="argument slider", value=slider, expected_type=type_hints["slider"])
                check_type(argname="argument text_area", value=text_area, expected_type=type_hints["text_area"])
                check_type(argname="argument text_field", value=text_field, expected_type=type_hints["text_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_picker is not None:
                self._values["date_time_picker"] = date_time_picker
            if dropdown is not None:
                self._values["dropdown"] = dropdown
            if list is not None:
                self._values["list"] = list
            if slider is not None:
                self._values["slider"] = slider
            if text_area is not None:
                self._values["text_area"] = text_area
            if text_field is not None:
                self._values["text_field"] = text_field

        @builtins.property
        def date_time_picker(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParameterDateTimePickerControlProperty"]]:
            '''A control from a date parameter that specifies date and time.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-datetimepicker
            '''
            result = self._values.get("date_time_picker")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParameterDateTimePickerControlProperty"]], result)

        @builtins.property
        def dropdown(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParameterDropDownControlProperty"]]:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-dropdown
            '''
            result = self._values.get("dropdown")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParameterDropDownControlProperty"]], result)

        @builtins.property
        def list(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParameterListControlProperty"]]:
            '''A control to display a list with buttons or boxes that are used to select either a single value or multiple values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-list
            '''
            result = self._values.get("list")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParameterListControlProperty"]], result)

        @builtins.property
        def slider(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParameterSliderControlProperty"]]:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-slider
            '''
            result = self._values.get("slider")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParameterSliderControlProperty"]], result)

        @builtins.property
        def text_area(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParameterTextAreaControlProperty"]]:
            '''A control to display a text box that is used to enter multiple entries.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-textarea
            '''
            result = self._values.get("text_area")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParameterTextAreaControlProperty"]], result)

        @builtins.property
        def text_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParameterTextFieldControlProperty"]]:
            '''A control to display a text box that is used to enter a single entry.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-textfield
            '''
            result = self._values.get("text_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParameterTextFieldControlProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ParameterDateTimePickerControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterDateTimePickerControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DateTimePickerControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control from a date parameter that specifies date and time.

            :param parameter_control_id: The ID of the ``ParameterDateTimePickerControl`` .
            :param source_parameter_name: The name of the ``ParameterDateTimePickerControl`` .
            :param title: The title of the ``ParameterDateTimePickerControl`` .
            :param display_options: The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_date_time_picker_control_property = quicksight.CfnDashboard.ParameterDateTimePickerControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a6fb8438f75d54be2e2704b76000c4c7685f2c8c0548fe82d3a4d7664a45d430)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterDateTimePickerControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html#cfn-quicksight-dashboard-parameterdatetimepickercontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The name of the ``ParameterDateTimePickerControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html#cfn-quicksight-dashboard-parameterdatetimepickercontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterDateTimePickerControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html#cfn-quicksight-dashboard-parameterdatetimepickercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateTimePickerControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html#cfn-quicksight-dashboard-parameterdatetimepickercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateTimePickerControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDateTimePickerControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_parameter_declaration": "dateTimeParameterDeclaration",
            "decimal_parameter_declaration": "decimalParameterDeclaration",
            "integer_parameter_declaration": "integerParameterDeclaration",
            "string_parameter_declaration": "stringParameterDeclaration",
        },
    )
    class ParameterDeclarationProperty:
        def __init__(
            self,
            *,
            date_time_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DateTimeParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            decimal_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DecimalParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            integer_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.IntegerParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            string_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.StringParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The declaration definition of a parameter.

            For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_parameter_declaration: A parameter declaration for the ``DateTime`` data type.
            :param decimal_parameter_declaration: A parameter declaration for the ``Decimal`` data type.
            :param integer_parameter_declaration: A parameter declaration for the ``Integer`` data type.
            :param string_parameter_declaration: A parameter declaration for the ``String`` data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_declaration_property = quicksight.CfnDashboard.ParameterDeclarationProperty(
                    date_time_parameter_declaration=quicksight.CfnDashboard.DateTimeParameterDeclarationProperty(
                        name="name",
                
                        # the properties below are optional
                        default_values=quicksight.CfnDashboard.DateTimeDefaultValuesProperty(
                            dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        time_granularity="timeGranularity",
                        value_when_unset=quicksight.CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    decimal_parameter_declaration=quicksight.CfnDashboard.DecimalParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnDashboard.DecimalDefaultValuesProperty(
                            dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnDashboard.DecimalValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    integer_parameter_declaration=quicksight.CfnDashboard.IntegerParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnDashboard.IntegerDefaultValuesProperty(
                            dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnDashboard.IntegerValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    string_parameter_declaration=quicksight.CfnDashboard.StringParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnDashboard.StringDefaultValuesProperty(
                            dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnDashboard.StringValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a05860ff5b329e2cbc2cf4547a1e0a254e5d56d6df8897a033522f8ab01b6d1e)
                check_type(argname="argument date_time_parameter_declaration", value=date_time_parameter_declaration, expected_type=type_hints["date_time_parameter_declaration"])
                check_type(argname="argument decimal_parameter_declaration", value=decimal_parameter_declaration, expected_type=type_hints["decimal_parameter_declaration"])
                check_type(argname="argument integer_parameter_declaration", value=integer_parameter_declaration, expected_type=type_hints["integer_parameter_declaration"])
                check_type(argname="argument string_parameter_declaration", value=string_parameter_declaration, expected_type=type_hints["string_parameter_declaration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_parameter_declaration is not None:
                self._values["date_time_parameter_declaration"] = date_time_parameter_declaration
            if decimal_parameter_declaration is not None:
                self._values["decimal_parameter_declaration"] = decimal_parameter_declaration
            if integer_parameter_declaration is not None:
                self._values["integer_parameter_declaration"] = integer_parameter_declaration
            if string_parameter_declaration is not None:
                self._values["string_parameter_declaration"] = string_parameter_declaration

        @builtins.property
        def date_time_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateTimeParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``DateTime`` data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html#cfn-quicksight-dashboard-parameterdeclaration-datetimeparameterdeclaration
            '''
            result = self._values.get("date_time_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateTimeParameterDeclarationProperty"]], result)

        @builtins.property
        def decimal_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DecimalParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``Decimal`` data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html#cfn-quicksight-dashboard-parameterdeclaration-decimalparameterdeclaration
            '''
            result = self._values.get("decimal_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DecimalParameterDeclarationProperty"]], result)

        @builtins.property
        def integer_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.IntegerParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``Integer`` data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html#cfn-quicksight-dashboard-parameterdeclaration-integerparameterdeclaration
            '''
            result = self._values.get("integer_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.IntegerParameterDeclarationProperty"]], result)

        @builtins.property
        def string_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.StringParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``String`` data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html#cfn-quicksight-dashboard-parameterdeclaration-stringparameterdeclaration
            '''
            result = self._values.get("string_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.StringParameterDeclarationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ParameterDropDownControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class ParameterDropDownControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DropDownControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ParameterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :param parameter_control_id: The ID of the ``ParameterDropDownControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterDropDownControl`` .
            :param title: The title of the ``ParameterDropDownControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type parameter name of the ``ParameterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_drop_down_control_property = quicksight.CfnDashboard.ParameterDropDownControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                        link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f6323a39d1aaf0938addd2bd3f5756d8f1844ffc27e7d2130636cfc342dbcdd3)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DropDownControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DropDownControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParameterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParameterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type parameter name of the ``ParameterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDropDownControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ParameterListControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class ParameterListControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ListControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ParameterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a list with buttons or boxes that are used to select either a single value or multiple values.

            :param parameter_control_id: The ID of the ``ParameterListControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterListControl`` .
            :param title: The title of the ``ParameterListControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of ``ParameterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_list_control_property = quicksight.CfnDashboard.ParameterListControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                        link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1a488e59915305b593c54f724cdabe9d29499ccb831d2ad64fd2e73bec399048)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ListControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ListControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParameterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParameterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``ParameterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterListControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ParameterSelectableValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "link_to_data_set_column": "linkToDataSetColumn",
            "values": "values",
        },
    )
    class ParameterSelectableValuesProperty:
        def __init__(
            self,
            *,
            link_to_data_set_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A list of selectable values that are used in a control.

            :param link_to_data_set_column: The column identifier that fetches values from the data set.
            :param values: The values that are used in ``ParameterSelectableValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterselectablevalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_selectable_values_property = quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                    link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d6b317eac2c33db00b8c09bd1340a5c09f2b4ce7e3a3e0283c33f32df0a475c2)
                check_type(argname="argument link_to_data_set_column", value=link_to_data_set_column, expected_type=type_hints["link_to_data_set_column"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if link_to_data_set_column is not None:
                self._values["link_to_data_set_column"] = link_to_data_set_column
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def link_to_data_set_column(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]]:
            '''The column identifier that fetches values from the data set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterselectablevalues.html#cfn-quicksight-dashboard-parameterselectablevalues-linktodatasetcolumn
            '''
            result = self._values.get("link_to_data_set_column")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]], result)

        @builtins.property
        def values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The values that are used in ``ParameterSelectableValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterselectablevalues.html#cfn-quicksight-dashboard-parameterselectablevalues-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterSelectableValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ParameterSliderControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "maximum_value": "maximumValue",
            "minimum_value": "minimumValue",
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "step_size": "stepSize",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterSliderControlProperty:
        def __init__(
            self,
            *,
            maximum_value: jsii.Number,
            minimum_value: jsii.Number,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            step_size: jsii.Number,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SliderControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :param maximum_value: The smaller value that is displayed at the left of the slider. Default: - 0
            :param minimum_value: The larger value that is displayed at the right of the slider. Default: - 0
            :param parameter_control_id: The ID of the ``ParameterSliderControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterSliderControl`` .
            :param step_size: The number of increments that the slider bar is divided into. Default: - 0
            :param title: The title of the ``ParameterSliderControl`` .
            :param display_options: The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_slider_control_property = quicksight.CfnDashboard.ParameterSliderControlProperty(
                    maximum_value=123,
                    minimum_value=123,
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    step_size=123,
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0f335200a996cfc311bc6eaf56f89ebcd68c9ee97b0bff54556bea2ea8e99387)
                check_type(argname="argument maximum_value", value=maximum_value, expected_type=type_hints["maximum_value"])
                check_type(argname="argument minimum_value", value=minimum_value, expected_type=type_hints["minimum_value"])
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "maximum_value": maximum_value,
                "minimum_value": minimum_value,
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "step_size": step_size,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def maximum_value(self) -> jsii.Number:
            '''The smaller value that is displayed at the left of the slider.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-maximumvalue
            '''
            result = self._values.get("maximum_value")
            assert result is not None, "Required property 'maximum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def minimum_value(self) -> jsii.Number:
            '''The larger value that is displayed at the right of the slider.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-minimumvalue
            '''
            result = self._values.get("minimum_value")
            assert result is not None, "Required property 'minimum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterSliderControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterSliderControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def step_size(self) -> jsii.Number:
            '''The number of increments that the slider bar is divided into.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-stepsize
            '''
            result = self._values.get("step_size")
            assert result is not None, "Required property 'step_size' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterSliderControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SliderControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SliderControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterSliderControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ParameterTextAreaControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "delimiter": "delimiter",
            "display_options": "displayOptions",
        },
    )
    class ParameterTextAreaControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            delimiter: typing.Optional[builtins.str] = None,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TextAreaControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter multiple entries.

            :param parameter_control_id: The ID of the ``ParameterTextAreaControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterTextAreaControl`` .
            :param title: The title of the ``ParameterTextAreaControl`` .
            :param delimiter: The delimiter that is used to separate the lines in text.
            :param display_options: The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_text_area_control_property = quicksight.CfnDashboard.ParameterTextAreaControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    delimiter="delimiter",
                    display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__25e1bc62de5af7f068adbb2392c15bcc529db2321930937b15c36ff9b1c77095)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument delimiter", value=delimiter, expected_type=type_hints["delimiter"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if delimiter is not None:
                self._values["delimiter"] = delimiter
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def delimiter(self) -> typing.Optional[builtins.str]:
            '''The delimiter that is used to separate the lines in text.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-delimiter
            '''
            result = self._values.get("delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TextAreaControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TextAreaControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterTextAreaControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ParameterTextFieldControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterTextFieldControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TextFieldControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter a single entry.

            :param parameter_control_id: The ID of the ``ParameterTextFieldControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterTextFieldControl`` .
            :param title: The title of the ``ParameterTextFieldControl`` .
            :param display_options: The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_text_field_control_property = quicksight.CfnDashboard.ParameterTextFieldControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__710574e730ad930b46c151023887cf834fa8a5f71fd91d84929925ec0b603391)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterTextFieldControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html#cfn-quicksight-dashboard-parametertextfieldcontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterTextFieldControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html#cfn-quicksight-dashboard-parametertextfieldcontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterTextFieldControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html#cfn-quicksight-dashboard-parametertextfieldcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TextFieldControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html#cfn-quicksight-dashboard-parametertextfieldcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TextFieldControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterTextFieldControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ParametersProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_parameters": "dateTimeParameters",
            "decimal_parameters": "decimalParameters",
            "integer_parameters": "integerParameters",
            "string_parameters": "stringParameters",
        },
    )
    class ParametersProperty:
        def __init__(
            self,
            *,
            date_time_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DateTimeParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            decimal_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DecimalParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            integer_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.IntegerParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            string_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.StringParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''A list of Amazon QuickSight parameters and the list's override values.

            :param date_time_parameters: The parameters that have a data type of date-time.
            :param decimal_parameters: The parameters that have a data type of decimal.
            :param integer_parameters: The parameters that have a data type of integer.
            :param string_parameters: The parameters that have a data type of string.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameters_property = quicksight.CfnDashboard.ParametersProperty(
                    date_time_parameters=[quicksight.CfnDashboard.DateTimeParameterProperty(
                        name="name",
                        values=["values"]
                    )],
                    decimal_parameters=[quicksight.CfnDashboard.DecimalParameterProperty(
                        name="name",
                        values=[123]
                    )],
                    integer_parameters=[quicksight.CfnDashboard.IntegerParameterProperty(
                        name="name",
                        values=[123]
                    )],
                    string_parameters=[quicksight.CfnDashboard.StringParameterProperty(
                        name="name",
                        values=["values"]
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__92d931d0fba6b11706d8e4c3181b34b41c26c6c1042657baa27632cc682c6a12)
                check_type(argname="argument date_time_parameters", value=date_time_parameters, expected_type=type_hints["date_time_parameters"])
                check_type(argname="argument decimal_parameters", value=decimal_parameters, expected_type=type_hints["decimal_parameters"])
                check_type(argname="argument integer_parameters", value=integer_parameters, expected_type=type_hints["integer_parameters"])
                check_type(argname="argument string_parameters", value=string_parameters, expected_type=type_hints["string_parameters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_parameters is not None:
                self._values["date_time_parameters"] = date_time_parameters
            if decimal_parameters is not None:
                self._values["decimal_parameters"] = decimal_parameters
            if integer_parameters is not None:
                self._values["integer_parameters"] = integer_parameters
            if string_parameters is not None:
                self._values["string_parameters"] = string_parameters

        @builtins.property
        def date_time_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateTimeParameterProperty"]]]]:
            '''The parameters that have a data type of date-time.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html#cfn-quicksight-dashboard-parameters-datetimeparameters
            '''
            result = self._values.get("date_time_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DateTimeParameterProperty"]]]], result)

        @builtins.property
        def decimal_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DecimalParameterProperty"]]]]:
            '''The parameters that have a data type of decimal.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html#cfn-quicksight-dashboard-parameters-decimalparameters
            '''
            result = self._values.get("decimal_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DecimalParameterProperty"]]]], result)

        @builtins.property
        def integer_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.IntegerParameterProperty"]]]]:
            '''The parameters that have a data type of integer.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html#cfn-quicksight-dashboard-parameters-integerparameters
            '''
            result = self._values.get("integer_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.IntegerParameterProperty"]]]], result)

        @builtins.property
        def string_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.StringParameterProperty"]]]]:
            '''The parameters that have a data type of string.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html#cfn-quicksight-dashboard-parameters-stringparameters
            '''
            result = self._values.get("string_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.StringParameterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PercentVisibleRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"from_": "from", "to": "to"},
    )
    class PercentVisibleRangeProperty:
        def __init__(
            self,
            *,
            from_: typing.Optional[jsii.Number] = None,
            to: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The percent range in the visible range.

            :param from_: The lower bound of the range.
            :param to: The top bound of the range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentvisiblerange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                percent_visible_range_property = quicksight.CfnDashboard.PercentVisibleRangeProperty(
                    from=123,
                    to=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__454af327f68004c0443555741b9f580a14dcdfe09ec03aea2ebca143ed597bdb)
                check_type(argname="argument from_", value=from_, expected_type=type_hints["from_"])
                check_type(argname="argument to", value=to, expected_type=type_hints["to"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if from_ is not None:
                self._values["from_"] = from_
            if to is not None:
                self._values["to"] = to

        @builtins.property
        def from_(self) -> typing.Optional[jsii.Number]:
            '''The lower bound of the range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentvisiblerange.html#cfn-quicksight-dashboard-percentvisiblerange-from
            '''
            result = self._values.get("from_")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def to(self) -> typing.Optional[jsii.Number]:
            '''The top bound of the range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentvisiblerange.html#cfn-quicksight-dashboard-percentvisiblerange-to
            '''
            result = self._values.get("to")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentVisibleRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
        },
    )
    class PercentageDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            negative_value_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            suffix: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the percentage display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param prefix: Determines the prefix value of the percentage format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the percentage format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                percentage_display_format_configuration_property = quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    prefix="prefix",
                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8a82125074cdf02d6f8401dd17680960f778c7f86df989fdee09ffe73e250bf9)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DecimalPlacesConfigurationProperty"]]:
            '''The option that determines the decimal places configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DecimalPlacesConfigurationProperty"]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NegativeValueConfigurationProperty"]]:
            '''The options that determine the negative value configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NegativeValueConfigurationProperty"]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the percentage format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericSeparatorConfigurationProperty"]]:
            '''The options that determine the numeric separator configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericSeparatorConfigurationProperty"]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the percentage format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentageDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PercentileAggregationProperty",
        jsii_struct_bases=[],
        name_mapping={"percentile_value": "percentileValue"},
    )
    class PercentileAggregationProperty:
        def __init__(
            self,
            *,
            percentile_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''An aggregation based on the percentile of values in a dimension or measure.

            :param percentile_value: The percentile value. This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentileaggregation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                percentile_aggregation_property = quicksight.CfnDashboard.PercentileAggregationProperty(
                    percentile_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a5b3017a1482c9ab5debf5891233c374814387651af82f8a7e521a2fb54dea5a)
                check_type(argname="argument percentile_value", value=percentile_value, expected_type=type_hints["percentile_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percentile_value is not None:
                self._values["percentile_value"] = percentile_value

        @builtins.property
        def percentile_value(self) -> typing.Optional[jsii.Number]:
            '''The percentile value.

            This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentileaggregation.html#cfn-quicksight-dashboard-percentileaggregation-percentilevalue
            '''
            result = self._values.get("percentile_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentileAggregationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PeriodOverPeriodComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "name": "name",
            "time": "time",
            "value": "value",
        },
    )
    class PeriodOverPeriodComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            name: typing.Optional[builtins.str] = None,
            time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The period over period computation configuration.

            :param computation_id: The ID for a computation.
            :param name: The name of a computation.
            :param time: The time field that is used in a computation.
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                period_over_period_computation_property = quicksight.CfnDashboard.PeriodOverPeriodComputationProperty(
                    computation_id="computationId",
                
                    # the properties below are optional
                    name="name",
                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__63068691f97a26ea9b52587611422559b470d0f4c8d79093773b261b88829854)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
            }
            if name is not None:
                self._values["name"] = name
            if time is not None:
                self._values["time"] = time
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html#cfn-quicksight-dashboard-periodoverperiodcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html#cfn-quicksight-dashboard-periodoverperiodcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]:
            '''The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html#cfn-quicksight-dashboard-periodoverperiodcomputation-time
            '''
            result = self._values.get("time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html#cfn-quicksight-dashboard-periodoverperiodcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PeriodOverPeriodComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PeriodToDateComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "name": "name",
            "period_time_granularity": "periodTimeGranularity",
            "time": "time",
            "value": "value",
        },
    )
    class PeriodToDateComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            name: typing.Optional[builtins.str] = None,
            period_time_granularity: typing.Optional[builtins.str] = None,
            time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The period to date computation configuration.

            :param computation_id: The ID for a computation.
            :param name: The name of a computation.
            :param period_time_granularity: The time granularity setup of period to date computation. Choose from the following options:. - YEAR: Year to date. - MONTH: Month to date.
            :param time: The time field that is used in a computation.
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                period_to_date_computation_property = quicksight.CfnDashboard.PeriodToDateComputationProperty(
                    computation_id="computationId",
                
                    # the properties below are optional
                    name="name",
                    period_time_granularity="periodTimeGranularity",
                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a80fd5af62a1f437e68660af73210c54d2dc9d98ff6bdddda9606d46cbe8ab04)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument period_time_granularity", value=period_time_granularity, expected_type=type_hints["period_time_granularity"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
            }
            if name is not None:
                self._values["name"] = name
            if period_time_granularity is not None:
                self._values["period_time_granularity"] = period_time_granularity
            if time is not None:
                self._values["time"] = time
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def period_time_granularity(self) -> typing.Optional[builtins.str]:
            '''The time granularity setup of period to date computation. Choose from the following options:.

            - YEAR: Year to date.
            - MONTH: Month to date.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-periodtimegranularity
            '''
            result = self._values.get("period_time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]:
            '''The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-time
            '''
            result = self._values.get("time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PeriodToDateComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PieChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class PieChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a pie chart.

            :param category: The category (group/color) field wells of a pie chart.
            :param small_multiples: The small multiples field well of a pie chart.
            :param values: The value field wells of a pie chart. Values are aggregated based on categories.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c017b6b08a6a48b214dbe969a491c25387eb7e3ab88e9782ce5ad34ca75ffe22)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The category (group/color) field wells of a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartaggregatedfieldwells.html#cfn-quicksight-dashboard-piechartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The small multiples field well of a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartaggregatedfieldwells.html#cfn-quicksight-dashboard-piechartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The value field wells of a pie chart.

            Values are aggregated based on categories.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartaggregatedfieldwells.html#cfn-quicksight-dashboard-piechartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PieChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "donut_options": "donutOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class PieChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            donut_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DonutOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PieChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PieChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a pie chart.

            :param category_label_options: The label options of the group/color that is displayed in a pie chart.
            :param contribution_analysis_defaults: The contribution analysis (anomaly configuration) setup of the visual.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param donut_options: The options that determine the shape of the chart. This option determines whether the chart is a pie chart or a donut chart.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a pie chart.
            :param tooltip: The tooltip display setup of the visual.
            :param value_label_options: The label options for the value that is displayed in a pie chart.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5646f673e0a66a4e291c909b66c41668edc2c647e1d1553f6a5348ac36ccf011)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument donut_options", value=donut_options, expected_type=type_hints["donut_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if donut_options is not None:
                self._values["donut_options"] = donut_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the group/color that is displayed in a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ContributionAnalysisDefaultProperty"]]]]:
            '''The contribution analysis (anomaly configuration) setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ContributionAnalysisDefaultProperty"]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def donut_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DonutOptionsProperty"]]:
            '''The options that determine the shape of the chart.

            This option determines whether the chart is a pie chart or a donut chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-donutoptions
            '''
            result = self._values.get("donut_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DonutOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PieChartFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PieChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SmallMultiplesOptionsProperty"]]:
            '''The small multiples setup for the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SmallMultiplesOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PieChartSortConfigurationProperty"]]:
            '''The sort configuration of a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PieChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options for the value that is displayed in a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PieChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pie_chart_aggregated_field_wells": "pieChartAggregatedFieldWells",
        },
    )
    class PieChartFieldWellsProperty:
        def __init__(
            self,
            *,
            pie_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PieChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a pie chart.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param pie_chart_aggregated_field_wells: The field well configuration of a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__89af0932ba7d86389a68553331219856efcb0fd7e5915a67a8393d7f330a4ce9)
                check_type(argname="argument pie_chart_aggregated_field_wells", value=pie_chart_aggregated_field_wells, expected_type=type_hints["pie_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pie_chart_aggregated_field_wells is not None:
                self._values["pie_chart_aggregated_field_wells"] = pie_chart_aggregated_field_wells

        @builtins.property
        def pie_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PieChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartfieldwells.html#cfn-quicksight-dashboard-piechartfieldwells-piechartaggregatedfieldwells
            '''
            result = self._values.get("pie_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PieChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PieChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class PieChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a pie chart.

            :param category_items_limit: The limit on the number of categories that are displayed in a pie chart.
            :param category_sort: The sort configuration of the category fields.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pie_chart_sort_configuration_property = quicksight.CfnDashboard.PieChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bdcbd7303f50d7a7d0ac68d8896f1ea0a99cb4146701b5d9a5aebcdccd1cd218)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories that are displayed in a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html#cfn-quicksight-dashboard-piechartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html#cfn-quicksight-dashboard-piechartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of small multiples panels that are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html#cfn-quicksight-dashboard-piechartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the small multiples field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html#cfn-quicksight-dashboard-piechartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PieChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class PieChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PieChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A pie or donut chart.

            The ``PieChartVisual`` structure describes a visual that is a member of the pie chart family.

            The following charts can be described by using this structure:

            - Pie charts
            - Donut charts

            For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .

            For more information, see `Using donut charts <https://docs.aws.amazon.com/quicksight/latest/user/donut-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a pie chart.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7d6df5178bd6d68f561cb2d13506da5c5df63858264f05d2e99af0995bc68d4e)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PieChartConfigurationProperty"]]:
            '''The configuration of a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PieChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotFieldSortOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "sort_by": "sortBy"},
    )
    class PivotFieldSortOptionsProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            sort_by: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTableSortByProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The field sort options for a pivot table sort configuration.

            :param field_id: The field ID for the field sort options.
            :param sort_by: The sort by field for the field sort options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivotfieldsortoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_field_sort_options_property = quicksight.CfnDashboard.PivotFieldSortOptionsProperty(
                    field_id="fieldId",
                    sort_by=quicksight.CfnDashboard.PivotTableSortByProperty(
                        column=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        data_path=quicksight.CfnDashboard.DataPathSortProperty(
                            direction="direction",
                            sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                                data_path_type=quicksight.CfnDashboard.DataPathTypeProperty(
                                    pivot_table_data_path_type="pivotTableDataPathType"
                                ),
                                field_id="fieldId",
                                field_value="fieldValue"
                            )]
                        ),
                        field=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1b7a6252c77a5343750b3a158ed34ede9f8f2fdcb13ec1c792508ae20f0db47a)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument sort_by", value=sort_by, expected_type=type_hints["sort_by"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
                "sort_by": sort_by,
            }

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for the field sort options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivotfieldsortoptions.html#cfn-quicksight-dashboard-pivotfieldsortoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_by(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableSortByProperty"]:
            '''The sort by field for the field sort options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivotfieldsortoptions.html#cfn-quicksight-dashboard-pivotfieldsortoptions-sortby
            '''
            result = self._values.get("sort_by")
            assert result is not None, "Required property 'sort_by' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableSortByProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotFieldSortOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotTableAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns", "rows": "rows", "values": "values"},
    )
    class PivotTableAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            columns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            rows: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well for the pivot table.

            :param columns: The columns field well for a pivot table. Values are grouped by columns fields.
            :param rows: The rows field well for a pivot table. Values are grouped by rows fields.
            :param values: The values field well for a pivot table. Values are aggregated based on rows and columns fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__99d93595e591308d67b9db0ab0ff1f07011c065172687176a1ecc6c7ab9f3c2c)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument rows", value=rows, expected_type=type_hints["rows"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if columns is not None:
                self._values["columns"] = columns
            if rows is not None:
                self._values["rows"] = rows
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def columns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The columns field well for a pivot table.

            Values are grouped by columns fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableaggregatedfieldwells.html#cfn-quicksight-dashboard-pivottableaggregatedfieldwells-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def rows(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The rows field well for a pivot table.

            Values are grouped by rows fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableaggregatedfieldwells.html#cfn-quicksight-dashboard-pivottableaggregatedfieldwells-rows
            '''
            result = self._values.get("rows")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The values field well for a pivot table.

            Values are aggregated based on rows and columns fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableaggregatedfieldwells.html#cfn-quicksight-dashboard-pivottableaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "scope": "scope",
            "scopes": "scopes",
            "text_format": "textFormat",
        },
    )
    class PivotTableCellConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            scope: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTableConditionalFormattingScopeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scopes: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTableConditionalFormattingScopeProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            text_format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TextConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cell conditional formatting option for a pivot table.

            :param field_id: The field ID of the cell for conditional formatting.
            :param scope: The scope of the cell for conditional formatting.
            :param scopes: A list of cell scopes for conditional formatting.
            :param text_format: The text format of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_cell_conditional_formatting_property = quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    scope=quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                        role="role"
                    ),
                    scopes=[quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                        role="role"
                    )],
                    text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1f8925cdb5343b18965f4a79b2fb5619ae156f764754d77883c9aa6f4456b032)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
                check_type(argname="argument scopes", value=scopes, expected_type=type_hints["scopes"])
                check_type(argname="argument text_format", value=text_format, expected_type=type_hints["text_format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if scope is not None:
                self._values["scope"] = scope
            if scopes is not None:
                self._values["scopes"] = scopes
            if text_format is not None:
                self._values["text_format"] = text_format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html#cfn-quicksight-dashboard-pivottablecellconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def scope(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableConditionalFormattingScopeProperty"]]:
            '''The scope of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html#cfn-quicksight-dashboard-pivottablecellconditionalformatting-scope
            '''
            result = self._values.get("scope")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableConditionalFormattingScopeProperty"]], result)

        @builtins.property
        def scopes(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableConditionalFormattingScopeProperty"]]]]:
            '''A list of cell scopes for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html#cfn-quicksight-dashboard-pivottablecellconditionalformatting-scopes
            '''
            result = self._values.get("scopes")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableConditionalFormattingScopeProperty"]]]], result)

        @builtins.property
        def text_format(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TextConditionalFormatProperty"]]:
            '''The text format of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html#cfn-quicksight-dashboard-pivottablecellconditionalformatting-textformat
            '''
            result = self._values.get("text_format")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TextConditionalFormatProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableCellConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotTableConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"cell": "cell"},
    )
    class PivotTableConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            cell: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTableCellConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :param cell: The cell conditional formatting option for a pivot table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_option_property = quicksight.CfnDashboard.PivotTableConditionalFormattingOptionProperty(
                    cell=quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        scope=quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                            role="role"
                        ),
                        scopes=[quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                            role="role"
                        )],
                        text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__04a83fbff7c12281297bf71879f6cc1210a30a86cf28df5275565b1d0c040e56)
                check_type(argname="argument cell", value=cell, expected_type=type_hints["cell"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell is not None:
                self._values["cell"] = cell

        @builtins.property
        def cell(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableCellConditionalFormattingProperty"]]:
            '''The cell conditional formatting option for a pivot table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformattingoption.html#cfn-quicksight-dashboard-pivottableconditionalformattingoption-cell
            '''
            result = self._values.get("cell")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableCellConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotTableConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class PivotTableConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTableConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :param conditional_formatting_options: Conditional formatting options for a ``PivotTableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_property = quicksight.CfnDashboard.PivotTableConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnDashboard.PivotTableConditionalFormattingOptionProperty(
                        cell=quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            scope=quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                                role="role"
                            ),
                            scopes=[quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                                role="role"
                            )],
                            text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__761b9c337605bed798719853421ef487f48123877d14ec5b706fbe06d543ad0a)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableConditionalFormattingOptionProperty"]]]]:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformatting.html#cfn-quicksight-dashboard-pivottableconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty",
        jsii_struct_bases=[],
        name_mapping={"role": "role"},
    )
    class PivotTableConditionalFormattingScopeProperty:
        def __init__(self, *, role: typing.Optional[builtins.str] = None) -> None:
            '''The scope of the cell for conditional formatting.

            :param role: The role (field, field total, grand total) of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformattingscope.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_scope_property = quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                    role="role"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8d1932fc7354734a1205d21d8846379573920557e14c417bb6a92a70998b1724)
                check_type(argname="argument role", value=role, expected_type=type_hints["role"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if role is not None:
                self._values["role"] = role

        @builtins.property
        def role(self) -> typing.Optional[builtins.str]:
            '''The role (field, field total, grand total) of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformattingscope.html#cfn-quicksight-dashboard-pivottableconditionalformattingscope-role
            '''
            result = self._values.get("role")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingScopeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotTableConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_options": "fieldOptions",
            "field_wells": "fieldWells",
            "paginated_report_options": "paginatedReportOptions",
            "sort_configuration": "sortConfiguration",
            "table_options": "tableOptions",
            "total_options": "totalOptions",
        },
    )
    class PivotTableConfigurationProperty:
        def __init__(
            self,
            *,
            field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTableFieldOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTableFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paginated_report_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTablePaginatedReportOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTableSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTableOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTableTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``PivotTableVisual`` .

            :param field_options: The field options for a pivot table visual.
            :param field_wells: The field wells of the visual.
            :param paginated_report_options: The paginated report options for a pivot table visual.
            :param sort_configuration: The sort configuration for a ``PivotTableVisual`` .
            :param table_options: The table options for a pivot table visual.
            :param total_options: The total options for a pivot table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e065e6a3b2f37689738a4b2e07811ce8f6e87add015e42c66a7806947832ca71)
                check_type(argname="argument field_options", value=field_options, expected_type=type_hints["field_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument paginated_report_options", value=paginated_report_options, expected_type=type_hints["paginated_report_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument table_options", value=table_options, expected_type=type_hints["table_options"])
                check_type(argname="argument total_options", value=total_options, expected_type=type_hints["total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_options is not None:
                self._values["field_options"] = field_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if paginated_report_options is not None:
                self._values["paginated_report_options"] = paginated_report_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if table_options is not None:
                self._values["table_options"] = table_options
            if total_options is not None:
                self._values["total_options"] = total_options

        @builtins.property
        def field_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableFieldOptionsProperty"]]:
            '''The field options for a pivot table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-fieldoptions
            '''
            result = self._values.get("field_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableFieldOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableFieldWellsProperty"]], result)

        @builtins.property
        def paginated_report_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTablePaginatedReportOptionsProperty"]]:
            '''The paginated report options for a pivot table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-paginatedreportoptions
            '''
            result = self._values.get("paginated_report_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTablePaginatedReportOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableSortConfigurationProperty"]]:
            '''The sort configuration for a ``PivotTableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableSortConfigurationProperty"]], result)

        @builtins.property
        def table_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableOptionsProperty"]]:
            '''The table options for a pivot table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-tableoptions
            '''
            result = self._values.get("table_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableOptionsProperty"]], result)

        @builtins.property
        def total_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableTotalOptionsProperty"]]:
            '''The total options for a pivot table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-totaloptions
            '''
            result = self._values.get("total_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableTotalOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotTableDataPathOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"data_path_list": "dataPathList", "width": "width"},
    )
    class PivotTableDataPathOptionProperty:
        def __init__(
            self,
            *,
            data_path_list: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]]]]],
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The data path options for the pivot table field options.

            :param data_path_list: The list of data path values for the data path options.
            :param width: The width of the data path option.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabledatapathoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_data_path_option_property = quicksight.CfnDashboard.PivotTableDataPathOptionProperty(
                    data_path_list=[quicksight.CfnDashboard.DataPathValueProperty(
                        data_path_type=quicksight.CfnDashboard.DataPathTypeProperty(
                            pivot_table_data_path_type="pivotTableDataPathType"
                        ),
                        field_id="fieldId",
                        field_value="fieldValue"
                    )],
                
                    # the properties below are optional
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5d2e668c60b8ac8bc95aa18f481f8c30486eef2a20e7b4f9e4ecec04a05d9d14)
                check_type(argname="argument data_path_list", value=data_path_list, expected_type=type_hints["data_path_list"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_path_list": data_path_list,
            }
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def data_path_list(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPathValueProperty"]]]:
            '''The list of data path values for the data path options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabledatapathoption.html#cfn-quicksight-dashboard-pivottabledatapathoption-datapathlist
            '''
            result = self._values.get("data_path_list")
            assert result is not None, "Required property 'data_path_list' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPathValueProperty"]]], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width of the data path option.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabledatapathoption.html#cfn-quicksight-dashboard-pivottabledatapathoption-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableDataPathOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotTableFieldCollapseStateOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"target": "target", "state": "state"},
    )
    class PivotTableFieldCollapseStateOptionProperty:
        def __init__(
            self,
            *,
            target: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTableFieldCollapseStateTargetProperty", typing.Dict[builtins.str, typing.Any]]],
            state: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The collapse state options for the pivot table field options.

            :param target: A tagged-union object that sets the collapse state.
            :param state: The state of the field target of a pivot table. Choose one of the following options:. - ``COLLAPSED`` - ``EXPANDED``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldcollapsestateoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_field_collapse_state_option_property = quicksight.CfnDashboard.PivotTableFieldCollapseStateOptionProperty(
                    target=quicksight.CfnDashboard.PivotTableFieldCollapseStateTargetProperty(
                        field_data_path_values=[quicksight.CfnDashboard.DataPathValueProperty(
                            data_path_type=quicksight.CfnDashboard.DataPathTypeProperty(
                                pivot_table_data_path_type="pivotTableDataPathType"
                            ),
                            field_id="fieldId",
                            field_value="fieldValue"
                        )],
                        field_id="fieldId"
                    ),
                
                    # the properties below are optional
                    state="state"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__69c348be65b74f4a060c424046f7921502df34cfd947cea9105546b2f4ba86ba)
                check_type(argname="argument target", value=target, expected_type=type_hints["target"])
                check_type(argname="argument state", value=state, expected_type=type_hints["state"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "target": target,
            }
            if state is not None:
                self._values["state"] = state

        @builtins.property
        def target(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableFieldCollapseStateTargetProperty"]:
            '''A tagged-union object that sets the collapse state.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldcollapsestateoption.html#cfn-quicksight-dashboard-pivottablefieldcollapsestateoption-target
            '''
            result = self._values.get("target")
            assert result is not None, "Required property 'target' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableFieldCollapseStateTargetProperty"], result)

        @builtins.property
        def state(self) -> typing.Optional[builtins.str]:
            '''The state of the field target of a pivot table. Choose one of the following options:.

            - ``COLLAPSED``
            - ``EXPANDED``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldcollapsestateoption.html#cfn-quicksight-dashboard-pivottablefieldcollapsestateoption-state
            '''
            result = self._values.get("state")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldCollapseStateOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotTableFieldCollapseStateTargetProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_data_path_values": "fieldDataPathValues",
            "field_id": "fieldId",
        },
    )
    class PivotTableFieldCollapseStateTargetProperty:
        def __init__(
            self,
            *,
            field_data_path_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            field_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The target of a pivot table field collapse state.

            :param field_data_path_values: The data path of the pivot table's header. Used to set the collapse state.
            :param field_id: The field ID of the pivot table that the collapse state needs to be set to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldcollapsestatetarget.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_field_collapse_state_target_property = quicksight.CfnDashboard.PivotTableFieldCollapseStateTargetProperty(
                    field_data_path_values=[quicksight.CfnDashboard.DataPathValueProperty(
                        data_path_type=quicksight.CfnDashboard.DataPathTypeProperty(
                            pivot_table_data_path_type="pivotTableDataPathType"
                        ),
                        field_id="fieldId",
                        field_value="fieldValue"
                    )],
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bb1a080b4975a48de553c244a7a0e3ae1cdd3fdac6bd777b3bc5cbfee3049fe7)
                check_type(argname="argument field_data_path_values", value=field_data_path_values, expected_type=type_hints["field_data_path_values"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_data_path_values is not None:
                self._values["field_data_path_values"] = field_data_path_values
            if field_id is not None:
                self._values["field_id"] = field_id

        @builtins.property
        def field_data_path_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPathValueProperty"]]]]:
            '''The data path of the pivot table's header.

            Used to set the collapse state.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldcollapsestatetarget.html#cfn-quicksight-dashboard-pivottablefieldcollapsestatetarget-fielddatapathvalues
            '''
            result = self._values.get("field_data_path_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPathValueProperty"]]]], result)

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the pivot table that the collapse state needs to be set to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldcollapsestatetarget.html#cfn-quicksight-dashboard-pivottablefieldcollapsestatetarget-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldCollapseStateTargetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotTableFieldOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "custom_label": "customLabel",
            "visibility": "visibility",
        },
    )
    class PivotTableFieldOptionProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            custom_label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The selected field options for the pivot table field options.

            :param field_id: The field ID of the pivot table field.
            :param custom_label: The custom label of the pivot table field.
            :param visibility: The visibility of the pivot table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_field_option_property = quicksight.CfnDashboard.PivotTableFieldOptionProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    custom_label="customLabel",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e0cc77c3bf5ee12e812c49de984b022379e1a733f2d905182816a4c36f6ffd8c)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the pivot table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoption.html#cfn-quicksight-dashboard-pivottablefieldoption-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label of the pivot table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoption.html#cfn-quicksight-dashboard-pivottablefieldoption-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the pivot table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoption.html#cfn-quicksight-dashboard-pivottablefieldoption-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotTableFieldOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "collapse_state_options": "collapseStateOptions",
            "data_path_options": "dataPathOptions",
            "selected_field_options": "selectedFieldOptions",
        },
    )
    class PivotTableFieldOptionsProperty:
        def __init__(
            self,
            *,
            collapse_state_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTableFieldCollapseStateOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_path_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTableDataPathOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            selected_field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTableFieldOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field options for a pivot table visual.

            :param collapse_state_options: The collapse state options for the pivot table field options.
            :param data_path_options: The data path options for the pivot table field options.
            :param selected_field_options: The selected field options for the pivot table field options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_field_options_property = quicksight.CfnDashboard.PivotTableFieldOptionsProperty(
                    collapse_state_options=[quicksight.CfnDashboard.PivotTableFieldCollapseStateOptionProperty(
                        target=quicksight.CfnDashboard.PivotTableFieldCollapseStateTargetProperty(
                            field_data_path_values=[quicksight.CfnDashboard.DataPathValueProperty(
                                data_path_type=quicksight.CfnDashboard.DataPathTypeProperty(
                                    pivot_table_data_path_type="pivotTableDataPathType"
                                ),
                                field_id="fieldId",
                                field_value="fieldValue"
                            )],
                            field_id="fieldId"
                        ),
                
                        # the properties below are optional
                        state="state"
                    )],
                    data_path_options=[quicksight.CfnDashboard.PivotTableDataPathOptionProperty(
                        data_path_list=[quicksight.CfnDashboard.DataPathValueProperty(
                            data_path_type=quicksight.CfnDashboard.DataPathTypeProperty(
                                pivot_table_data_path_type="pivotTableDataPathType"
                            ),
                            field_id="fieldId",
                            field_value="fieldValue"
                        )],
                
                        # the properties below are optional
                        width="width"
                    )],
                    selected_field_options=[quicksight.CfnDashboard.PivotTableFieldOptionProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        custom_label="customLabel",
                        visibility="visibility"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bc9e2dbfbe3589245e73f83c34f9db73054fd84f0ad392eb306d5d2e5f78ee3b)
                check_type(argname="argument collapse_state_options", value=collapse_state_options, expected_type=type_hints["collapse_state_options"])
                check_type(argname="argument data_path_options", value=data_path_options, expected_type=type_hints["data_path_options"])
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if collapse_state_options is not None:
                self._values["collapse_state_options"] = collapse_state_options
            if data_path_options is not None:
                self._values["data_path_options"] = data_path_options
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options

        @builtins.property
        def collapse_state_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableFieldCollapseStateOptionProperty"]]]]:
            '''The collapse state options for the pivot table field options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoptions.html#cfn-quicksight-dashboard-pivottablefieldoptions-collapsestateoptions
            '''
            result = self._values.get("collapse_state_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableFieldCollapseStateOptionProperty"]]]], result)

        @builtins.property
        def data_path_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableDataPathOptionProperty"]]]]:
            '''The data path options for the pivot table field options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoptions.html#cfn-quicksight-dashboard-pivottablefieldoptions-datapathoptions
            '''
            result = self._values.get("data_path_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableDataPathOptionProperty"]]]], result)

        @builtins.property
        def selected_field_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableFieldOptionProperty"]]]]:
            '''The selected field options for the pivot table field options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoptions.html#cfn-quicksight-dashboard-pivottablefieldoptions-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableFieldOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId"},
    )
    class PivotTableFieldSubtotalOptionsProperty:
        def __init__(self, *, field_id: typing.Optional[builtins.str] = None) -> None:
            '''The optional configuration of subtotals cells.

            :param field_id: The field ID of the subtotal options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldsubtotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_field_subtotal_options_property = quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d7b3b6281f5250110629c115d4d3320188b38d92d180c2458031a5b631a9be9b)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the subtotal options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldsubtotaloptions.html#cfn-quicksight-dashboard-pivottablefieldsubtotaloptions-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldSubtotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotTableFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pivot_table_aggregated_field_wells": "pivotTableAggregatedFieldWells",
        },
    )
    class PivotTableFieldWellsProperty:
        def __init__(
            self,
            *,
            pivot_table_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTableAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells for a pivot table visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param pivot_table_aggregated_field_wells: The aggregated field well for the pivot table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__80921cb7c502eceb637b3c7f3fa875fa80369256ed3db956566b70a9b8bb96fd)
                check_type(argname="argument pivot_table_aggregated_field_wells", value=pivot_table_aggregated_field_wells, expected_type=type_hints["pivot_table_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pivot_table_aggregated_field_wells is not None:
                self._values["pivot_table_aggregated_field_wells"] = pivot_table_aggregated_field_wells

        @builtins.property
        def pivot_table_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableAggregatedFieldWellsProperty"]]:
            '''The aggregated field well for the pivot table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldwells.html#cfn-quicksight-dashboard-pivottablefieldwells-pivottableaggregatedfieldwells
            '''
            result = self._values.get("pivot_table_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotTableOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cell_style": "cellStyle",
            "collapsed_row_dimensions_visibility": "collapsedRowDimensionsVisibility",
            "column_header_style": "columnHeaderStyle",
            "column_names_visibility": "columnNamesVisibility",
            "default_cell_width": "defaultCellWidth",
            "metric_placement": "metricPlacement",
            "row_alternate_color_options": "rowAlternateColorOptions",
            "row_field_names_style": "rowFieldNamesStyle",
            "row_header_style": "rowHeaderStyle",
            "rows_label_options": "rowsLabelOptions",
            "rows_layout": "rowsLayout",
            "single_metric_visibility": "singleMetricVisibility",
            "toggle_buttons_visibility": "toggleButtonsVisibility",
        },
    )
    class PivotTableOptionsProperty:
        def __init__(
            self,
            *,
            cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            collapsed_row_dimensions_visibility: typing.Optional[builtins.str] = None,
            column_header_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_names_visibility: typing.Optional[builtins.str] = None,
            default_cell_width: typing.Optional[builtins.str] = None,
            metric_placement: typing.Optional[builtins.str] = None,
            row_alternate_color_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.RowAlternateColorOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_field_names_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_header_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rows_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTableRowsLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rows_layout: typing.Optional[builtins.str] = None,
            single_metric_visibility: typing.Optional[builtins.str] = None,
            toggle_buttons_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The table options for a pivot table visual.

            :param cell_style: The table cell style of cells.
            :param collapsed_row_dimensions_visibility: The visibility setting of a pivot table's collapsed row dimension fields. If the value of this structure is ``HIDDEN`` , all collapsed columns in a pivot table are automatically hidden. The default value is ``VISIBLE`` .
            :param column_header_style: The table cell style of the column header.
            :param column_names_visibility: The visibility of the column names.
            :param default_cell_width: The default cell width of the pivot table.
            :param metric_placement: The metric placement (row, column) options.
            :param row_alternate_color_options: The row alternate color options (widget status, row alternate colors).
            :param row_field_names_style: The table cell style of row field names.
            :param row_header_style: The table cell style of the row headers.
            :param rows_label_options: The options for the label that is located above the row headers. This option is only applicable when ``RowsLayout`` is set to ``HIERARCHY`` .
            :param rows_layout: The layout for the row dimension headers of a pivot table. Choose one of the following options. - ``TABULAR`` : (Default) Each row field is displayed in a separate column. - ``HIERARCHY`` : All row fields are displayed in a single column. Indentation is used to differentiate row headers of different fields.
            :param single_metric_visibility: The visibility of the single metric options.
            :param toggle_buttons_visibility: Determines the visibility of the pivot table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_options_property = quicksight.CfnDashboard.PivotTableOptionsProperty(
                    cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    collapsed_row_dimensions_visibility="collapsedRowDimensionsVisibility",
                    column_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    column_names_visibility="columnNamesVisibility",
                    default_cell_width="defaultCellWidth",
                    metric_placement="metricPlacement",
                    row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                        row_alternate_colors=["rowAlternateColors"],
                        status="status",
                        use_primary_background_color="usePrimaryBackgroundColor"
                    ),
                    row_field_names_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    row_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    rows_label_options=quicksight.CfnDashboard.PivotTableRowsLabelOptionsProperty(
                        custom_label="customLabel",
                        visibility="visibility"
                    ),
                    rows_layout="rowsLayout",
                    single_metric_visibility="singleMetricVisibility",
                    toggle_buttons_visibility="toggleButtonsVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__647bc3514c4755920ad2bc82545b3653fb6bca626410bc3b47ce4f6ab59093cc)
                check_type(argname="argument cell_style", value=cell_style, expected_type=type_hints["cell_style"])
                check_type(argname="argument collapsed_row_dimensions_visibility", value=collapsed_row_dimensions_visibility, expected_type=type_hints["collapsed_row_dimensions_visibility"])
                check_type(argname="argument column_header_style", value=column_header_style, expected_type=type_hints["column_header_style"])
                check_type(argname="argument column_names_visibility", value=column_names_visibility, expected_type=type_hints["column_names_visibility"])
                check_type(argname="argument default_cell_width", value=default_cell_width, expected_type=type_hints["default_cell_width"])
                check_type(argname="argument metric_placement", value=metric_placement, expected_type=type_hints["metric_placement"])
                check_type(argname="argument row_alternate_color_options", value=row_alternate_color_options, expected_type=type_hints["row_alternate_color_options"])
                check_type(argname="argument row_field_names_style", value=row_field_names_style, expected_type=type_hints["row_field_names_style"])
                check_type(argname="argument row_header_style", value=row_header_style, expected_type=type_hints["row_header_style"])
                check_type(argname="argument rows_label_options", value=rows_label_options, expected_type=type_hints["rows_label_options"])
                check_type(argname="argument rows_layout", value=rows_layout, expected_type=type_hints["rows_layout"])
                check_type(argname="argument single_metric_visibility", value=single_metric_visibility, expected_type=type_hints["single_metric_visibility"])
                check_type(argname="argument toggle_buttons_visibility", value=toggle_buttons_visibility, expected_type=type_hints["toggle_buttons_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell_style is not None:
                self._values["cell_style"] = cell_style
            if collapsed_row_dimensions_visibility is not None:
                self._values["collapsed_row_dimensions_visibility"] = collapsed_row_dimensions_visibility
            if column_header_style is not None:
                self._values["column_header_style"] = column_header_style
            if column_names_visibility is not None:
                self._values["column_names_visibility"] = column_names_visibility
            if default_cell_width is not None:
                self._values["default_cell_width"] = default_cell_width
            if metric_placement is not None:
                self._values["metric_placement"] = metric_placement
            if row_alternate_color_options is not None:
                self._values["row_alternate_color_options"] = row_alternate_color_options
            if row_field_names_style is not None:
                self._values["row_field_names_style"] = row_field_names_style
            if row_header_style is not None:
                self._values["row_header_style"] = row_header_style
            if rows_label_options is not None:
                self._values["rows_label_options"] = rows_label_options
            if rows_layout is not None:
                self._values["rows_layout"] = rows_layout
            if single_metric_visibility is not None:
                self._values["single_metric_visibility"] = single_metric_visibility
            if toggle_buttons_visibility is not None:
                self._values["toggle_buttons_visibility"] = toggle_buttons_visibility

        @builtins.property
        def cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]]:
            '''The table cell style of cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-cellstyle
            '''
            result = self._values.get("cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def collapsed_row_dimensions_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility setting of a pivot table's collapsed row dimension fields.

            If the value of this structure is ``HIDDEN`` , all collapsed columns in a pivot table are automatically hidden. The default value is ``VISIBLE`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-collapsedrowdimensionsvisibility
            '''
            result = self._values.get("collapsed_row_dimensions_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def column_header_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]]:
            '''The table cell style of the column header.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-columnheaderstyle
            '''
            result = self._values.get("column_header_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def column_names_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the column names.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-columnnamesvisibility
            '''
            result = self._values.get("column_names_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def default_cell_width(self) -> typing.Optional[builtins.str]:
            '''The default cell width of the pivot table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-defaultcellwidth
            '''
            result = self._values.get("default_cell_width")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def metric_placement(self) -> typing.Optional[builtins.str]:
            '''The metric placement (row, column) options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-metricplacement
            '''
            result = self._values.get("metric_placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def row_alternate_color_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RowAlternateColorOptionsProperty"]]:
            '''The row alternate color options (widget status, row alternate colors).

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-rowalternatecoloroptions
            '''
            result = self._values.get("row_alternate_color_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RowAlternateColorOptionsProperty"]], result)

        @builtins.property
        def row_field_names_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]]:
            '''The table cell style of row field names.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-rowfieldnamesstyle
            '''
            result = self._values.get("row_field_names_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def row_header_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]]:
            '''The table cell style of the row headers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-rowheaderstyle
            '''
            result = self._values.get("row_header_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def rows_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableRowsLabelOptionsProperty"]]:
            '''The options for the label that is located above the row headers.

            This option is only applicable when ``RowsLayout`` is set to ``HIERARCHY`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-rowslabeloptions
            '''
            result = self._values.get("rows_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableRowsLabelOptionsProperty"]], result)

        @builtins.property
        def rows_layout(self) -> typing.Optional[builtins.str]:
            '''The layout for the row dimension headers of a pivot table. Choose one of the following options.

            - ``TABULAR`` : (Default) Each row field is displayed in a separate column.
            - ``HIERARCHY`` : All row fields are displayed in a single column. Indentation is used to differentiate row headers of different fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-rowslayout
            '''
            result = self._values.get("rows_layout")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def single_metric_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the single metric options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-singlemetricvisibility
            '''
            result = self._values.get("single_metric_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def toggle_buttons_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the pivot table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-togglebuttonsvisibility
            '''
            result = self._values.get("toggle_buttons_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotTablePaginatedReportOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "overflow_column_header_visibility": "overflowColumnHeaderVisibility",
            "vertical_overflow_visibility": "verticalOverflowVisibility",
        },
    )
    class PivotTablePaginatedReportOptionsProperty:
        def __init__(
            self,
            *,
            overflow_column_header_visibility: typing.Optional[builtins.str] = None,
            vertical_overflow_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The paginated report options for a pivot table visual.

            :param overflow_column_header_visibility: The visibility of the repeating header rows on each page.
            :param vertical_overflow_visibility: The visibility of the printing table overflow across pages.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablepaginatedreportoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_paginated_report_options_property = quicksight.CfnDashboard.PivotTablePaginatedReportOptionsProperty(
                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                    vertical_overflow_visibility="verticalOverflowVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2f3c0005696cb23fd498b71c5de2425da46f04c93805086400da946862377e82)
                check_type(argname="argument overflow_column_header_visibility", value=overflow_column_header_visibility, expected_type=type_hints["overflow_column_header_visibility"])
                check_type(argname="argument vertical_overflow_visibility", value=vertical_overflow_visibility, expected_type=type_hints["vertical_overflow_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if overflow_column_header_visibility is not None:
                self._values["overflow_column_header_visibility"] = overflow_column_header_visibility
            if vertical_overflow_visibility is not None:
                self._values["vertical_overflow_visibility"] = vertical_overflow_visibility

        @builtins.property
        def overflow_column_header_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the repeating header rows on each page.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablepaginatedreportoptions.html#cfn-quicksight-dashboard-pivottablepaginatedreportoptions-overflowcolumnheadervisibility
            '''
            result = self._values.get("overflow_column_header_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_overflow_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the printing table overflow across pages.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablepaginatedreportoptions.html#cfn-quicksight-dashboard-pivottablepaginatedreportoptions-verticaloverflowvisibility
            '''
            result = self._values.get("vertical_overflow_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTablePaginatedReportOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotTableRowsLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_label": "customLabel", "visibility": "visibility"},
    )
    class PivotTableRowsLabelOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for the label thta is located above the row headers.

            This option is only applicable when ``RowsLayout`` is set to ``HIERARCHY`` .

            :param custom_label: The custom label string for the rows label.
            :param visibility: The visibility of the rows label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablerowslabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_rows_label_options_property = quicksight.CfnDashboard.PivotTableRowsLabelOptionsProperty(
                    custom_label="customLabel",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__96429ea8e3ed4ba817d09eed2497a2a71cbae45bbb215ca360cb79ccfaaa00e0)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the rows label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablerowslabeloptions.html#cfn-quicksight-dashboard-pivottablerowslabeloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the rows label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablerowslabeloptions.html#cfn-quicksight-dashboard-pivottablerowslabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableRowsLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotTableSortByProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "data_path": "dataPath", "field": "field"},
    )
    class PivotTableSortByProperty:
        def __init__(
            self,
            *,
            column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_path: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataPathSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The sort by field for the field sort options.

            :param column: The column sort (field id, direction) for the pivot table sort by options.
            :param data_path: The data path sort (data path value, direction) for the pivot table sort by options.
            :param field: The field sort (field id, direction) for the pivot table sort by options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortby.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_sort_by_property = quicksight.CfnDashboard.PivotTableSortByProperty(
                    column=quicksight.CfnDashboard.ColumnSortProperty(
                        direction="direction",
                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                            attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                simple_attribute_aggregation="simpleAttributeAggregation",
                                value_for_multiple_values="valueForMultipleValues"
                            ),
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    data_path=quicksight.CfnDashboard.DataPathSortProperty(
                        direction="direction",
                        sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                            data_path_type=quicksight.CfnDashboard.DataPathTypeProperty(
                                pivot_table_data_path_type="pivotTableDataPathType"
                            ),
                            field_id="fieldId",
                            field_value="fieldValue"
                        )]
                    ),
                    field=quicksight.CfnDashboard.FieldSortProperty(
                        direction="direction",
                        field_id="fieldId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__18992597bc6d52b2cd3a0a7d81f5ad09cec19f639c3421b146611bdeff7f1871)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument data_path", value=data_path, expected_type=type_hints["data_path"])
                check_type(argname="argument field", value=field, expected_type=type_hints["field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column is not None:
                self._values["column"] = column
            if data_path is not None:
                self._values["data_path"] = data_path
            if field is not None:
                self._values["field"] = field

        @builtins.property
        def column(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnSortProperty"]]:
            '''The column sort (field id, direction) for the pivot table sort by options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortby.html#cfn-quicksight-dashboard-pivottablesortby-column
            '''
            result = self._values.get("column")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnSortProperty"]], result)

        @builtins.property
        def data_path(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPathSortProperty"]]:
            '''The data path sort (data path value, direction) for the pivot table sort by options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortby.html#cfn-quicksight-dashboard-pivottablesortby-datapath
            '''
            result = self._values.get("data_path")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPathSortProperty"]], result)

        @builtins.property
        def field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortProperty"]]:
            '''The field sort (field id, direction) for the pivot table sort by options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortby.html#cfn-quicksight-dashboard-pivottablesortby-field
            '''
            result = self._values.get("field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableSortByProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotTableSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"field_sort_options": "fieldSortOptions"},
    )
    class PivotTableSortConfigurationProperty:
        def __init__(
            self,
            *,
            field_sort_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotFieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration for a ``PivotTableVisual`` .

            :param field_sort_options: The field sort options for a pivot table sort configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_sort_configuration_property = quicksight.CfnDashboard.PivotTableSortConfigurationProperty(
                    field_sort_options=[quicksight.CfnDashboard.PivotFieldSortOptionsProperty(
                        field_id="fieldId",
                        sort_by=quicksight.CfnDashboard.PivotTableSortByProperty(
                            column=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                        simple_attribute_aggregation="simpleAttributeAggregation",
                                        value_for_multiple_values="valueForMultipleValues"
                                    ),
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            data_path=quicksight.CfnDashboard.DataPathSortProperty(
                                direction="direction",
                                sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                                    data_path_type=quicksight.CfnDashboard.DataPathTypeProperty(
                                        pivot_table_data_path_type="pivotTableDataPathType"
                                    ),
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                )]
                            ),
                            field=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__128ecd0c48f46fd1ef9c2887afca956252afdfc417006cefc8994174c0a49d3c)
                check_type(argname="argument field_sort_options", value=field_sort_options, expected_type=type_hints["field_sort_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_sort_options is not None:
                self._values["field_sort_options"] = field_sort_options

        @builtins.property
        def field_sort_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotFieldSortOptionsProperty"]]]]:
            '''The field sort options for a pivot table sort configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortconfiguration.html#cfn-quicksight-dashboard-pivottablesortconfiguration-fieldsortoptions
            '''
            result = self._values.get("field_sort_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotFieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotTableTotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_subtotal_options": "columnSubtotalOptions",
            "column_total_options": "columnTotalOptions",
            "row_subtotal_options": "rowSubtotalOptions",
            "row_total_options": "rowTotalOptions",
        },
    )
    class PivotTableTotalOptionsProperty:
        def __init__(
            self,
            *,
            column_subtotal_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_subtotal_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The total options for a pivot table visual.

            :param column_subtotal_options: The column subtotal options.
            :param column_total_options: The column total options.
            :param row_subtotal_options: The row subtotal options.
            :param row_total_options: The row total options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c7ffe22539985673bb9a56d7a28def50da65e12afff107cda6f85953e112a8c3)
                check_type(argname="argument column_subtotal_options", value=column_subtotal_options, expected_type=type_hints["column_subtotal_options"])
                check_type(argname="argument column_total_options", value=column_total_options, expected_type=type_hints["column_total_options"])
                check_type(argname="argument row_subtotal_options", value=row_subtotal_options, expected_type=type_hints["row_subtotal_options"])
                check_type(argname="argument row_total_options", value=row_total_options, expected_type=type_hints["row_total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_subtotal_options is not None:
                self._values["column_subtotal_options"] = column_subtotal_options
            if column_total_options is not None:
                self._values["column_total_options"] = column_total_options
            if row_subtotal_options is not None:
                self._values["row_subtotal_options"] = row_subtotal_options
            if row_total_options is not None:
                self._values["row_total_options"] = row_total_options

        @builtins.property
        def column_subtotal_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SubtotalOptionsProperty"]]:
            '''The column subtotal options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html#cfn-quicksight-dashboard-pivottabletotaloptions-columnsubtotaloptions
            '''
            result = self._values.get("column_subtotal_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SubtotalOptionsProperty"]], result)

        @builtins.property
        def column_total_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTotalOptionsProperty"]]:
            '''The column total options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html#cfn-quicksight-dashboard-pivottabletotaloptions-columntotaloptions
            '''
            result = self._values.get("column_total_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTotalOptionsProperty"]], result)

        @builtins.property
        def row_subtotal_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SubtotalOptionsProperty"]]:
            '''The row subtotal options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html#cfn-quicksight-dashboard-pivottabletotaloptions-rowsubtotaloptions
            '''
            result = self._values.get("row_subtotal_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SubtotalOptionsProperty"]], result)

        @builtins.property
        def row_total_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTotalOptionsProperty"]]:
            '''The row total options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html#cfn-quicksight-dashboard-pivottabletotaloptions-rowtotaloptions
            '''
            result = self._values.get("row_total_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTotalOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableTotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotTableVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class PivotTableVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTableConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTableConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A pivot table.

            For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param conditional_formatting: The conditional formatting for a ``PivotTableVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__17f823054c3b5510a12fe64995f8311fffb344955711669303c5c7d75692f19a)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableConfigurationProperty"]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableConditionalFormattingProperty"]]:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PivotTotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "metric_header_cell_style": "metricHeaderCellStyle",
            "placement": "placement",
            "scroll_status": "scrollStatus",
            "total_aggregation_options": "totalAggregationOptions",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
            "value_cell_style": "valueCellStyle",
        },
    )
    class PivotTotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            metric_header_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            placement: typing.Optional[builtins.str] = None,
            scroll_status: typing.Optional[builtins.str] = None,
            total_aggregation_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TotalAggregationOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            total_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
            value_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The optional configuration of totals cells in a ``PivotTableVisual`` .

            :param custom_label: The custom label string for the total cells.
            :param metric_header_cell_style: The cell styling options for the total of header cells.
            :param placement: The placement (start, end) for the total cells.
            :param scroll_status: The scroll status (pinned, scrolled) for the total cells.
            :param total_aggregation_options: The total aggregation options for each value field.
            :param total_cell_style: The cell styling options for the total cells.
            :param totals_visibility: The visibility configuration for the total cells.
            :param value_cell_style: The cell styling options for the totals of value cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_total_options_property = quicksight.CfnDashboard.PivotTotalOptionsProperty(
                    custom_label="customLabel",
                    metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    placement="placement",
                    scroll_status="scrollStatus",
                    total_aggregation_options=[quicksight.CfnDashboard.TotalAggregationOptionProperty(
                        field_id="fieldId",
                        total_aggregation_function=quicksight.CfnDashboard.TotalAggregationFunctionProperty(
                            simple_total_aggregation_function="simpleTotalAggregationFunction"
                        )
                    )],
                    total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility",
                    value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8c9f9ef553aa6664e46fd6b9709a239463e1b02039328214aad0792872cafe00)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument metric_header_cell_style", value=metric_header_cell_style, expected_type=type_hints["metric_header_cell_style"])
                check_type(argname="argument placement", value=placement, expected_type=type_hints["placement"])
                check_type(argname="argument scroll_status", value=scroll_status, expected_type=type_hints["scroll_status"])
                check_type(argname="argument total_aggregation_options", value=total_aggregation_options, expected_type=type_hints["total_aggregation_options"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
                check_type(argname="argument value_cell_style", value=value_cell_style, expected_type=type_hints["value_cell_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if metric_header_cell_style is not None:
                self._values["metric_header_cell_style"] = metric_header_cell_style
            if placement is not None:
                self._values["placement"] = placement
            if scroll_status is not None:
                self._values["scroll_status"] = scroll_status
            if total_aggregation_options is not None:
                self._values["total_aggregation_options"] = total_aggregation_options
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility
            if value_cell_style is not None:
                self._values["value_cell_style"] = value_cell_style

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def metric_header_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]]:
            '''The cell styling options for the total of header cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-metricheadercellstyle
            '''
            result = self._values.get("metric_header_cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def placement(self) -> typing.Optional[builtins.str]:
            '''The placement (start, end) for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-placement
            '''
            result = self._values.get("placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scroll_status(self) -> typing.Optional[builtins.str]:
            '''The scroll status (pinned, scrolled) for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-scrollstatus
            '''
            result = self._values.get("scroll_status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def total_aggregation_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TotalAggregationOptionProperty"]]]]:
            '''The total aggregation options for each value field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-totalaggregationoptions
            '''
            result = self._values.get("total_aggregation_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TotalAggregationOptionProperty"]]]], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]]:
            '''The cell styling options for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]]:
            '''The cell styling options for the totals of value cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-valuecellstyle
            '''
            result = self._values.get("value_cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.PredefinedHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class PredefinedHierarchyProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]]],
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields that are defined during data preparation.

            These fields are available to use in any analysis that uses the data source.

            :param columns: The list of columns that define the predefined hierarchy.
            :param hierarchy_id: The hierarchy ID of the predefined hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the predefined hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-predefinedhierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                predefined_hierarchy_property = quicksight.CfnDashboard.PredefinedHierarchyProperty(
                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7a1728d0c09a8313ef184532312285397fa5c2dc0820846adf497ed679e05522)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]]]:
            '''The list of columns that define the predefined hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-predefinedhierarchy.html#cfn-quicksight-dashboard-predefinedhierarchy-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]]], result)

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the predefined hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-predefinedhierarchy.html#cfn-quicksight-dashboard-predefinedhierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DrillDownFilterProperty"]]]]:
            '''The option that determines the drill down filters for the predefined hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-predefinedhierarchy.html#cfn-quicksight-dashboard-predefinedhierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DrillDownFilterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PredefinedHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ProgressBarOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ProgressBarOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of the progress bar of a KPI visual.

            :param visibility: The visibility of the progress bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-progressbaroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                progress_bar_options_property = quicksight.CfnDashboard.ProgressBarOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7b749fd545ef26437f40040ce3d66eb5fc1f74dd885bdbd215d96299ae633448)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the progress bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-progressbaroptions.html#cfn-quicksight-dashboard-progressbaroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ProgressBarOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.RadarChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"category": "category", "color": "color", "values": "values"},
    )
    class RadarChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well configuration of a ``RadarChartVisual`` .

            :param category: The aggregated field well categories of a radar chart.
            :param color: The color that are assigned to the aggregated field wells of a radar chart.
            :param values: The values that are assigned to the aggregated field wells of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__62e03423d11f9d7c54d2dbabdc23b969f7868353b929e4d5ed40a4a2e3caac79)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if color is not None:
                self._values["color"] = color
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The aggregated field well categories of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartaggregatedfieldwells.html#cfn-quicksight-dashboard-radarchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The color that are assigned to the aggregated field wells of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartaggregatedfieldwells.html#cfn-quicksight-dashboard-radarchartaggregatedfieldwells-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The values that are assigned to the aggregated field wells of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartaggregatedfieldwells.html#cfn-quicksight-dashboard-radarchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class RadarChartAreaStyleSettingsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configured style settings of a radar chart.

            :param visibility: The visibility settings of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartareastylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                radar_chart_area_style_settings_property = quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3574d25bb1ec71053c4a291fcc2d7fa3e00d83cbc5635aee40652325bfc3fc2b)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility settings of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartareastylesettings.html#cfn-quicksight-dashboard-radarchartareastylesettings-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartAreaStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.RadarChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "alternate_band_colors_visibility": "alternateBandColorsVisibility",
            "alternate_band_even_color": "alternateBandEvenColor",
            "alternate_band_odd_color": "alternateBandOddColor",
            "axes_range_scale": "axesRangeScale",
            "base_series_settings": "baseSeriesSettings",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_axis": "colorAxis",
            "color_label_options": "colorLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "shape": "shape",
            "sort_configuration": "sortConfiguration",
            "start_angle": "startAngle",
            "visual_palette": "visualPalette",
        },
    )
    class RadarChartConfigurationProperty:
        def __init__(
            self,
            *,
            alternate_band_colors_visibility: typing.Optional[builtins.str] = None,
            alternate_band_even_color: typing.Optional[builtins.str] = None,
            alternate_band_odd_color: typing.Optional[builtins.str] = None,
            axes_range_scale: typing.Optional[builtins.str] = None,
            base_series_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.RadarChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.RadarChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            shape: typing.Optional[builtins.str] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.RadarChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            start_angle: typing.Optional[jsii.Number] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``RadarChartVisual`` .

            :param alternate_band_colors_visibility: Determines the visibility of the colors of alternatign bands in a radar chart.
            :param alternate_band_even_color: The color of the even-numbered alternate bands of a radar chart.
            :param alternate_band_odd_color: The color of the odd-numbered alternate bands of a radar chart.
            :param axes_range_scale: The axis behavior options of a radar chart.
            :param base_series_settings: The base sreies settings of a radar chart.
            :param category_axis: The category axis of a radar chart.
            :param category_label_options: The category label options of a radar chart.
            :param color_axis: The color axis of a radar chart.
            :param color_label_options: The color label options of a radar chart.
            :param field_wells: The field well configuration of a ``RadarChartVisual`` .
            :param legend: The legend display setup of the visual.
            :param shape: The shape of the radar chart.
            :param sort_configuration: The sort configuration of a ``RadarChartVisual`` .
            :param start_angle: The start angle of a radar chart's axis.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f8b2b95ea63c2d804761b6d030d52bbc1ab1dda02416747db69f54542b5ffb3b)
                check_type(argname="argument alternate_band_colors_visibility", value=alternate_band_colors_visibility, expected_type=type_hints["alternate_band_colors_visibility"])
                check_type(argname="argument alternate_band_even_color", value=alternate_band_even_color, expected_type=type_hints["alternate_band_even_color"])
                check_type(argname="argument alternate_band_odd_color", value=alternate_band_odd_color, expected_type=type_hints["alternate_band_odd_color"])
                check_type(argname="argument axes_range_scale", value=axes_range_scale, expected_type=type_hints["axes_range_scale"])
                check_type(argname="argument base_series_settings", value=base_series_settings, expected_type=type_hints["base_series_settings"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_axis", value=color_axis, expected_type=type_hints["color_axis"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument shape", value=shape, expected_type=type_hints["shape"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument start_angle", value=start_angle, expected_type=type_hints["start_angle"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if alternate_band_colors_visibility is not None:
                self._values["alternate_band_colors_visibility"] = alternate_band_colors_visibility
            if alternate_band_even_color is not None:
                self._values["alternate_band_even_color"] = alternate_band_even_color
            if alternate_band_odd_color is not None:
                self._values["alternate_band_odd_color"] = alternate_band_odd_color
            if axes_range_scale is not None:
                self._values["axes_range_scale"] = axes_range_scale
            if base_series_settings is not None:
                self._values["base_series_settings"] = base_series_settings
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_axis is not None:
                self._values["color_axis"] = color_axis
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if shape is not None:
                self._values["shape"] = shape
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if start_angle is not None:
                self._values["start_angle"] = start_angle
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def alternate_band_colors_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the colors of alternatign bands in a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-alternatebandcolorsvisibility
            '''
            result = self._values.get("alternate_band_colors_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def alternate_band_even_color(self) -> typing.Optional[builtins.str]:
            '''The color of the even-numbered alternate bands of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-alternatebandevencolor
            '''
            result = self._values.get("alternate_band_even_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def alternate_band_odd_color(self) -> typing.Optional[builtins.str]:
            '''The color of the odd-numbered alternate bands of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-alternatebandoddcolor
            '''
            result = self._values.get("alternate_band_odd_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def axes_range_scale(self) -> typing.Optional[builtins.str]:
            '''The axis behavior options of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-axesrangescale
            '''
            result = self._values.get("axes_range_scale")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def base_series_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RadarChartSeriesSettingsProperty"]]:
            '''The base sreies settings of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-baseseriessettings
            '''
            result = self._values.get("base_series_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RadarChartSeriesSettingsProperty"]], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The category axis of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The category label options of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The color axis of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-coloraxis
            '''
            result = self._values.get("color_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The color label options of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RadarChartFieldWellsProperty"]]:
            '''The field well configuration of a ``RadarChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RadarChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def shape(self) -> typing.Optional[builtins.str]:
            '''The shape of the radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-shape
            '''
            result = self._values.get("shape")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RadarChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``RadarChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RadarChartSortConfigurationProperty"]], result)

        @builtins.property
        def start_angle(self) -> typing.Optional[jsii.Number]:
            '''The start angle of a radar chart's axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-startangle
            '''
            result = self._values.get("start_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.RadarChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "radar_chart_aggregated_field_wells": "radarChartAggregatedFieldWells",
        },
    )
    class RadarChartFieldWellsProperty:
        def __init__(
            self,
            *,
            radar_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.RadarChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a radar chart visual.

            :param radar_chart_aggregated_field_wells: The aggregated field wells of a radar chart visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d27f31b10381cf6b0b6ed55c67b45cd75c7a2ded433efdc724930790753d71c4)
                check_type(argname="argument radar_chart_aggregated_field_wells", value=radar_chart_aggregated_field_wells, expected_type=type_hints["radar_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if radar_chart_aggregated_field_wells is not None:
                self._values["radar_chart_aggregated_field_wells"] = radar_chart_aggregated_field_wells

        @builtins.property
        def radar_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RadarChartAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a radar chart visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartfieldwells.html#cfn-quicksight-dashboard-radarchartfieldwells-radarchartaggregatedfieldwells
            '''
            result = self._values.get("radar_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RadarChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.RadarChartSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={"area_style_settings": "areaStyleSettings"},
    )
    class RadarChartSeriesSettingsProperty:
        def __init__(
            self,
            *,
            area_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.RadarChartAreaStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The series settings of a radar chart.

            :param area_style_settings: The area style settings of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                radar_chart_series_settings_property = quicksight.CfnDashboard.RadarChartSeriesSettingsProperty(
                    area_style_settings=quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a4004a3e1c32d894c31463894410a7a70880545fbf036b9ec5bd72fd6638e46a)
                check_type(argname="argument area_style_settings", value=area_style_settings, expected_type=type_hints["area_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if area_style_settings is not None:
                self._values["area_style_settings"] = area_style_settings

        @builtins.property
        def area_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RadarChartAreaStyleSettingsProperty"]]:
            '''The area style settings of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartseriessettings.html#cfn-quicksight-dashboard-radarchartseriessettings-areastylesettings
            '''
            result = self._values.get("area_style_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RadarChartAreaStyleSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.RadarChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
        },
    )
    class RadarChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``RadarChartVisual`` .

            :param category_items_limit: The category items limit for a radar chart.
            :param category_sort: The category sort options of a radar chart.
            :param color_items_limit: The color items limit of a radar chart.
            :param color_sort: The color sort configuration of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                radar_chart_sort_configuration_property = quicksight.CfnDashboard.RadarChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5d9eac0d17c16fd208c75930518bd566ad2f9eec8739688a8d5c0cb256ac414f)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The category items limit for a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html#cfn-quicksight-dashboard-radarchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The category sort options of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html#cfn-quicksight-dashboard-radarchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The color items limit of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html#cfn-quicksight-dashboard-radarchartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The color sort configuration of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html#cfn-quicksight-dashboard-radarchartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.RadarChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class RadarChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.RadarChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A radar chart visual.

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e6d067660fed84a2ae13210d98360271bc1aea0cffe8c96910b68705ed5251d5)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RadarChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RadarChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.RangeEndsLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class RangeEndsLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The range ends label type of a data path label.

            :param visibility: The visibility of the range ends label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rangeendslabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                range_ends_label_type_property = quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fa68ac0dee70640e44360e40bcd349230a00eff9342a2feaa8aa638ad3f4e726)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the range ends label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rangeendslabeltype.html#cfn-quicksight-dashboard-rangeendslabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RangeEndsLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_label": "customLabel"},
    )
    class ReferenceLineCustomLabelConfigurationProperty:
        def __init__(self, *, custom_label: builtins.str) -> None:
            '''The configuration for a custom label on a ``ReferenceLine`` .

            :param custom_label: The string text of the custom label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinecustomlabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_custom_label_configuration_property = quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                    custom_label="customLabel"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ee64c1f668eea654b8957c17488ee38a60038469bf8dc04ce4689a01508c5781)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "custom_label": custom_label,
            }

        @builtins.property
        def custom_label(self) -> builtins.str:
            '''The string text of the custom label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinecustomlabelconfiguration.html#cfn-quicksight-dashboard-referencelinecustomlabelconfiguration-customlabel
            '''
            result = self._values.get("custom_label")
            assert result is not None, "Required property 'custom_label' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineCustomLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "dynamic_configuration": "dynamicConfiguration",
            "series_type": "seriesType",
            "static_configuration": "staticConfiguration",
        },
    )
    class ReferenceLineDataConfigurationProperty:
        def __init__(
            self,
            *,
            axis_binding: typing.Optional[builtins.str] = None,
            dynamic_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ReferenceLineDynamicDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            series_type: typing.Optional[builtins.str] = None,
            static_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ReferenceLineStaticDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The data configuration of the reference line.

            :param axis_binding: The axis binding type of the reference line. Choose one of the following options:. - ``PrimaryY`` - ``SecondaryY``
            :param dynamic_configuration: The dynamic configuration of the reference line data configuration.
            :param series_type: The series type of the reference line data configuration. Choose one of the following options:. - ``BAR`` - ``LINE``
            :param static_configuration: The static data configuration of the reference line data configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_data_configuration_property = quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                    axis_binding="axisBinding",
                    dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                        calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        ),
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                            attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                simple_attribute_aggregation="simpleAttributeAggregation",
                                value_for_multiple_values="valueForMultipleValues"
                            ),
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    series_type="seriesType",
                    static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                        value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8d33a2d7c5fd4d4c51fd48a8a96752ae149d40e45bd87bab473c5a4ceafce71f)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument dynamic_configuration", value=dynamic_configuration, expected_type=type_hints["dynamic_configuration"])
                check_type(argname="argument series_type", value=series_type, expected_type=type_hints["series_type"])
                check_type(argname="argument static_configuration", value=static_configuration, expected_type=type_hints["static_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_binding is not None:
                self._values["axis_binding"] = axis_binding
            if dynamic_configuration is not None:
                self._values["dynamic_configuration"] = dynamic_configuration
            if series_type is not None:
                self._values["series_type"] = series_type
            if static_configuration is not None:
                self._values["static_configuration"] = static_configuration

        @builtins.property
        def axis_binding(self) -> typing.Optional[builtins.str]:
            '''The axis binding type of the reference line. Choose one of the following options:.

            - ``PrimaryY``
            - ``SecondaryY``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html#cfn-quicksight-dashboard-referencelinedataconfiguration-axisbinding
            '''
            result = self._values.get("axis_binding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def dynamic_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineDynamicDataConfigurationProperty"]]:
            '''The dynamic configuration of the reference line data configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html#cfn-quicksight-dashboard-referencelinedataconfiguration-dynamicconfiguration
            '''
            result = self._values.get("dynamic_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineDynamicDataConfigurationProperty"]], result)

        @builtins.property
        def series_type(self) -> typing.Optional[builtins.str]:
            '''The series type of the reference line data configuration. Choose one of the following options:.

            - ``BAR``
            - ``LINE``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html#cfn-quicksight-dashboard-referencelinedataconfiguration-seriestype
            '''
            result = self._values.get("series_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def static_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineStaticDataConfigurationProperty"]]:
            '''The static data configuration of the reference line data configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html#cfn-quicksight-dashboard-referencelinedataconfiguration-staticconfiguration
            '''
            result = self._values.get("static_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineStaticDataConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "calculation": "calculation",
            "column": "column",
            "measure_aggregation_function": "measureAggregationFunction",
        },
    )
    class ReferenceLineDynamicDataConfigurationProperty:
        def __init__(
            self,
            *,
            calculation: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]],
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            measure_aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The dynamic configuration of the reference line data configuration.

            :param calculation: The calculation that is used in the dynamic data.
            :param column: The column that the dynamic data targets.
            :param measure_aggregation_function: The aggregation function that is used in the dynamic data.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedynamicdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_dynamic_data_configuration_property = quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                    calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    ),
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                        attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                            simple_attribute_aggregation="simpleAttributeAggregation",
                            value_for_multiple_values="valueForMultipleValues"
                        ),
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__21da6679fe329754114304fa280ba42be3e8008c471e4782bbd89f5e9bb2c3e5)
                check_type(argname="argument calculation", value=calculation, expected_type=type_hints["calculation"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument measure_aggregation_function", value=measure_aggregation_function, expected_type=type_hints["measure_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "calculation": calculation,
                "column": column,
            }
            if measure_aggregation_function is not None:
                self._values["measure_aggregation_function"] = measure_aggregation_function

        @builtins.property
        def calculation(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericalAggregationFunctionProperty"]:
            '''The calculation that is used in the dynamic data.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedynamicdataconfiguration.html#cfn-quicksight-dashboard-referencelinedynamicdataconfiguration-calculation
            '''
            result = self._values.get("calculation")
            assert result is not None, "Required property 'calculation' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericalAggregationFunctionProperty"], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the dynamic data targets.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedynamicdataconfiguration.html#cfn-quicksight-dashboard-referencelinedynamicdataconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def measure_aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AggregationFunctionProperty"]]:
            '''The aggregation function that is used in the dynamic data.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedynamicdataconfiguration.html#cfn-quicksight-dashboard-referencelinedynamicdataconfiguration-measureaggregationfunction
            '''
            result = self._values.get("measure_aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AggregationFunctionProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineDynamicDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label_configuration": "customLabelConfiguration",
            "font_color": "fontColor",
            "font_configuration": "fontConfiguration",
            "horizontal_position": "horizontalPosition",
            "value_label_configuration": "valueLabelConfiguration",
            "vertical_position": "verticalPosition",
        },
    )
    class ReferenceLineLabelConfigurationProperty:
        def __init__(
            self,
            *,
            custom_label_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ReferenceLineCustomLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            font_color: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            horizontal_position: typing.Optional[builtins.str] = None,
            value_label_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ReferenceLineValueLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            vertical_position: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label configuration of a reference line.

            :param custom_label_configuration: The custom label configuration of the label in a reference line.
            :param font_color: The font color configuration of the label in a reference line.
            :param font_configuration: The font configuration of the label in a reference line.
            :param horizontal_position: The horizontal position configuration of the label in a reference line. Choose one of the following options:. - ``LEFT`` - ``CENTER`` - ``RIGHT``
            :param value_label_configuration: The value label configuration of the label in a reference line.
            :param vertical_position: The vertical position configuration of the label in a reference line. Choose one of the following options:. - ``ABOVE`` - ``BELOW``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_label_configuration_property = quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                    custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                        custom_label="customLabel"
                    ),
                    font_color="fontColor",
                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    horizontal_position="horizontalPosition",
                    value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        relative_position="relativePosition"
                    ),
                    vertical_position="verticalPosition"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__62967aa6515f20b6aecf5b6c0b61f4f605dcfc33d23a40962adceed2559c71f6)
                check_type(argname="argument custom_label_configuration", value=custom_label_configuration, expected_type=type_hints["custom_label_configuration"])
                check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument horizontal_position", value=horizontal_position, expected_type=type_hints["horizontal_position"])
                check_type(argname="argument value_label_configuration", value=value_label_configuration, expected_type=type_hints["value_label_configuration"])
                check_type(argname="argument vertical_position", value=vertical_position, expected_type=type_hints["vertical_position"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label_configuration is not None:
                self._values["custom_label_configuration"] = custom_label_configuration
            if font_color is not None:
                self._values["font_color"] = font_color
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if horizontal_position is not None:
                self._values["horizontal_position"] = horizontal_position
            if value_label_configuration is not None:
                self._values["value_label_configuration"] = value_label_configuration
            if vertical_position is not None:
                self._values["vertical_position"] = vertical_position

        @builtins.property
        def custom_label_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineCustomLabelConfigurationProperty"]]:
            '''The custom label configuration of the label in a reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-customlabelconfiguration
            '''
            result = self._values.get("custom_label_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineCustomLabelConfigurationProperty"]], result)

        @builtins.property
        def font_color(self) -> typing.Optional[builtins.str]:
            '''The font color configuration of the label in a reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-fontcolor
            '''
            result = self._values.get("font_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"]]:
            '''The font configuration of the label in a reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"]], result)

        @builtins.property
        def horizontal_position(self) -> typing.Optional[builtins.str]:
            '''The horizontal position configuration of the label in a reference line. Choose one of the following options:.

            - ``LEFT``
            - ``CENTER``
            - ``RIGHT``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-horizontalposition
            '''
            result = self._values.get("horizontal_position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_label_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineValueLabelConfigurationProperty"]]:
            '''The value label configuration of the label in a reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-valuelabelconfiguration
            '''
            result = self._values.get("value_label_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineValueLabelConfigurationProperty"]], result)

        @builtins.property
        def vertical_position(self) -> typing.Optional[builtins.str]:
            '''The vertical position configuration of the label in a reference line. Choose one of the following options:.

            - ``ABOVE``
            - ``BELOW``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-verticalposition
            '''
            result = self._values.get("vertical_position")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ReferenceLineProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_configuration": "dataConfiguration",
            "label_configuration": "labelConfiguration",
            "status": "status",
            "style_configuration": "styleConfiguration",
        },
    )
    class ReferenceLineProperty:
        def __init__(
            self,
            *,
            data_configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ReferenceLineDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            label_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ReferenceLineLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            status: typing.Optional[builtins.str] = None,
            style_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ReferenceLineStyleConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The reference line visual display options.

            :param data_configuration: The data configuration of the reference line.
            :param label_configuration: The label configuration of the reference line.
            :param status: The status of the reference line. Choose one of the following options:. - ``ENABLE`` - ``DISABLE``
            :param style_configuration: The style configuration of the reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_property = quicksight.CfnDashboard.ReferenceLineProperty(
                    data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                        axis_binding="axisBinding",
                        dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                            calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        series_type="seriesType",
                        static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                            value=123
                        )
                    ),
                
                    # the properties below are optional
                    label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                        custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                            custom_label="customLabel"
                        ),
                        font_color="fontColor",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        horizontal_position="horizontalPosition",
                        value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            ),
                            relative_position="relativePosition"
                        ),
                        vertical_position="verticalPosition"
                    ),
                    status="status",
                    style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                        color="color",
                        pattern="pattern"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c838752ba4837b2434d363756aa31b60049b628a02ada11c1bf7a5fa7a5de955)
                check_type(argname="argument data_configuration", value=data_configuration, expected_type=type_hints["data_configuration"])
                check_type(argname="argument label_configuration", value=label_configuration, expected_type=type_hints["label_configuration"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument style_configuration", value=style_configuration, expected_type=type_hints["style_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_configuration": data_configuration,
            }
            if label_configuration is not None:
                self._values["label_configuration"] = label_configuration
            if status is not None:
                self._values["status"] = status
            if style_configuration is not None:
                self._values["style_configuration"] = style_configuration

        @builtins.property
        def data_configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineDataConfigurationProperty"]:
            '''The data configuration of the reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html#cfn-quicksight-dashboard-referenceline-dataconfiguration
            '''
            result = self._values.get("data_configuration")
            assert result is not None, "Required property 'data_configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineDataConfigurationProperty"], result)

        @builtins.property
        def label_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineLabelConfigurationProperty"]]:
            '''The label configuration of the reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html#cfn-quicksight-dashboard-referenceline-labelconfiguration
            '''
            result = self._values.get("label_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineLabelConfigurationProperty"]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the reference line. Choose one of the following options:.

            - ``ENABLE``
            - ``DISABLE``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html#cfn-quicksight-dashboard-referenceline-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineStyleConfigurationProperty"]]:
            '''The style configuration of the reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html#cfn-quicksight-dashboard-referenceline-styleconfiguration
            '''
            result = self._values.get("style_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ReferenceLineStyleConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"value": "value"},
    )
    class ReferenceLineStaticDataConfigurationProperty:
        def __init__(self, *, value: jsii.Number) -> None:
            '''The static data configuration of the reference line data configuration.

            :param value: The double input of the static data. Default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestaticdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_static_data_configuration_property = quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3b30b9703c5dbcaf4cd9c0e32404ef5b45ed3a46cbf071cf138aef9a262e0a27)
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "value": value,
            }

        @builtins.property
        def value(self) -> jsii.Number:
            '''The double input of the static data.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestaticdataconfiguration.html#cfn-quicksight-dashboard-referencelinestaticdataconfiguration-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineStaticDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "pattern": "pattern"},
    )
    class ReferenceLineStyleConfigurationProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            pattern: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The style configuration of the reference line.

            :param color: The hex color of the reference line.
            :param pattern: The pattern type of the line style. Choose one of the following options:. - ``SOLID`` - ``DASHED`` - ``DOTTED``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestyleconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_style_configuration_property = quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                    color="color",
                    pattern="pattern"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5a3de76085c19eb5a66bd01b1a0630ba106a324c78389fa048377ffd821b8370)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if pattern is not None:
                self._values["pattern"] = pattern

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The hex color of the reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestyleconfiguration.html#cfn-quicksight-dashboard-referencelinestyleconfiguration-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def pattern(self) -> typing.Optional[builtins.str]:
            '''The pattern type of the line style. Choose one of the following options:.

            - ``SOLID``
            - ``DASHED``
            - ``DOTTED``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestyleconfiguration.html#cfn-quicksight-dashboard-referencelinestyleconfiguration-pattern
            '''
            result = self._values.get("pattern")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineStyleConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "format_configuration": "formatConfiguration",
            "relative_position": "relativePosition",
        },
    )
    class ReferenceLineValueLabelConfigurationProperty:
        def __init__(
            self,
            *,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relative_position: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The value label configuration of the label in a reference line.

            :param format_configuration: The format configuration of the value label.
            :param relative_position: The relative position of the value label. Choose one of the following options:. - ``BEFORE_CUSTOM_LABEL`` - ``AFTER_CUSTOM_LABEL``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinevaluelabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_value_label_configuration_property = quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    ),
                    relative_position="relativePosition"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3247f974de1aad308687fd85c41b9a628efd021717e77a6c5c0dab4822c8f49c)
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument relative_position", value=relative_position, expected_type=type_hints["relative_position"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if relative_position is not None:
                self._values["relative_position"] = relative_position

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericFormatConfigurationProperty"]]:
            '''The format configuration of the value label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinevaluelabelconfiguration.html#cfn-quicksight-dashboard-referencelinevaluelabelconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericFormatConfigurationProperty"]], result)

        @builtins.property
        def relative_position(self) -> typing.Optional[builtins.str]:
            '''The relative position of the value label. Choose one of the following options:.

            - ``BEFORE_CUSTOM_LABEL``
            - ``AFTER_CUSTOM_LABEL``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinevaluelabelconfiguration.html#cfn-quicksight-dashboard-referencelinevaluelabelconfiguration-relativeposition
            '''
            result = self._values.get("relative_position")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineValueLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "info_icon_label_options": "infoIconLabelOptions",
            "title_options": "titleOptions",
        },
    )
    class RelativeDateTimeControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SheetControlInfoIconLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param date_time_format: Customize how dates are formatted in controls.
            :param info_icon_label_options: The configuration of info icon label options.
            :param title_options: The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatetimecontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                relative_date_time_control_display_options_property = quicksight.CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty(
                    date_time_format="dateTimeFormat",
                    info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                        info_icon_text="infoIconText",
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c342e4ed494f223863cfc40aab4ebc0bef453336b864af3eda85f85d4a084b37)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument info_icon_label_options", value=info_icon_label_options, expected_type=type_hints["info_icon_label_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if info_icon_label_options is not None:
                self._values["info_icon_label_options"] = info_icon_label_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Customize how dates are formatted in controls.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatetimecontroldisplayoptions.html#cfn-quicksight-dashboard-relativedatetimecontroldisplayoptions-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def info_icon_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetControlInfoIconLabelOptionsProperty"]]:
            '''The configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatetimecontroldisplayoptions.html#cfn-quicksight-dashboard-relativedatetimecontroldisplayoptions-infoiconlabeloptions
            '''
            result = self._values.get("info_icon_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetControlInfoIconLabelOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatetimecontroldisplayoptions.html#cfn-quicksight-dashboard-relativedatetimecontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RelativeDateTimeControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.RelativeDatesFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "anchor_date_configuration": "anchorDateConfiguration",
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "relative_date_type": "relativeDateType",
            "time_granularity": "timeGranularity",
            "exclude_period_configuration": "excludePeriodConfiguration",
            "minimum_granularity": "minimumGranularity",
            "parameter_name": "parameterName",
            "relative_date_value": "relativeDateValue",
        },
    )
    class RelativeDatesFilterProperty:
        def __init__(
            self,
            *,
            anchor_date_configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AnchorDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            null_option: builtins.str,
            relative_date_type: builtins.str,
            time_granularity: builtins.str,
            exclude_period_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ExcludePeriodConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            minimum_granularity: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            relative_date_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A ``RelativeDatesFilter`` filters relative dates values.

            :param anchor_date_configuration: The date configuration of the filter.
            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param relative_date_type: The range date type of the filter. Choose one of the options below:. - ``PREVIOUS`` - ``THIS`` - ``LAST`` - ``NOW`` - ``NEXT``
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param exclude_period_configuration: The configuration for the exclude period of the filter.
            :param minimum_granularity: The minimum granularity (period granularity) of the relative dates filter.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param relative_date_value: The date value of the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                relative_dates_filter_property = quicksight.CfnDashboard.RelativeDatesFilterProperty(
                    anchor_date_configuration=quicksight.CfnDashboard.AnchorDateConfigurationProperty(
                        anchor_option="anchorOption",
                        parameter_name="parameterName"
                    ),
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                    relative_date_type="relativeDateType",
                    time_granularity="timeGranularity",
                
                    # the properties below are optional
                    exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                        amount=123,
                        granularity="granularity",
                
                        # the properties below are optional
                        status="status"
                    ),
                    minimum_granularity="minimumGranularity",
                    parameter_name="parameterName",
                    relative_date_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0008784bd98efe44d920740108b262dbb255d2b3791bc7026913dde3cd832e92)
                check_type(argname="argument anchor_date_configuration", value=anchor_date_configuration, expected_type=type_hints["anchor_date_configuration"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument relative_date_type", value=relative_date_type, expected_type=type_hints["relative_date_type"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument exclude_period_configuration", value=exclude_period_configuration, expected_type=type_hints["exclude_period_configuration"])
                check_type(argname="argument minimum_granularity", value=minimum_granularity, expected_type=type_hints["minimum_granularity"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument relative_date_value", value=relative_date_value, expected_type=type_hints["relative_date_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "anchor_date_configuration": anchor_date_configuration,
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
                "relative_date_type": relative_date_type,
                "time_granularity": time_granularity,
            }
            if exclude_period_configuration is not None:
                self._values["exclude_period_configuration"] = exclude_period_configuration
            if minimum_granularity is not None:
                self._values["minimum_granularity"] = minimum_granularity
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if relative_date_value is not None:
                self._values["relative_date_value"] = relative_date_value

        @builtins.property
        def anchor_date_configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.AnchorDateConfigurationProperty"]:
            '''The date configuration of the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-anchordateconfiguration
            '''
            result = self._values.get("anchor_date_configuration")
            assert result is not None, "Required property 'anchor_date_configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.AnchorDateConfigurationProperty"], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def relative_date_type(self) -> builtins.str:
            '''The range date type of the filter. Choose one of the options below:.

            - ``PREVIOUS``
            - ``THIS``
            - ``LAST``
            - ``NOW``
            - ``NEXT``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-relativedatetype
            '''
            result = self._values.get("relative_date_type")
            assert result is not None, "Required property 'relative_date_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time_granularity(self) -> builtins.str:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            assert result is not None, "Required property 'time_granularity' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def exclude_period_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ExcludePeriodConfigurationProperty"]]:
            '''The configuration for the exclude period of the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-excludeperiodconfiguration
            '''
            result = self._values.get("exclude_period_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ExcludePeriodConfigurationProperty"]], result)

        @builtins.property
        def minimum_granularity(self) -> typing.Optional[builtins.str]:
            '''The minimum granularity (period granularity) of the relative dates filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-minimumgranularity
            '''
            result = self._values.get("minimum_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def relative_date_value(self) -> typing.Optional[jsii.Number]:
            '''The date value of the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-relativedatevalue
            '''
            result = self._values.get("relative_date_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RelativeDatesFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ResourcePermissionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "actions": "actions",
            "principal": "principal",
            "resource": "resource",
        },
    )
    class ResourcePermissionProperty:
        def __init__(
            self,
            *,
            actions: typing.Sequence[builtins.str],
            principal: builtins.str,
            resource: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Permission for the resource.

            :param actions: The IAM action to grant or revoke permissions on.
            :param principal: The Amazon Resource Name (ARN) of the principal. This can be one of the following:. - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.) - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.) - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
            :param resource: 

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-resourcepermission.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                resource_permission_property = quicksight.CfnDashboard.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal",
                
                    # the properties below are optional
                    resource="resource"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__76baf4fdfbee4ab96cf6c6ee179d48b7f41788ca1c0f3b487a3068b2a53ceff0)
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
                check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "actions": actions,
                "principal": principal,
            }
            if resource is not None:
                self._values["resource"] = resource

        @builtins.property
        def actions(self) -> typing.List[builtins.str]:
            '''The IAM action to grant or revoke permissions on.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-resourcepermission.html#cfn-quicksight-dashboard-resourcepermission-actions
            '''
            result = self._values.get("actions")
            assert result is not None, "Required property 'actions' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def principal(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the principal. This can be one of the following:.

            - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
            - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
            - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-resourcepermission.html#cfn-quicksight-dashboard-resourcepermission-principal
            '''
            result = self._values.get("principal")
            assert result is not None, "Required property 'principal' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def resource(self) -> typing.Optional[builtins.str]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-resourcepermission.html#cfn-quicksight-dashboard-resourcepermission-resource
            '''
            result = self._values.get("resource")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ResourcePermissionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.RollingDateConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "expression": "expression",
            "data_set_identifier": "dataSetIdentifier",
        },
    )
    class RollingDateConfigurationProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            data_set_identifier: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The rolling date configuration of a date time filter.

            :param expression: The expression of the rolling date configuration.
            :param data_set_identifier: The data set that is used in the rolling date configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rollingdateconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                rolling_date_configuration_property = quicksight.CfnDashboard.RollingDateConfigurationProperty(
                    expression="expression",
                
                    # the properties below are optional
                    data_set_identifier="dataSetIdentifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d26546e673b70144dd615534198e359d326a13a387cfcebc6115efd3706a9f72)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if data_set_identifier is not None:
                self._values["data_set_identifier"] = data_set_identifier

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the rolling date configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rollingdateconfiguration.html#cfn-quicksight-dashboard-rollingdateconfiguration-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_identifier(self) -> typing.Optional[builtins.str]:
            '''The data set that is used in the rolling date configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rollingdateconfiguration.html#cfn-quicksight-dashboard-rollingdateconfiguration-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RollingDateConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.RowAlternateColorOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "row_alternate_colors": "rowAlternateColors",
            "status": "status",
            "use_primary_background_color": "usePrimaryBackgroundColor",
        },
    )
    class RowAlternateColorOptionsProperty:
        def __init__(
            self,
            *,
            row_alternate_colors: typing.Optional[typing.Sequence[builtins.str]] = None,
            status: typing.Optional[builtins.str] = None,
            use_primary_background_color: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the row alternate color options.

            :param row_alternate_colors: Determines the list of row alternate colors.
            :param status: Determines the widget status.
            :param use_primary_background_color: The primary background color options for alternate rows.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rowalternatecoloroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                row_alternate_color_options_property = quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                    row_alternate_colors=["rowAlternateColors"],
                    status="status",
                    use_primary_background_color="usePrimaryBackgroundColor"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__de90f049fc7af8d233e801e1edd3c66ff98671bb99f41a27bd52e4c8e31173ac)
                check_type(argname="argument row_alternate_colors", value=row_alternate_colors, expected_type=type_hints["row_alternate_colors"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument use_primary_background_color", value=use_primary_background_color, expected_type=type_hints["use_primary_background_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if row_alternate_colors is not None:
                self._values["row_alternate_colors"] = row_alternate_colors
            if status is not None:
                self._values["status"] = status
            if use_primary_background_color is not None:
                self._values["use_primary_background_color"] = use_primary_background_color

        @builtins.property
        def row_alternate_colors(self) -> typing.Optional[typing.List[builtins.str]]:
            '''Determines the list of row alternate colors.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rowalternatecoloroptions.html#cfn-quicksight-dashboard-rowalternatecoloroptions-rowalternatecolors
            '''
            result = self._values.get("row_alternate_colors")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''Determines the widget status.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rowalternatecoloroptions.html#cfn-quicksight-dashboard-rowalternatecoloroptions-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def use_primary_background_color(self) -> typing.Optional[builtins.str]:
            '''The primary background color options for alternate rows.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rowalternatecoloroptions.html#cfn-quicksight-dashboard-rowalternatecoloroptions-useprimarybackgroundcolor
            '''
            result = self._values.get("use_primary_background_color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RowAlternateColorOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "target_visual_options": "targetVisualOptions",
            "target_visuals": "targetVisuals",
        },
    )
    class SameSheetTargetVisualConfigurationProperty:
        def __init__(
            self,
            *,
            target_visual_options: typing.Optional[builtins.str] = None,
            target_visuals: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The configuration of the same-sheet target visuals that you want to be filtered.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param target_visual_options: The options that choose the target visual in the same sheet. Valid values are defined as follows: - ``ALL_VISUALS`` : Applies the filter operation to all visuals in the same sheet.
            :param target_visuals: A list of the target visual IDs that are located in the same sheet of the analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-samesheettargetvisualconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                same_sheet_target_visual_configuration_property = quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                    target_visual_options="targetVisualOptions",
                    target_visuals=["targetVisuals"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__42e16bb197e37e28120a16bae2760af644cdd84794cbc104da17753006df235f)
                check_type(argname="argument target_visual_options", value=target_visual_options, expected_type=type_hints["target_visual_options"])
                check_type(argname="argument target_visuals", value=target_visuals, expected_type=type_hints["target_visuals"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_visual_options is not None:
                self._values["target_visual_options"] = target_visual_options
            if target_visuals is not None:
                self._values["target_visuals"] = target_visuals

        @builtins.property
        def target_visual_options(self) -> typing.Optional[builtins.str]:
            '''The options that choose the target visual in the same sheet.

            Valid values are defined as follows:

            - ``ALL_VISUALS`` : Applies the filter operation to all visuals in the same sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-samesheettargetvisualconfiguration.html#cfn-quicksight-dashboard-samesheettargetvisualconfiguration-targetvisualoptions
            '''
            result = self._values.get("target_visual_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def target_visuals(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of the target visual IDs that are located in the same sheet of the analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-samesheettargetvisualconfiguration.html#cfn-quicksight-dashboard-samesheettargetvisualconfiguration-targetvisuals
            '''
            result = self._values.get("target_visuals")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SameSheetTargetVisualConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination": "destination",
            "source": "source",
            "weight": "weight",
        },
    )
    class SankeyDiagramAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            destination: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            source: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            weight: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a sankey diagram.

            :param destination: The destination field wells of a sankey diagram.
            :param source: The source field wells of a sankey diagram.
            :param weight: The weight field wells of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ee4a2eaf929abf485229c8d2440a138583328585facb13b77cbc368a3249320e)
                check_type(argname="argument destination", value=destination, expected_type=type_hints["destination"])
                check_type(argname="argument source", value=source, expected_type=type_hints["source"])
                check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if destination is not None:
                self._values["destination"] = destination
            if source is not None:
                self._values["source"] = source
            if weight is not None:
                self._values["weight"] = weight

        @builtins.property
        def destination(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The destination field wells of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-dashboard-sankeydiagramaggregatedfieldwells-destination
            '''
            result = self._values.get("destination")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def source(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The source field wells of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-dashboard-sankeydiagramaggregatedfieldwells-source
            '''
            result = self._values.get("source")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def weight(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The weight field wells of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-dashboard-sankeydiagramaggregatedfieldwells-weight
            '''
            result = self._values.get("weight")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SankeyDiagramChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
        },
    )
    class SankeyDiagramChartConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SankeyDiagramFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SankeyDiagramSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a sankey diagram.

            :param data_labels: The data label configuration of a sankey diagram.
            :param field_wells: The field well configuration of a sankey diagram.
            :param sort_configuration: The sort configuration of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0636b945f2ef0e5d19120e4627fc00b3fbd5e631c051ee43b365ee48f51b5c86)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The data label configuration of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramchartconfiguration.html#cfn-quicksight-dashboard-sankeydiagramchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SankeyDiagramFieldWellsProperty"]]:
            '''The field well configuration of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramchartconfiguration.html#cfn-quicksight-dashboard-sankeydiagramchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SankeyDiagramFieldWellsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SankeyDiagramSortConfigurationProperty"]]:
            '''The sort configuration of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramchartconfiguration.html#cfn-quicksight-dashboard-sankeydiagramchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SankeyDiagramSortConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SankeyDiagramFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sankey_diagram_aggregated_field_wells": "sankeyDiagramAggregatedFieldWells",
        },
    )
    class SankeyDiagramFieldWellsProperty:
        def __init__(
            self,
            *,
            sankey_diagram_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a sankey diagram.

            :param sankey_diagram_aggregated_field_wells: The field well configuration of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e9a0f8249543a1cd1e7253bbb36240b21fc3f228b0827ac37f8802c7425bc501)
                check_type(argname="argument sankey_diagram_aggregated_field_wells", value=sankey_diagram_aggregated_field_wells, expected_type=type_hints["sankey_diagram_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sankey_diagram_aggregated_field_wells is not None:
                self._values["sankey_diagram_aggregated_field_wells"] = sankey_diagram_aggregated_field_wells

        @builtins.property
        def sankey_diagram_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramfieldwells.html#cfn-quicksight-dashboard-sankeydiagramfieldwells-sankeydiagramaggregatedfieldwells
            '''
            result = self._values.get("sankey_diagram_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SankeyDiagramSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination_items_limit": "destinationItemsLimit",
            "source_items_limit": "sourceItemsLimit",
            "weight_sort": "weightSort",
        },
    )
    class SankeyDiagramSortConfigurationProperty:
        def __init__(
            self,
            *,
            destination_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            source_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            weight_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a sankey diagram.

            :param destination_items_limit: The limit on the number of destination nodes that are displayed in a sankey diagram.
            :param source_items_limit: The limit on the number of source nodes that are displayed in a sankey diagram.
            :param weight_sort: The sort configuration of the weight fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sankey_diagram_sort_configuration_property = quicksight.CfnDashboard.SankeyDiagramSortConfigurationProperty(
                    destination_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    source_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    weight_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dc1fb051324d447ccc2b575ed29849ff5b7aa81520770576276b3bdc64c1da1f)
                check_type(argname="argument destination_items_limit", value=destination_items_limit, expected_type=type_hints["destination_items_limit"])
                check_type(argname="argument source_items_limit", value=source_items_limit, expected_type=type_hints["source_items_limit"])
                check_type(argname="argument weight_sort", value=weight_sort, expected_type=type_hints["weight_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if destination_items_limit is not None:
                self._values["destination_items_limit"] = destination_items_limit
            if source_items_limit is not None:
                self._values["source_items_limit"] = source_items_limit
            if weight_sort is not None:
                self._values["weight_sort"] = weight_sort

        @builtins.property
        def destination_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of destination nodes that are displayed in a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramsortconfiguration.html#cfn-quicksight-dashboard-sankeydiagramsortconfiguration-destinationitemslimit
            '''
            result = self._values.get("destination_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def source_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of source nodes that are displayed in a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramsortconfiguration.html#cfn-quicksight-dashboard-sankeydiagramsortconfiguration-sourceitemslimit
            '''
            result = self._values.get("source_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def weight_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the weight fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramsortconfiguration.html#cfn-quicksight-dashboard-sankeydiagramsortconfiguration-weightsort
            '''
            result = self._values.get("weight_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SankeyDiagramVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class SankeyDiagramVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SankeyDiagramChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A sankey diagram.

            For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a sankey diagram.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c795d90423eb073ac50c0e342dd78fc3141a08747d1a0d0ffe92c763882d5d51)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SankeyDiagramChartConfigurationProperty"]]:
            '''The configuration of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SankeyDiagramChartConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "label": "label",
            "size": "size",
            "x_axis": "xAxis",
            "y_axis": "yAxis",
        },
    )
    class ScatterPlotCategoricallyAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            label: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            x_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            y_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well of a scatter plot.

            :param category: The category field well of a scatter plot.
            :param label: The label field well of a scatter plot.
            :param size: The size field well of a scatter plot.
            :param x_axis: The x-axis field well of a scatter plot. The x-axis is aggregated by category.
            :param y_axis: The y-axis field well of a scatter plot. The y-axis is aggregated by category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__afb04368edb6462289491b2ee7238ddf87123656f93f6a48d968ab46b63f1964)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
                check_type(argname="argument x_axis", value=x_axis, expected_type=type_hints["x_axis"])
                check_type(argname="argument y_axis", value=y_axis, expected_type=type_hints["y_axis"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if label is not None:
                self._values["label"] = label
            if size is not None:
                self._values["size"] = size
            if x_axis is not None:
                self._values["x_axis"] = x_axis
            if y_axis is not None:
                self._values["y_axis"] = y_axis

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The category field well of a scatter plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def label(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The label field well of a scatter plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The size field well of a scatter plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        @builtins.property
        def x_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The x-axis field well of a scatter plot.

            The x-axis is aggregated by category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-xaxis
            '''
            result = self._values.get("x_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        @builtins.property
        def y_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The y-axis field well of a scatter plot.

            The y-axis is aggregated by category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-yaxis
            '''
            result = self._values.get("y_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotCategoricallyAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ScatterPlotConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
            "y_axis_display_options": "yAxisDisplayOptions",
            "y_axis_label_options": "yAxisLabelOptions",
        },
    )
    class ScatterPlotConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ScatterPlotFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a scatter plot.

            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param tooltip: The legend display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.
            :param x_axis_display_options: The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.
            :param x_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.
            :param y_axis_display_options: The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.
            :param y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c9ec0c108590fc491b71bdbd53aa8553faba4c081a35edbf7a454da967b5f430)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
                check_type(argname="argument y_axis_display_options", value=y_axis_display_options, expected_type=type_hints["y_axis_display_options"])
                check_type(argname="argument y_axis_label_options", value=y_axis_label_options, expected_type=type_hints["y_axis_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options
            if y_axis_display_options is not None:
                self._values["y_axis_display_options"] = y_axis_display_options
            if y_axis_label_options is not None:
                self._values["y_axis_label_options"] = y_axis_label_options

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ScatterPlotFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ScatterPlotFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-yaxisdisplayoptions
            '''
            result = self._values.get("y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-yaxislabeloptions
            '''
            result = self._values.get("y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ScatterPlotFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "scatter_plot_categorically_aggregated_field_wells": "scatterPlotCategoricallyAggregatedFieldWells",
            "scatter_plot_unaggregated_field_wells": "scatterPlotUnaggregatedFieldWells",
        },
    )
    class ScatterPlotFieldWellsProperty:
        def __init__(
            self,
            *,
            scatter_plot_categorically_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scatter_plot_unaggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a scatter plot.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param scatter_plot_categorically_aggregated_field_wells: The aggregated field wells of a scatter plot. The x and y-axes of scatter plots with aggregated field wells are aggregated by category, label, or both.
            :param scatter_plot_unaggregated_field_wells: The unaggregated field wells of a scatter plot. The x and y-axes of these scatter plots are unaggregated.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__80b49b59e41a288cf59f6f1fc2e0325c9914f3ec5eca29c9b1893a9c2cf5b3da)
                check_type(argname="argument scatter_plot_categorically_aggregated_field_wells", value=scatter_plot_categorically_aggregated_field_wells, expected_type=type_hints["scatter_plot_categorically_aggregated_field_wells"])
                check_type(argname="argument scatter_plot_unaggregated_field_wells", value=scatter_plot_unaggregated_field_wells, expected_type=type_hints["scatter_plot_unaggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if scatter_plot_categorically_aggregated_field_wells is not None:
                self._values["scatter_plot_categorically_aggregated_field_wells"] = scatter_plot_categorically_aggregated_field_wells
            if scatter_plot_unaggregated_field_wells is not None:
                self._values["scatter_plot_unaggregated_field_wells"] = scatter_plot_unaggregated_field_wells

        @builtins.property
        def scatter_plot_categorically_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a scatter plot.

            The x and y-axes of scatter plots with aggregated field wells are aggregated by category, label, or both.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotfieldwells.html#cfn-quicksight-dashboard-scatterplotfieldwells-scatterplotcategoricallyaggregatedfieldwells
            '''
            result = self._values.get("scatter_plot_categorically_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty"]], result)

        @builtins.property
        def scatter_plot_unaggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty"]]:
            '''The unaggregated field wells of a scatter plot.

            The x and y-axes of these scatter plots are unaggregated.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotfieldwells.html#cfn-quicksight-dashboard-scatterplotfieldwells-scatterplotunaggregatedfieldwells
            '''
            result = self._values.get("scatter_plot_unaggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "label": "label",
            "size": "size",
            "x_axis": "xAxis",
            "y_axis": "yAxis",
        },
    )
    class ScatterPlotUnaggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            label: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            x_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            y_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The unaggregated field wells of a scatter plot.

            :param category: The category field well of a scatter plot.
            :param label: The label field well of a scatter plot.
            :param size: The size field well of a scatter plot.
            :param x_axis: The x-axis field well of a scatter plot. The x-axis is a dimension field and cannot be aggregated.
            :param y_axis: The y-axis field well of a scatter plot. The y-axis is a dimension field and cannot be aggregated.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0baab9465872a9e82200203dfc1817299d65d6033fedfa4b613d6f7a54098dfe)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
                check_type(argname="argument x_axis", value=x_axis, expected_type=type_hints["x_axis"])
                check_type(argname="argument y_axis", value=y_axis, expected_type=type_hints["y_axis"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if label is not None:
                self._values["label"] = label
            if size is not None:
                self._values["size"] = size
            if x_axis is not None:
                self._values["x_axis"] = x_axis
            if y_axis is not None:
                self._values["y_axis"] = y_axis

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The category field well of a scatter plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotunaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def label(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The label field well of a scatter plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotunaggregatedfieldwells-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The size field well of a scatter plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotunaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        @builtins.property
        def x_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The x-axis field well of a scatter plot.

            The x-axis is a dimension field and cannot be aggregated.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotunaggregatedfieldwells-xaxis
            '''
            result = self._values.get("x_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def y_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The y-axis field well of a scatter plot.

            The y-axis is a dimension field and cannot be aggregated.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotunaggregatedfieldwells-yaxis
            '''
            result = self._values.get("y_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotUnaggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ScatterPlotVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class ScatterPlotVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ScatterPlotConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A scatter plot.

            For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3c7eeeaa3747d4234f74ffa1969b0ff67487d36a9b2cd6ab792ae5ebe9f6abb8)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ScatterPlotConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ScatterPlotConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ScrollBarOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility", "visible_range": "visibleRange"},
    )
    class ScrollBarOptionsProperty:
        def __init__(
            self,
            *,
            visibility: typing.Optional[builtins.str] = None,
            visible_range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisibleRangeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The visual display options for a data zoom scroll bar.

            :param visibility: The visibility of the data zoom scroll bar.
            :param visible_range: The visibility range for the data zoom scroll bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scrollbaroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                scroll_bar_options_property = quicksight.CfnDashboard.ScrollBarOptionsProperty(
                    visibility="visibility",
                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                            from=123,
                            to=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__67187c0ea52237b7a1309d55d73f1ec005aaef59acdccfb29202ec38502e851f)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument visible_range", value=visible_range, expected_type=type_hints["visible_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility
            if visible_range is not None:
                self._values["visible_range"] = visible_range

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the data zoom scroll bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scrollbaroptions.html#cfn-quicksight-dashboard-scrollbaroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visible_range(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisibleRangeOptionsProperty"]]:
            '''The visibility range for the data zoom scroll bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scrollbaroptions.html#cfn-quicksight-dashboard-scrollbaroptions-visiblerange
            '''
            result = self._values.get("visible_range")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisibleRangeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScrollBarOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SecondaryValueOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class SecondaryValueOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of the secondary value of a KPI visual.

            :param visibility: Determines the visibility of the secondary value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-secondaryvalueoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                secondary_value_options_property = quicksight.CfnDashboard.SecondaryValueOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d0d4223d7f393790d88a12cfd85e5412183ce22f19d2061932a7ddd429d1c946)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the secondary value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-secondaryvalueoptions.html#cfn-quicksight-dashboard-secondaryvalueoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SecondaryValueOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SectionAfterPageBreakProperty",
        jsii_struct_bases=[],
        name_mapping={"status": "status"},
    )
    class SectionAfterPageBreakProperty:
        def __init__(self, *, status: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of a page break after a section.

            :param status: The option that enables or disables a page break at the end of a section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionafterpagebreak.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                section_after_page_break_property = quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__24e09d22397f0380bf044ac43d3963b66fb0f68511ba7e86dc1c91ecb4271fd2)
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The option that enables or disables a page break at the end of a section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionafterpagebreak.html#cfn-quicksight-dashboard-sectionafterpagebreak-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionAfterPageBreakProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"paper_canvas_size_options": "paperCanvasSizeOptions"},
    )
    class SectionBasedLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            paper_canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options for the canvas of a section-based layout.

            :param paper_canvas_size_options: The options for a paper canvas of a section-based layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                section_based_layout_canvas_size_options_property = quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                    paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                        paper_margin=quicksight.CfnDashboard.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        ),
                        paper_orientation="paperOrientation",
                        paper_size="paperSize"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__495327177acafd80c66111e7551a848e8e9dd4c01a38fc0fbe69aa5edfedddc2)
                check_type(argname="argument paper_canvas_size_options", value=paper_canvas_size_options, expected_type=type_hints["paper_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if paper_canvas_size_options is not None:
                self._values["paper_canvas_size_options"] = paper_canvas_size_options

        @builtins.property
        def paper_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty"]]:
            '''The options for a paper canvas of a section-based layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutcanvassizeoptions.html#cfn-quicksight-dashboard-sectionbasedlayoutcanvassizeoptions-papercanvassizeoptions
            '''
            result = self._values.get("paper_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SectionBasedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "body_sections": "bodySections",
            "canvas_size_options": "canvasSizeOptions",
            "footer_sections": "footerSections",
            "header_sections": "headerSections",
        },
    )
    class SectionBasedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            body_sections: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.BodySectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
            footer_sections: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.HeaderFooterSectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            header_sections: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.HeaderFooterSectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The configuration for a section-based layout.

            :param body_sections: A list of body section configurations.
            :param canvas_size_options: The options for the canvas of a section-based layout.
            :param footer_sections: A list of footer section configurations.
            :param header_sections: A list of header section configurations.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                section_based_layout_configuration_property = quicksight.CfnDashboard.SectionBasedLayoutConfigurationProperty(
                    body_sections=[quicksight.CfnDashboard.BodySectionConfigurationProperty(
                        content=quicksight.CfnDashboard.BodySectionContentProperty(
                            layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        page_break_configuration=quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                            after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                                status="status"
                            )
                        ),
                        style=quicksight.CfnDashboard.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnDashboard.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )],
                    canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                        paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                            paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            ),
                            paper_orientation="paperOrientation",
                            paper_size="paperSize"
                        )
                    ),
                    footer_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                        layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        style=quicksight.CfnDashboard.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnDashboard.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )],
                    header_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                        layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        style=quicksight.CfnDashboard.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnDashboard.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__587b23641d0ea9bbaf975c38c597885abfe3e7a2bc26dd1e872f9ef93c7e3719)
                check_type(argname="argument body_sections", value=body_sections, expected_type=type_hints["body_sections"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
                check_type(argname="argument footer_sections", value=footer_sections, expected_type=type_hints["footer_sections"])
                check_type(argname="argument header_sections", value=header_sections, expected_type=type_hints["header_sections"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "body_sections": body_sections,
                "canvas_size_options": canvas_size_options,
                "footer_sections": footer_sections,
                "header_sections": header_sections,
            }

        @builtins.property
        def body_sections(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BodySectionConfigurationProperty"]]]:
            '''A list of body section configurations.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-sectionbasedlayoutconfiguration-bodysections
            '''
            result = self._values.get("body_sections")
            assert result is not None, "Required property 'body_sections' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BodySectionConfigurationProperty"]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty"]:
            '''The options for the canvas of a section-based layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-sectionbasedlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty"], result)

        @builtins.property
        def footer_sections(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HeaderFooterSectionConfigurationProperty"]]]:
            '''A list of footer section configurations.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-sectionbasedlayoutconfiguration-footersections
            '''
            result = self._values.get("footer_sections")
            assert result is not None, "Required property 'footer_sections' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HeaderFooterSectionConfigurationProperty"]]], result)

        @builtins.property
        def header_sections(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HeaderFooterSectionConfigurationProperty"]]]:
            '''A list of header section configurations.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-sectionbasedlayoutconfiguration-headersections
            '''
            result = self._values.get("header_sections")
            assert result is not None, "Required property 'header_sections' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HeaderFooterSectionConfigurationProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "paper_margin": "paperMargin",
            "paper_orientation": "paperOrientation",
            "paper_size": "paperSize",
        },
    )
    class SectionBasedLayoutPaperCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            paper_margin: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SpacingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paper_orientation: typing.Optional[builtins.str] = None,
            paper_size: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for a paper canvas of a section-based layout.

            :param paper_margin: Defines the spacing between the canvas content and the top, bottom, left, and right edges.
            :param paper_orientation: The paper orientation that is used to define canvas dimensions. Choose one of the following options:. - PORTRAIT - LANDSCAPE
            :param paper_size: The paper size that is used to define canvas dimensions.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                section_based_layout_paper_canvas_size_options_property = quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                    paper_margin=quicksight.CfnDashboard.SpacingProperty(
                        bottom="bottom",
                        left="left",
                        right="right",
                        top="top"
                    ),
                    paper_orientation="paperOrientation",
                    paper_size="paperSize"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2d985ce1432be0a9a0d2d1a3117155a415cca72f565e156ba54202458e98363e)
                check_type(argname="argument paper_margin", value=paper_margin, expected_type=type_hints["paper_margin"])
                check_type(argname="argument paper_orientation", value=paper_orientation, expected_type=type_hints["paper_orientation"])
                check_type(argname="argument paper_size", value=paper_size, expected_type=type_hints["paper_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if paper_margin is not None:
                self._values["paper_margin"] = paper_margin
            if paper_orientation is not None:
                self._values["paper_orientation"] = paper_orientation
            if paper_size is not None:
                self._values["paper_size"] = paper_size

        @builtins.property
        def paper_margin(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SpacingProperty"]]:
            '''Defines the spacing between the canvas content and the top, bottom, left, and right edges.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions-papermargin
            '''
            result = self._values.get("paper_margin")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SpacingProperty"]], result)

        @builtins.property
        def paper_orientation(self) -> typing.Optional[builtins.str]:
            '''The paper orientation that is used to define canvas dimensions. Choose one of the following options:.

            - PORTRAIT
            - LANDSCAPE

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions-paperorientation
            '''
            result = self._values.get("paper_orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def paper_size(self) -> typing.Optional[builtins.str]:
            '''The paper size that is used to define canvas dimensions.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions-papersize
            '''
            result = self._values.get("paper_size")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutPaperCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SectionLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"free_form_layout": "freeFormLayout"},
    )
    class SectionLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form_layout: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FreeFormSectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The layout configuration of a section.

            :param free_form_layout: The free-form layout configuration of a section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                section_layout_configuration_property = quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                    free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                        elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                            element_id="elementId",
                            element_type="elementType",
                            height="height",
                            width="width",
                            x_axis_location="xAxisLocation",
                            y_axis_location="yAxisLocation",
                
                            # the properties below are optional
                            background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                visibility="visibility"
                            ),
                            rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                    visibility="visibility"
                                ),
                                expression="expression"
                            )],
                            selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            visibility="visibility"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9c8e818c306efc959258be69024de08ca92ae96e91aba1a71a3007ff59c1fc89)
                check_type(argname="argument free_form_layout", value=free_form_layout, expected_type=type_hints["free_form_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "free_form_layout": free_form_layout,
            }

        @builtins.property
        def free_form_layout(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.FreeFormSectionLayoutConfigurationProperty"]:
            '''The free-form layout configuration of a section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionlayoutconfiguration.html#cfn-quicksight-dashboard-sectionlayoutconfiguration-freeformlayout
            '''
            result = self._values.get("free_form_layout")
            assert result is not None, "Required property 'free_form_layout' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.FreeFormSectionLayoutConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SectionPageBreakConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"after": "after"},
    )
    class SectionPageBreakConfigurationProperty:
        def __init__(
            self,
            *,
            after: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SectionAfterPageBreakProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a page break for a section.

            :param after: The configuration of a page break after a section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionpagebreakconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                section_page_break_configuration_property = quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                    after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                        status="status"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0b78fcebc9723e8f7123340cb0bb1d0a299a2938ae8dc76b038c1a7333e8ac56)
                check_type(argname="argument after", value=after, expected_type=type_hints["after"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if after is not None:
                self._values["after"] = after

        @builtins.property
        def after(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SectionAfterPageBreakProperty"]]:
            '''The configuration of a page break after a section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionpagebreakconfiguration.html#cfn-quicksight-dashboard-sectionpagebreakconfiguration-after
            '''
            result = self._values.get("after")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SectionAfterPageBreakProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionPageBreakConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SectionStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"height": "height", "padding": "padding"},
    )
    class SectionStyleProperty:
        def __init__(
            self,
            *,
            height: typing.Optional[builtins.str] = None,
            padding: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SpacingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that style a section.

            :param height: The height of a section. Heights can only be defined for header and footer sections. The default height margin is 0.5 inches.
            :param padding: The spacing between section content and its top, bottom, left, and right edges. There is no padding by default.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                section_style_property = quicksight.CfnDashboard.SectionStyleProperty(
                    height="height",
                    padding=quicksight.CfnDashboard.SpacingProperty(
                        bottom="bottom",
                        left="left",
                        right="right",
                        top="top"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b5c6b58857ccef291e8a9afd5e061889c39dc7ff97611c8b6b79fa22a4ed431f)
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument padding", value=padding, expected_type=type_hints["padding"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if height is not None:
                self._values["height"] = height
            if padding is not None:
                self._values["padding"] = padding

        @builtins.property
        def height(self) -> typing.Optional[builtins.str]:
            '''The height of a section.

            Heights can only be defined for header and footer sections. The default height margin is 0.5 inches.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionstyle.html#cfn-quicksight-dashboard-sectionstyle-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def padding(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SpacingProperty"]]:
            '''The spacing between section content and its top, bottom, left, and right edges.

            There is no padding by default.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionstyle.html#cfn-quicksight-dashboard-sectionstyle-padding
            '''
            result = self._values.get("padding")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SpacingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sheet_visual_scoping_configurations": "sheetVisualScopingConfigurations",
        },
    )
    class SelectedSheetsFilterScopeConfigurationProperty:
        def __init__(
            self,
            *,
            sheet_visual_scoping_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SheetVisualScopingConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The configuration for applying a filter to specific sheets or visuals.

            You can apply this filter to multiple visuals that are on one sheet or to all visuals on a sheet.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param sheet_visual_scoping_configurations: The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-selectedsheetsfilterscopeconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                selected_sheets_filter_scope_configuration_property = quicksight.CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty(
                    sheet_visual_scoping_configurations=[quicksight.CfnDashboard.SheetVisualScopingConfigurationProperty(
                        scope="scope",
                        sheet_id="sheetId",
                
                        # the properties below are optional
                        visual_ids=["visualIds"]
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__44d84419a2ccaeba2d2d8ab98032c9a8ce5a0e884fcc08a683154634a3fa0c98)
                check_type(argname="argument sheet_visual_scoping_configurations", value=sheet_visual_scoping_configurations, expected_type=type_hints["sheet_visual_scoping_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sheet_visual_scoping_configurations is not None:
                self._values["sheet_visual_scoping_configurations"] = sheet_visual_scoping_configurations

        @builtins.property
        def sheet_visual_scoping_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetVisualScopingConfigurationProperty"]]]]:
            '''The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-selectedsheetsfilterscopeconfiguration.html#cfn-quicksight-dashboard-selectedsheetsfilterscopeconfiguration-sheetvisualscopingconfigurations
            '''
            result = self._values.get("sheet_visual_scoping_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetVisualScopingConfigurationProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SelectedSheetsFilterScopeConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_field_series_item": "dataFieldSeriesItem",
            "field_series_item": "fieldSeriesItem",
        },
    )
    class SeriesItemProperty:
        def __init__(
            self,
            *,
            data_field_series_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataFieldSeriesItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_series_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSeriesItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The series item configuration of a line chart.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_field_series_item: The data field series item configuration of a line chart.
            :param field_series_item: The field series item configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-seriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                series_item_property = quicksight.CfnDashboard.SeriesItemProperty(
                    data_field_series_item=quicksight.CfnDashboard.DataFieldSeriesItemProperty(
                        axis_binding="axisBinding",
                        field_id="fieldId",
                
                        # the properties below are optional
                        field_value="fieldValue",
                        settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                            line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        )
                    ),
                    field_series_item=quicksight.CfnDashboard.FieldSeriesItemProperty(
                        axis_binding="axisBinding",
                        field_id="fieldId",
                
                        # the properties below are optional
                        settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                            line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6807c28b152ac4c8984cc472ce658edff6ac0f5fda4be920d4b956e59968fccf)
                check_type(argname="argument data_field_series_item", value=data_field_series_item, expected_type=type_hints["data_field_series_item"])
                check_type(argname="argument field_series_item", value=field_series_item, expected_type=type_hints["field_series_item"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_field_series_item is not None:
                self._values["data_field_series_item"] = data_field_series_item
            if field_series_item is not None:
                self._values["field_series_item"] = field_series_item

        @builtins.property
        def data_field_series_item(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataFieldSeriesItemProperty"]]:
            '''The data field series item configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-seriesitem.html#cfn-quicksight-dashboard-seriesitem-datafieldseriesitem
            '''
            result = self._values.get("data_field_series_item")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataFieldSeriesItemProperty"]], result)

        @builtins.property
        def field_series_item(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSeriesItemProperty"]]:
            '''The field series item configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-seriesitem.html#cfn-quicksight-dashboard-seriesitem-fieldseriesitem
            '''
            result = self._values.get("field_series_item")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSeriesItemProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SetParameterValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination_parameter_name": "destinationParameterName",
            "value": "value",
        },
    )
    class SetParameterValueConfigurationProperty:
        def __init__(
            self,
            *,
            destination_parameter_name: builtins.str,
            value: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DestinationParameterValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The configuration of adding parameters in action.

            :param destination_parameter_name: The destination parameter name of the ``SetParameterValueConfiguration`` .
            :param value: 

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-setparametervalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                set_parameter_value_configuration_property = quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                    destination_parameter_name="destinationParameterName",
                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                date_time_values=["dateTimeValues"],
                                decimal_values=[123],
                                integer_values=[123],
                                string_values=["stringValues"]
                            ),
                
                            # the properties below are optional
                            include_null_value=False
                        ),
                        select_all_value_options="selectAllValueOptions",
                        source_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        source_field="sourceField",
                        source_parameter_name="sourceParameterName"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__14b79606996bfaf0121a4d5c43b698f35c8ec425311d759a972dac3514280bdc)
                check_type(argname="argument destination_parameter_name", value=destination_parameter_name, expected_type=type_hints["destination_parameter_name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "destination_parameter_name": destination_parameter_name,
                "value": value,
            }

        @builtins.property
        def destination_parameter_name(self) -> builtins.str:
            '''The destination parameter name of the ``SetParameterValueConfiguration`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-setparametervalueconfiguration.html#cfn-quicksight-dashboard-setparametervalueconfiguration-destinationparametername
            '''
            result = self._values.get("destination_parameter_name")
            assert result is not None, "Required property 'destination_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.DestinationParameterValueConfigurationProperty"]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-setparametervalueconfiguration.html#cfn-quicksight-dashboard-setparametervalueconfiguration-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.DestinationParameterValueConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SetParameterValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ShapeConditionalFormatProperty",
        jsii_struct_bases=[],
        name_mapping={"background_color": "backgroundColor"},
    )
    class ShapeConditionalFormatProperty:
        def __init__(
            self,
            *,
            background_color: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The shape conditional formatting of a filled map visual.

            :param background_color: The conditional formatting for the shape background color of a filled map visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shapeconditionalformat.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                shape_conditional_format_property = quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                    background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__de2604ab9ac3d695300a68b68c8b29b113661d1999fe8c5bfce193f70b394c0f)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "background_color": background_color,
            }

        @builtins.property
        def background_color(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"]:
            '''The conditional formatting for the shape background color of a filled map visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shapeconditionalformat.html#cfn-quicksight-dashboard-shapeconditionalformat-backgroundcolor
            '''
            result = self._values.get("background_color")
            assert result is not None, "Required property 'background_color' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ShapeConditionalFormatProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"info_icon_text": "infoIconText", "visibility": "visibility"},
    )
    class SheetControlInfoIconLabelOptionsProperty:
        def __init__(
            self,
            *,
            info_icon_text: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display info icons for filters and parameters.

            :param info_icon_text: The text content of info icon.
            :param visibility: The visibility configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrolinfoiconlabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_control_info_icon_label_options_property = quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                    info_icon_text="infoIconText",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__599adf629d949910b210780f4a78dc6f061309d68fa4524092a633f4ec352c7d)
                check_type(argname="argument info_icon_text", value=info_icon_text, expected_type=type_hints["info_icon_text"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if info_icon_text is not None:
                self._values["info_icon_text"] = info_icon_text
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def info_icon_text(self) -> typing.Optional[builtins.str]:
            '''The text content of info icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrolinfoiconlabeloptions.html#cfn-quicksight-dashboard-sheetcontrolinfoiconlabeloptions-infoicontext
            '''
            result = self._values.get("info_icon_text")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrolinfoiconlabeloptions.html#cfn-quicksight-dashboard-sheetcontrolinfoiconlabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlInfoIconLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SheetControlLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"grid_layout": "gridLayout"},
    )
    class SheetControlLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            grid_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :param grid_layout: The configuration that determines the elements and canvas size options of sheet control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrollayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_control_layout_configuration_property = quicksight.CfnDashboard.SheetControlLayoutConfigurationProperty(
                    grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                        elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                            column_span=123,
                            element_id="elementId",
                            element_type="elementType",
                            row_span=123,
                
                            # the properties below are optional
                            column_index=123,
                            row_index=123
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ac462e2787833fe5b6163c4a32a6170dd269b1e564b46c30555f5715308ccad2)
                check_type(argname="argument grid_layout", value=grid_layout, expected_type=type_hints["grid_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if grid_layout is not None:
                self._values["grid_layout"] = grid_layout

        @builtins.property
        def grid_layout(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GridLayoutConfigurationProperty"]]:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrollayoutconfiguration.html#cfn-quicksight-dashboard-sheetcontrollayoutconfiguration-gridlayout
            '''
            result = self._values.get("grid_layout")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GridLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SheetControlLayoutProperty",
        jsii_struct_bases=[],
        name_mapping={"configuration": "configuration"},
    )
    class SheetControlLayoutProperty:
        def __init__(
            self,
            *,
            configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SheetControlLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''A grid layout to define the placement of sheet control.

            :param configuration: The configuration that determines the elements and canvas size options of sheet control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrollayout.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_control_layout_property = quicksight.CfnDashboard.SheetControlLayoutProperty(
                    configuration=quicksight.CfnDashboard.SheetControlLayoutConfigurationProperty(
                        grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                            elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                column_span=123,
                                element_id="elementId",
                                element_type="elementType",
                                row_span=123,
                
                                # the properties below are optional
                                column_index=123,
                                row_index=123
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d689e338dfa6b8e3395217b892a787ce6e5bd14bcde45e27b12d2f99d322e1b1)
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration": configuration,
            }

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetControlLayoutConfigurationProperty"]:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrollayout.html#cfn-quicksight-dashboard-sheetcontrollayout-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetControlLayoutConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlLayoutProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SheetControlsOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility_state": "visibilityState"},
    )
    class SheetControlsOptionProperty:
        def __init__(
            self,
            *,
            visibility_state: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Sheet controls option.

            :param visibility_state: Visibility state.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrolsoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_controls_option_property = quicksight.CfnDashboard.SheetControlsOptionProperty(
                    visibility_state="visibilityState"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__42787bc8f0211e44eff888e419c7529757d9bde5886a97c9673a45a0ea3c0e53)
                check_type(argname="argument visibility_state", value=visibility_state, expected_type=type_hints["visibility_state"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility_state is not None:
                self._values["visibility_state"] = visibility_state

        @builtins.property
        def visibility_state(self) -> typing.Optional[builtins.str]:
            '''Visibility state.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrolsoption.html#cfn-quicksight-dashboard-sheetcontrolsoption-visibilitystate
            '''
            result = self._values.get("visibility_state")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlsOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SheetDefinitionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sheet_id": "sheetId",
            "content_type": "contentType",
            "description": "description",
            "filter_controls": "filterControls",
            "layouts": "layouts",
            "name": "name",
            "parameter_controls": "parameterControls",
            "sheet_control_layouts": "sheetControlLayouts",
            "text_boxes": "textBoxes",
            "title": "title",
            "visuals": "visuals",
        },
    )
    class SheetDefinitionProperty:
        def __init__(
            self,
            *,
            sheet_id: builtins.str,
            content_type: typing.Optional[builtins.str] = None,
            description: typing.Optional[builtins.str] = None,
            filter_controls: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilterControlProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            layouts: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LayoutProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            name: typing.Optional[builtins.str] = None,
            parameter_controls: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ParameterControlProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sheet_control_layouts: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SheetControlLayoutProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            text_boxes: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SheetTextBoxProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            title: typing.Optional[builtins.str] = None,
            visuals: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''A sheet is an object that contains a set of visuals that are viewed together on one page in a paginated report.

            Every analysis and dashboard must contain at least one sheet.

            :param sheet_id: The unique identifier of a sheet.
            :param content_type: The layout content type of the sheet. Choose one of the following options:. - ``PAGINATED`` : Creates a sheet for a paginated report. - ``INTERACTIVE`` : Creates a sheet for an interactive dashboard.
            :param description: A description of the sheet.
            :param filter_controls: The list of filter controls that are on a sheet. For more information, see `Adding filter controls to analysis sheets <https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html>`_ in the *Amazon QuickSight User Guide* .
            :param layouts: Layouts define how the components of a sheet are arranged. For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .
            :param name: The name of the sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
            :param parameter_controls: The list of parameter controls that are on a sheet. For more information, see `Using a Control with a Parameter in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html>`_ in the *Amazon QuickSight User Guide* .
            :param sheet_control_layouts: The control layouts of the sheet.
            :param text_boxes: The text boxes that are on a sheet.
            :param title: The title of the sheet.
            :param visuals: A list of the visuals that are on a sheet. Visual placement is determined by the layout of the sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__637ce407686da3a298cdda27878a91a61d365d7bec20a48b7fc6bb6d13de60cb)
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
                check_type(argname="argument content_type", value=content_type, expected_type=type_hints["content_type"])
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
                check_type(argname="argument filter_controls", value=filter_controls, expected_type=type_hints["filter_controls"])
                check_type(argname="argument layouts", value=layouts, expected_type=type_hints["layouts"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_controls", value=parameter_controls, expected_type=type_hints["parameter_controls"])
                check_type(argname="argument sheet_control_layouts", value=sheet_control_layouts, expected_type=type_hints["sheet_control_layouts"])
                check_type(argname="argument text_boxes", value=text_boxes, expected_type=type_hints["text_boxes"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument visuals", value=visuals, expected_type=type_hints["visuals"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "sheet_id": sheet_id,
            }
            if content_type is not None:
                self._values["content_type"] = content_type
            if description is not None:
                self._values["description"] = description
            if filter_controls is not None:
                self._values["filter_controls"] = filter_controls
            if layouts is not None:
                self._values["layouts"] = layouts
            if name is not None:
                self._values["name"] = name
            if parameter_controls is not None:
                self._values["parameter_controls"] = parameter_controls
            if sheet_control_layouts is not None:
                self._values["sheet_control_layouts"] = sheet_control_layouts
            if text_boxes is not None:
                self._values["text_boxes"] = text_boxes
            if title is not None:
                self._values["title"] = title
            if visuals is not None:
                self._values["visuals"] = visuals

        @builtins.property
        def sheet_id(self) -> builtins.str:
            '''The unique identifier of a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-sheetid
            '''
            result = self._values.get("sheet_id")
            assert result is not None, "Required property 'sheet_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def content_type(self) -> typing.Optional[builtins.str]:
            '''The layout content type of the sheet. Choose one of the following options:.

            - ``PAGINATED`` : Creates a sheet for a paginated report.
            - ``INTERACTIVE`` : Creates a sheet for an interactive dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-contenttype
            '''
            result = self._values.get("content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''A description of the sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def filter_controls(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterControlProperty"]]]]:
            '''The list of filter controls that are on a sheet.

            For more information, see `Adding filter controls to analysis sheets <https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-filtercontrols
            '''
            result = self._values.get("filter_controls")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilterControlProperty"]]]], result)

        @builtins.property
        def layouts(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LayoutProperty"]]]]:
            '''Layouts define how the components of a sheet are arranged.

            For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-layouts
            '''
            result = self._values.get("layouts")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LayoutProperty"]]]], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of the sheet.

            This name is displayed on the sheet's tab in the Amazon QuickSight console.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_controls(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParameterControlProperty"]]]]:
            '''The list of parameter controls that are on a sheet.

            For more information, see `Using a Control with a Parameter in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-parametercontrols
            '''
            result = self._values.get("parameter_controls")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ParameterControlProperty"]]]], result)

        @builtins.property
        def sheet_control_layouts(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetControlLayoutProperty"]]]]:
            '''The control layouts of the sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-sheetcontrollayouts
            '''
            result = self._values.get("sheet_control_layouts")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetControlLayoutProperty"]]]], result)

        @builtins.property
        def text_boxes(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetTextBoxProperty"]]]]:
            '''The text boxes that are on a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-textboxes
            '''
            result = self._values.get("text_boxes")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetTextBoxProperty"]]]], result)

        @builtins.property
        def title(self) -> typing.Optional[builtins.str]:
            '''The title of the sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visuals(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualProperty"]]]]:
            '''A list of the visuals that are on a sheet.

            Visual placement is determined by the layout of the sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-visuals
            '''
            result = self._values.get("visuals")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetDefinitionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class SheetElementConfigurationOverridesProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The override configuration of the rendering rules of a sheet.

            :param visibility: Determines whether or not the overrides are visible. Choose one of the following options:. - ``VISIBLE`` - ``HIDDEN``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementconfigurationoverrides.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_element_configuration_overrides_property = quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fe51cb7cd4e5b9d742998a2d14d76c934dbb381558ef1d842903a487376fdddd)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the overrides are visible. Choose one of the following options:.

            - ``VISIBLE``
            - ``HIDDEN``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementconfigurationoverrides.html#cfn-quicksight-dashboard-sheetelementconfigurationoverrides-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetElementConfigurationOverridesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SheetElementRenderingRuleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "configuration_overrides": "configurationOverrides",
            "expression": "expression",
        },
    )
    class SheetElementRenderingRuleProperty:
        def __init__(
            self,
            *,
            configuration_overrides: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SheetElementConfigurationOverridesProperty", typing.Dict[builtins.str, typing.Any]]],
            expression: builtins.str,
        ) -> None:
            '''The rendering rules of a sheet that uses a free-form layout.

            :param configuration_overrides: The override configuration of the rendering rules of a sheet.
            :param expression: The expression of the rendering rules of a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementrenderingrule.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_element_rendering_rule_property = quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                        visibility="visibility"
                    ),
                    expression="expression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__499b540c99ada6d60c4dde2ea7bf4eb135be45d43d14bffa9f2d7b0f25f8b0d7)
                check_type(argname="argument configuration_overrides", value=configuration_overrides, expected_type=type_hints["configuration_overrides"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration_overrides": configuration_overrides,
                "expression": expression,
            }

        @builtins.property
        def configuration_overrides(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetElementConfigurationOverridesProperty"]:
            '''The override configuration of the rendering rules of a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementrenderingrule.html#cfn-quicksight-dashboard-sheetelementrenderingrule-configurationoverrides
            '''
            result = self._values.get("configuration_overrides")
            assert result is not None, "Required property 'configuration_overrides' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetElementConfigurationOverridesProperty"], result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the rendering rules of a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementrenderingrule.html#cfn-quicksight-dashboard-sheetelementrenderingrule-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetElementRenderingRuleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SheetLayoutElementMaximizationOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class SheetLayoutElementMaximizationOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The sheet layout maximization options of a dashbaord.

            :param availability_status: The status of the sheet layout maximization options of a dashbaord.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetlayoutelementmaximizationoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_layout_element_maximization_option_property = quicksight.CfnDashboard.SheetLayoutElementMaximizationOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9c21837468111244c3de56b5fe2dacbe15de4699bb18a76919a5f3901e2f4cc1)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The status of the sheet layout maximization options of a dashbaord.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetlayoutelementmaximizationoption.html#cfn-quicksight-dashboard-sheetlayoutelementmaximizationoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetLayoutElementMaximizationOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SheetProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "sheet_id": "sheetId"},
    )
    class SheetProperty:
        def __init__(
            self,
            *,
            name: typing.Optional[builtins.str] = None,
            sheet_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A *sheet* , which is an object that contains a set of visuals that are viewed together on one page in Amazon QuickSight.

            Every analysis and dashboard contains at least one sheet. Each sheet contains at least one visualization widget, for example a chart, pivot table, or narrative insight. Sheets can be associated with other components, such as controls, filters, and so on.

            :param name: The name of a sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
            :param sheet_id: The unique identifier associated with a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheet.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_property = quicksight.CfnDashboard.SheetProperty(
                    name="name",
                    sheet_id="sheetId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ea1cfc41e0d0c9d637e38e0e7c0c54ba218ec89243b7b2666a061612e4ba1568)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if name is not None:
                self._values["name"] = name
            if sheet_id is not None:
                self._values["sheet_id"] = sheet_id

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a sheet.

            This name is displayed on the sheet's tab in the Amazon QuickSight console.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheet.html#cfn-quicksight-dashboard-sheet-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sheet_id(self) -> typing.Optional[builtins.str]:
            '''The unique identifier associated with a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheet.html#cfn-quicksight-dashboard-sheet-sheetid
            '''
            result = self._values.get("sheet_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SheetTextBoxProperty",
        jsii_struct_bases=[],
        name_mapping={"sheet_text_box_id": "sheetTextBoxId", "content": "content"},
    )
    class SheetTextBoxProperty:
        def __init__(
            self,
            *,
            sheet_text_box_id: builtins.str,
            content: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A text box.

            :param sheet_text_box_id: The unique identifier for a text box. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.
            :param content: The content that is displayed in the text box.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheettextbox.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_text_box_property = quicksight.CfnDashboard.SheetTextBoxProperty(
                    sheet_text_box_id="sheetTextBoxId",
                
                    # the properties below are optional
                    content="content"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__74c00d97e53826dff384253ef732f8c7e273f9a87d88b52bce179fff04f324de)
                check_type(argname="argument sheet_text_box_id", value=sheet_text_box_id, expected_type=type_hints["sheet_text_box_id"])
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "sheet_text_box_id": sheet_text_box_id,
            }
            if content is not None:
                self._values["content"] = content

        @builtins.property
        def sheet_text_box_id(self) -> builtins.str:
            '''The unique identifier for a text box.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheettextbox.html#cfn-quicksight-dashboard-sheettextbox-sheettextboxid
            '''
            result = self._values.get("sheet_text_box_id")
            assert result is not None, "Required property 'sheet_text_box_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def content(self) -> typing.Optional[builtins.str]:
            '''The content that is displayed in the text box.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheettextbox.html#cfn-quicksight-dashboard-sheettextbox-content
            '''
            result = self._values.get("content")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetTextBoxProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SheetVisualScopingConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "scope": "scope",
            "sheet_id": "sheetId",
            "visual_ids": "visualIds",
        },
    )
    class SheetVisualScopingConfigurationProperty:
        def __init__(
            self,
            *,
            scope: builtins.str,
            sheet_id: builtins.str,
            visual_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The filter that is applied to the options.

            :param scope: The scope of the applied entities. Choose one of the following options:. - ``ALL_VISUALS`` - ``SELECTED_VISUALS``
            :param sheet_id: The selected sheet that the filter is applied to.
            :param visual_ids: The selected visuals that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetvisualscopingconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_visual_scoping_configuration_property = quicksight.CfnDashboard.SheetVisualScopingConfigurationProperty(
                    scope="scope",
                    sheet_id="sheetId",
                
                    # the properties below are optional
                    visual_ids=["visualIds"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9279f1b0b78c57fec0f29c8290a407cce9b28e9beb086d1ef3a3b460002d9148)
                check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
                check_type(argname="argument visual_ids", value=visual_ids, expected_type=type_hints["visual_ids"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "scope": scope,
                "sheet_id": sheet_id,
            }
            if visual_ids is not None:
                self._values["visual_ids"] = visual_ids

        @builtins.property
        def scope(self) -> builtins.str:
            '''The scope of the applied entities. Choose one of the following options:.

            - ``ALL_VISUALS``
            - ``SELECTED_VISUALS``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetvisualscopingconfiguration.html#cfn-quicksight-dashboard-sheetvisualscopingconfiguration-scope
            '''
            result = self._values.get("scope")
            assert result is not None, "Required property 'scope' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sheet_id(self) -> builtins.str:
            '''The selected sheet that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetvisualscopingconfiguration.html#cfn-quicksight-dashboard-sheetvisualscopingconfiguration-sheetid
            '''
            result = self._values.get("sheet_id")
            assert result is not None, "Required property 'sheet_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_ids(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The selected visuals that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetvisualscopingconfiguration.html#cfn-quicksight-dashboard-sheetvisualscopingconfiguration-visualids
            '''
            result = self._values.get("visual_ids")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetVisualScopingConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ShortFormatTextProperty",
        jsii_struct_bases=[],
        name_mapping={"plain_text": "plainText", "rich_text": "richText"},
    )
    class ShortFormatTextProperty:
        def __init__(
            self,
            *,
            plain_text: typing.Optional[builtins.str] = None,
            rich_text: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The text format for the title.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param plain_text: Plain text format.
            :param rich_text: Rich text. Examples of rich text include bold, underline, and italics.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shortformattext.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                short_format_text_property = quicksight.CfnDashboard.ShortFormatTextProperty(
                    plain_text="plainText",
                    rich_text="richText"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__befd7183370b0dc4bfd2047acab63e998cb7a8c5356e897d8988828ed460470b)
                check_type(argname="argument plain_text", value=plain_text, expected_type=type_hints["plain_text"])
                check_type(argname="argument rich_text", value=rich_text, expected_type=type_hints["rich_text"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if plain_text is not None:
                self._values["plain_text"] = plain_text
            if rich_text is not None:
                self._values["rich_text"] = rich_text

        @builtins.property
        def plain_text(self) -> typing.Optional[builtins.str]:
            '''Plain text format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shortformattext.html#cfn-quicksight-dashboard-shortformattext-plaintext
            '''
            result = self._values.get("plain_text")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rich_text(self) -> typing.Optional[builtins.str]:
            '''Rich text.

            Examples of rich text include bold, underline, and italics.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shortformattext.html#cfn-quicksight-dashboard-shortformattext-richtext
            '''
            result = self._values.get("rich_text")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ShortFormatTextProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SimpleClusterMarkerProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color"},
    )
    class SimpleClusterMarkerProperty:
        def __init__(self, *, color: typing.Optional[builtins.str] = None) -> None:
            '''The simple cluster marker of the cluster marker.

            :param color: The color of the simple cluster marker.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-simpleclustermarker.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                simple_cluster_marker_property = quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                    color="color"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__882e164d216977769910a03fd5a932d20e987923108ac1451ca186ea5481d49f)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color of the simple cluster marker.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-simpleclustermarker.html#cfn-quicksight-dashboard-simpleclustermarker-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SimpleClusterMarkerProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SliderControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "info_icon_label_options": "infoIconLabelOptions",
            "title_options": "titleOptions",
        },
    )
    class SliderControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SheetControlInfoIconLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param info_icon_label_options: The configuration of info icon label options.
            :param title_options: The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-slidercontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                slider_control_display_options_property = quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                    info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                        info_icon_text="infoIconText",
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e239d7632b9f718c785c202aa5d162b9f047c8bd0bf05dcd02582a4eace25922)
                check_type(argname="argument info_icon_label_options", value=info_icon_label_options, expected_type=type_hints["info_icon_label_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if info_icon_label_options is not None:
                self._values["info_icon_label_options"] = info_icon_label_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def info_icon_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetControlInfoIconLabelOptionsProperty"]]:
            '''The configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-slidercontroldisplayoptions.html#cfn-quicksight-dashboard-slidercontroldisplayoptions-infoiconlabeloptions
            '''
            result = self._values.get("info_icon_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetControlInfoIconLabelOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-slidercontroldisplayoptions.html#cfn-quicksight-dashboard-slidercontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SliderControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SmallMultiplesAxisPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={"placement": "placement", "scale": "scale"},
    )
    class SmallMultiplesAxisPropertiesProperty:
        def __init__(
            self,
            *,
            placement: typing.Optional[builtins.str] = None,
            scale: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Configures the properties of a chart's axes that are used by small multiples panels.

            :param placement: Defines the placement of the axis. By default, axes are rendered ``OUTSIDE`` of the panels. Axes with ``INDEPENDENT`` scale are rendered ``INSIDE`` the panels.
            :param scale: Determines whether scale of the axes are shared or independent. The default value is ``SHARED`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesaxisproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                small_multiples_axis_properties_property = quicksight.CfnDashboard.SmallMultiplesAxisPropertiesProperty(
                    placement="placement",
                    scale="scale"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d4dbf2cee4d3cacab4653209bfaec3505dfa674374f7efbfcc5cd60580804b33)
                check_type(argname="argument placement", value=placement, expected_type=type_hints["placement"])
                check_type(argname="argument scale", value=scale, expected_type=type_hints["scale"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if placement is not None:
                self._values["placement"] = placement
            if scale is not None:
                self._values["scale"] = scale

        @builtins.property
        def placement(self) -> typing.Optional[builtins.str]:
            '''Defines the placement of the axis.

            By default, axes are rendered ``OUTSIDE`` of the panels. Axes with ``INDEPENDENT`` scale are rendered ``INSIDE`` the panels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesaxisproperties.html#cfn-quicksight-dashboard-smallmultiplesaxisproperties-placement
            '''
            result = self._values.get("placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scale(self) -> typing.Optional[builtins.str]:
            '''Determines whether scale of the axes are shared or independent.

            The default value is ``SHARED`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesaxisproperties.html#cfn-quicksight-dashboard-smallmultiplesaxisproperties-scale
            '''
            result = self._values.get("scale")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SmallMultiplesAxisPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SmallMultiplesOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "max_visible_columns": "maxVisibleColumns",
            "max_visible_rows": "maxVisibleRows",
            "panel_configuration": "panelConfiguration",
            "x_axis": "xAxis",
            "y_axis": "yAxis",
        },
    )
    class SmallMultiplesOptionsProperty:
        def __init__(
            self,
            *,
            max_visible_columns: typing.Optional[jsii.Number] = None,
            max_visible_rows: typing.Optional[jsii.Number] = None,
            panel_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PanelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SmallMultiplesAxisPropertiesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            y_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SmallMultiplesAxisPropertiesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Options that determine the layout and display options of a chart's small multiples.

            :param max_visible_columns: Sets the maximum number of visible columns to display in the grid of small multiples panels. The default is ``Auto`` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.
            :param max_visible_rows: Sets the maximum number of visible rows to display in the grid of small multiples panels. The default value is ``Auto`` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.
            :param panel_configuration: Configures the display options for each small multiples panel.
            :param x_axis: The properties of a small multiples X axis.
            :param y_axis: The properties of a small multiples Y axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                small_multiples_options_property = quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                    max_visible_columns=123,
                    max_visible_rows=123,
                    panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                        background_color="backgroundColor",
                        background_visibility="backgroundVisibility",
                        border_color="borderColor",
                        border_style="borderStyle",
                        border_thickness="borderThickness",
                        border_visibility="borderVisibility",
                        gutter_spacing="gutterSpacing",
                        gutter_visibility="gutterVisibility",
                        title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_text_alignment="horizontalTextAlignment",
                            visibility="visibility"
                        )
                    ),
                    x_axis=quicksight.CfnDashboard.SmallMultiplesAxisPropertiesProperty(
                        placement="placement",
                        scale="scale"
                    ),
                    y_axis=quicksight.CfnDashboard.SmallMultiplesAxisPropertiesProperty(
                        placement="placement",
                        scale="scale"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9a014fd4be360a4c78a4686a8a43e25bd3e6547115381267b0fa1145da9a130f)
                check_type(argname="argument max_visible_columns", value=max_visible_columns, expected_type=type_hints["max_visible_columns"])
                check_type(argname="argument max_visible_rows", value=max_visible_rows, expected_type=type_hints["max_visible_rows"])
                check_type(argname="argument panel_configuration", value=panel_configuration, expected_type=type_hints["panel_configuration"])
                check_type(argname="argument x_axis", value=x_axis, expected_type=type_hints["x_axis"])
                check_type(argname="argument y_axis", value=y_axis, expected_type=type_hints["y_axis"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if max_visible_columns is not None:
                self._values["max_visible_columns"] = max_visible_columns
            if max_visible_rows is not None:
                self._values["max_visible_rows"] = max_visible_rows
            if panel_configuration is not None:
                self._values["panel_configuration"] = panel_configuration
            if x_axis is not None:
                self._values["x_axis"] = x_axis
            if y_axis is not None:
                self._values["y_axis"] = y_axis

        @builtins.property
        def max_visible_columns(self) -> typing.Optional[jsii.Number]:
            '''Sets the maximum number of visible columns to display in the grid of small multiples panels.

            The default is ``Auto`` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html#cfn-quicksight-dashboard-smallmultiplesoptions-maxvisiblecolumns
            '''
            result = self._values.get("max_visible_columns")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def max_visible_rows(self) -> typing.Optional[jsii.Number]:
            '''Sets the maximum number of visible rows to display in the grid of small multiples panels.

            The default value is ``Auto`` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html#cfn-quicksight-dashboard-smallmultiplesoptions-maxvisiblerows
            '''
            result = self._values.get("max_visible_rows")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def panel_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PanelConfigurationProperty"]]:
            '''Configures the display options for each small multiples panel.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html#cfn-quicksight-dashboard-smallmultiplesoptions-panelconfiguration
            '''
            result = self._values.get("panel_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PanelConfigurationProperty"]], result)

        @builtins.property
        def x_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SmallMultiplesAxisPropertiesProperty"]]:
            '''The properties of a small multiples X axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html#cfn-quicksight-dashboard-smallmultiplesoptions-xaxis
            '''
            result = self._values.get("x_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SmallMultiplesAxisPropertiesProperty"]], result)

        @builtins.property
        def y_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SmallMultiplesAxisPropertiesProperty"]]:
            '''The properties of a small multiples Y axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html#cfn-quicksight-dashboard-smallmultiplesoptions-yaxis
            '''
            result = self._values.get("y_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SmallMultiplesAxisPropertiesProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SmallMultiplesOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SpacingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bottom": "bottom",
            "left": "left",
            "right": "right",
            "top": "top",
        },
    )
    class SpacingProperty:
        def __init__(
            self,
            *,
            bottom: typing.Optional[builtins.str] = None,
            left: typing.Optional[builtins.str] = None,
            right: typing.Optional[builtins.str] = None,
            top: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of spacing (often a margin or padding).

            :param bottom: Define the bottom spacing.
            :param left: Define the left spacing.
            :param right: Define the right spacing.
            :param top: Define the top spacing.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                spacing_property = quicksight.CfnDashboard.SpacingProperty(
                    bottom="bottom",
                    left="left",
                    right="right",
                    top="top"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d10af48042761075c34e6231d9ffa8fcffc93a894863bf3364b3dc12157b229c)
                check_type(argname="argument bottom", value=bottom, expected_type=type_hints["bottom"])
                check_type(argname="argument left", value=left, expected_type=type_hints["left"])
                check_type(argname="argument right", value=right, expected_type=type_hints["right"])
                check_type(argname="argument top", value=top, expected_type=type_hints["top"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bottom is not None:
                self._values["bottom"] = bottom
            if left is not None:
                self._values["left"] = left
            if right is not None:
                self._values["right"] = right
            if top is not None:
                self._values["top"] = top

        @builtins.property
        def bottom(self) -> typing.Optional[builtins.str]:
            '''Define the bottom spacing.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html#cfn-quicksight-dashboard-spacing-bottom
            '''
            result = self._values.get("bottom")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def left(self) -> typing.Optional[builtins.str]:
            '''Define the left spacing.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html#cfn-quicksight-dashboard-spacing-left
            '''
            result = self._values.get("left")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def right(self) -> typing.Optional[builtins.str]:
            '''Define the right spacing.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html#cfn-quicksight-dashboard-spacing-right
            '''
            result = self._values.get("right")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def top(self) -> typing.Optional[builtins.str]:
            '''Define the top spacing.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html#cfn-quicksight-dashboard-spacing-top
            '''
            result = self._values.get("top")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SpacingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.StringDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class StringDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The default values of the ``StringParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``StringDefaultValues`` . Different defaults displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``DecimalDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                string_default_values_property = quicksight.CfnDashboard.StringDefaultValuesProperty(
                    dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=["staticValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e7c2c1d26ecfc57ea393a168f598cba69bab52250071aaa23976fd4e22ce1152)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``StringDefaultValues`` .

            Different defaults displayed according to users, groups, and values mapping.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringdefaultvalues.html#cfn-quicksight-dashboard-stringdefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The static values of the ``DecimalDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringdefaultvalues.html#cfn-quicksight-dashboard-stringdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.StringFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "numeric_format_configuration": "numericFormatConfiguration",
        },
    )
    class StringFormatConfigurationProperty:
        def __init__(
            self,
            *,
            null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Formatting configuration for string fields.

            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param numeric_format_configuration: The formatting configuration for numeric strings.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                string_format_configuration_property = quicksight.CfnDashboard.StringFormatConfigurationProperty(
                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__579192884d4af9500fc2c9fb480930669120e1c45145b4a731200b153f76cbfa)
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument numeric_format_configuration", value=numeric_format_configuration, expected_type=type_hints["numeric_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if numeric_format_configuration is not None:
                self._values["numeric_format_configuration"] = numeric_format_configuration

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringformatconfiguration.html#cfn-quicksight-dashboard-stringformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def numeric_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericFormatConfigurationProperty"]]:
            '''The formatting configuration for numeric strings.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringformatconfiguration.html#cfn-quicksight-dashboard-stringformatconfiguration-numericformatconfiguration
            '''
            result = self._values.get("numeric_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.NumericFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.StringParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class StringParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.StringDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.StringValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``String`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: 
            :param value_when_unset: The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                string_parameter_declaration_property = quicksight.CfnDashboard.StringParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnDashboard.StringDefaultValuesProperty(
                        dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=["staticValues"]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnDashboard.StringValueWhenUnsetConfigurationProperty(
                        custom_value="customValue",
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8919687a098bd84dfbce9e9db5766d8a599df1749c9283ee17350f1ae11ab322)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.StringDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.StringDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MappedDataSetParameterProperty"]]]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.StringValueWhenUnsetConfigurationProperty"]]:
            '''The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.StringValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.StringParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class StringParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Sequence[builtins.str],
        ) -> None:
            '''A string parameter.

            :param name: A display name for a string parameter.
            :param values: The values of a string parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                string_parameter_property = quicksight.CfnDashboard.StringParameterProperty(
                    name="name",
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4b4982b38fff331d5bba21e46051ef446b46e234e4a98ea8e852a803b149d26c)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for a string parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameter.html#cfn-quicksight-dashboard-stringparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(self) -> typing.List[builtins.str]:
            '''The values of a string parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameter.html#cfn-quicksight-dashboard-stringparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.List[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.StringValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class StringValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[builtins.str] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringvaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                string_value_when_unset_configuration_property = quicksight.CfnDashboard.StringValueWhenUnsetConfigurationProperty(
                    custom_value="customValue",
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__018e089951fc42c095c3906a3363edc2a9e6acd283d4e41e332d6e000612e362)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[builtins.str]:
            '''A custom value that's used when the value of a parameter isn't set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringvaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-stringvaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringvaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-stringvaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.SubtotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "field_level": "fieldLevel",
            "field_level_options": "fieldLevelOptions",
            "metric_header_cell_style": "metricHeaderCellStyle",
            "style_targets": "styleTargets",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
            "value_cell_style": "valueCellStyle",
        },
    )
    class SubtotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            field_level: typing.Optional[builtins.str] = None,
            field_level_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTableFieldSubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            metric_header_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            style_targets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableStyleTargetProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            total_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
            value_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The subtotal options.

            :param custom_label: The custom label string for the subtotal cells.
            :param field_level: The field level (all, custom, last) for the subtotal cells.
            :param field_level_options: The optional configuration of subtotal cells.
            :param metric_header_cell_style: The cell styling options for the subtotals of header cells.
            :param style_targets: The style targets options for subtotals.
            :param total_cell_style: The cell styling options for the subtotal cells.
            :param totals_visibility: The visibility configuration for the subtotal cells.
            :param value_cell_style: The cell styling options for the subtotals of value cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                subtotal_options_property = quicksight.CfnDashboard.SubtotalOptionsProperty(
                    custom_label="customLabel",
                    field_level="fieldLevel",
                    field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                        field_id="fieldId"
                    )],
                    metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    style_targets=[quicksight.CfnDashboard.TableStyleTargetProperty(
                        cell_type="cellType"
                    )],
                    total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility",
                    value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__26b5761cb80bd4eb296fb14cc2ace3e489d48b01f174b636486e6b67e10ee691)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument field_level", value=field_level, expected_type=type_hints["field_level"])
                check_type(argname="argument field_level_options", value=field_level_options, expected_type=type_hints["field_level_options"])
                check_type(argname="argument metric_header_cell_style", value=metric_header_cell_style, expected_type=type_hints["metric_header_cell_style"])
                check_type(argname="argument style_targets", value=style_targets, expected_type=type_hints["style_targets"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
                check_type(argname="argument value_cell_style", value=value_cell_style, expected_type=type_hints["value_cell_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if field_level is not None:
                self._values["field_level"] = field_level
            if field_level_options is not None:
                self._values["field_level_options"] = field_level_options
            if metric_header_cell_style is not None:
                self._values["metric_header_cell_style"] = metric_header_cell_style
            if style_targets is not None:
                self._values["style_targets"] = style_targets
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility
            if value_cell_style is not None:
                self._values["value_cell_style"] = value_cell_style

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the subtotal cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_level(self) -> typing.Optional[builtins.str]:
            '''The field level (all, custom, last) for the subtotal cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-fieldlevel
            '''
            result = self._values.get("field_level")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_level_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableFieldSubtotalOptionsProperty"]]]]:
            '''The optional configuration of subtotal cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-fieldleveloptions
            '''
            result = self._values.get("field_level_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableFieldSubtotalOptionsProperty"]]]], result)

        @builtins.property
        def metric_header_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]]:
            '''The cell styling options for the subtotals of header cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-metricheadercellstyle
            '''
            result = self._values.get("metric_header_cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def style_targets(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableStyleTargetProperty"]]]]:
            '''The style targets options for subtotals.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-styletargets
            '''
            result = self._values.get("style_targets")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableStyleTargetProperty"]]]], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]]:
            '''The cell styling options for the subtotal cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the subtotal cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]]:
            '''The cell styling options for the subtotals of value cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-valuecellstyle
            '''
            result = self._values.get("value_cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SubtotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "values": "values"},
    )
    class TableAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well for the table.

            :param group_by: The group by field well for a pivot table. Values are grouped by group by fields.
            :param values: The values field well for a pivot table. Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_aggregated_field_wells_property = quicksight.CfnDashboard.TableAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__06ec3e26048e42a36acdc448a052cbfb6d8f79af7a0c7a45d9c4329ecf139a6c)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The group by field well for a pivot table.

            Values are grouped by group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableaggregatedfieldwells.html#cfn-quicksight-dashboard-tableaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The values field well for a pivot table.

            Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableaggregatedfieldwells.html#cfn-quicksight-dashboard-tableaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "style": "style", "thickness": "thickness"},
    )
    class TableBorderOptionsProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            style: typing.Optional[builtins.str] = None,
            thickness: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The border options for a table border.

            :param color: The color of a table border.
            :param style: The style (none, solid) of a table border.
            :param thickness: The thickness of a table border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_border_options_property = quicksight.CfnDashboard.TableBorderOptionsProperty(
                    color="color",
                    style="style",
                    thickness=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__91428afe0f06f4a2f7f630653be17e89c86fc298d88dae4cd7b46bd937dc832f)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
                check_type(argname="argument thickness", value=thickness, expected_type=type_hints["thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if style is not None:
                self._values["style"] = style
            if thickness is not None:
                self._values["thickness"] = thickness

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color of a table border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableborderoptions.html#cfn-quicksight-dashboard-tableborderoptions-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style(self) -> typing.Optional[builtins.str]:
            '''The style (none, solid) of a table border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableborderoptions.html#cfn-quicksight-dashboard-tableborderoptions-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def thickness(self) -> typing.Optional[jsii.Number]:
            '''The thickness of a table border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableborderoptions.html#cfn-quicksight-dashboard-tableborderoptions-thickness
            '''
            result = self._values.get("thickness")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableCellConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "text_format": "textFormat"},
    )
    class TableCellConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            text_format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TextConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cell conditional formatting option for a table.

            :param field_id: The field ID of the cell for conditional formatting.
            :param text_format: The text format of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_cell_conditional_formatting_property = quicksight.CfnDashboard.TableCellConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__97dd9d6b6f88b3cbbeae34b532eeb67c5dbf9bbfee4b2843b60ad5927f1c340e)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument text_format", value=text_format, expected_type=type_hints["text_format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if text_format is not None:
                self._values["text_format"] = text_format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellconditionalformatting.html#cfn-quicksight-dashboard-tablecellconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def text_format(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TextConditionalFormatProperty"]]:
            '''The text format of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellconditionalformatting.html#cfn-quicksight-dashboard-tablecellconditionalformatting-textformat
            '''
            result = self._values.get("text_format")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TextConditionalFormatProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "table_cell_image_scaling_configuration": "tableCellImageScalingConfiguration",
        },
    )
    class TableCellImageSizingConfigurationProperty:
        def __init__(
            self,
            *,
            table_cell_image_scaling_configuration: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The sizing options for the table image configuration.

            :param table_cell_image_scaling_configuration: The cell scaling configuration of the sizing options for the table image configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellimagesizingconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_cell_image_sizing_configuration_property = quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__148cb2bb5db864bd1928be0914a1f93b9a8fc631677ceeb9ca88c364c4ea9889)
                check_type(argname="argument table_cell_image_scaling_configuration", value=table_cell_image_scaling_configuration, expected_type=type_hints["table_cell_image_scaling_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if table_cell_image_scaling_configuration is not None:
                self._values["table_cell_image_scaling_configuration"] = table_cell_image_scaling_configuration

        @builtins.property
        def table_cell_image_scaling_configuration(
            self,
        ) -> typing.Optional[builtins.str]:
            '''The cell scaling configuration of the sizing options for the table image configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellimagesizingconfiguration.html#cfn-quicksight-dashboard-tablecellimagesizingconfiguration-tablecellimagescalingconfiguration
            '''
            result = self._values.get("table_cell_image_scaling_configuration")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellImageSizingConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableCellStyleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "border": "border",
            "font_configuration": "fontConfiguration",
            "height": "height",
            "horizontal_text_alignment": "horizontalTextAlignment",
            "text_wrap": "textWrap",
            "vertical_text_alignment": "verticalTextAlignment",
            "visibility": "visibility",
        },
    )
    class TableCellStyleProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[builtins.str] = None,
            border: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GlobalTableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            height: typing.Optional[jsii.Number] = None,
            horizontal_text_alignment: typing.Optional[builtins.str] = None,
            text_wrap: typing.Optional[builtins.str] = None,
            vertical_text_alignment: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The table cell style for a cell in pivot table or table visual.

            :param background_color: The background color for the table cells.
            :param border: The borders for the table cells.
            :param font_configuration: The font configuration of the table cells.
            :param height: The height color for the table cells.
            :param horizontal_text_alignment: The horizontal text alignment (left, center, right, auto) for the table cells.
            :param text_wrap: The text wrap (none, wrap) for the table cells.
            :param vertical_text_alignment: The vertical text alignment (top, middle, bottom) for the table cells.
            :param visibility: The visibility of the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_cell_style_property = quicksight.CfnDashboard.TableCellStyleProperty(
                    background_color="backgroundColor",
                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        )
                    ),
                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    height=123,
                    horizontal_text_alignment="horizontalTextAlignment",
                    text_wrap="textWrap",
                    vertical_text_alignment="verticalTextAlignment",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4725b1bc64b9968cf7bf1909f7e619eb95067c9cc334cd0cb73d8a67cf676531)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument border", value=border, expected_type=type_hints["border"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument horizontal_text_alignment", value=horizontal_text_alignment, expected_type=type_hints["horizontal_text_alignment"])
                check_type(argname="argument text_wrap", value=text_wrap, expected_type=type_hints["text_wrap"])
                check_type(argname="argument vertical_text_alignment", value=vertical_text_alignment, expected_type=type_hints["vertical_text_alignment"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if border is not None:
                self._values["border"] = border
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if height is not None:
                self._values["height"] = height
            if horizontal_text_alignment is not None:
                self._values["horizontal_text_alignment"] = horizontal_text_alignment
            if text_wrap is not None:
                self._values["text_wrap"] = text_wrap
            if vertical_text_alignment is not None:
                self._values["vertical_text_alignment"] = vertical_text_alignment
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def background_color(self) -> typing.Optional[builtins.str]:
            '''The background color for the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GlobalTableBorderOptionsProperty"]]:
            '''The borders for the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-border
            '''
            result = self._values.get("border")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GlobalTableBorderOptionsProperty"]], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"]]:
            '''The font configuration of the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"]], result)

        @builtins.property
        def height(self) -> typing.Optional[jsii.Number]:
            '''The height color for the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def horizontal_text_alignment(self) -> typing.Optional[builtins.str]:
            '''The horizontal text alignment (left, center, right, auto) for the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-horizontaltextalignment
            '''
            result = self._values.get("horizontal_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def text_wrap(self) -> typing.Optional[builtins.str]:
            '''The text wrap (none, wrap) for the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-textwrap
            '''
            result = self._values.get("text_wrap")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_text_alignment(self) -> typing.Optional[builtins.str]:
            '''The vertical text alignment (top, middle, bottom) for the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-verticaltextalignment
            '''
            result = self._values.get("vertical_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"cell": "cell", "row": "row"},
    )
    class TableConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            cell: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableCellConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableRowConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :param cell: The cell conditional formatting option for a table.
            :param row: The row conditional formatting option for a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_conditional_formatting_option_property = quicksight.CfnDashboard.TableConditionalFormattingOptionProperty(
                    cell=quicksight.CfnDashboard.TableCellConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    ),
                    row=quicksight.CfnDashboard.TableRowConditionalFormattingProperty(
                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__904f4095015ac5d1118f1e032355f861ae96504172670bef5fcc07d0db2a06b9)
                check_type(argname="argument cell", value=cell, expected_type=type_hints["cell"])
                check_type(argname="argument row", value=row, expected_type=type_hints["row"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell is not None:
                self._values["cell"] = cell
            if row is not None:
                self._values["row"] = row

        @builtins.property
        def cell(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellConditionalFormattingProperty"]]:
            '''The cell conditional formatting option for a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformattingoption.html#cfn-quicksight-dashboard-tableconditionalformattingoption-cell
            '''
            result = self._values.get("cell")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellConditionalFormattingProperty"]], result)

        @builtins.property
        def row(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableRowConditionalFormattingProperty"]]:
            '''The row conditional formatting option for a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformattingoption.html#cfn-quicksight-dashboard-tableconditionalformattingoption-row
            '''
            result = self._values.get("row")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableRowConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class TableConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :param conditional_formatting_options: Conditional formatting options for a ``PivotTableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_conditional_formatting_property = quicksight.CfnDashboard.TableConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnDashboard.TableConditionalFormattingOptionProperty(
                        cell=quicksight.CfnDashboard.TableCellConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        ),
                        row=quicksight.CfnDashboard.TableRowConditionalFormattingProperty(
                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__af82137c10212c69fa09dafa2375d4ac0f88d3d4321f11717643d592af28a491)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableConditionalFormattingOptionProperty"]]]]:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformatting.html#cfn-quicksight-dashboard-tableconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_options": "fieldOptions",
            "field_wells": "fieldWells",
            "paginated_report_options": "paginatedReportOptions",
            "sort_configuration": "sortConfiguration",
            "table_inline_visualizations": "tableInlineVisualizations",
            "table_options": "tableOptions",
            "total_options": "totalOptions",
        },
    )
    class TableConfigurationProperty:
        def __init__(
            self,
            *,
            field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableFieldOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paginated_report_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TablePaginatedReportOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_inline_visualizations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableInlineVisualizationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            table_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``TableVisual`` .

            :param field_options: The field options for a table visual.
            :param field_wells: The field wells of the visual.
            :param paginated_report_options: The paginated report options for a table visual.
            :param sort_configuration: The sort configuration for a ``TableVisual`` .
            :param table_inline_visualizations: A collection of inline visualizations to display within a chart.
            :param table_options: The table options for a table visual.
            :param total_options: The total options for a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a5829fc9800027963440705a81ef3be5c95d9cb4321812c444350ba9dce447e3)
                check_type(argname="argument field_options", value=field_options, expected_type=type_hints["field_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument paginated_report_options", value=paginated_report_options, expected_type=type_hints["paginated_report_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument table_inline_visualizations", value=table_inline_visualizations, expected_type=type_hints["table_inline_visualizations"])
                check_type(argname="argument table_options", value=table_options, expected_type=type_hints["table_options"])
                check_type(argname="argument total_options", value=total_options, expected_type=type_hints["total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_options is not None:
                self._values["field_options"] = field_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if paginated_report_options is not None:
                self._values["paginated_report_options"] = paginated_report_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if table_inline_visualizations is not None:
                self._values["table_inline_visualizations"] = table_inline_visualizations
            if table_options is not None:
                self._values["table_options"] = table_options
            if total_options is not None:
                self._values["total_options"] = total_options

        @builtins.property
        def field_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableFieldOptionsProperty"]]:
            '''The field options for a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-fieldoptions
            '''
            result = self._values.get("field_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableFieldOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableFieldWellsProperty"]], result)

        @builtins.property
        def paginated_report_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TablePaginatedReportOptionsProperty"]]:
            '''The paginated report options for a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-paginatedreportoptions
            '''
            result = self._values.get("paginated_report_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TablePaginatedReportOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableSortConfigurationProperty"]]:
            '''The sort configuration for a ``TableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableSortConfigurationProperty"]], result)

        @builtins.property
        def table_inline_visualizations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableInlineVisualizationProperty"]]]]:
            '''A collection of inline visualizations to display within a chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-tableinlinevisualizations
            '''
            result = self._values.get("table_inline_visualizations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableInlineVisualizationProperty"]]]], result)

        @builtins.property
        def table_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableOptionsProperty"]]:
            '''The table options for a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-tableoptions
            '''
            result = self._values.get("table_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableOptionsProperty"]], result)

        @builtins.property
        def total_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TotalOptionsProperty"]]:
            '''The total options for a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-totaloptions
            '''
            result = self._values.get("total_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TotalOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableFieldCustomIconContentProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon"},
    )
    class TableFieldCustomIconContentProperty:
        def __init__(self, *, icon: typing.Optional[builtins.str] = None) -> None:
            '''The custom icon content for the table link content configuration.

            :param icon: The icon set type (link) of the custom icon content for table URL link content.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomiconcontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_custom_icon_content_property = quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                    icon="icon"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7e528dd56da6f2bdc132410b8b05cc00ffdfe869350cab673bed9637be7ebd36)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon

        @builtins.property
        def icon(self) -> typing.Optional[builtins.str]:
            '''The icon set type (link) of the custom icon content for table URL link content.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomiconcontent.html#cfn-quicksight-dashboard-tablefieldcustomiconcontent-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldCustomIconContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableFieldCustomTextContentProperty",
        jsii_struct_bases=[],
        name_mapping={"font_configuration": "fontConfiguration", "value": "value"},
    )
    class TableFieldCustomTextContentProperty:
        def __init__(
            self,
            *,
            font_configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The custom text content (value, font configuration) for the table link content configuration.

            :param font_configuration: The font configuration of the custom text content for the table URL link content.
            :param value: The string value of the custom text content for the table URL link content.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomtextcontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_custom_text_content_property = quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                
                    # the properties below are optional
                    value="value"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9ce9d7bc7f8a9c4dac84ada50400eb4f79abac8466d390fa3739627e5d182eba)
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "font_configuration": font_configuration,
            }
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"]:
            '''The font configuration of the custom text content for the table URL link content.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomtextcontent.html#cfn-quicksight-dashboard-tablefieldcustomtextcontent-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            assert result is not None, "Required property 'font_configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.FontConfigurationProperty"], result)

        @builtins.property
        def value(self) -> typing.Optional[builtins.str]:
            '''The string value of the custom text content for the table URL link content.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomtextcontent.html#cfn-quicksight-dashboard-tablefieldcustomtextcontent-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldCustomTextContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableFieldImageConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"sizing_options": "sizingOptions"},
    )
    class TableFieldImageConfigurationProperty:
        def __init__(
            self,
            *,
            sizing_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableCellImageSizingConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The image configuration of a table field URL.

            :param sizing_options: The sizing options for the table image configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldimageconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_image_configuration_property = quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                    sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9a737949c68d33bc9425fec6a238be37344aa023096329fce23b2b3dd7d03eb9)
                check_type(argname="argument sizing_options", value=sizing_options, expected_type=type_hints["sizing_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sizing_options is not None:
                self._values["sizing_options"] = sizing_options

        @builtins.property
        def sizing_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellImageSizingConfigurationProperty"]]:
            '''The sizing options for the table image configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldimageconfiguration.html#cfn-quicksight-dashboard-tablefieldimageconfiguration-sizingoptions
            '''
            result = self._values.get("sizing_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellImageSizingConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldImageConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableFieldLinkConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"content": "content", "target": "target"},
    )
    class TableFieldLinkConfigurationProperty:
        def __init__(
            self,
            *,
            content: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableFieldLinkContentConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            target: builtins.str,
        ) -> None:
            '''The link configuration of a table field URL.

            :param content: The URL content (text, icon) for the table link configuration.
            :param target: The URL target (new tab, new window, same tab) for the table link configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_link_configuration_property = quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                    content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                        custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                            icon="icon"
                        ),
                        custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                
                            # the properties below are optional
                            value="value"
                        )
                    ),
                    target="target"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4670d1d0f5e8b98564c1607bafb6ff8568818c9c78279ba45bea1c5726cdf17f)
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
                check_type(argname="argument target", value=target, expected_type=type_hints["target"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "content": content,
                "target": target,
            }

        @builtins.property
        def content(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableFieldLinkContentConfigurationProperty"]:
            '''The URL content (text, icon) for the table link configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkconfiguration.html#cfn-quicksight-dashboard-tablefieldlinkconfiguration-content
            '''
            result = self._values.get("content")
            assert result is not None, "Required property 'content' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableFieldLinkContentConfigurationProperty"], result)

        @builtins.property
        def target(self) -> builtins.str:
            '''The URL target (new tab, new window, same tab) for the table link configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkconfiguration.html#cfn-quicksight-dashboard-tablefieldlinkconfiguration-target
            '''
            result = self._values.get("target")
            assert result is not None, "Required property 'target' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldLinkConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_icon_content": "customIconContent",
            "custom_text_content": "customTextContent",
        },
    )
    class TableFieldLinkContentConfigurationProperty:
        def __init__(
            self,
            *,
            custom_icon_content: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableFieldCustomIconContentProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_text_content: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableFieldCustomTextContentProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The URL content (text, icon) for the table link configuration.

            :param custom_icon_content: The custom icon content for the table link content configuration.
            :param custom_text_content: The custom text content (value, font configuration) for the table link content configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkcontentconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_link_content_configuration_property = quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                    custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                        icon="icon"
                    ),
                    custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                
                        # the properties below are optional
                        value="value"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7e6c8d36af961087ba9d67e20be2e0a3e98078b4f0a03250a01f0ab491d64581)
                check_type(argname="argument custom_icon_content", value=custom_icon_content, expected_type=type_hints["custom_icon_content"])
                check_type(argname="argument custom_text_content", value=custom_text_content, expected_type=type_hints["custom_text_content"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_icon_content is not None:
                self._values["custom_icon_content"] = custom_icon_content
            if custom_text_content is not None:
                self._values["custom_text_content"] = custom_text_content

        @builtins.property
        def custom_icon_content(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableFieldCustomIconContentProperty"]]:
            '''The custom icon content for the table link content configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkcontentconfiguration.html#cfn-quicksight-dashboard-tablefieldlinkcontentconfiguration-customiconcontent
            '''
            result = self._values.get("custom_icon_content")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableFieldCustomIconContentProperty"]], result)

        @builtins.property
        def custom_text_content(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableFieldCustomTextContentProperty"]]:
            '''The custom text content (value, font configuration) for the table link content configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkcontentconfiguration.html#cfn-quicksight-dashboard-tablefieldlinkcontentconfiguration-customtextcontent
            '''
            result = self._values.get("custom_text_content")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableFieldCustomTextContentProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldLinkContentConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableFieldOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "custom_label": "customLabel",
            "url_styling": "urlStyling",
            "visibility": "visibility",
            "width": "width",
        },
    )
    class TableFieldOptionProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            custom_label: typing.Optional[builtins.str] = None,
            url_styling: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableFieldURLConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for a table field.

            :param field_id: The field ID for a table field.
            :param custom_label: The custom label for a table field.
            :param url_styling: The URL configuration for a table field.
            :param visibility: The visibility of a table field.
            :param width: The width for a table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_option_property = quicksight.CfnDashboard.TableFieldOptionProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    custom_label="customLabel",
                    url_styling=quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                        image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                            sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                                table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                            )
                        ),
                        link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                            content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                                custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                    icon="icon"
                                ),
                                custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    value="value"
                                )
                            ),
                            target="target"
                        )
                    ),
                    visibility="visibility",
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__202a64e8c6661e5c0dd724d0e71c19aab1a8e9922ae97db8496df4d4544b0a24)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument url_styling", value=url_styling, expected_type=type_hints["url_styling"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if url_styling is not None:
                self._values["url_styling"] = url_styling
            if visibility is not None:
                self._values["visibility"] = visibility
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for a table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label for a table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def url_styling(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableFieldURLConfigurationProperty"]]:
            '''The URL configuration for a table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-urlstyling
            '''
            result = self._values.get("url_styling")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableFieldURLConfigurationProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of a table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width for a table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableFieldOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "order": "order",
            "pinned_field_options": "pinnedFieldOptions",
            "selected_field_options": "selectedFieldOptions",
        },
    )
    class TableFieldOptionsProperty:
        def __init__(
            self,
            *,
            order: typing.Optional[typing.Sequence[builtins.str]] = None,
            pinned_field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TablePinnedFieldOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selected_field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableFieldOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field options of a table visual.

            :param order: The order of the field IDs that are configured as field options for a table visual.
            :param pinned_field_options: The settings for the pinned columns of a table visual.
            :param selected_field_options: The field options to be configured to a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_options_property = quicksight.CfnDashboard.TableFieldOptionsProperty(
                    order=["order"],
                    pinned_field_options=quicksight.CfnDashboard.TablePinnedFieldOptionsProperty(
                        pinned_left_fields=["pinnedLeftFields"]
                    ),
                    selected_field_options=[quicksight.CfnDashboard.TableFieldOptionProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        custom_label="customLabel",
                        url_styling=quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                            image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                                sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                )
                            ),
                            link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                                content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                                    custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                        icon="icon"
                                    ),
                                    custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        value="value"
                                    )
                                ),
                                target="target"
                            )
                        ),
                        visibility="visibility",
                        width="width"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__72ee146032d78abdf24c9225b55a85b01c617371b25550f6b22f15a263905c19)
                check_type(argname="argument order", value=order, expected_type=type_hints["order"])
                check_type(argname="argument pinned_field_options", value=pinned_field_options, expected_type=type_hints["pinned_field_options"])
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if order is not None:
                self._values["order"] = order
            if pinned_field_options is not None:
                self._values["pinned_field_options"] = pinned_field_options
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options

        @builtins.property
        def order(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The order of the field IDs that are configured as field options for a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoptions.html#cfn-quicksight-dashboard-tablefieldoptions-order
            '''
            result = self._values.get("order")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def pinned_field_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TablePinnedFieldOptionsProperty"]]:
            '''The settings for the pinned columns of a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoptions.html#cfn-quicksight-dashboard-tablefieldoptions-pinnedfieldoptions
            '''
            result = self._values.get("pinned_field_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TablePinnedFieldOptionsProperty"]], result)

        @builtins.property
        def selected_field_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableFieldOptionProperty"]]]]:
            '''The field options to be configured to a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoptions.html#cfn-quicksight-dashboard-tablefieldoptions-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableFieldOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableFieldURLConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "image_configuration": "imageConfiguration",
            "link_configuration": "linkConfiguration",
        },
    )
    class TableFieldURLConfigurationProperty:
        def __init__(
            self,
            *,
            image_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableFieldImageConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            link_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableFieldLinkConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The URL configuration for a table field.

            :param image_configuration: The image configuration of a table field URL.
            :param link_configuration: The link configuration of a table field URL.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldurlconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_uRLConfiguration_property = quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                    image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                        sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                            table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                        )
                    ),
                    link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                        content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                            custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                icon="icon"
                            ),
                            custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                
                                # the properties below are optional
                                value="value"
                            )
                        ),
                        target="target"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__83d9aa30bd42df19076e9b2ca1e2f474c465a691f0bfecd4fcd15ce4ed41f12f)
                check_type(argname="argument image_configuration", value=image_configuration, expected_type=type_hints["image_configuration"])
                check_type(argname="argument link_configuration", value=link_configuration, expected_type=type_hints["link_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if image_configuration is not None:
                self._values["image_configuration"] = image_configuration
            if link_configuration is not None:
                self._values["link_configuration"] = link_configuration

        @builtins.property
        def image_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableFieldImageConfigurationProperty"]]:
            '''The image configuration of a table field URL.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldurlconfiguration.html#cfn-quicksight-dashboard-tablefieldurlconfiguration-imageconfiguration
            '''
            result = self._values.get("image_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableFieldImageConfigurationProperty"]], result)

        @builtins.property
        def link_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableFieldLinkConfigurationProperty"]]:
            '''The link configuration of a table field URL.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldurlconfiguration.html#cfn-quicksight-dashboard-tablefieldurlconfiguration-linkconfiguration
            '''
            result = self._values.get("link_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableFieldLinkConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldURLConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "table_aggregated_field_wells": "tableAggregatedFieldWells",
            "table_unaggregated_field_wells": "tableUnaggregatedFieldWells",
        },
    )
    class TableFieldWellsProperty:
        def __init__(
            self,
            *,
            table_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_unaggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableUnaggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells for a table visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param table_aggregated_field_wells: The aggregated field well for the table.
            :param table_unaggregated_field_wells: The unaggregated field well for the table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f779abd17ec8354f58f4dcd429883d6cbc69963b366968f0877f9a8f43d9b370)
                check_type(argname="argument table_aggregated_field_wells", value=table_aggregated_field_wells, expected_type=type_hints["table_aggregated_field_wells"])
                check_type(argname="argument table_unaggregated_field_wells", value=table_unaggregated_field_wells, expected_type=type_hints["table_unaggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if table_aggregated_field_wells is not None:
                self._values["table_aggregated_field_wells"] = table_aggregated_field_wells
            if table_unaggregated_field_wells is not None:
                self._values["table_unaggregated_field_wells"] = table_unaggregated_field_wells

        @builtins.property
        def table_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableAggregatedFieldWellsProperty"]]:
            '''The aggregated field well for the table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldwells.html#cfn-quicksight-dashboard-tablefieldwells-tableaggregatedfieldwells
            '''
            result = self._values.get("table_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableAggregatedFieldWellsProperty"]], result)

        @builtins.property
        def table_unaggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableUnaggregatedFieldWellsProperty"]]:
            '''The unaggregated field well for the table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldwells.html#cfn-quicksight-dashboard-tablefieldwells-tableunaggregatedfieldwells
            '''
            result = self._values.get("table_unaggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableUnaggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableInlineVisualizationProperty",
        jsii_struct_bases=[],
        name_mapping={"data_bars": "dataBars"},
    )
    class TableInlineVisualizationProperty:
        def __init__(
            self,
            *,
            data_bars: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataBarsOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The inline visualization of a specific type to display within a chart.

            :param data_bars: The configuration of the inline visualization of the data bars within a chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableinlinevisualization.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_inline_visualization_property = quicksight.CfnDashboard.TableInlineVisualizationProperty(
                    data_bars=quicksight.CfnDashboard.DataBarsOptionsProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        negative_color="negativeColor",
                        positive_color="positiveColor"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__075d2b8a76bbea5648b0262047449d5700569c47654e81c5220160437f892365)
                check_type(argname="argument data_bars", value=data_bars, expected_type=type_hints["data_bars"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_bars is not None:
                self._values["data_bars"] = data_bars

        @builtins.property
        def data_bars(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataBarsOptionsProperty"]]:
            '''The configuration of the inline visualization of the data bars within a chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableinlinevisualization.html#cfn-quicksight-dashboard-tableinlinevisualization-databars
            '''
            result = self._values.get("data_bars")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataBarsOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableInlineVisualizationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cell_style": "cellStyle",
            "header_style": "headerStyle",
            "orientation": "orientation",
            "row_alternate_color_options": "rowAlternateColorOptions",
        },
    )
    class TableOptionsProperty:
        def __init__(
            self,
            *,
            cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            header_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            orientation: typing.Optional[builtins.str] = None,
            row_alternate_color_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.RowAlternateColorOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The table options for a table visual.

            :param cell_style: The table cell style of table cells.
            :param header_style: The table cell style of a table header.
            :param orientation: The orientation (vertical, horizontal) for a table.
            :param row_alternate_color_options: The row alternate color options (widget status, row alternate colors) for a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_options_property = quicksight.CfnDashboard.TableOptionsProperty(
                    cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    orientation="orientation",
                    row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                        row_alternate_colors=["rowAlternateColors"],
                        status="status",
                        use_primary_background_color="usePrimaryBackgroundColor"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c635b9421451d4c53104a38c4586b7ed4a7d7cd618e641c768344bf83477e3f9)
                check_type(argname="argument cell_style", value=cell_style, expected_type=type_hints["cell_style"])
                check_type(argname="argument header_style", value=header_style, expected_type=type_hints["header_style"])
                check_type(argname="argument orientation", value=orientation, expected_type=type_hints["orientation"])
                check_type(argname="argument row_alternate_color_options", value=row_alternate_color_options, expected_type=type_hints["row_alternate_color_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell_style is not None:
                self._values["cell_style"] = cell_style
            if header_style is not None:
                self._values["header_style"] = header_style
            if orientation is not None:
                self._values["orientation"] = orientation
            if row_alternate_color_options is not None:
                self._values["row_alternate_color_options"] = row_alternate_color_options

        @builtins.property
        def cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]]:
            '''The table cell style of table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html#cfn-quicksight-dashboard-tableoptions-cellstyle
            '''
            result = self._values.get("cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def header_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]]:
            '''The table cell style of a table header.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html#cfn-quicksight-dashboard-tableoptions-headerstyle
            '''
            result = self._values.get("header_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def orientation(self) -> typing.Optional[builtins.str]:
            '''The orientation (vertical, horizontal) for a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html#cfn-quicksight-dashboard-tableoptions-orientation
            '''
            result = self._values.get("orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def row_alternate_color_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RowAlternateColorOptionsProperty"]]:
            '''The row alternate color options (widget status, row alternate colors) for a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html#cfn-quicksight-dashboard-tableoptions-rowalternatecoloroptions
            '''
            result = self._values.get("row_alternate_color_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RowAlternateColorOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TablePaginatedReportOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "overflow_column_header_visibility": "overflowColumnHeaderVisibility",
            "vertical_overflow_visibility": "verticalOverflowVisibility",
        },
    )
    class TablePaginatedReportOptionsProperty:
        def __init__(
            self,
            *,
            overflow_column_header_visibility: typing.Optional[builtins.str] = None,
            vertical_overflow_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The paginated report options for a table visual.

            :param overflow_column_header_visibility: The visibility of repeating header rows on each page.
            :param vertical_overflow_visibility: The visibility of printing table overflow across pages.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablepaginatedreportoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_paginated_report_options_property = quicksight.CfnDashboard.TablePaginatedReportOptionsProperty(
                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                    vertical_overflow_visibility="verticalOverflowVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4f0aadb280e9d6f01117c85a605f50b9cfeaa5c244f047b536abf34b9d5a1fe4)
                check_type(argname="argument overflow_column_header_visibility", value=overflow_column_header_visibility, expected_type=type_hints["overflow_column_header_visibility"])
                check_type(argname="argument vertical_overflow_visibility", value=vertical_overflow_visibility, expected_type=type_hints["vertical_overflow_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if overflow_column_header_visibility is not None:
                self._values["overflow_column_header_visibility"] = overflow_column_header_visibility
            if vertical_overflow_visibility is not None:
                self._values["vertical_overflow_visibility"] = vertical_overflow_visibility

        @builtins.property
        def overflow_column_header_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of repeating header rows on each page.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablepaginatedreportoptions.html#cfn-quicksight-dashboard-tablepaginatedreportoptions-overflowcolumnheadervisibility
            '''
            result = self._values.get("overflow_column_header_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_overflow_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of printing table overflow across pages.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablepaginatedreportoptions.html#cfn-quicksight-dashboard-tablepaginatedreportoptions-verticaloverflowvisibility
            '''
            result = self._values.get("vertical_overflow_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TablePaginatedReportOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TablePinnedFieldOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"pinned_left_fields": "pinnedLeftFields"},
    )
    class TablePinnedFieldOptionsProperty:
        def __init__(
            self,
            *,
            pinned_left_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The settings for the pinned columns of a table visual.

            :param pinned_left_fields: A list of columns to be pinned to the left of a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablepinnedfieldoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_pinned_field_options_property = quicksight.CfnDashboard.TablePinnedFieldOptionsProperty(
                    pinned_left_fields=["pinnedLeftFields"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__33457a3c8423dbaa75e524d9d1499fa98efa3094dce4e543d7e40e78a1dd9165)
                check_type(argname="argument pinned_left_fields", value=pinned_left_fields, expected_type=type_hints["pinned_left_fields"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pinned_left_fields is not None:
                self._values["pinned_left_fields"] = pinned_left_fields

        @builtins.property
        def pinned_left_fields(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of columns to be pinned to the left of a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablepinnedfieldoptions.html#cfn-quicksight-dashboard-tablepinnedfieldoptions-pinnedleftfields
            '''
            result = self._values.get("pinned_left_fields")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TablePinnedFieldOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableRowConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "text_color": "textColor",
        },
    )
    class TableRowConditionalFormattingProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting of a table row.

            :param background_color: The conditional formatting color (solid, gradient) of the background for a table row.
            :param text_color: The conditional formatting color (solid, gradient) of the text for a table row.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablerowconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_row_conditional_formatting_property = quicksight.CfnDashboard.TableRowConditionalFormattingProperty(
                    background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    ),
                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a70ca40b8f7620081051428a4a06534fac14d4125c7f387a10c5d9ad65d28245)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def background_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting color (solid, gradient) of the background for a table row.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablerowconditionalformatting.html#cfn-quicksight-dashboard-tablerowconditionalformatting-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting color (solid, gradient) of the text for a table row.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablerowconditionalformatting.html#cfn-quicksight-dashboard-tablerowconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableRowConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableSideBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bottom": "bottom",
            "inner_horizontal": "innerHorizontal",
            "inner_vertical": "innerVertical",
            "left": "left",
            "right": "right",
            "top": "top",
        },
    )
    class TableSideBorderOptionsProperty:
        def __init__(
            self,
            *,
            bottom: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            inner_horizontal: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            inner_vertical: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            left: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            right: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The side border options for a table.

            :param bottom: The table border options of the bottom border.
            :param inner_horizontal: The table border options of the inner horizontal border.
            :param inner_vertical: The table border options of the inner vertical border.
            :param left: The table border options of the left border.
            :param right: The table border options of the right border.
            :param top: The table border options of the top border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_side_border_options_property = quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0c5b25638ec93acd618d1393d3489d3835cd716296efe5fc56d51fd38a8a196e)
                check_type(argname="argument bottom", value=bottom, expected_type=type_hints["bottom"])
                check_type(argname="argument inner_horizontal", value=inner_horizontal, expected_type=type_hints["inner_horizontal"])
                check_type(argname="argument inner_vertical", value=inner_vertical, expected_type=type_hints["inner_vertical"])
                check_type(argname="argument left", value=left, expected_type=type_hints["left"])
                check_type(argname="argument right", value=right, expected_type=type_hints["right"])
                check_type(argname="argument top", value=top, expected_type=type_hints["top"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bottom is not None:
                self._values["bottom"] = bottom
            if inner_horizontal is not None:
                self._values["inner_horizontal"] = inner_horizontal
            if inner_vertical is not None:
                self._values["inner_vertical"] = inner_vertical
            if left is not None:
                self._values["left"] = left
            if right is not None:
                self._values["right"] = right
            if top is not None:
                self._values["top"] = top

        @builtins.property
        def bottom(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableBorderOptionsProperty"]]:
            '''The table border options of the bottom border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-bottom
            '''
            result = self._values.get("bottom")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableBorderOptionsProperty"]], result)

        @builtins.property
        def inner_horizontal(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableBorderOptionsProperty"]]:
            '''The table border options of the inner horizontal border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-innerhorizontal
            '''
            result = self._values.get("inner_horizontal")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableBorderOptionsProperty"]], result)

        @builtins.property
        def inner_vertical(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableBorderOptionsProperty"]]:
            '''The table border options of the inner vertical border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-innervertical
            '''
            result = self._values.get("inner_vertical")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableBorderOptionsProperty"]], result)

        @builtins.property
        def left(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableBorderOptionsProperty"]]:
            '''The table border options of the left border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-left
            '''
            result = self._values.get("left")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableBorderOptionsProperty"]], result)

        @builtins.property
        def right(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableBorderOptionsProperty"]]:
            '''The table border options of the right border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-right
            '''
            result = self._values.get("right")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableBorderOptionsProperty"]], result)

        @builtins.property
        def top(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableBorderOptionsProperty"]]:
            '''The table border options of the top border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-top
            '''
            result = self._values.get("top")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableBorderOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableSideBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pagination_configuration": "paginationConfiguration",
            "row_sort": "rowSort",
        },
    )
    class TableSortConfigurationProperty:
        def __init__(
            self,
            *,
            pagination_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PaginationConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration for a ``TableVisual`` .

            :param pagination_configuration: The pagination configuration (page size, page number) for the table.
            :param row_sort: The field sort options for rows in the table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_sort_configuration_property = quicksight.CfnDashboard.TableSortConfigurationProperty(
                    pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                        page_number=123,
                        page_size=123
                    ),
                    row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c742ce7f5c9426ba306a01098393e8e152d4115fcd77fda54e5a32c9c56d012b)
                check_type(argname="argument pagination_configuration", value=pagination_configuration, expected_type=type_hints["pagination_configuration"])
                check_type(argname="argument row_sort", value=row_sort, expected_type=type_hints["row_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pagination_configuration is not None:
                self._values["pagination_configuration"] = pagination_configuration
            if row_sort is not None:
                self._values["row_sort"] = row_sort

        @builtins.property
        def pagination_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PaginationConfigurationProperty"]]:
            '''The pagination configuration (page size, page number) for the table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesortconfiguration.html#cfn-quicksight-dashboard-tablesortconfiguration-paginationconfiguration
            '''
            result = self._values.get("pagination_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PaginationConfigurationProperty"]], result)

        @builtins.property
        def row_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The field sort options for rows in the table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesortconfiguration.html#cfn-quicksight-dashboard-tablesortconfiguration-rowsort
            '''
            result = self._values.get("row_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableStyleTargetProperty",
        jsii_struct_bases=[],
        name_mapping={"cell_type": "cellType"},
    )
    class TableStyleTargetProperty:
        def __init__(self, *, cell_type: builtins.str) -> None:
            '''The table style target.

            :param cell_type: The cell type of the table style target.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablestyletarget.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_style_target_property = quicksight.CfnDashboard.TableStyleTargetProperty(
                    cell_type="cellType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__100658bc93c03c66f2266c5b34775cb90d2fb3deeccec60f4ce7aa8b7fb51a0e)
                check_type(argname="argument cell_type", value=cell_type, expected_type=type_hints["cell_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "cell_type": cell_type,
            }

        @builtins.property
        def cell_type(self) -> builtins.str:
            '''The cell type of the table style target.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablestyletarget.html#cfn-quicksight-dashboard-tablestyletarget-celltype
            '''
            result = self._values.get("cell_type")
            assert result is not None, "Required property 'cell_type' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableStyleTargetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class TableUnaggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.UnaggregatedFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The unaggregated field well for the table.

            :param values: The values field well for a pivot table. Values are unaggregated for an unaggregated table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableunaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_unaggregated_field_wells_property = quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty(
                    values=[quicksight.CfnDashboard.UnaggregatedFieldProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                            date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e2bd9325300d3bc1219d7551e1c8b8fcabf75cb9898fe57abd0ef8bc497b63e4)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.UnaggregatedFieldProperty"]]]]:
            '''The values field well for a pivot table.

            Values are unaggregated for an unaggregated table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableunaggregatedfieldwells.html#cfn-quicksight-dashboard-tableunaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.UnaggregatedFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableUnaggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TableVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class TableVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A table visual.

            For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param conditional_formatting: The conditional formatting for a ``PivotTableVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8ec6aa6562cd1657a3a4d99afedd9f68d0d4c922d8e322a694e892f62d854120)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableConfigurationProperty"]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableConditionalFormattingProperty"]]:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "info_icon_label_options": "infoIconLabelOptions",
            "placeholder_options": "placeholderOptions",
            "title_options": "titleOptions",
        },
    )
    class TextAreaControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SheetControlInfoIconLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            placeholder_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TextControlPlaceholderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param info_icon_label_options: The configuration of info icon label options.
            :param placeholder_options: The configuration of the placeholder options in a text area control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textareacontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                text_area_control_display_options_property = quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                    info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                        info_icon_text="infoIconText",
                        visibility="visibility"
                    ),
                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e96346e2e0d21e86aa1d52552e64994342afdef67dbcf38bb1f565c355f1ae5d)
                check_type(argname="argument info_icon_label_options", value=info_icon_label_options, expected_type=type_hints["info_icon_label_options"])
                check_type(argname="argument placeholder_options", value=placeholder_options, expected_type=type_hints["placeholder_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if info_icon_label_options is not None:
                self._values["info_icon_label_options"] = info_icon_label_options
            if placeholder_options is not None:
                self._values["placeholder_options"] = placeholder_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def info_icon_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetControlInfoIconLabelOptionsProperty"]]:
            '''The configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textareacontroldisplayoptions.html#cfn-quicksight-dashboard-textareacontroldisplayoptions-infoiconlabeloptions
            '''
            result = self._values.get("info_icon_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetControlInfoIconLabelOptionsProperty"]], result)

        @builtins.property
        def placeholder_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TextControlPlaceholderOptionsProperty"]]:
            '''The configuration of the placeholder options in a text area control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textareacontroldisplayoptions.html#cfn-quicksight-dashboard-textareacontroldisplayoptions-placeholderoptions
            '''
            result = self._values.get("placeholder_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TextControlPlaceholderOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textareacontroldisplayoptions.html#cfn-quicksight-dashboard-textareacontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextAreaControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TextConditionalFormatProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "icon": "icon",
            "text_color": "textColor",
        },
    )
    class TextConditionalFormatProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the text.

            :param background_color: The conditional formatting for the text background color.
            :param icon: The conditional formatting for the icon.
            :param text_color: The conditional formatting for the text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textconditionalformat.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                text_conditional_format_property = quicksight.CfnDashboard.TextConditionalFormatProperty(
                    background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    ),
                    icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d4c9b1c8be6ed1e8a3d995c65d03262c03b6789bf9be98ab76ab401bbb158d9b)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def background_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting for the text background color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textconditionalformat.html#cfn-quicksight-dashboard-textconditionalformat-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"]], result)

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting for the icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textconditionalformat.html#cfn-quicksight-dashboard-textconditionalformat-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting for the text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textconditionalformat.html#cfn-quicksight-dashboard-textconditionalformat-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextConditionalFormatProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class TextControlPlaceholderOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the placeholder options in a text control.

            :param visibility: The visibility configuration of the placeholder options in a text control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textcontrolplaceholderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                text_control_placeholder_options_property = quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__db0456c8bedcaf2160cb6972a01b4b75ff071d5904c9ae688269b540b2fc6a09)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the placeholder options in a text control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textcontrolplaceholderoptions.html#cfn-quicksight-dashboard-textcontrolplaceholderoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextControlPlaceholderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "info_icon_label_options": "infoIconLabelOptions",
            "placeholder_options": "placeholderOptions",
            "title_options": "titleOptions",
        },
    )
    class TextFieldControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SheetControlInfoIconLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            placeholder_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TextControlPlaceholderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param info_icon_label_options: The configuration of info icon label options.
            :param placeholder_options: The configuration of the placeholder options in a text field control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textfieldcontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                text_field_control_display_options_property = quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                    info_icon_label_options=quicksight.CfnDashboard.SheetControlInfoIconLabelOptionsProperty(
                        info_icon_text="infoIconText",
                        visibility="visibility"
                    ),
                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f042fa9f65668c58aeeacd2a40752f44945cf74b3e2c26be6285ba0048ad7a28)
                check_type(argname="argument info_icon_label_options", value=info_icon_label_options, expected_type=type_hints["info_icon_label_options"])
                check_type(argname="argument placeholder_options", value=placeholder_options, expected_type=type_hints["placeholder_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if info_icon_label_options is not None:
                self._values["info_icon_label_options"] = info_icon_label_options
            if placeholder_options is not None:
                self._values["placeholder_options"] = placeholder_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def info_icon_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetControlInfoIconLabelOptionsProperty"]]:
            '''The configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textfieldcontroldisplayoptions.html#cfn-quicksight-dashboard-textfieldcontroldisplayoptions-infoiconlabeloptions
            '''
            result = self._values.get("info_icon_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SheetControlInfoIconLabelOptionsProperty"]], result)

        @builtins.property
        def placeholder_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TextControlPlaceholderOptionsProperty"]]:
            '''The configuration of the placeholder options in a text field control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textfieldcontroldisplayoptions.html#cfn-quicksight-dashboard-textfieldcontroldisplayoptions-placeholderoptions
            '''
            result = self._values.get("placeholder_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TextControlPlaceholderOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textfieldcontroldisplayoptions.html#cfn-quicksight-dashboard-textfieldcontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextFieldControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ThousandSeparatorOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"symbol": "symbol", "visibility": "visibility"},
    )
    class ThousandSeparatorOptionsProperty:
        def __init__(
            self,
            *,
            symbol: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the thousands separator configuration.

            :param symbol: Determines the thousands separator symbol.
            :param visibility: Determines the visibility of the thousands separator.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-thousandseparatoroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                thousand_separator_options_property = quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                    symbol="symbol",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__481e106c212c71713aba9a31e49487994eefaf5c8029e7105d2e9ed0cb2143b9)
                check_type(argname="argument symbol", value=symbol, expected_type=type_hints["symbol"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if symbol is not None:
                self._values["symbol"] = symbol
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def symbol(self) -> typing.Optional[builtins.str]:
            '''Determines the thousands separator symbol.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-thousandseparatoroptions.html#cfn-quicksight-dashboard-thousandseparatoroptions-symbol
            '''
            result = self._values.get("symbol")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the thousands separator.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-thousandseparatoroptions.html#cfn-quicksight-dashboard-thousandseparatoroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ThousandSeparatorOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "lower_boundary": "lowerBoundary",
            "periods_backward": "periodsBackward",
            "periods_forward": "periodsForward",
            "prediction_interval": "predictionInterval",
            "seasonality": "seasonality",
            "upper_boundary": "upperBoundary",
        },
    )
    class TimeBasedForecastPropertiesProperty:
        def __init__(
            self,
            *,
            lower_boundary: typing.Optional[jsii.Number] = None,
            periods_backward: typing.Optional[jsii.Number] = None,
            periods_forward: typing.Optional[jsii.Number] = None,
            prediction_interval: typing.Optional[jsii.Number] = None,
            seasonality: typing.Optional[jsii.Number] = None,
            upper_boundary: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The forecast properties setup of a forecast in the line chart.

            :param lower_boundary: The lower boundary setup of a forecast computation.
            :param periods_backward: The periods backward setup of a forecast computation.
            :param periods_forward: The periods forward setup of a forecast computation.
            :param prediction_interval: The prediction interval setup of a forecast computation.
            :param seasonality: The seasonality setup of a forecast computation. Choose one of the following options:. - ``NULL`` : The input is set to ``NULL`` . - ``NON_NULL`` : The input is set to a custom value.
            :param upper_boundary: The upper boundary setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                time_based_forecast_properties_property = quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty(
                    lower_boundary=123,
                    periods_backward=123,
                    periods_forward=123,
                    prediction_interval=123,
                    seasonality=123,
                    upper_boundary=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bd94fab62c2c39db7fd878a6725a388a9ddb30a6ab99012874b606c8405a4404)
                check_type(argname="argument lower_boundary", value=lower_boundary, expected_type=type_hints["lower_boundary"])
                check_type(argname="argument periods_backward", value=periods_backward, expected_type=type_hints["periods_backward"])
                check_type(argname="argument periods_forward", value=periods_forward, expected_type=type_hints["periods_forward"])
                check_type(argname="argument prediction_interval", value=prediction_interval, expected_type=type_hints["prediction_interval"])
                check_type(argname="argument seasonality", value=seasonality, expected_type=type_hints["seasonality"])
                check_type(argname="argument upper_boundary", value=upper_boundary, expected_type=type_hints["upper_boundary"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if lower_boundary is not None:
                self._values["lower_boundary"] = lower_boundary
            if periods_backward is not None:
                self._values["periods_backward"] = periods_backward
            if periods_forward is not None:
                self._values["periods_forward"] = periods_forward
            if prediction_interval is not None:
                self._values["prediction_interval"] = prediction_interval
            if seasonality is not None:
                self._values["seasonality"] = seasonality
            if upper_boundary is not None:
                self._values["upper_boundary"] = upper_boundary

        @builtins.property
        def lower_boundary(self) -> typing.Optional[jsii.Number]:
            '''The lower boundary setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-lowerboundary
            '''
            result = self._values.get("lower_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_backward(self) -> typing.Optional[jsii.Number]:
            '''The periods backward setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-periodsbackward
            '''
            result = self._values.get("periods_backward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_forward(self) -> typing.Optional[jsii.Number]:
            '''The periods forward setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-periodsforward
            '''
            result = self._values.get("periods_forward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def prediction_interval(self) -> typing.Optional[jsii.Number]:
            '''The prediction interval setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-predictioninterval
            '''
            result = self._values.get("prediction_interval")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def seasonality(self) -> typing.Optional[jsii.Number]:
            '''The seasonality setup of a forecast computation. Choose one of the following options:.

            - ``NULL`` : The input is set to ``NULL`` .
            - ``NON_NULL`` : The input is set to a custom value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-seasonality
            '''
            result = self._values.get("seasonality")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def upper_boundary(self) -> typing.Optional[jsii.Number]:
            '''The upper boundary setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-upperboundary
            '''
            result = self._values.get("upper_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeBasedForecastPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TimeEqualityFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "parameter_name": "parameterName",
            "rolling_date": "rollingDate",
            "time_granularity": "timeGranularity",
            "value": "value",
        },
    )
    class TimeEqualityFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            parameter_name: typing.Optional[builtins.str] = None,
            rolling_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.RollingDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
            value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TimeEqualityFilter`` filters values that are equal to a given value.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param parameter_name: The parameter whose value should be used for the filter value. This field is mutually exclusive to ``Value`` and ``RollingDate`` .
            :param rolling_date: The rolling date input for the ``TimeEquality`` filter. This field is mutually exclusive to ``Value`` and ``ParameterName`` .
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param value: The value of a ``TimeEquality`` filter. This field is mutually exclusive to ``RollingDate`` and ``ParameterName`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                time_equality_filter_property = quicksight.CfnDashboard.TimeEqualityFilterProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                
                    # the properties below are optional
                    parameter_name="parameterName",
                    rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                        expression="expression",
                
                        # the properties below are optional
                        data_set_identifier="dataSetIdentifier"
                    ),
                    time_granularity="timeGranularity",
                    value="value"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c16f147af64b9d1eea3e12eda2458de69cb410351d05e72cc4d552dddeac78b5)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument rolling_date", value=rolling_date, expected_type=type_hints["rolling_date"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
            }
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if rolling_date is not None:
                self._values["rolling_date"] = rolling_date
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            This field is mutually exclusive to ``Value`` and ``RollingDate`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rolling_date(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RollingDateConfigurationProperty"]]:
            '''The rolling date input for the ``TimeEquality`` filter.

            This field is mutually exclusive to ``Value`` and ``ParameterName`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-rollingdate
            '''
            result = self._values.get("rolling_date")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RollingDateConfigurationProperty"]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(self) -> typing.Optional[builtins.str]:
            '''The value of a ``TimeEquality`` filter.

            This field is mutually exclusive to ``RollingDate`` and ``ParameterName`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeEqualityFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "range_maximum": "rangeMaximum",
            "range_minimum": "rangeMinimum",
            "time_granularity": "timeGranularity",
        },
    )
    class TimeRangeDrillDownFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            range_maximum: builtins.str,
            range_minimum: builtins.str,
            time_granularity: builtins.str,
        ) -> None:
            '''The time range drill down filter.

            :param column: The column that the filter is applied to.
            :param range_maximum: The maximum value for the filter value range.
            :param range_minimum: The minimum value for the filter value range.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                time_range_drill_down_filter_property = quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    range_maximum="rangeMaximum",
                    range_minimum="rangeMinimum",
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6926d6f7438814f850f457ce463359fbf7ce0acdae4350dcab06806ea44abaaf)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument range_maximum", value=range_maximum, expected_type=type_hints["range_maximum"])
                check_type(argname="argument range_minimum", value=range_minimum, expected_type=type_hints["range_minimum"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "range_maximum": range_maximum,
                "range_minimum": range_minimum,
                "time_granularity": time_granularity,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html#cfn-quicksight-dashboard-timerangedrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def range_maximum(self) -> builtins.str:
            '''The maximum value for the filter value range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html#cfn-quicksight-dashboard-timerangedrilldownfilter-rangemaximum
            '''
            result = self._values.get("range_maximum")
            assert result is not None, "Required property 'range_maximum' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def range_minimum(self) -> builtins.str:
            '''The minimum value for the filter value range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html#cfn-quicksight-dashboard-timerangedrilldownfilter-rangeminimum
            '''
            result = self._values.get("range_minimum")
            assert result is not None, "Required property 'range_minimum' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time_granularity(self) -> builtins.str:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html#cfn-quicksight-dashboard-timerangedrilldownfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            assert result is not None, "Required property 'time_granularity' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TimeRangeFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "exclude_period_configuration": "excludePeriodConfiguration",
            "include_maximum": "includeMaximum",
            "include_minimum": "includeMinimum",
            "range_maximum_value": "rangeMaximumValue",
            "range_minimum_value": "rangeMinimumValue",
            "time_granularity": "timeGranularity",
        },
    )
    class TimeRangeFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            null_option: builtins.str,
            exclude_period_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ExcludePeriodConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
            include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
            range_maximum_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TimeRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            range_minimum_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TimeRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TimeRangeFilter`` filters values that are between two specified values.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param exclude_period_configuration: The exclude period of the time range filter.
            :param include_maximum: Determines whether the maximum value in the filter value range should be included in the filtered results.
            :param include_minimum: Determines whether the minimum value in the filter value range should be included in the filtered results.
            :param range_maximum_value: The maximum value for the filter value range.
            :param range_minimum_value: The minimum value for the filter value range.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                time_range_filter_property = quicksight.CfnDashboard.TimeRangeFilterProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                
                    # the properties below are optional
                    exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                        amount=123,
                        granularity="granularity",
                
                        # the properties below are optional
                        status="status"
                    ),
                    include_maximum=False,
                    include_minimum=False,
                    range_maximum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                        parameter="parameter",
                        rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_value="staticValue"
                    ),
                    range_minimum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                        parameter="parameter",
                        rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_value="staticValue"
                    ),
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e7d6ff152c92765570086d7d642fd87966432b2c80384c704edc04415162060a)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument exclude_period_configuration", value=exclude_period_configuration, expected_type=type_hints["exclude_period_configuration"])
                check_type(argname="argument include_maximum", value=include_maximum, expected_type=type_hints["include_maximum"])
                check_type(argname="argument include_minimum", value=include_minimum, expected_type=type_hints["include_minimum"])
                check_type(argname="argument range_maximum_value", value=range_maximum_value, expected_type=type_hints["range_maximum_value"])
                check_type(argname="argument range_minimum_value", value=range_minimum_value, expected_type=type_hints["range_minimum_value"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
            }
            if exclude_period_configuration is not None:
                self._values["exclude_period_configuration"] = exclude_period_configuration
            if include_maximum is not None:
                self._values["include_maximum"] = include_maximum
            if include_minimum is not None:
                self._values["include_minimum"] = include_minimum
            if range_maximum_value is not None:
                self._values["range_maximum_value"] = range_maximum_value
            if range_minimum_value is not None:
                self._values["range_minimum_value"] = range_minimum_value
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def exclude_period_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ExcludePeriodConfigurationProperty"]]:
            '''The exclude period of the time range filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-excludeperiodconfiguration
            '''
            result = self._values.get("exclude_period_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ExcludePeriodConfigurationProperty"]], result)

        @builtins.property
        def include_maximum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''Determines whether the maximum value in the filter value range should be included in the filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-includemaximum
            '''
            result = self._values.get("include_maximum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        @builtins.property
        def include_minimum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''Determines whether the minimum value in the filter value range should be included in the filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-includeminimum
            '''
            result = self._values.get("include_minimum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        @builtins.property
        def range_maximum_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TimeRangeFilterValueProperty"]]:
            '''The maximum value for the filter value range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-rangemaximumvalue
            '''
            result = self._values.get("range_maximum_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TimeRangeFilterValueProperty"]], result)

        @builtins.property
        def range_minimum_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TimeRangeFilterValueProperty"]]:
            '''The minimum value for the filter value range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-rangeminimumvalue
            '''
            result = self._values.get("range_minimum_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TimeRangeFilterValueProperty"]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TimeRangeFilterValueProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter": "parameter",
            "rolling_date": "rollingDate",
            "static_value": "staticValue",
        },
    )
    class TimeRangeFilterValueProperty:
        def __init__(
            self,
            *,
            parameter: typing.Optional[builtins.str] = None,
            rolling_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.RollingDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The value of a time range filter.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param parameter: The parameter type input value.
            :param rolling_date: The rolling date input value.
            :param static_value: The static input value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefiltervalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                time_range_filter_value_property = quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                    parameter="parameter",
                    rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                        expression="expression",
                
                        # the properties below are optional
                        data_set_identifier="dataSetIdentifier"
                    ),
                    static_value="staticValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3da8049a47704beec28b810be20d8ec123f13cf41311c4c1b4d0e470ef2c1e7d)
                check_type(argname="argument parameter", value=parameter, expected_type=type_hints["parameter"])
                check_type(argname="argument rolling_date", value=rolling_date, expected_type=type_hints["rolling_date"])
                check_type(argname="argument static_value", value=static_value, expected_type=type_hints["static_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if parameter is not None:
                self._values["parameter"] = parameter
            if rolling_date is not None:
                self._values["rolling_date"] = rolling_date
            if static_value is not None:
                self._values["static_value"] = static_value

        @builtins.property
        def parameter(self) -> typing.Optional[builtins.str]:
            '''The parameter type input value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefiltervalue.html#cfn-quicksight-dashboard-timerangefiltervalue-parameter
            '''
            result = self._values.get("parameter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rolling_date(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RollingDateConfigurationProperty"]]:
            '''The rolling date input value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefiltervalue.html#cfn-quicksight-dashboard-timerangefiltervalue-rollingdate
            '''
            result = self._values.get("rolling_date")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RollingDateConfigurationProperty"]], result)

        @builtins.property
        def static_value(self) -> typing.Optional[builtins.str]:
            '''The static input value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefiltervalue.html#cfn-quicksight-dashboard-timerangefiltervalue-staticvalue
            '''
            result = self._values.get("static_value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeFilterValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_tooltip_item": "columnTooltipItem",
            "field_tooltip_item": "fieldTooltipItem",
        },
    )
    class TooltipItemProperty:
        def __init__(
            self,
            *,
            column_tooltip_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnTooltipItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_tooltip_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldTooltipItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The tooltip.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param column_tooltip_item: The tooltip item for the columns that are not part of a field well.
            :param field_tooltip_item: The tooltip item for the fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                tooltip_item_property = quicksight.CfnDashboard.TooltipItemProperty(
                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                            attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                simple_attribute_aggregation="simpleAttributeAggregation",
                                value_for_multiple_values="valueForMultipleValues"
                            ),
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        label="label",
                        visibility="visibility"
                    ),
                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        label="label",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a03f0377cbe55f598c272899419f61a9e1ad0e44bffd279007bd41a69bfe13cd)
                check_type(argname="argument column_tooltip_item", value=column_tooltip_item, expected_type=type_hints["column_tooltip_item"])
                check_type(argname="argument field_tooltip_item", value=field_tooltip_item, expected_type=type_hints["field_tooltip_item"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_tooltip_item is not None:
                self._values["column_tooltip_item"] = column_tooltip_item
            if field_tooltip_item is not None:
                self._values["field_tooltip_item"] = field_tooltip_item

        @builtins.property
        def column_tooltip_item(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnTooltipItemProperty"]]:
            '''The tooltip item for the columns that are not part of a field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipitem.html#cfn-quicksight-dashboard-tooltipitem-columntooltipitem
            '''
            result = self._values.get("column_tooltip_item")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnTooltipItemProperty"]], result)

        @builtins.property
        def field_tooltip_item(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldTooltipItemProperty"]]:
            '''The tooltip item for the fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipitem.html#cfn-quicksight-dashboard-tooltipitem-fieldtooltipitem
            '''
            result = self._values.get("field_tooltip_item")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldTooltipItemProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TooltipOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_based_tooltip": "fieldBasedTooltip",
            "selected_tooltip_type": "selectedTooltipType",
            "tooltip_visibility": "tooltipVisibility",
        },
    )
    class TooltipOptionsProperty:
        def __init__(
            self,
            *,
            field_based_tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldBasedTooltipProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selected_tooltip_type: typing.Optional[builtins.str] = None,
            tooltip_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The display options for the visual tooltip.

            :param field_based_tooltip: The setup for the detailed tooltip. The tooltip setup is always saved. The display type is decided based on the tooltip type.
            :param selected_tooltip_type: The selected type for the tooltip. Choose one of the following options:. - ``BASIC`` : A basic tooltip. - ``DETAILED`` : A detailed tooltip.
            :param tooltip_visibility: Determines whether or not the tooltip is visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                tooltip_options_property = quicksight.CfnDashboard.TooltipOptionsProperty(
                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                        aggregation_visibility="aggregationVisibility",
                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                        simple_attribute_aggregation="simpleAttributeAggregation",
                                        value_for_multiple_values="valueForMultipleValues"
                                    ),
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                label="label",
                                visibility="visibility"
                            ),
                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                label="label",
                                visibility="visibility"
                            )
                        )],
                        tooltip_title_type="tooltipTitleType"
                    ),
                    selected_tooltip_type="selectedTooltipType",
                    tooltip_visibility="tooltipVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b7a503d2cbf643ce64daf5b14fa13c0f188bb34d44528b229b80696067b5e58a)
                check_type(argname="argument field_based_tooltip", value=field_based_tooltip, expected_type=type_hints["field_based_tooltip"])
                check_type(argname="argument selected_tooltip_type", value=selected_tooltip_type, expected_type=type_hints["selected_tooltip_type"])
                check_type(argname="argument tooltip_visibility", value=tooltip_visibility, expected_type=type_hints["tooltip_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_based_tooltip is not None:
                self._values["field_based_tooltip"] = field_based_tooltip
            if selected_tooltip_type is not None:
                self._values["selected_tooltip_type"] = selected_tooltip_type
            if tooltip_visibility is not None:
                self._values["tooltip_visibility"] = tooltip_visibility

        @builtins.property
        def field_based_tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldBasedTooltipProperty"]]:
            '''The setup for the detailed tooltip.

            The tooltip setup is always saved. The display type is decided based on the tooltip type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipoptions.html#cfn-quicksight-dashboard-tooltipoptions-fieldbasedtooltip
            '''
            result = self._values.get("field_based_tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldBasedTooltipProperty"]], result)

        @builtins.property
        def selected_tooltip_type(self) -> typing.Optional[builtins.str]:
            '''The selected type for the tooltip. Choose one of the following options:.

            - ``BASIC`` : A basic tooltip.
            - ``DETAILED`` : A detailed tooltip.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipoptions.html#cfn-quicksight-dashboard-tooltipoptions-selectedtooltiptype
            '''
            result = self._values.get("selected_tooltip_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tooltip_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the tooltip is visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipoptions.html#cfn-quicksight-dashboard-tooltipoptions-tooltipvisibility
            '''
            result = self._values.get("tooltip_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TooltipOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TopBottomFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_sort_configurations": "aggregationSortConfigurations",
            "column": "column",
            "filter_id": "filterId",
            "limit": "limit",
            "parameter_name": "parameterName",
            "time_granularity": "timeGranularity",
        },
    )
    class TopBottomFilterProperty:
        def __init__(
            self,
            *,
            aggregation_sort_configurations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AggregationSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            limit: typing.Optional[jsii.Number] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TopBottomFilter`` filters values that are at the top or the bottom.

            :param aggregation_sort_configurations: The aggregation and sort configuration of the top bottom filter.
            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param limit: The number of items to include in the top bottom filter results.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                top_bottom_filter_property = quicksight.CfnDashboard.TopBottomFilterProperty(
                    aggregation_sort_configurations=[quicksight.CfnDashboard.AggregationSortConfigurationProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        sort_direction="sortDirection",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                            attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                simple_attribute_aggregation="simpleAttributeAggregation",
                                value_for_multiple_values="valueForMultipleValues"
                            ),
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    )],
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                
                    # the properties below are optional
                    limit=123,
                    parameter_name="parameterName",
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0001e11b06c63e33cd7b2f3b6e7bec4ac8e5dfb8cb8b05fe132d59864e80e80e)
                check_type(argname="argument aggregation_sort_configurations", value=aggregation_sort_configurations, expected_type=type_hints["aggregation_sort_configurations"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "aggregation_sort_configurations": aggregation_sort_configurations,
                "column": column,
                "filter_id": filter_id,
            }
            if limit is not None:
                self._values["limit"] = limit
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def aggregation_sort_configurations(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AggregationSortConfigurationProperty"]]]:
            '''The aggregation and sort configuration of the top bottom filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-aggregationsortconfigurations
            '''
            result = self._values.get("aggregation_sort_configurations")
            assert result is not None, "Required property 'aggregation_sort_configurations' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AggregationSortConfigurationProperty"]]], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def limit(self) -> typing.Optional[jsii.Number]:
            '''The number of items to include in the top bottom filter results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-limit
            '''
            result = self._values.get("limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TopBottomMoversComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "type": "type",
            "category": "category",
            "mover_size": "moverSize",
            "name": "name",
            "sort_order": "sortOrder",
            "time": "time",
            "value": "value",
        },
    )
    class TopBottomMoversComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            type: builtins.str,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mover_size: typing.Optional[jsii.Number] = None,
            name: typing.Optional[builtins.str] = None,
            sort_order: typing.Optional[builtins.str] = None,
            time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The top movers and bottom movers computation setup.

            :param computation_id: The ID for a computation.
            :param type: The computation type. Choose from the following options:. - TOP: Top movers computation. - BOTTOM: Bottom movers computation.
            :param category: The category field that is used in a computation.
            :param mover_size: The mover size setup of the top and bottom movers computation. Default: - 0
            :param name: The name of a computation.
            :param sort_order: The sort order setup of the top and bottom movers computation.
            :param time: The time field that is used in a computation.
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d0c2bf9ae4b5f907a3760a6863a5b44047c3dfe6624d4072a3d7b13749d9b492)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument mover_size", value=mover_size, expected_type=type_hints["mover_size"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sort_order", value=sort_order, expected_type=type_hints["sort_order"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "type": type,
            }
            if category is not None:
                self._values["category"] = category
            if mover_size is not None:
                self._values["mover_size"] = mover_size
            if name is not None:
                self._values["name"] = name
            if sort_order is not None:
                self._values["sort_order"] = sort_order
            if time is not None:
                self._values["time"] = time
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The computation type. Choose from the following options:.

            - TOP: Top movers computation.
            - BOTTOM: Bottom movers computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]:
            '''The category field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]], result)

        @builtins.property
        def mover_size(self) -> typing.Optional[jsii.Number]:
            '''The mover size setup of the top and bottom movers computation.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-moversize
            '''
            result = self._values.get("mover_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sort_order(self) -> typing.Optional[builtins.str]:
            '''The sort order setup of the top and bottom movers computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-sortorder
            '''
            result = self._values.get("sort_order")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]:
            '''The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-time
            '''
            result = self._values.get("time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomMoversComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TopBottomRankedComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "type": "type",
            "category": "category",
            "name": "name",
            "result_size": "resultSize",
            "value": "value",
        },
    )
    class TopBottomRankedComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            type: builtins.str,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            name: typing.Optional[builtins.str] = None,
            result_size: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The top ranked and bottom ranked computation configuration.

            :param computation_id: The ID for a computation.
            :param type: The computation type. Choose one of the following options:. - TOP: A top ranked computation. - BOTTOM: A bottom ranked computation.
            :param category: The category field that is used in a computation.
            :param name: The name of a computation.
            :param result_size: The result size of a top and bottom ranked computation. Default: - 0
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ac5f83641526bd59afbacd5fe960eca2bf930211b9c0a203855eee191c6166b8)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument result_size", value=result_size, expected_type=type_hints["result_size"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "type": type,
            }
            if category is not None:
                self._values["category"] = category
            if name is not None:
                self._values["name"] = name
            if result_size is not None:
                self._values["result_size"] = result_size
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The computation type. Choose one of the following options:.

            - TOP: A top ranked computation.
            - BOTTOM: A bottom ranked computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]:
            '''The category field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def result_size(self) -> typing.Optional[jsii.Number]:
            '''The result size of a top and bottom ranked computation.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-resultsize
            '''
            result = self._values.get("result_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomRankedComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TotalAggregationComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "name": "name",
            "value": "value",
        },
    )
    class TotalAggregationComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            name: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The total aggregation computation configuration.

            :param computation_id: The ID for a computation.
            :param name: The name of a computation.
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                total_aggregation_computation_property = quicksight.CfnDashboard.TotalAggregationComputationProperty(
                    computation_id="computationId",
                
                    # the properties below are optional
                    name="name",
                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__12b50a808892fb708508224e48921824e5642b34f79bc3859879a83386d66354)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
            }
            if name is not None:
                self._values["name"] = name
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationcomputation.html#cfn-quicksight-dashboard-totalaggregationcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationcomputation.html#cfn-quicksight-dashboard-totalaggregationcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationcomputation.html#cfn-quicksight-dashboard-totalaggregationcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalAggregationComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TotalAggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "simple_total_aggregation_function": "simpleTotalAggregationFunction",
        },
    )
    class TotalAggregationFunctionProperty:
        def __init__(
            self,
            *,
            simple_total_aggregation_function: typing.Optional[builtins.str] = None,
        ) -> None:
            '''An aggregation function that aggregates the total values of a measure.

            :param simple_total_aggregation_function: A built in aggregation function for total values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                total_aggregation_function_property = quicksight.CfnDashboard.TotalAggregationFunctionProperty(
                    simple_total_aggregation_function="simpleTotalAggregationFunction"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__111fe23d82009affd215f44e006244102c4ad2f4016b003d064509d1bf621cf3)
                check_type(argname="argument simple_total_aggregation_function", value=simple_total_aggregation_function, expected_type=type_hints["simple_total_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if simple_total_aggregation_function is not None:
                self._values["simple_total_aggregation_function"] = simple_total_aggregation_function

        @builtins.property
        def simple_total_aggregation_function(self) -> typing.Optional[builtins.str]:
            '''A built in aggregation function for total values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationfunction.html#cfn-quicksight-dashboard-totalaggregationfunction-simpletotalaggregationfunction
            '''
            result = self._values.get("simple_total_aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalAggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TotalAggregationOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "total_aggregation_function": "totalAggregationFunction",
        },
    )
    class TotalAggregationOptionProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            total_aggregation_function: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TotalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The total aggregation settings map of a field id.

            :param field_id: The field id that's associated with the total aggregation option.
            :param total_aggregation_function: The total aggregation function that you want to set for a specified field id.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                total_aggregation_option_property = quicksight.CfnDashboard.TotalAggregationOptionProperty(
                    field_id="fieldId",
                    total_aggregation_function=quicksight.CfnDashboard.TotalAggregationFunctionProperty(
                        simple_total_aggregation_function="simpleTotalAggregationFunction"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d25344f72a4f3714539caee04de57bb3f85250ce722ef9daf8d4b3a7d37ea29b)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument total_aggregation_function", value=total_aggregation_function, expected_type=type_hints["total_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
                "total_aggregation_function": total_aggregation_function,
            }

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field id that's associated with the total aggregation option.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationoption.html#cfn-quicksight-dashboard-totalaggregationoption-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def total_aggregation_function(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.TotalAggregationFunctionProperty"]:
            '''The total aggregation function that you want to set for a specified field id.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationoption.html#cfn-quicksight-dashboard-totalaggregationoption-totalaggregationfunction
            '''
            result = self._values.get("total_aggregation_function")
            assert result is not None, "Required property 'total_aggregation_function' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.TotalAggregationFunctionProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalAggregationOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "placement": "placement",
            "scroll_status": "scrollStatus",
            "total_aggregation_options": "totalAggregationOptions",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
        },
    )
    class TotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            placement: typing.Optional[builtins.str] = None,
            scroll_status: typing.Optional[builtins.str] = None,
            total_aggregation_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TotalAggregationOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            total_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The total options for a table visual.

            :param custom_label: The custom label string for the total cells.
            :param placement: The placement (start, end) for the total cells.
            :param scroll_status: The scroll status (pinned, scrolled) for the total cells.
            :param total_aggregation_options: The total aggregation settings for each value field.
            :param total_cell_style: Cell styling options for the total cells.
            :param totals_visibility: The visibility configuration for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                total_options_property = quicksight.CfnDashboard.TotalOptionsProperty(
                    custom_label="customLabel",
                    placement="placement",
                    scroll_status="scrollStatus",
                    total_aggregation_options=[quicksight.CfnDashboard.TotalAggregationOptionProperty(
                        field_id="fieldId",
                        total_aggregation_function=quicksight.CfnDashboard.TotalAggregationFunctionProperty(
                            simple_total_aggregation_function="simpleTotalAggregationFunction"
                        )
                    )],
                    total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7fc179aae0ac597c1c7159cbab8982679a211fb2e95fa4887f018e61956a2171)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument placement", value=placement, expected_type=type_hints["placement"])
                check_type(argname="argument scroll_status", value=scroll_status, expected_type=type_hints["scroll_status"])
                check_type(argname="argument total_aggregation_options", value=total_aggregation_options, expected_type=type_hints["total_aggregation_options"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if placement is not None:
                self._values["placement"] = placement
            if scroll_status is not None:
                self._values["scroll_status"] = scroll_status
            if total_aggregation_options is not None:
                self._values["total_aggregation_options"] = total_aggregation_options
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def placement(self) -> typing.Optional[builtins.str]:
            '''The placement (start, end) for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-placement
            '''
            result = self._values.get("placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scroll_status(self) -> typing.Optional[builtins.str]:
            '''The scroll status (pinned, scrolled) for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-scrollstatus
            '''
            result = self._values.get("scroll_status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def total_aggregation_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TotalAggregationOptionProperty"]]]]:
            '''The total aggregation settings for each value field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-totalaggregationoptions
            '''
            result = self._values.get("total_aggregation_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TotalAggregationOptionProperty"]]]], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]]:
            '''Cell styling options for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TreeMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"colors": "colors", "groups": "groups", "sizes": "sizes"},
    )
    class TreeMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sizes: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''Aggregated field wells of a tree map.

            :param colors: The color field well of a tree map. Values are grouped by aggregations based on group by fields.
            :param groups: The group by field well of a tree map. Values are grouped based on group by fields.
            :param sizes: The size field well of a tree map. Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__13a1765b077c5f3d55533e4d4b702a544c3a66e9b0e70ecbd0c56008193a408e)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument groups", value=groups, expected_type=type_hints["groups"])
                check_type(argname="argument sizes", value=sizes, expected_type=type_hints["sizes"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors
            if groups is not None:
                self._values["groups"] = groups
            if sizes is not None:
                self._values["sizes"] = sizes

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The color field well of a tree map.

            Values are grouped by aggregations based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapaggregatedfieldwells.html#cfn-quicksight-dashboard-treemapaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        @builtins.property
        def groups(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The group by field well of a tree map.

            Values are grouped based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapaggregatedfieldwells.html#cfn-quicksight-dashboard-treemapaggregatedfieldwells-groups
            '''
            result = self._values.get("groups")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def sizes(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The size field well of a tree map.

            Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapaggregatedfieldwells.html#cfn-quicksight-dashboard-treemapaggregatedfieldwells-sizes
            '''
            result = self._values.get("sizes")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TreeMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_label_options": "colorLabelOptions",
            "color_scale": "colorScale",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "group_label_options": "groupLabelOptions",
            "legend": "legend",
            "size_label_options": "sizeLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
        },
    )
    class TreeMapConfigurationProperty:
        def __init__(
            self,
            *,
            color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_scale: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColorScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TreeMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            group_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            size_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TreeMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a tree map.

            :param color_label_options: The label options (label text, label visibility) for the colors displayed in a tree map.
            :param color_scale: The color options (gradient color, point of divergence) of a tree map.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param group_label_options: The label options (label text, label visibility) of the groups that are displayed in a tree map.
            :param legend: The legend display setup of the visual.
            :param size_label_options: The label options (label text, label visibility) of the sizes that are displayed in a tree map.
            :param sort_configuration: The sort configuration of a tree map.
            :param tooltip: The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fbe7f2abf62b52b7c12391a741ab9378cddd5611467bd29c3ee5643fa6cdc2e0)
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument color_scale", value=color_scale, expected_type=type_hints["color_scale"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument group_label_options", value=group_label_options, expected_type=type_hints["group_label_options"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument size_label_options", value=size_label_options, expected_type=type_hints["size_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if color_scale is not None:
                self._values["color_scale"] = color_scale
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if group_label_options is not None:
                self._values["group_label_options"] = group_label_options
            if legend is not None:
                self._values["legend"] = legend
            if size_label_options is not None:
                self._values["size_label_options"] = size_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility) for the colors displayed in a tree map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_scale(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColorScaleProperty"]]:
            '''The color options (gradient color, point of divergence) of a tree map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-colorscale
            '''
            result = self._values.get("color_scale")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColorScaleProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TreeMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TreeMapFieldWellsProperty"]], result)

        @builtins.property
        def group_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility) of the groups that are displayed in a tree map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-grouplabeloptions
            '''
            result = self._values.get("group_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def size_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility) of the sizes that are displayed in a tree map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-sizelabeloptions
            '''
            result = self._values.get("size_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TreeMapSortConfigurationProperty"]]:
            '''The sort configuration of a tree map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TreeMapSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TooltipOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TreeMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "tree_map_aggregated_field_wells": "treeMapAggregatedFieldWells",
        },
    )
    class TreeMapFieldWellsProperty:
        def __init__(
            self,
            *,
            tree_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TreeMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a tree map.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param tree_map_aggregated_field_wells: The aggregated field wells of a tree map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cc1ed4b157d486792fe2995df45d70dec38c9055a4d217cc2c596cc31fc213e3)
                check_type(argname="argument tree_map_aggregated_field_wells", value=tree_map_aggregated_field_wells, expected_type=type_hints["tree_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if tree_map_aggregated_field_wells is not None:
                self._values["tree_map_aggregated_field_wells"] = tree_map_aggregated_field_wells

        @builtins.property
        def tree_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TreeMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a tree map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapfieldwells.html#cfn-quicksight-dashboard-treemapfieldwells-treemapaggregatedfieldwells
            '''
            result = self._values.get("tree_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TreeMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TreeMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "tree_map_group_items_limit_configuration": "treeMapGroupItemsLimitConfiguration",
            "tree_map_sort": "treeMapSort",
        },
    )
    class TreeMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            tree_map_group_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tree_map_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a tree map.

            :param tree_map_group_items_limit_configuration: The limit on the number of groups that are displayed.
            :param tree_map_sort: The sort configuration of group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                tree_map_sort_configuration_property = quicksight.CfnDashboard.TreeMapSortConfigurationProperty(
                    tree_map_group_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    tree_map_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2e487c2bf562f77d2421b558a0726ff982725189d022ae5475ce059d4571f032)
                check_type(argname="argument tree_map_group_items_limit_configuration", value=tree_map_group_items_limit_configuration, expected_type=type_hints["tree_map_group_items_limit_configuration"])
                check_type(argname="argument tree_map_sort", value=tree_map_sort, expected_type=type_hints["tree_map_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if tree_map_group_items_limit_configuration is not None:
                self._values["tree_map_group_items_limit_configuration"] = tree_map_group_items_limit_configuration
            if tree_map_sort is not None:
                self._values["tree_map_sort"] = tree_map_sort

        @builtins.property
        def tree_map_group_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of groups that are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapsortconfiguration.html#cfn-quicksight-dashboard-treemapsortconfiguration-treemapgroupitemslimitconfiguration
            '''
            result = self._values.get("tree_map_group_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def tree_map_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapsortconfiguration.html#cfn-quicksight-dashboard-treemapsortconfiguration-treemapsort
            '''
            result = self._values.get("tree_map_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TreeMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class TreeMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TreeMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A tree map.

            For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c415fbc50da0b54310da83c3cb3e6830cc15263c6d31a905fdb3c67d8b6b8c15)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TreeMapConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TreeMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.TrendArrowOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class TrendArrowOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of trend arrows in a KPI visual.

            :param visibility: The visibility of the trend arrows.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-trendarrowoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                trend_arrow_options_property = quicksight.CfnDashboard.TrendArrowOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__790821eed201a9e42659e23dc0e5569f31f85eb1f007460ceb349c1c1087d15a)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the trend arrows.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-trendarrowoptions.html#cfn-quicksight-dashboard-trendarrowoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TrendArrowOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.UnaggregatedFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
        },
    )
    class UnaggregatedFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The unaggregated field for a table.

            :param column: The column that is used in the ``UnaggregatedField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-unaggregatedfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                unaggregated_field_property = quicksight.CfnDashboard.UnaggregatedFieldProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9edce176783b802e7011e635b84c0ec5f1e5117e23c0fbcf26f42108389f8cc0)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that is used in the ``UnaggregatedField`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-unaggregatedfield.html#cfn-quicksight-dashboard-unaggregatedfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-unaggregatedfield.html#cfn-quicksight-dashboard-unaggregatedfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-unaggregatedfield.html#cfn-quicksight-dashboard-unaggregatedfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UnaggregatedFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.UniqueValuesComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "category": "category",
            "name": "name",
        },
    )
    class UniqueValuesComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The unique values computation configuration.

            :param computation_id: The ID for a computation.
            :param category: The category field that is used in a computation.
            :param name: The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-uniquevaluescomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                unique_values_computation_property = quicksight.CfnDashboard.UniqueValuesComputationProperty(
                    computation_id="computationId",
                
                    # the properties below are optional
                    category=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8cb3da93863693b3294cd64796ece90af0a94a38f860b8a7457dd0ab73ad00ef)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
            }
            if category is not None:
                self._values["category"] = category
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-uniquevaluescomputation.html#cfn-quicksight-dashboard-uniquevaluescomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]:
            '''The category field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-uniquevaluescomputation.html#cfn-quicksight-dashboard-uniquevaluescomputation-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-uniquevaluescomputation.html#cfn-quicksight-dashboard-uniquevaluescomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UniqueValuesComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.ValidationStrategyProperty",
        jsii_struct_bases=[],
        name_mapping={"mode": "mode"},
    )
    class ValidationStrategyProperty:
        def __init__(self, *, mode: builtins.str) -> None:
            '''The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects.

            When you set this value to ``LENIENT`` , validation is skipped for specific errors.

            :param mode: The mode of validation for the asset to be created or updated. When you set this value to ``STRICT`` , strict validation for every error is enforced. When you set this value to ``LENIENT`` , validation is skipped for specific UI errors.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-validationstrategy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                validation_strategy_property = quicksight.CfnDashboard.ValidationStrategyProperty(
                    mode="mode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9866c0121e30b0debc4dba0dc43db31d1a4f10b2c29c992c5457fbfd011d0414)
                check_type(argname="argument mode", value=mode, expected_type=type_hints["mode"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "mode": mode,
            }

        @builtins.property
        def mode(self) -> builtins.str:
            '''The mode of validation for the asset to be created or updated.

            When you set this value to ``STRICT`` , strict validation for every error is enforced. When you set this value to ``LENIENT`` , validation is skipped for specific UI errors.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-validationstrategy.html#cfn-quicksight-dashboard-validationstrategy-mode
            '''
            result = self._values.get("mode")
            assert result is not None, "Required property 'mode' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ValidationStrategyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.VisibleRangeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"percent_range": "percentRange"},
    )
    class VisibleRangeOptionsProperty:
        def __init__(
            self,
            *,
            percent_range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PercentVisibleRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The range options for the data zoom scroll bar.

            :param percent_range: The percent range in the visible range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visiblerangeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                visible_range_options_property = quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                        from=123,
                        to=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cb10b50aa2435e54c2b4f09d4df8f9c42c20f0167eb7c3d20b92f3d7b5ccd4dc)
                check_type(argname="argument percent_range", value=percent_range, expected_type=type_hints["percent_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percent_range is not None:
                self._values["percent_range"] = percent_range

        @builtins.property
        def percent_range(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PercentVisibleRangeProperty"]]:
            '''The percent range in the visible range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visiblerangeoptions.html#cfn-quicksight-dashboard-visiblerangeoptions-percentrange
            '''
            result = self._values.get("percent_range")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PercentVisibleRangeProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisibleRangeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.VisualAxisSortOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class VisualAxisSortOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The axis sort options for a visual.

            :param availability_status: The availaiblity status of a visual's axis sort options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualaxissortoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                visual_axis_sort_option_property = quicksight.CfnDashboard.VisualAxisSortOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d33d5dcd3d748910eab608644e829b1955d62d5dd0cba3d106e413f4f1ed4277)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The availaiblity status of a visual's axis sort options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualaxissortoption.html#cfn-quicksight-dashboard-visualaxissortoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualAxisSortOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.VisualCustomActionOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_operation": "filterOperation",
            "navigation_operation": "navigationOperation",
            "set_parameters_operation": "setParametersOperation",
            "url_operation": "urlOperation",
        },
    )
    class VisualCustomActionOperationProperty:
        def __init__(
            self,
            *,
            filter_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CustomActionFilterOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            navigation_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CustomActionNavigationOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            set_parameters_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CustomActionSetParametersOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            url_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CustomActionURLOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The operation that is defined by the custom action.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param filter_operation: The filter operation that filters data included in a visual or in an entire sheet.
            :param navigation_operation: The navigation operation that navigates between different sheets in the same analysis.
            :param set_parameters_operation: The set parameter operation that sets parameters in custom action.
            :param url_operation: The URL operation that opens a link to another webpage.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                visual_custom_action_operation_property = quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                            selected_columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            selected_field_options="selectedFieldOptions",
                            selected_fields=["selectedFields"]
                        ),
                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                target_visual_options="targetVisualOptions",
                                target_visuals=["targetVisuals"]
                            )
                        )
                    ),
                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                            target_sheet_id="targetSheetId"
                        )
                    ),
                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                            destination_parameter_name="destinationParameterName",
                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                        date_time_values=["dateTimeValues"],
                                        decimal_values=[123],
                                        integer_values=[123],
                                        string_values=["stringValues"]
                                    ),
                
                                    # the properties below are optional
                                    include_null_value=False
                                ),
                                select_all_value_options="selectAllValueOptions",
                                source_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_field="sourceField",
                                source_parameter_name="sourceParameterName"
                            )
                        )]
                    ),
                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                        url_target="urlTarget",
                        url_template="urlTemplate"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__53f0a1da4f6a76661864aa4737c512d664b39d14e0aba25468ee2c44da469bd2)
                check_type(argname="argument filter_operation", value=filter_operation, expected_type=type_hints["filter_operation"])
                check_type(argname="argument navigation_operation", value=navigation_operation, expected_type=type_hints["navigation_operation"])
                check_type(argname="argument set_parameters_operation", value=set_parameters_operation, expected_type=type_hints["set_parameters_operation"])
                check_type(argname="argument url_operation", value=url_operation, expected_type=type_hints["url_operation"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if filter_operation is not None:
                self._values["filter_operation"] = filter_operation
            if navigation_operation is not None:
                self._values["navigation_operation"] = navigation_operation
            if set_parameters_operation is not None:
                self._values["set_parameters_operation"] = set_parameters_operation
            if url_operation is not None:
                self._values["url_operation"] = url_operation

        @builtins.property
        def filter_operation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomActionFilterOperationProperty"]]:
            '''The filter operation that filters data included in a visual or in an entire sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html#cfn-quicksight-dashboard-visualcustomactionoperation-filteroperation
            '''
            result = self._values.get("filter_operation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomActionFilterOperationProperty"]], result)

        @builtins.property
        def navigation_operation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomActionNavigationOperationProperty"]]:
            '''The navigation operation that navigates between different sheets in the same analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html#cfn-quicksight-dashboard-visualcustomactionoperation-navigationoperation
            '''
            result = self._values.get("navigation_operation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomActionNavigationOperationProperty"]], result)

        @builtins.property
        def set_parameters_operation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomActionSetParametersOperationProperty"]]:
            '''The set parameter operation that sets parameters in custom action.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html#cfn-quicksight-dashboard-visualcustomactionoperation-setparametersoperation
            '''
            result = self._values.get("set_parameters_operation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomActionSetParametersOperationProperty"]], result)

        @builtins.property
        def url_operation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomActionURLOperationProperty"]]:
            '''The URL operation that opens a link to another webpage.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html#cfn-quicksight-dashboard-visualcustomactionoperation-urloperation
            '''
            result = self._values.get("url_operation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomActionURLOperationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualCustomActionOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.VisualCustomActionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "action_operations": "actionOperations",
            "custom_action_id": "customActionId",
            "name": "name",
            "trigger": "trigger",
            "status": "status",
        },
    )
    class VisualCustomActionProperty:
        def __init__(
            self,
            *,
            action_operations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionOperationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            custom_action_id: builtins.str,
            name: builtins.str,
            trigger: builtins.str,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A custom action defined on a visual.

            :param action_operations: A list of ``VisualCustomActionOperations`` . This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
            :param custom_action_id: The ID of the ``VisualCustomAction`` .
            :param name: The name of the ``VisualCustomAction`` .
            :param trigger: The trigger of the ``VisualCustomAction`` . Valid values are defined as follows: - ``DATA_POINT_CLICK`` : Initiates a custom action by a left pointer click on a data point. - ``DATA_POINT_MENU`` : Initiates a custom action by right pointer click from the menu.
            :param status: The status of the ``VisualCustomAction`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                visual_custom_action_property = quicksight.CfnDashboard.VisualCustomActionProperty(
                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                selected_columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                selected_field_options="selectedFieldOptions",
                                selected_fields=["selectedFields"]
                            ),
                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                    target_visual_options="targetVisualOptions",
                                    target_visuals=["targetVisuals"]
                                )
                            )
                        ),
                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                target_sheet_id="targetSheetId"
                            )
                        ),
                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                destination_parameter_name="destinationParameterName",
                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                            date_time_values=["dateTimeValues"],
                                            decimal_values=[123],
                                            integer_values=[123],
                                            string_values=["stringValues"]
                                        ),
                
                                        # the properties below are optional
                                        include_null_value=False
                                    ),
                                    select_all_value_options="selectAllValueOptions",
                                    source_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_field="sourceField",
                                    source_parameter_name="sourceParameterName"
                                )
                            )]
                        ),
                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                            url_target="urlTarget",
                            url_template="urlTemplate"
                        )
                    )],
                    custom_action_id="customActionId",
                    name="name",
                    trigger="trigger",
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__eb0f39821608039a7811382a5857633915dcb72f45adf6050cf21c3fd43f3134)
                check_type(argname="argument action_operations", value=action_operations, expected_type=type_hints["action_operations"])
                check_type(argname="argument custom_action_id", value=custom_action_id, expected_type=type_hints["custom_action_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument trigger", value=trigger, expected_type=type_hints["trigger"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "action_operations": action_operations,
                "custom_action_id": custom_action_id,
                "name": name,
                "trigger": trigger,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def action_operations(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionOperationProperty"]]]:
            '''A list of ``VisualCustomActionOperations`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-actionoperations
            '''
            result = self._values.get("action_operations")
            assert result is not None, "Required property 'action_operations' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionOperationProperty"]]], result)

        @builtins.property
        def custom_action_id(self) -> builtins.str:
            '''The ID of the ``VisualCustomAction`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-customactionid
            '''
            result = self._values.get("custom_action_id")
            assert result is not None, "Required property 'custom_action_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the ``VisualCustomAction`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def trigger(self) -> builtins.str:
            '''The trigger of the ``VisualCustomAction`` .

            Valid values are defined as follows:

            - ``DATA_POINT_CLICK`` : Initiates a custom action by a left pointer click on a data point.
            - ``DATA_POINT_MENU`` : Initiates a custom action by right pointer click from the menu.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-trigger
            '''
            result = self._values.get("trigger")
            assert result is not None, "Required property 'trigger' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the ``VisualCustomAction`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualCustomActionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.VisualMenuOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class VisualMenuOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The menu options for a visual.

            :param availability_status: The availaiblity status of a visual's menu options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualmenuoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                visual_menu_option_property = quicksight.CfnDashboard.VisualMenuOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2812a2f0ead91339e0ad280e56a2126e5c88c7dd642bee0c3bbe02d4c146d875)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The availaiblity status of a visual's menu options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualmenuoption.html#cfn-quicksight-dashboard-visualmenuoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualMenuOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.VisualPaletteProperty",
        jsii_struct_bases=[],
        name_mapping={"chart_color": "chartColor", "color_map": "colorMap"},
    )
    class VisualPaletteProperty:
        def __init__(
            self,
            *,
            chart_color: typing.Optional[builtins.str] = None,
            color_map: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataPathColorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The visual display options for the visual palette.

            :param chart_color: The chart color options for the visual palette.
            :param color_map: The color map options for the visual palette.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualpalette.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                visual_palette_property = quicksight.CfnDashboard.VisualPaletteProperty(
                    chart_color="chartColor",
                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                        color="color",
                        element=quicksight.CfnDashboard.DataPathValueProperty(
                            data_path_type=quicksight.CfnDashboard.DataPathTypeProperty(
                                pivot_table_data_path_type="pivotTableDataPathType"
                            ),
                            field_id="fieldId",
                            field_value="fieldValue"
                        ),
                
                        # the properties below are optional
                        time_granularity="timeGranularity"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2d567e9d819c5aeded7e23d832da9d24b91fa74244eac355da593ae3780d415e)
                check_type(argname="argument chart_color", value=chart_color, expected_type=type_hints["chart_color"])
                check_type(argname="argument color_map", value=color_map, expected_type=type_hints["color_map"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if chart_color is not None:
                self._values["chart_color"] = chart_color
            if color_map is not None:
                self._values["color_map"] = color_map

        @builtins.property
        def chart_color(self) -> typing.Optional[builtins.str]:
            '''The chart color options for the visual palette.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualpalette.html#cfn-quicksight-dashboard-visualpalette-chartcolor
            '''
            result = self._values.get("chart_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def color_map(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPathColorProperty"]]]]:
            '''The color map options for the visual palette.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualpalette.html#cfn-quicksight-dashboard-visualpalette-colormap
            '''
            result = self._values.get("color_map")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataPathColorProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualPaletteProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.VisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_chart_visual": "barChartVisual",
            "box_plot_visual": "boxPlotVisual",
            "combo_chart_visual": "comboChartVisual",
            "custom_content_visual": "customContentVisual",
            "empty_visual": "emptyVisual",
            "filled_map_visual": "filledMapVisual",
            "funnel_chart_visual": "funnelChartVisual",
            "gauge_chart_visual": "gaugeChartVisual",
            "geospatial_map_visual": "geospatialMapVisual",
            "heat_map_visual": "heatMapVisual",
            "histogram_visual": "histogramVisual",
            "insight_visual": "insightVisual",
            "kpi_visual": "kpiVisual",
            "line_chart_visual": "lineChartVisual",
            "pie_chart_visual": "pieChartVisual",
            "pivot_table_visual": "pivotTableVisual",
            "radar_chart_visual": "radarChartVisual",
            "sankey_diagram_visual": "sankeyDiagramVisual",
            "scatter_plot_visual": "scatterPlotVisual",
            "table_visual": "tableVisual",
            "tree_map_visual": "treeMapVisual",
            "waterfall_visual": "waterfallVisual",
            "word_cloud_visual": "wordCloudVisual",
        },
    )
    class VisualProperty:
        def __init__(
            self,
            *,
            bar_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.BarChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            box_plot_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.BoxPlotVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            combo_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ComboChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_content_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.CustomContentVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            empty_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.EmptyVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            filled_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FilledMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            funnel_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FunnelChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            gauge_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GaugeChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            geospatial_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.GeospatialMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            heat_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.HeatMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            histogram_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.HistogramVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            insight_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.InsightVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            kpi_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.KPIVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            line_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LineChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            pie_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PieChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            pivot_table_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.PivotTableVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            radar_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.RadarChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sankey_diagram_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.SankeyDiagramVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scatter_plot_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ScatterPlotVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TableVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tree_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.TreeMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            waterfall_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.WaterfallVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            word_cloud_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.WordCloudVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A visual displayed on a sheet in an analysis, dashboard, or template.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param bar_chart_visual: A bar chart. For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param box_plot_visual: A box plot. For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .
            :param combo_chart_visual: A combo chart. For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param custom_content_visual: A visual that contains custom content. For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .
            :param empty_visual: An empty visual.
            :param filled_map_visual: A filled map. For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .
            :param funnel_chart_visual: A funnel chart. For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .
            :param gauge_chart_visual: A gauge chart. For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param geospatial_map_visual: A geospatial map or a points on map visual. For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .
            :param heat_map_visual: A heat map. For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .
            :param histogram_visual: A histogram. For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param insight_visual: An insight visual. For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .
            :param kpi_visual: A key performance indicator (KPI). For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .
            :param line_chart_visual: A line chart. For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param pie_chart_visual: A pie or donut chart. For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param pivot_table_visual: A pivot table. For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .
            :param radar_chart_visual: A radar chart visual. For more information, see `Using radar charts <https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param sankey_diagram_visual: A sankey diagram. For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .
            :param scatter_plot_visual: A scatter plot. For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .
            :param table_visual: A table visual. For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .
            :param tree_map_visual: A tree map. For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .
            :param waterfall_visual: A waterfall chart. For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param word_cloud_visual: A word cloud. For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__db7a7e19c2aa0584ce468063502cc098c100d0ffba0208af1f984e822f260f09)
                check_type(argname="argument bar_chart_visual", value=bar_chart_visual, expected_type=type_hints["bar_chart_visual"])
                check_type(argname="argument box_plot_visual", value=box_plot_visual, expected_type=type_hints["box_plot_visual"])
                check_type(argname="argument combo_chart_visual", value=combo_chart_visual, expected_type=type_hints["combo_chart_visual"])
                check_type(argname="argument custom_content_visual", value=custom_content_visual, expected_type=type_hints["custom_content_visual"])
                check_type(argname="argument empty_visual", value=empty_visual, expected_type=type_hints["empty_visual"])
                check_type(argname="argument filled_map_visual", value=filled_map_visual, expected_type=type_hints["filled_map_visual"])
                check_type(argname="argument funnel_chart_visual", value=funnel_chart_visual, expected_type=type_hints["funnel_chart_visual"])
                check_type(argname="argument gauge_chart_visual", value=gauge_chart_visual, expected_type=type_hints["gauge_chart_visual"])
                check_type(argname="argument geospatial_map_visual", value=geospatial_map_visual, expected_type=type_hints["geospatial_map_visual"])
                check_type(argname="argument heat_map_visual", value=heat_map_visual, expected_type=type_hints["heat_map_visual"])
                check_type(argname="argument histogram_visual", value=histogram_visual, expected_type=type_hints["histogram_visual"])
                check_type(argname="argument insight_visual", value=insight_visual, expected_type=type_hints["insight_visual"])
                check_type(argname="argument kpi_visual", value=kpi_visual, expected_type=type_hints["kpi_visual"])
                check_type(argname="argument line_chart_visual", value=line_chart_visual, expected_type=type_hints["line_chart_visual"])
                check_type(argname="argument pie_chart_visual", value=pie_chart_visual, expected_type=type_hints["pie_chart_visual"])
                check_type(argname="argument pivot_table_visual", value=pivot_table_visual, expected_type=type_hints["pivot_table_visual"])
                check_type(argname="argument radar_chart_visual", value=radar_chart_visual, expected_type=type_hints["radar_chart_visual"])
                check_type(argname="argument sankey_diagram_visual", value=sankey_diagram_visual, expected_type=type_hints["sankey_diagram_visual"])
                check_type(argname="argument scatter_plot_visual", value=scatter_plot_visual, expected_type=type_hints["scatter_plot_visual"])
                check_type(argname="argument table_visual", value=table_visual, expected_type=type_hints["table_visual"])
                check_type(argname="argument tree_map_visual", value=tree_map_visual, expected_type=type_hints["tree_map_visual"])
                check_type(argname="argument waterfall_visual", value=waterfall_visual, expected_type=type_hints["waterfall_visual"])
                check_type(argname="argument word_cloud_visual", value=word_cloud_visual, expected_type=type_hints["word_cloud_visual"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_chart_visual is not None:
                self._values["bar_chart_visual"] = bar_chart_visual
            if box_plot_visual is not None:
                self._values["box_plot_visual"] = box_plot_visual
            if combo_chart_visual is not None:
                self._values["combo_chart_visual"] = combo_chart_visual
            if custom_content_visual is not None:
                self._values["custom_content_visual"] = custom_content_visual
            if empty_visual is not None:
                self._values["empty_visual"] = empty_visual
            if filled_map_visual is not None:
                self._values["filled_map_visual"] = filled_map_visual
            if funnel_chart_visual is not None:
                self._values["funnel_chart_visual"] = funnel_chart_visual
            if gauge_chart_visual is not None:
                self._values["gauge_chart_visual"] = gauge_chart_visual
            if geospatial_map_visual is not None:
                self._values["geospatial_map_visual"] = geospatial_map_visual
            if heat_map_visual is not None:
                self._values["heat_map_visual"] = heat_map_visual
            if histogram_visual is not None:
                self._values["histogram_visual"] = histogram_visual
            if insight_visual is not None:
                self._values["insight_visual"] = insight_visual
            if kpi_visual is not None:
                self._values["kpi_visual"] = kpi_visual
            if line_chart_visual is not None:
                self._values["line_chart_visual"] = line_chart_visual
            if pie_chart_visual is not None:
                self._values["pie_chart_visual"] = pie_chart_visual
            if pivot_table_visual is not None:
                self._values["pivot_table_visual"] = pivot_table_visual
            if radar_chart_visual is not None:
                self._values["radar_chart_visual"] = radar_chart_visual
            if sankey_diagram_visual is not None:
                self._values["sankey_diagram_visual"] = sankey_diagram_visual
            if scatter_plot_visual is not None:
                self._values["scatter_plot_visual"] = scatter_plot_visual
            if table_visual is not None:
                self._values["table_visual"] = table_visual
            if tree_map_visual is not None:
                self._values["tree_map_visual"] = tree_map_visual
            if waterfall_visual is not None:
                self._values["waterfall_visual"] = waterfall_visual
            if word_cloud_visual is not None:
                self._values["word_cloud_visual"] = word_cloud_visual

        @builtins.property
        def bar_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BarChartVisualProperty"]]:
            '''A bar chart.

            For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-barchartvisual
            '''
            result = self._values.get("bar_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BarChartVisualProperty"]], result)

        @builtins.property
        def box_plot_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BoxPlotVisualProperty"]]:
            '''A box plot.

            For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-boxplotvisual
            '''
            result = self._values.get("box_plot_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.BoxPlotVisualProperty"]], result)

        @builtins.property
        def combo_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ComboChartVisualProperty"]]:
            '''A combo chart.

            For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-combochartvisual
            '''
            result = self._values.get("combo_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ComboChartVisualProperty"]], result)

        @builtins.property
        def custom_content_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomContentVisualProperty"]]:
            '''A visual that contains custom content.

            For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-customcontentvisual
            '''
            result = self._values.get("custom_content_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.CustomContentVisualProperty"]], result)

        @builtins.property
        def empty_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.EmptyVisualProperty"]]:
            '''An empty visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-emptyvisual
            '''
            result = self._values.get("empty_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.EmptyVisualProperty"]], result)

        @builtins.property
        def filled_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilledMapVisualProperty"]]:
            '''A filled map.

            For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-filledmapvisual
            '''
            result = self._values.get("filled_map_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FilledMapVisualProperty"]], result)

        @builtins.property
        def funnel_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FunnelChartVisualProperty"]]:
            '''A funnel chart.

            For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-funnelchartvisual
            '''
            result = self._values.get("funnel_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FunnelChartVisualProperty"]], result)

        @builtins.property
        def gauge_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GaugeChartVisualProperty"]]:
            '''A gauge chart.

            For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-gaugechartvisual
            '''
            result = self._values.get("gauge_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GaugeChartVisualProperty"]], result)

        @builtins.property
        def geospatial_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialMapVisualProperty"]]:
            '''A geospatial map or a points on map visual.

            For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-geospatialmapvisual
            '''
            result = self._values.get("geospatial_map_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.GeospatialMapVisualProperty"]], result)

        @builtins.property
        def heat_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HeatMapVisualProperty"]]:
            '''A heat map.

            For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-heatmapvisual
            '''
            result = self._values.get("heat_map_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HeatMapVisualProperty"]], result)

        @builtins.property
        def histogram_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HistogramVisualProperty"]]:
            '''A histogram.

            For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-histogramvisual
            '''
            result = self._values.get("histogram_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.HistogramVisualProperty"]], result)

        @builtins.property
        def insight_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.InsightVisualProperty"]]:
            '''An insight visual.

            For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-insightvisual
            '''
            result = self._values.get("insight_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.InsightVisualProperty"]], result)

        @builtins.property
        def kpi_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIVisualProperty"]]:
            '''A key performance indicator (KPI).

            For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-kpivisual
            '''
            result = self._values.get("kpi_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.KPIVisualProperty"]], result)

        @builtins.property
        def line_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartVisualProperty"]]:
            '''A line chart.

            For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-linechartvisual
            '''
            result = self._values.get("line_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LineChartVisualProperty"]], result)

        @builtins.property
        def pie_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PieChartVisualProperty"]]:
            '''A pie or donut chart.

            For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-piechartvisual
            '''
            result = self._values.get("pie_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PieChartVisualProperty"]], result)

        @builtins.property
        def pivot_table_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableVisualProperty"]]:
            '''A pivot table.

            For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-pivottablevisual
            '''
            result = self._values.get("pivot_table_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.PivotTableVisualProperty"]], result)

        @builtins.property
        def radar_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RadarChartVisualProperty"]]:
            '''A radar chart visual.

            For more information, see `Using radar charts <https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-radarchartvisual
            '''
            result = self._values.get("radar_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.RadarChartVisualProperty"]], result)

        @builtins.property
        def sankey_diagram_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SankeyDiagramVisualProperty"]]:
            '''A sankey diagram.

            For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-sankeydiagramvisual
            '''
            result = self._values.get("sankey_diagram_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.SankeyDiagramVisualProperty"]], result)

        @builtins.property
        def scatter_plot_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ScatterPlotVisualProperty"]]:
            '''A scatter plot.

            For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-scatterplotvisual
            '''
            result = self._values.get("scatter_plot_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ScatterPlotVisualProperty"]], result)

        @builtins.property
        def table_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableVisualProperty"]]:
            '''A table visual.

            For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-tablevisual
            '''
            result = self._values.get("table_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TableVisualProperty"]], result)

        @builtins.property
        def tree_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TreeMapVisualProperty"]]:
            '''A tree map.

            For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-treemapvisual
            '''
            result = self._values.get("tree_map_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.TreeMapVisualProperty"]], result)

        @builtins.property
        def waterfall_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WaterfallVisualProperty"]]:
            '''A waterfall chart.

            For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-waterfallvisual
            '''
            result = self._values.get("waterfall_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WaterfallVisualProperty"]], result)

        @builtins.property
        def word_cloud_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WordCloudVisualProperty"]]:
            '''A word cloud.

            For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-wordcloudvisual
            '''
            result = self._values.get("word_cloud_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WordCloudVisualProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"format_text": "formatText", "visibility": "visibility"},
    )
    class VisualSubtitleLabelOptionsProperty:
        def __init__(
            self,
            *,
            format_text: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LongFormatTextProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The subtitle label options for a visual.

            :param format_text: The long text format of the subtitle label, such as plain text or rich text.
            :param visibility: The visibility of the subtitle label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualsubtitlelabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                visual_subtitle_label_options_property = quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                        plain_text="plainText",
                        rich_text="richText"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bed265a8cc34abdd36eaf527e2cbf0f5d70e44fa104d04a26ae31b32cfa05ae5)
                check_type(argname="argument format_text", value=format_text, expected_type=type_hints["format_text"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_text is not None:
                self._values["format_text"] = format_text
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def format_text(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LongFormatTextProperty"]]:
            '''The long text format of the subtitle label, such as plain text or rich text.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualsubtitlelabeloptions.html#cfn-quicksight-dashboard-visualsubtitlelabeloptions-formattext
            '''
            result = self._values.get("format_text")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LongFormatTextProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the subtitle label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualsubtitlelabeloptions.html#cfn-quicksight-dashboard-visualsubtitlelabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualSubtitleLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.VisualTitleLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"format_text": "formatText", "visibility": "visibility"},
    )
    class VisualTitleLabelOptionsProperty:
        def __init__(
            self,
            *,
            format_text: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ShortFormatTextProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The title label options for a visual.

            :param format_text: The short text format of the title label, such as plain text or rich text.
            :param visibility: The visibility of the title label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualtitlelabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                visual_title_label_options_property = quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                        plain_text="plainText",
                        rich_text="richText"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__574aa79ab37beabdf8a2fa1398505f48d0cf2a4662cf29561433ceacf291f26f)
                check_type(argname="argument format_text", value=format_text, expected_type=type_hints["format_text"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_text is not None:
                self._values["format_text"] = format_text
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def format_text(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ShortFormatTextProperty"]]:
            '''The short text format of the title label, such as plain text or rich text.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualtitlelabeloptions.html#cfn-quicksight-dashboard-visualtitlelabeloptions-formattext
            '''
            result = self._values.get("format_text")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ShortFormatTextProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the title label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualtitlelabeloptions.html#cfn-quicksight-dashboard-visualtitlelabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualTitleLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.WaterfallChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "breakdowns": "breakdowns",
            "categories": "categories",
            "values": "values",
        },
    )
    class WaterfallChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            breakdowns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            categories: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a waterfall visual.

            :param breakdowns: The breakdown field wells of a waterfall visual.
            :param categories: The category field wells of a waterfall visual.
            :param values: The value field wells of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f15cd7e197704ff4a3b3e7538fae0832f807a52bcc5b6b98d16c47c4273ddb83)
                check_type(argname="argument breakdowns", value=breakdowns, expected_type=type_hints["breakdowns"])
                check_type(argname="argument categories", value=categories, expected_type=type_hints["categories"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if breakdowns is not None:
                self._values["breakdowns"] = breakdowns
            if categories is not None:
                self._values["categories"] = categories
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def breakdowns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The breakdown field wells of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartaggregatedfieldwells.html#cfn-quicksight-dashboard-waterfallchartaggregatedfieldwells-breakdowns
            '''
            result = self._values.get("breakdowns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def categories(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The category field wells of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartaggregatedfieldwells.html#cfn-quicksight-dashboard-waterfallchartaggregatedfieldwells-categories
            '''
            result = self._values.get("categories")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The value field wells of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartaggregatedfieldwells.html#cfn-quicksight-dashboard-waterfallchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.WaterfallChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_axis_display_options": "categoryAxisDisplayOptions",
            "category_axis_label_options": "categoryAxisLabelOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "sort_configuration": "sortConfiguration",
            "visual_palette": "visualPalette",
            "waterfall_chart_options": "waterfallChartOptions",
        },
    )
    class WaterfallChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.WaterfallChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.WaterfallChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            waterfall_chart_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.WaterfallChartOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a waterfall visual.

            :param category_axis_display_options: The options that determine the presentation of the category axis.
            :param category_axis_label_options: The options that determine the presentation of the category axis label.
            :param data_labels: The data label configuration of a waterfall visual.
            :param field_wells: The field well configuration of a waterfall visual.
            :param legend: The legend configuration of a waterfall visual.
            :param primary_y_axis_display_options: The options that determine the presentation of the y-axis.
            :param primary_y_axis_label_options: The options that determine the presentation of the y-axis label.
            :param sort_configuration: The sort configuration of a waterfall visual.
            :param visual_palette: The visual palette configuration of a waterfall visual.
            :param waterfall_chart_options: The options that determine the presentation of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ad38f0eb69b8cad148b7d6c01c1f46d46616e386d0867fe699ceb550feeb9ddf)
                check_type(argname="argument category_axis_display_options", value=category_axis_display_options, expected_type=type_hints["category_axis_display_options"])
                check_type(argname="argument category_axis_label_options", value=category_axis_label_options, expected_type=type_hints["category_axis_label_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument waterfall_chart_options", value=waterfall_chart_options, expected_type=type_hints["waterfall_chart_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_axis_display_options is not None:
                self._values["category_axis_display_options"] = category_axis_display_options
            if category_axis_label_options is not None:
                self._values["category_axis_label_options"] = category_axis_label_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if waterfall_chart_options is not None:
                self._values["waterfall_chart_options"] = waterfall_chart_options

        @builtins.property
        def category_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the category axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-categoryaxisdisplayoptions
            '''
            result = self._values.get("category_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the category axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-categoryaxislabeloptions
            '''
            result = self._values.get("category_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The data label configuration of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WaterfallChartFieldWellsProperty"]]:
            '''The field well configuration of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WaterfallChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend configuration of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WaterfallChartSortConfigurationProperty"]]:
            '''The sort configuration of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WaterfallChartSortConfigurationProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]]:
            '''The visual palette configuration of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualPaletteProperty"]], result)

        @builtins.property
        def waterfall_chart_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WaterfallChartOptionsProperty"]]:
            '''The options that determine the presentation of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-waterfallchartoptions
            '''
            result = self._values.get("waterfall_chart_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WaterfallChartOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.WaterfallChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "waterfall_chart_aggregated_field_wells": "waterfallChartAggregatedFieldWells",
        },
    )
    class WaterfallChartFieldWellsProperty:
        def __init__(
            self,
            *,
            waterfall_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.WaterfallChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a waterfall visual.

            :param waterfall_chart_aggregated_field_wells: The field well configuration of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0b3e2e432ab1177d5a569cbb7519e42a3a7cadd71db940881d20cee54c60145a)
                check_type(argname="argument waterfall_chart_aggregated_field_wells", value=waterfall_chart_aggregated_field_wells, expected_type=type_hints["waterfall_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if waterfall_chart_aggregated_field_wells is not None:
                self._values["waterfall_chart_aggregated_field_wells"] = waterfall_chart_aggregated_field_wells

        @builtins.property
        def waterfall_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WaterfallChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartfieldwells.html#cfn-quicksight-dashboard-waterfallchartfieldwells-waterfallchartaggregatedfieldwells
            '''
            result = self._values.get("waterfall_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WaterfallChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.WaterfallChartOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"total_bar_label": "totalBarLabel"},
    )
    class WaterfallChartOptionsProperty:
        def __init__(
            self,
            *,
            total_bar_label: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of a waterfall visual.

            :param total_bar_label: This option determines the total bar label of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                waterfall_chart_options_property = quicksight.CfnDashboard.WaterfallChartOptionsProperty(
                    total_bar_label="totalBarLabel"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__83f1a91b7244b7831b478de44a6d6cb01c27206e29f5768f88284bd10a9ab21d)
                check_type(argname="argument total_bar_label", value=total_bar_label, expected_type=type_hints["total_bar_label"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if total_bar_label is not None:
                self._values["total_bar_label"] = total_bar_label

        @builtins.property
        def total_bar_label(self) -> typing.Optional[builtins.str]:
            '''This option determines the total bar label of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartoptions.html#cfn-quicksight-dashboard-waterfallchartoptions-totalbarlabel
            '''
            result = self._values.get("total_bar_label")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.WaterfallChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "breakdown_items_limit": "breakdownItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class WaterfallChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            breakdown_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a waterfall visual.

            :param breakdown_items_limit: The limit on the number of bar groups that are displayed.
            :param category_sort: The sort configuration of the category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                waterfall_chart_sort_configuration_property = quicksight.CfnDashboard.WaterfallChartSortConfigurationProperty(
                    breakdown_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8d55dfb376fae774c51ae8486cda285719fc93fb8ac18dc30405f86c1a9f5a21)
                check_type(argname="argument breakdown_items_limit", value=breakdown_items_limit, expected_type=type_hints["breakdown_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if breakdown_items_limit is not None:
                self._values["breakdown_items_limit"] = breakdown_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def breakdown_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of bar groups that are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartsortconfiguration.html#cfn-quicksight-dashboard-waterfallchartsortconfiguration-breakdownitemslimit
            '''
            result = self._values.get("breakdown_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartsortconfiguration.html#cfn-quicksight-dashboard-waterfallchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.WaterfallVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class WaterfallVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.WaterfallChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A waterfall chart.

            For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration for a waterfall visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aab4332ec94b68c3229bed0be35e50a8defe85b13beb74e469caf6f98a37c781)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WaterfallChartConfigurationProperty"]]:
            '''The configuration for a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WaterfallChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.WhatIfPointScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={"date": "date", "value": "value"},
    )
    class WhatIfPointScenarioProperty:
        def __init__(self, *, date: builtins.str, value: jsii.Number) -> None:
            '''Provides the forecast to meet the target for a particular date.

            :param date: The date that you need the forecast results for.
            :param value: The target value that you want to meet for the provided date. Default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifpointscenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                what_if_point_scenario_property = quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                    date="date",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d450cff5883e4559c682e32b90005a4e929478190db5fef38b7c43f32c780467)
                check_type(argname="argument date", value=date, expected_type=type_hints["date"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "date": date,
                "value": value,
            }

        @builtins.property
        def date(self) -> builtins.str:
            '''The date that you need the forecast results for.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifpointscenario.html#cfn-quicksight-dashboard-whatifpointscenario-date
            '''
            result = self._values.get("date")
            assert result is not None, "Required property 'date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The target value that you want to meet for the provided date.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifpointscenario.html#cfn-quicksight-dashboard-whatifpointscenario-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WhatIfPointScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.WhatIfRangeScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={
            "end_date": "endDate",
            "start_date": "startDate",
            "value": "value",
        },
    )
    class WhatIfRangeScenarioProperty:
        def __init__(
            self,
            *,
            end_date: builtins.str,
            start_date: builtins.str,
            value: jsii.Number,
        ) -> None:
            '''Provides the forecast to meet the target for a particular date range.

            :param end_date: The end date in the date range that you need the forecast results for.
            :param start_date: The start date in the date range that you need the forecast results for.
            :param value: The target value that you want to meet for the provided date range. Default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifrangescenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                what_if_range_scenario_property = quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                    end_date="endDate",
                    start_date="startDate",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__46bc58f6ee30c901779762ffc386a8ceaf3d3d6554323851ae2a7eaa3eb02963)
                check_type(argname="argument end_date", value=end_date, expected_type=type_hints["end_date"])
                check_type(argname="argument start_date", value=start_date, expected_type=type_hints["start_date"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "end_date": end_date,
                "start_date": start_date,
                "value": value,
            }

        @builtins.property
        def end_date(self) -> builtins.str:
            '''The end date in the date range that you need the forecast results for.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifrangescenario.html#cfn-quicksight-dashboard-whatifrangescenario-enddate
            '''
            result = self._values.get("end_date")
            assert result is not None, "Required property 'end_date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def start_date(self) -> builtins.str:
            '''The start date in the date range that you need the forecast results for.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifrangescenario.html#cfn-quicksight-dashboard-whatifrangescenario-startdate
            '''
            result = self._values.get("start_date")
            assert result is not None, "Required property 'start_date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The target value that you want to meet for the provided date range.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifrangescenario.html#cfn-quicksight-dashboard-whatifrangescenario-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WhatIfRangeScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "size": "size"},
    )
    class WordCloudAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a word cloud.

            :param group_by: The group by field well of a word cloud. Values are grouped by group by fields.
            :param size: The size field well of a word cloud. Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                word_cloud_aggregated_field_wells_property = quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    size=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__79e77d16dd6a4dc68eac07b992f227ec5ff37edeed8ece760ece3c87aa27878f)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if size is not None:
                self._values["size"] = size

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The group by field well of a word cloud.

            Values are grouped by group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudaggregatedfieldwells.html#cfn-quicksight-dashboard-wordcloudaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The size field well of a word cloud.

            Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudaggregatedfieldwells.html#cfn-quicksight-dashboard-wordcloudaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.WordCloudChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
            "word_cloud_options": "wordCloudOptions",
        },
    )
    class WordCloudChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.WordCloudFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.WordCloudSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            word_cloud_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.WordCloudOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a word cloud visual.

            :param category_label_options: The label options (label text, label visibility, and sort icon visibility) for the word cloud category.
            :param field_wells: The field wells of the visual.
            :param sort_configuration: The sort configuration of a word cloud visual.
            :param word_cloud_options: The options for a word cloud visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d18660a6c55f5407acd69f460a89f7eae547013400ae1751fdd008021f68204d)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument word_cloud_options", value=word_cloud_options, expected_type=type_hints["word_cloud_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if word_cloud_options is not None:
                self._values["word_cloud_options"] = word_cloud_options

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) for the word cloud category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html#cfn-quicksight-dashboard-wordcloudchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WordCloudFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html#cfn-quicksight-dashboard-wordcloudchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WordCloudFieldWellsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WordCloudSortConfigurationProperty"]]:
            '''The sort configuration of a word cloud visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html#cfn-quicksight-dashboard-wordcloudchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WordCloudSortConfigurationProperty"]], result)

        @builtins.property
        def word_cloud_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WordCloudOptionsProperty"]]:
            '''The options for a word cloud visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html#cfn-quicksight-dashboard-wordcloudchartconfiguration-wordcloudoptions
            '''
            result = self._values.get("word_cloud_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WordCloudOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.WordCloudFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "word_cloud_aggregated_field_wells": "wordCloudAggregatedFieldWells",
        },
    )
    class WordCloudFieldWellsProperty:
        def __init__(
            self,
            *,
            word_cloud_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.WordCloudAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a word cloud visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param word_cloud_aggregated_field_wells: The aggregated field wells of a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                word_cloud_field_wells_property = quicksight.CfnDashboard.WordCloudFieldWellsProperty(
                    word_cloud_aggregated_field_wells=quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        size=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__993ffd94b28f2b97e5e6ce988e6a60d0df0710996e198b1ef1422a3b551a2dc6)
                check_type(argname="argument word_cloud_aggregated_field_wells", value=word_cloud_aggregated_field_wells, expected_type=type_hints["word_cloud_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if word_cloud_aggregated_field_wells is not None:
                self._values["word_cloud_aggregated_field_wells"] = word_cloud_aggregated_field_wells

        @builtins.property
        def word_cloud_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WordCloudAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudfieldwells.html#cfn-quicksight-dashboard-wordcloudfieldwells-wordcloudaggregatedfieldwells
            '''
            result = self._values.get("word_cloud_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WordCloudAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.WordCloudOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cloud_layout": "cloudLayout",
            "maximum_string_length": "maximumStringLength",
            "word_casing": "wordCasing",
            "word_orientation": "wordOrientation",
            "word_padding": "wordPadding",
            "word_scaling": "wordScaling",
        },
    )
    class WordCloudOptionsProperty:
        def __init__(
            self,
            *,
            cloud_layout: typing.Optional[builtins.str] = None,
            maximum_string_length: typing.Optional[jsii.Number] = None,
            word_casing: typing.Optional[builtins.str] = None,
            word_orientation: typing.Optional[builtins.str] = None,
            word_padding: typing.Optional[builtins.str] = None,
            word_scaling: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The word cloud options for a word cloud visual.

            :param cloud_layout: The cloud layout options (fluid, normal) of a word cloud.
            :param maximum_string_length: The length limit of each word from 1-100.
            :param word_casing: The word casing options (lower_case, existing_case) for the words in a word cloud.
            :param word_orientation: The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.
            :param word_padding: The word padding options (none, small, medium, large) for the words in a word cloud.
            :param word_scaling: The word scaling options (emphasize, normal) for the words in a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                word_cloud_options_property = quicksight.CfnDashboard.WordCloudOptionsProperty(
                    cloud_layout="cloudLayout",
                    maximum_string_length=123,
                    word_casing="wordCasing",
                    word_orientation="wordOrientation",
                    word_padding="wordPadding",
                    word_scaling="wordScaling"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3de2ee4c24514cef4d4c9febe81b96f78843d3a88347340d5f97dd1e88964130)
                check_type(argname="argument cloud_layout", value=cloud_layout, expected_type=type_hints["cloud_layout"])
                check_type(argname="argument maximum_string_length", value=maximum_string_length, expected_type=type_hints["maximum_string_length"])
                check_type(argname="argument word_casing", value=word_casing, expected_type=type_hints["word_casing"])
                check_type(argname="argument word_orientation", value=word_orientation, expected_type=type_hints["word_orientation"])
                check_type(argname="argument word_padding", value=word_padding, expected_type=type_hints["word_padding"])
                check_type(argname="argument word_scaling", value=word_scaling, expected_type=type_hints["word_scaling"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cloud_layout is not None:
                self._values["cloud_layout"] = cloud_layout
            if maximum_string_length is not None:
                self._values["maximum_string_length"] = maximum_string_length
            if word_casing is not None:
                self._values["word_casing"] = word_casing
            if word_orientation is not None:
                self._values["word_orientation"] = word_orientation
            if word_padding is not None:
                self._values["word_padding"] = word_padding
            if word_scaling is not None:
                self._values["word_scaling"] = word_scaling

        @builtins.property
        def cloud_layout(self) -> typing.Optional[builtins.str]:
            '''The cloud layout options (fluid, normal) of a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-cloudlayout
            '''
            result = self._values.get("cloud_layout")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def maximum_string_length(self) -> typing.Optional[jsii.Number]:
            '''The length limit of each word from 1-100.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-maximumstringlength
            '''
            result = self._values.get("maximum_string_length")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def word_casing(self) -> typing.Optional[builtins.str]:
            '''The word casing options (lower_case, existing_case) for the words in a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-wordcasing
            '''
            result = self._values.get("word_casing")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_orientation(self) -> typing.Optional[builtins.str]:
            '''The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-wordorientation
            '''
            result = self._values.get("word_orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_padding(self) -> typing.Optional[builtins.str]:
            '''The word padding options (none, small, medium, large) for the words in a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-wordpadding
            '''
            result = self._values.get("word_padding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_scaling(self) -> typing.Optional[builtins.str]:
            '''The word scaling options (emphasize, normal) for the words in a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-wordscaling
            '''
            result = self._values.get("word_scaling")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.WordCloudSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class WordCloudSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a word cloud visual.

            :param category_items_limit: The limit on the number of groups that are displayed in a word cloud.
            :param category_sort: The sort configuration of group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                word_cloud_sort_configuration_property = quicksight.CfnDashboard.WordCloudSortConfigurationProperty(
                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnDashboard.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4d7858c0cd2937d4ef09cf5618dae906097d90d87f0357b28790183303e3f675)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of groups that are displayed in a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudsortconfiguration.html#cfn-quicksight-dashboard-wordcloudsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudsortconfiguration.html#cfn-quicksight-dashboard-wordcloudsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboard.WordCloudVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class WordCloudVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.WordCloudChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A word cloud.

            For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7a1870e6ad824dc17b4907d57e71b903f2d02b7a13c0351e5de4340d15c08a59)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WordCloudChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.WordCloudChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="aws-cdk-lib.aws_quicksight.CfnDashboardProps",
    jsii_struct_bases=[],
    name_mapping={
        "aws_account_id": "awsAccountId",
        "dashboard_id": "dashboardId",
        "name": "name",
        "dashboard_publish_options": "dashboardPublishOptions",
        "definition": "definition",
        "link_sharing_configuration": "linkSharingConfiguration",
        "parameters": "parameters",
        "permissions": "permissions",
        "source_entity": "sourceEntity",
        "tags": "tags",
        "theme_arn": "themeArn",
        "validation_strategy": "validationStrategy",
        "version_description": "versionDescription",
    },
)
class CfnDashboardProps:
    def __init__(
        self,
        *,
        aws_account_id: builtins.str,
        dashboard_id: builtins.str,
        name: builtins.str,
        dashboard_publish_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DashboardPublishOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        definition: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DashboardVersionDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        link_sharing_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LinkSharingConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        source_entity: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DashboardSourceEntityProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
        theme_arn: typing.Optional[builtins.str] = None,
        validation_strategy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ValidationStrategyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        version_description: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Properties for defining a ``CfnDashboard``.

        :param aws_account_id: The ID of the AWS account where you want to create the dashboard.
        :param dashboard_id: The ID for the dashboard, also added to the IAM policy.
        :param name: The display name of the dashboard.
        :param dashboard_publish_options: Options for publishing the dashboard when you create it:. - ``AvailabilityStatus`` for ``AdHocFilteringOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . When this is set to ``DISABLED`` , Amazon QuickSight disables the left filter pane on the published dashboard, which can be used for ad hoc (one-time) filtering. This option is ``ENABLED`` by default. - ``AvailabilityStatus`` for ``ExportToCSVOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . The visual option to export data to .CSV format isn't enabled when this is set to ``DISABLED`` . This option is ``ENABLED`` by default. - ``VisibilityState`` for ``SheetControlsOption`` - This visibility state can be either ``COLLAPSED`` or ``EXPANDED`` . This option is ``COLLAPSED`` by default.
        :param definition: 
        :param link_sharing_configuration: A structure that contains the link sharing configurations that you want to apply overrides to.
        :param parameters: The parameters for the creation of the dashboard, which you want to use to override the default settings. A dashboard can have any type of parameters, and some parameters might accept multiple values.
        :param permissions: A structure that contains the permissions of the dashboard. You can use this structure for granting permissions by providing a list of IAM action information for each principal ARN. To specify no permissions, omit the permissions list.
        :param source_entity: The entity that you are using as a source when you create the dashboard. In ``SourceEntity`` , you specify the type of object that you want to use. You can only create a dashboard from a template, so you use a ``SourceTemplate`` entity. If you need to create a dashboard from an analysis, first convert the analysis to a template by using the ``CreateTemplate`` API operation. For ``SourceTemplate`` , specify the Amazon Resource Name (ARN) of the source template. The ``SourceTemplate`` ARN can contain any AWS account; and any QuickSight-supported AWS Region . Use the ``DataSetReferences`` entity within ``SourceTemplate`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the dashboard.
        :param theme_arn: The Amazon Resource Name (ARN) of the theme that is being used for this dashboard. If you add a value for this field, it overrides the value that is used in the source entity. The theme ARN must exist in the same AWS account where you create the dashboard.
        :param validation_strategy: The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects. When you set this value to ``LENIENT`` , validation is skipped for specific errors.
        :param version_description: A description for the first version of the dashboard being created.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html
        :exampleMetadata: fixture=_generated

        Example::

            
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b83b0d20e5f4dc99e603d3a3d5cffb1cc46142034276d5f015ae3ed7f334ead3)
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument dashboard_id", value=dashboard_id, expected_type=type_hints["dashboard_id"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument dashboard_publish_options", value=dashboard_publish_options, expected_type=type_hints["dashboard_publish_options"])
            check_type(argname="argument definition", value=definition, expected_type=type_hints["definition"])
            check_type(argname="argument link_sharing_configuration", value=link_sharing_configuration, expected_type=type_hints["link_sharing_configuration"])
            check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
            check_type(argname="argument permissions", value=permissions, expected_type=type_hints["permissions"])
            check_type(argname="argument source_entity", value=source_entity, expected_type=type_hints["source_entity"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument theme_arn", value=theme_arn, expected_type=type_hints["theme_arn"])
            check_type(argname="argument validation_strategy", value=validation_strategy, expected_type=type_hints["validation_strategy"])
            check_type(argname="argument version_description", value=version_description, expected_type=type_hints["version_description"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aws_account_id": aws_account_id,
            "dashboard_id": dashboard_id,
            "name": name,
        }
        if dashboard_publish_options is not None:
            self._values["dashboard_publish_options"] = dashboard_publish_options
        if definition is not None:
            self._values["definition"] = definition
        if link_sharing_configuration is not None:
            self._values["link_sharing_configuration"] = link_sharing_configuration
        if parameters is not None:
            self._values["parameters"] = parameters
        if permissions is not None:
            self._values["permissions"] = permissions
        if source_entity is not None:
            self._values["source_entity"] = source_entity
        if tags is not None:
            self._values["tags"] = tags
        if theme_arn is not None:
            self._values["theme_arn"] = theme_arn
        if validation_strategy is not None:
            self._values["validation_strategy"] = validation_strategy
        if version_description is not None:
            self._values["version_description"] = version_description

    @builtins.property
    def aws_account_id(self) -> builtins.str:
        '''The ID of the AWS account where you want to create the dashboard.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        assert result is not None, "Required property 'aws_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def dashboard_id(self) -> builtins.str:
        '''The ID for the dashboard, also added to the IAM policy.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-dashboardid
        '''
        result = self._values.get("dashboard_id")
        assert result is not None, "Required property 'dashboard_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The display name of the dashboard.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-name
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def dashboard_publish_options(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDashboard.DashboardPublishOptionsProperty]]:
        '''Options for publishing the dashboard when you create it:.

        - ``AvailabilityStatus`` for ``AdHocFilteringOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . When this is set to ``DISABLED`` , Amazon QuickSight disables the left filter pane on the published dashboard, which can be used for ad hoc (one-time) filtering. This option is ``ENABLED`` by default.
        - ``AvailabilityStatus`` for ``ExportToCSVOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . The visual option to export data to .CSV format isn't enabled when this is set to ``DISABLED`` . This option is ``ENABLED`` by default.
        - ``VisibilityState`` for ``SheetControlsOption`` - This visibility state can be either ``COLLAPSED`` or ``EXPANDED`` . This option is ``COLLAPSED`` by default.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-dashboardpublishoptions
        '''
        result = self._values.get("dashboard_publish_options")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDashboard.DashboardPublishOptionsProperty]], result)

    @builtins.property
    def definition(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDashboard.DashboardVersionDefinitionProperty]]:
        '''
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-definition
        '''
        result = self._values.get("definition")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDashboard.DashboardVersionDefinitionProperty]], result)

    @builtins.property
    def link_sharing_configuration(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDashboard.LinkSharingConfigurationProperty]]:
        '''A structure that contains the link sharing configurations that you want to apply overrides to.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-linksharingconfiguration
        '''
        result = self._values.get("link_sharing_configuration")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDashboard.LinkSharingConfigurationProperty]], result)

    @builtins.property
    def parameters(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDashboard.ParametersProperty]]:
        '''The parameters for the creation of the dashboard, which you want to use to override the default settings.

        A dashboard can have any type of parameters, and some parameters might accept multiple values.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-parameters
        '''
        result = self._values.get("parameters")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDashboard.ParametersProperty]], result)

    @builtins.property
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnDashboard.ResourcePermissionProperty]]]]:
        '''A structure that contains the permissions of the dashboard.

        You can use this structure for granting permissions by providing a list of IAM action information for each principal ARN.

        To specify no permissions, omit the permissions list.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-permissions
        '''
        result = self._values.get("permissions")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnDashboard.ResourcePermissionProperty]]]], result)

    @builtins.property
    def source_entity(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDashboard.DashboardSourceEntityProperty]]:
        '''The entity that you are using as a source when you create the dashboard.

        In ``SourceEntity`` , you specify the type of object that you want to use. You can only create a dashboard from a template, so you use a ``SourceTemplate`` entity. If you need to create a dashboard from an analysis, first convert the analysis to a template by using the ``CreateTemplate`` API operation. For ``SourceTemplate`` , specify the Amazon Resource Name (ARN) of the source template. The ``SourceTemplate`` ARN can contain any AWS account; and any QuickSight-supported AWS Region .

        Use the ``DataSetReferences`` entity within ``SourceTemplate`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-sourceentity
        '''
        result = self._values.get("source_entity")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDashboard.DashboardSourceEntityProperty]], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[_CfnTag_f6864754]]:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the dashboard.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-tags
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[_CfnTag_f6864754]], result)

    @builtins.property
    def theme_arn(self) -> typing.Optional[builtins.str]:
        '''The Amazon Resource Name (ARN) of the theme that is being used for this dashboard.

        If you add a value for this field, it overrides the value that is used in the source entity. The theme ARN must exist in the same AWS account where you create the dashboard.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-themearn
        '''
        result = self._values.get("theme_arn")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def validation_strategy(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDashboard.ValidationStrategyProperty]]:
        '''The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects.

        When you set this value to ``LENIENT`` , validation is skipped for specific errors.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-validationstrategy
        '''
        result = self._values.get("validation_strategy")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDashboard.ValidationStrategyProperty]], result)

    @builtins.property
    def version_description(self) -> typing.Optional[builtins.str]:
        '''A description for the first version of the dashboard being created.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-versiondescription
        '''
        result = self._values.get("version_description")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnDashboardProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_IInspectable_c2943556, _ITaggable_36806126)
class CfnDataSet(
    _CfnResource_9df397a6,
    metaclass=jsii.JSIIMeta,
    jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet",
):
    '''Creates a dataset.

    This operation doesn't support datasets that include uploaded files as a source.

    :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html
    :cloudformationResource: AWS::QuickSight::DataSet
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        from aws_cdk import aws_quicksight as quicksight
        
        # tag_rule_configurations: Any
        
        cfn_data_set = quicksight.CfnDataSet(self, "MyCfnDataSet",
            aws_account_id="awsAccountId",
            column_groups=[quicksight.CfnDataSet.ColumnGroupProperty(
                geo_spatial_column_group=quicksight.CfnDataSet.GeoSpatialColumnGroupProperty(
                    columns=["columns"],
                    name="name",
        
                    # the properties below are optional
                    country_code="countryCode"
                )
            )],
            column_level_permission_rules=[quicksight.CfnDataSet.ColumnLevelPermissionRuleProperty(
                column_names=["columnNames"],
                principals=["principals"]
            )],
            data_set_id="dataSetId",
            dataset_parameters=[quicksight.CfnDataSet.DatasetParameterProperty(
                date_time_dataset_parameter=quicksight.CfnDataSet.DateTimeDatasetParameterProperty(
                    id="id",
                    name="name",
                    value_type="valueType",
        
                    # the properties below are optional
                    default_values=quicksight.CfnDataSet.DateTimeDatasetParameterDefaultValuesProperty(
                        static_values=["staticValues"]
                    ),
                    time_granularity="timeGranularity"
                ),
                decimal_dataset_parameter=quicksight.CfnDataSet.DecimalDatasetParameterProperty(
                    id="id",
                    name="name",
                    value_type="valueType",
        
                    # the properties below are optional
                    default_values=quicksight.CfnDataSet.DecimalDatasetParameterDefaultValuesProperty(
                        static_values=[123]
                    )
                ),
                integer_dataset_parameter=quicksight.CfnDataSet.IntegerDatasetParameterProperty(
                    id="id",
                    name="name",
                    value_type="valueType",
        
                    # the properties below are optional
                    default_values=quicksight.CfnDataSet.IntegerDatasetParameterDefaultValuesProperty(
                        static_values=[123]
                    )
                ),
                string_dataset_parameter=quicksight.CfnDataSet.StringDatasetParameterProperty(
                    id="id",
                    name="name",
                    value_type="valueType",
        
                    # the properties below are optional
                    default_values=quicksight.CfnDataSet.StringDatasetParameterDefaultValuesProperty(
                        static_values=["staticValues"]
                    )
                )
            )],
            data_set_refresh_properties=quicksight.CfnDataSet.DataSetRefreshPropertiesProperty(
                refresh_configuration=quicksight.CfnDataSet.RefreshConfigurationProperty(
                    incremental_refresh=quicksight.CfnDataSet.IncrementalRefreshProperty(
                        lookback_window=quicksight.CfnDataSet.LookbackWindowProperty(
                            column_name="columnName",
                            size=123,
                            size_unit="sizeUnit"
                        )
                    )
                )
            ),
            data_set_usage_configuration=quicksight.CfnDataSet.DataSetUsageConfigurationProperty(
                disable_use_as_direct_query_source=False,
                disable_use_as_imported_source=False
            ),
            field_folders={
                "field_folders_key": quicksight.CfnDataSet.FieldFolderProperty(
                    columns=["columns"],
                    description="description"
                )
            },
            import_mode="importMode",
            ingestion_wait_policy=quicksight.CfnDataSet.IngestionWaitPolicyProperty(
                ingestion_wait_time_in_hours=123,
                wait_for_spice_ingestion=False
            ),
            logical_table_map={
                "logical_table_map_key": quicksight.CfnDataSet.LogicalTableProperty(
                    alias="alias",
                    source=quicksight.CfnDataSet.LogicalTableSourceProperty(
                        data_set_arn="dataSetArn",
                        join_instruction=quicksight.CfnDataSet.JoinInstructionProperty(
                            left_operand="leftOperand",
                            on_clause="onClause",
                            right_operand="rightOperand",
                            type="type",
        
                            # the properties below are optional
                            left_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                                unique_key=False
                            ),
                            right_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                                unique_key=False
                            )
                        ),
                        physical_table_id="physicalTableId"
                    ),
        
                    # the properties below are optional
                    data_transforms=[quicksight.CfnDataSet.TransformOperationProperty(
                        cast_column_type_operation=quicksight.CfnDataSet.CastColumnTypeOperationProperty(
                            column_name="columnName",
                            new_column_type="newColumnType",
        
                            # the properties below are optional
                            format="format",
                            sub_type="subType"
                        ),
                        create_columns_operation=quicksight.CfnDataSet.CreateColumnsOperationProperty(
                            columns=[quicksight.CfnDataSet.CalculatedColumnProperty(
                                column_id="columnId",
                                column_name="columnName",
                                expression="expression"
                            )]
                        ),
                        filter_operation=quicksight.CfnDataSet.FilterOperationProperty(
                            condition_expression="conditionExpression"
                        ),
                        override_dataset_parameter_operation=quicksight.CfnDataSet.OverrideDatasetParameterOperationProperty(
                            parameter_name="parameterName",
        
                            # the properties below are optional
                            new_default_values=quicksight.CfnDataSet.NewDefaultValuesProperty(
                                date_time_static_values=["dateTimeStaticValues"],
                                decimal_static_values=[123],
                                integer_static_values=[123],
                                string_static_values=["stringStaticValues"]
                            ),
                            new_parameter_name="newParameterName"
                        ),
                        project_operation=quicksight.CfnDataSet.ProjectOperationProperty(
                            projected_columns=["projectedColumns"]
                        ),
                        rename_column_operation=quicksight.CfnDataSet.RenameColumnOperationProperty(
                            column_name="columnName",
                            new_column_name="newColumnName"
                        ),
                        tag_column_operation=quicksight.CfnDataSet.TagColumnOperationProperty(
                            column_name="columnName",
                            tags=[quicksight.CfnDataSet.ColumnTagProperty(
                                column_description=quicksight.CfnDataSet.ColumnDescriptionProperty(
                                    text="text"
                                ),
                                column_geographic_role="columnGeographicRole"
                            )]
                        )
                    )]
                )
            },
            name="name",
            permissions=[quicksight.CfnDataSet.ResourcePermissionProperty(
                actions=["actions"],
                principal="principal"
            )],
            physical_table_map={
                "physical_table_map_key": quicksight.CfnDataSet.PhysicalTableProperty(
                    custom_sql=quicksight.CfnDataSet.CustomSqlProperty(
                        columns=[quicksight.CfnDataSet.InputColumnProperty(
                            name="name",
                            type="type",
        
                            # the properties below are optional
                            sub_type="subType"
                        )],
                        data_source_arn="dataSourceArn",
                        name="name",
                        sql_query="sqlQuery"
                    ),
                    relational_table=quicksight.CfnDataSet.RelationalTableProperty(
                        data_source_arn="dataSourceArn",
                        input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                            name="name",
                            type="type",
        
                            # the properties below are optional
                            sub_type="subType"
                        )],
                        name="name",
        
                        # the properties below are optional
                        catalog="catalog",
                        schema="schema"
                    ),
                    s3_source=quicksight.CfnDataSet.S3SourceProperty(
                        data_source_arn="dataSourceArn",
                        input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                            name="name",
                            type="type",
        
                            # the properties below are optional
                            sub_type="subType"
                        )],
        
                        # the properties below are optional
                        upload_settings=quicksight.CfnDataSet.UploadSettingsProperty(
                            contains_header=False,
                            delimiter="delimiter",
                            format="format",
                            start_from_row=123,
                            text_qualifier="textQualifier"
                        )
                    )
                )
            },
            row_level_permission_data_set=quicksight.CfnDataSet.RowLevelPermissionDataSetProperty(
                arn="arn",
                permission_policy="permissionPolicy",
        
                # the properties below are optional
                format_version="formatVersion",
                namespace="namespace",
                status="status"
            ),
            row_level_permission_tag_configuration=quicksight.CfnDataSet.RowLevelPermissionTagConfigurationProperty(
                tag_rules=[quicksight.CfnDataSet.RowLevelPermissionTagRuleProperty(
                    column_name="columnName",
                    tag_key="tagKey",
        
                    # the properties below are optional
                    match_all_value="matchAllValue",
                    tag_multi_value_delimiter="tagMultiValueDelimiter"
                )],
        
                # the properties below are optional
                status="status",
                tag_rule_configurations=tag_rule_configurations
            ),
            tags=[CfnTag(
                key="key",
                value="value"
            )]
        )
    '''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.Construct,
        id: builtins.str,
        *,
        aws_account_id: typing.Optional[builtins.str] = None,
        column_groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.ColumnGroupProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        column_level_permission_rules: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.ColumnLevelPermissionRuleProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        data_set_id: typing.Optional[builtins.str] = None,
        dataset_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.DatasetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        data_set_refresh_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.DataSetRefreshPropertiesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        data_set_usage_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.DataSetUsageConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        field_folders: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.FieldFolderProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        import_mode: typing.Optional[builtins.str] = None,
        ingestion_wait_policy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.IngestionWaitPolicyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        logical_table_map: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.LogicalTableProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.ResourcePermissionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        physical_table_map: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.PhysicalTableProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        row_level_permission_data_set: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.RowLevelPermissionDataSetProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        row_level_permission_tag_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.RowLevelPermissionTagConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
    ) -> None:
        '''
        :param scope: Scope in which this resource is defined.
        :param id: Construct identifier for this resource (unique in its scope).
        :param aws_account_id: The AWS account ID.
        :param column_groups: Groupings of columns that work together in certain Amazon QuickSight features. Currently, only geospatial hierarchy is supported.
        :param column_level_permission_rules: A set of one or more definitions of a ``ColumnLevelPermissionRule`` .
        :param data_set_id: An ID for the dataset that you want to create. This ID is unique per AWS Region for each AWS account.
        :param dataset_parameters: The parameters that are declared in a dataset.
        :param data_set_refresh_properties: The refresh properties of a dataset.
        :param data_set_usage_configuration: The usage configuration to apply to child datasets that reference this dataset as a source.
        :param field_folders: The folder that contains fields and nested subfolders for your dataset.
        :param import_mode: Indicates whether you want to import the data into SPICE.
        :param ingestion_wait_policy: The wait policy to use when creating or updating a Dataset. The default is to wait for SPICE ingestion to finish with timeout of 36 hours.
        :param logical_table_map: Configures the combination and transformation of the data from the physical tables.
        :param name: The display name for the dataset.
        :param permissions: A list of resource permissions on the dataset.
        :param physical_table_map: Declares the physical tables that are available in the underlying data sources.
        :param row_level_permission_data_set: The row-level security configuration for the data that you want to create.
        :param row_level_permission_tag_configuration: The element you can use to define tags for row-level security.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72d075b7003c65fe0f5754c362b528fce8eccbf0c8bca521f7a3200fbe0f67f5)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnDataSetProps(
            aws_account_id=aws_account_id,
            column_groups=column_groups,
            column_level_permission_rules=column_level_permission_rules,
            data_set_id=data_set_id,
            dataset_parameters=dataset_parameters,
            data_set_refresh_properties=data_set_refresh_properties,
            data_set_usage_configuration=data_set_usage_configuration,
            field_folders=field_folders,
            import_mode=import_mode,
            ingestion_wait_policy=ingestion_wait_policy,
            logical_table_map=logical_table_map,
            name=name,
            permissions=permissions,
            physical_table_map=physical_table_map,
            row_level_permission_data_set=row_level_permission_data_set,
            row_level_permission_tag_configuration=row_level_permission_tag_configuration,
            tags=tags,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _TreeInspector_488e0dd5) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec5ac6f5f08d1896a0e729a544f16b9dd14b6ca545e08c0ed29f38402c3ea53c)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5aabb7b753ce9305d116e2ef3c8cfeabdc2a4633bf23b84eeed79bc90969ab0e)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) of the dataset.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="attrConsumedSpiceCapacityInBytes")
    def attr_consumed_spice_capacity_in_bytes(self) -> _IResolvable_da3f097b:
        '''
        This is 0 if the dataset isn't
        imported into SPICE.

        :cloudformationAttribute: ConsumedSpiceCapacityInBytes
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrConsumedSpiceCapacityInBytes"))

    @builtins.property
    @jsii.member(jsii_name="attrCreatedTime")
    def attr_created_time(self) -> builtins.str:
        '''The time this dataset version was created.

        :cloudformationAttribute: CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrLastUpdatedTime")
    def attr_last_updated_time(self) -> builtins.str:
        '''The time this dataset version was last updated.

        :cloudformationAttribute: LastUpdatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastUpdatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrOutputColumns")
    def attr_output_columns(self) -> _IResolvable_da3f097b:
        '''
        These columns are available in templates,
        analyses, and dashboards.

        :cloudformationAttribute: OutputColumns
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrOutputColumns"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> _TagManager_0a598cb3:
        '''Tag Manager which manages the tags for this resource.'''
        return typing.cast(_TagManager_0a598cb3, jsii.get(self, "tags"))

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2aca042c4006d0815bbe3f37fabf0c6c4a17108a63b68bf2c62d9d0bb69c6d8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="columnGroups")
    def column_groups(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.ColumnGroupProperty"]]]]:
        '''Groupings of columns that work together in certain Amazon QuickSight features.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.ColumnGroupProperty"]]]], jsii.get(self, "columnGroups"))

    @column_groups.setter
    def column_groups(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.ColumnGroupProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bfc1b3a06d0828187a15e4f2444856f0d38ece159fc7179e0bdc666fa156231d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "columnGroups", value)

    @builtins.property
    @jsii.member(jsii_name="columnLevelPermissionRules")
    def column_level_permission_rules(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.ColumnLevelPermissionRuleProperty"]]]]:
        '''A set of one or more definitions of a ``ColumnLevelPermissionRule`` .'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.ColumnLevelPermissionRuleProperty"]]]], jsii.get(self, "columnLevelPermissionRules"))

    @column_level_permission_rules.setter
    def column_level_permission_rules(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.ColumnLevelPermissionRuleProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ade1676b50bbf68ddcdc602d5e40307a31f3822c63e277a8cf478e2c5872640)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "columnLevelPermissionRules", value)

    @builtins.property
    @jsii.member(jsii_name="dataSetId")
    def data_set_id(self) -> typing.Optional[builtins.str]:
        '''An ID for the dataset that you want to create.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSetId"))

    @data_set_id.setter
    def data_set_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__057a8daa561746a60e341f0a5ece96f4eca188303835b43304bb19fce6aec643)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSetId", value)

    @builtins.property
    @jsii.member(jsii_name="datasetParameters")
    def dataset_parameters(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.DatasetParameterProperty"]]]]:
        '''The parameters that are declared in a dataset.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.DatasetParameterProperty"]]]], jsii.get(self, "datasetParameters"))

    @dataset_parameters.setter
    def dataset_parameters(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.DatasetParameterProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a893621de91975c4909cf8242c00f4482f5c447cdd22eb27c686ac2fb4b69464)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "datasetParameters", value)

    @builtins.property
    @jsii.member(jsii_name="dataSetRefreshProperties")
    def data_set_refresh_properties(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.DataSetRefreshPropertiesProperty"]]:
        '''The refresh properties of a dataset.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.DataSetRefreshPropertiesProperty"]], jsii.get(self, "dataSetRefreshProperties"))

    @data_set_refresh_properties.setter
    def data_set_refresh_properties(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.DataSetRefreshPropertiesProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ed4af1aba9ebff3fbb06e99636946af8c88ed6fe7c6a450684d9b4b6c14a5ab)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSetRefreshProperties", value)

    @builtins.property
    @jsii.member(jsii_name="dataSetUsageConfiguration")
    def data_set_usage_configuration(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.DataSetUsageConfigurationProperty"]]:
        '''The usage configuration to apply to child datasets that reference this dataset as a source.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.DataSetUsageConfigurationProperty"]], jsii.get(self, "dataSetUsageConfiguration"))

    @data_set_usage_configuration.setter
    def data_set_usage_configuration(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.DataSetUsageConfigurationProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bf3408380f9b3ee1c1ea22fb4f4a824ff5f9de5a846e28e604c80597826c5806)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSetUsageConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="fieldFolders")
    def field_folders(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, "CfnDataSet.FieldFolderProperty"]]]]:
        '''The folder that contains fields and nested subfolders for your dataset.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, "CfnDataSet.FieldFolderProperty"]]]], jsii.get(self, "fieldFolders"))

    @field_folders.setter
    def field_folders(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, "CfnDataSet.FieldFolderProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__376e551a3e7551cc01277dd007428ce4ffd31dd297b01d97d2e891fc2e9be07f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "fieldFolders", value)

    @builtins.property
    @jsii.member(jsii_name="importMode")
    def import_mode(self) -> typing.Optional[builtins.str]:
        '''Indicates whether you want to import the data into SPICE.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "importMode"))

    @import_mode.setter
    def import_mode(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2d4f671f44dcd084b30794fd761c8eac3c1b00283622fa5674fdf0e00f49832)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "importMode", value)

    @builtins.property
    @jsii.member(jsii_name="ingestionWaitPolicy")
    def ingestion_wait_policy(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.IngestionWaitPolicyProperty"]]:
        '''The wait policy to use when creating or updating a Dataset.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.IngestionWaitPolicyProperty"]], jsii.get(self, "ingestionWaitPolicy"))

    @ingestion_wait_policy.setter
    def ingestion_wait_policy(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.IngestionWaitPolicyProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__78487a367319f7d35b3fb5065e030e5843500f800bfe4b40f1ac2ad6fb9140cd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "ingestionWaitPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="logicalTableMap")
    def logical_table_map(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, "CfnDataSet.LogicalTableProperty"]]]]:
        '''Configures the combination and transformation of the data from the physical tables.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, "CfnDataSet.LogicalTableProperty"]]]], jsii.get(self, "logicalTableMap"))

    @logical_table_map.setter
    def logical_table_map(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, "CfnDataSet.LogicalTableProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74c2bc6065a9fbf14a6895d8ade28cdfd09ca0b45c8a7d9736168fac1cfcf726)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "logicalTableMap", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        '''The display name for the dataset.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "name"))

    @name.setter
    def name(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ea6faccf86873209626a4e60dd29bcaad05116e37856cb62be693bbdac8407af)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.ResourcePermissionProperty"]]]]:
        '''A list of resource permissions on the dataset.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.ResourcePermissionProperty"]]]], jsii.get(self, "permissions"))

    @permissions.setter
    def permissions(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.ResourcePermissionProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e96079d694dd059bb9a8c40170f70894c1f86392667641611d31edf7787111a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "permissions", value)

    @builtins.property
    @jsii.member(jsii_name="physicalTableMap")
    def physical_table_map(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, "CfnDataSet.PhysicalTableProperty"]]]]:
        '''Declares the physical tables that are available in the underlying data sources.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, "CfnDataSet.PhysicalTableProperty"]]]], jsii.get(self, "physicalTableMap"))

    @physical_table_map.setter
    def physical_table_map(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, "CfnDataSet.PhysicalTableProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__209e835d9289f136344058e886fce3fcdedbaa0f7384ae32dbf6f9cad4559b54)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "physicalTableMap", value)

    @builtins.property
    @jsii.member(jsii_name="rowLevelPermissionDataSet")
    def row_level_permission_data_set(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.RowLevelPermissionDataSetProperty"]]:
        '''The row-level security configuration for the data that you want to create.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.RowLevelPermissionDataSetProperty"]], jsii.get(self, "rowLevelPermissionDataSet"))

    @row_level_permission_data_set.setter
    def row_level_permission_data_set(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.RowLevelPermissionDataSetProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43d473d210e7648e9c1f74143bdd02ab2782474ae542ae1332653506abca38f2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "rowLevelPermissionDataSet", value)

    @builtins.property
    @jsii.member(jsii_name="rowLevelPermissionTagConfiguration")
    def row_level_permission_tag_configuration(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.RowLevelPermissionTagConfigurationProperty"]]:
        '''The element you can use to define tags for row-level security.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.RowLevelPermissionTagConfigurationProperty"]], jsii.get(self, "rowLevelPermissionTagConfiguration"))

    @row_level_permission_tag_configuration.setter
    def row_level_permission_tag_configuration(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.RowLevelPermissionTagConfigurationProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8bc00e5cb53b8e610ea4e4002e1ad1d313e453c8dd37779836bbe1c1d3e3be03)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "rowLevelPermissionTagConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="tagsRaw")
    def tags_raw(self) -> typing.Optional[typing.List[_CfnTag_f6864754]]:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset.'''
        return typing.cast(typing.Optional[typing.List[_CfnTag_f6864754]], jsii.get(self, "tagsRaw"))

    @tags_raw.setter
    def tags_raw(self, value: typing.Optional[typing.List[_CfnTag_f6864754]]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0e864069859eae5b6577c26a255c633579a87c4792fb22892d990896aff4b48d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tagsRaw", value)

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.CalculatedColumnProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_id": "columnId",
            "column_name": "columnName",
            "expression": "expression",
        },
    )
    class CalculatedColumnProperty:
        def __init__(
            self,
            *,
            column_id: builtins.str,
            column_name: builtins.str,
            expression: builtins.str,
        ) -> None:
            '''A calculated column for a dataset.

            :param column_id: A unique ID to identify a calculated column. During a dataset update, if the column ID of a calculated column matches that of an existing calculated column, Amazon QuickSight preserves the existing calculated column.
            :param column_name: Column name.
            :param expression: An expression that defines the calculated column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-calculatedcolumn.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                calculated_column_property = quicksight.CfnDataSet.CalculatedColumnProperty(
                    column_id="columnId",
                    column_name="columnName",
                    expression="expression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c1231ad01a76710b79ae378de78ccc76bb05c75d0f0df4211be06aa6a0b32293)
                check_type(argname="argument column_id", value=column_id, expected_type=type_hints["column_id"])
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_id": column_id,
                "column_name": column_name,
                "expression": expression,
            }

        @builtins.property
        def column_id(self) -> builtins.str:
            '''A unique ID to identify a calculated column.

            During a dataset update, if the column ID of a calculated column matches that of an existing calculated column, Amazon QuickSight preserves the existing calculated column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-calculatedcolumn.html#cfn-quicksight-dataset-calculatedcolumn-columnid
            '''
            result = self._values.get("column_id")
            assert result is not None, "Required property 'column_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def column_name(self) -> builtins.str:
            '''Column name.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-calculatedcolumn.html#cfn-quicksight-dataset-calculatedcolumn-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''An expression that defines the calculated column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-calculatedcolumn.html#cfn-quicksight-dataset-calculatedcolumn-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CalculatedColumnProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.CastColumnTypeOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_name": "columnName",
            "new_column_type": "newColumnType",
            "format": "format",
            "sub_type": "subType",
        },
    )
    class CastColumnTypeOperationProperty:
        def __init__(
            self,
            *,
            column_name: builtins.str,
            new_column_type: builtins.str,
            format: typing.Optional[builtins.str] = None,
            sub_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A transform operation that casts a column to a different type.

            :param column_name: Column name.
            :param new_column_type: New column data type.
            :param format: When casting a column from string to datetime type, you can supply a string in a format supported by Amazon QuickSight to denote the source data format.
            :param sub_type: The sub data type of the new column. Sub types are only available for decimal columns that are part of a SPICE dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                cast_column_type_operation_property = quicksight.CfnDataSet.CastColumnTypeOperationProperty(
                    column_name="columnName",
                    new_column_type="newColumnType",
                
                    # the properties below are optional
                    format="format",
                    sub_type="subType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e2fded724bbc6640c2fbe9fe33aee3a869a672cc8cfd40186128cdc1c929ffb6)
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument new_column_type", value=new_column_type, expected_type=type_hints["new_column_type"])
                check_type(argname="argument format", value=format, expected_type=type_hints["format"])
                check_type(argname="argument sub_type", value=sub_type, expected_type=type_hints["sub_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_name": column_name,
                "new_column_type": new_column_type,
            }
            if format is not None:
                self._values["format"] = format
            if sub_type is not None:
                self._values["sub_type"] = sub_type

        @builtins.property
        def column_name(self) -> builtins.str:
            '''Column name.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html#cfn-quicksight-dataset-castcolumntypeoperation-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def new_column_type(self) -> builtins.str:
            '''New column data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html#cfn-quicksight-dataset-castcolumntypeoperation-newcolumntype
            '''
            result = self._values.get("new_column_type")
            assert result is not None, "Required property 'new_column_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format(self) -> typing.Optional[builtins.str]:
            '''When casting a column from string to datetime type, you can supply a string in a format supported by Amazon QuickSight to denote the source data format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html#cfn-quicksight-dataset-castcolumntypeoperation-format
            '''
            result = self._values.get("format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sub_type(self) -> typing.Optional[builtins.str]:
            '''The sub data type of the new column.

            Sub types are only available for decimal columns that are part of a SPICE dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html#cfn-quicksight-dataset-castcolumntypeoperation-subtype
            '''
            result = self._values.get("sub_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CastColumnTypeOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.ColumnDescriptionProperty",
        jsii_struct_bases=[],
        name_mapping={"text": "text"},
    )
    class ColumnDescriptionProperty:
        def __init__(self, *, text: typing.Optional[builtins.str] = None) -> None:
            '''Metadata that contains a description for a column.

            :param text: The text of a description for a column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columndescription.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_description_property = quicksight.CfnDataSet.ColumnDescriptionProperty(
                    text="text"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b2759b7d3d1f57d4d62490bc88bd45b76a794157c5475aa21855cd5babb42b5a)
                check_type(argname="argument text", value=text, expected_type=type_hints["text"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if text is not None:
                self._values["text"] = text

        @builtins.property
        def text(self) -> typing.Optional[builtins.str]:
            '''The text of a description for a column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columndescription.html#cfn-quicksight-dataset-columndescription-text
            '''
            result = self._values.get("text")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnDescriptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.ColumnGroupProperty",
        jsii_struct_bases=[],
        name_mapping={"geo_spatial_column_group": "geoSpatialColumnGroup"},
    )
    class ColumnGroupProperty:
        def __init__(
            self,
            *,
            geo_spatial_column_group: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.GeoSpatialColumnGroupProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Groupings of columns that work together in certain Amazon QuickSight features.

            This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

            :param geo_spatial_column_group: Geospatial column group that denotes a hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columngroup.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_group_property = quicksight.CfnDataSet.ColumnGroupProperty(
                    geo_spatial_column_group=quicksight.CfnDataSet.GeoSpatialColumnGroupProperty(
                        columns=["columns"],
                        name="name",
                
                        # the properties below are optional
                        country_code="countryCode"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__73b46bfcd2001ac56263a167bea84d22e838ed2c267d9bf17cf6ef4bbeea2eb1)
                check_type(argname="argument geo_spatial_column_group", value=geo_spatial_column_group, expected_type=type_hints["geo_spatial_column_group"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if geo_spatial_column_group is not None:
                self._values["geo_spatial_column_group"] = geo_spatial_column_group

        @builtins.property
        def geo_spatial_column_group(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.GeoSpatialColumnGroupProperty"]]:
            '''Geospatial column group that denotes a hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columngroup.html#cfn-quicksight-dataset-columngroup-geospatialcolumngroup
            '''
            result = self._values.get("geo_spatial_column_group")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.GeoSpatialColumnGroupProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnGroupProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.ColumnLevelPermissionRuleProperty",
        jsii_struct_bases=[],
        name_mapping={"column_names": "columnNames", "principals": "principals"},
    )
    class ColumnLevelPermissionRuleProperty:
        def __init__(
            self,
            *,
            column_names: typing.Optional[typing.Sequence[builtins.str]] = None,
            principals: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A rule defined to grant access on one or more restricted columns.

            Each dataset can have multiple rules. To create a restricted column, you add it to one or more rules. Each rule must contain at least one column and at least one user or group. To be able to see a restricted column, a user or group needs to be added to a rule for that column.

            :param column_names: An array of column names.
            :param principals: An array of Amazon Resource Names (ARNs) for Amazon QuickSight users or groups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columnlevelpermissionrule.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_level_permission_rule_property = quicksight.CfnDataSet.ColumnLevelPermissionRuleProperty(
                    column_names=["columnNames"],
                    principals=["principals"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6d7c23cfccd7b2f4aa3ff0e3759008536670b1877eb51b3a21d05d689f576e1c)
                check_type(argname="argument column_names", value=column_names, expected_type=type_hints["column_names"])
                check_type(argname="argument principals", value=principals, expected_type=type_hints["principals"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_names is not None:
                self._values["column_names"] = column_names
            if principals is not None:
                self._values["principals"] = principals

        @builtins.property
        def column_names(self) -> typing.Optional[typing.List[builtins.str]]:
            '''An array of column names.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columnlevelpermissionrule.html#cfn-quicksight-dataset-columnlevelpermissionrule-columnnames
            '''
            result = self._values.get("column_names")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def principals(self) -> typing.Optional[typing.List[builtins.str]]:
            '''An array of Amazon Resource Names (ARNs) for Amazon QuickSight users or groups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columnlevelpermissionrule.html#cfn-quicksight-dataset-columnlevelpermissionrule-principals
            '''
            result = self._values.get("principals")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnLevelPermissionRuleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.ColumnTagProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_description": "columnDescription",
            "column_geographic_role": "columnGeographicRole",
        },
    )
    class ColumnTagProperty:
        def __init__(
            self,
            *,
            column_description: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.ColumnDescriptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_geographic_role: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A tag for a column in a ``[TagColumnOperation](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_TagColumnOperation.html)`` structure. This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

            :param column_description: A description for a column.
            :param column_geographic_role: A geospatial role for a column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columntag.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_tag_property = quicksight.CfnDataSet.ColumnTagProperty(
                    column_description=quicksight.CfnDataSet.ColumnDescriptionProperty(
                        text="text"
                    ),
                    column_geographic_role="columnGeographicRole"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8810951f5cd6f00a3afedc51ad0485b75cccc19bb1600c05ce272802125fa30b)
                check_type(argname="argument column_description", value=column_description, expected_type=type_hints["column_description"])
                check_type(argname="argument column_geographic_role", value=column_geographic_role, expected_type=type_hints["column_geographic_role"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_description is not None:
                self._values["column_description"] = column_description
            if column_geographic_role is not None:
                self._values["column_geographic_role"] = column_geographic_role

        @builtins.property
        def column_description(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.ColumnDescriptionProperty"]]:
            '''A description for a column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columntag.html#cfn-quicksight-dataset-columntag-columndescription
            '''
            result = self._values.get("column_description")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.ColumnDescriptionProperty"]], result)

        @builtins.property
        def column_geographic_role(self) -> typing.Optional[builtins.str]:
            '''A geospatial role for a column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columntag.html#cfn-quicksight-dataset-columntag-columngeographicrole
            '''
            result = self._values.get("column_geographic_role")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnTagProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.CreateColumnsOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns"},
    )
    class CreateColumnsOperationProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.CalculatedColumnProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''A transform operation that creates calculated columns.

            Columns created in one such operation form a lexical closure.

            :param columns: Calculated columns to create.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-createcolumnsoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                create_columns_operation_property = quicksight.CfnDataSet.CreateColumnsOperationProperty(
                    columns=[quicksight.CfnDataSet.CalculatedColumnProperty(
                        column_id="columnId",
                        column_name="columnName",
                        expression="expression"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__126d3e583c2ac58ef2048d1e7c04201d7b8c4b386e6e2ce57b085e7d0ff1622f)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
            }

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.CalculatedColumnProperty"]]]:
            '''Calculated columns to create.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-createcolumnsoperation.html#cfn-quicksight-dataset-createcolumnsoperation-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.CalculatedColumnProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CreateColumnsOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.CustomSqlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "data_source_arn": "dataSourceArn",
            "name": "name",
            "sql_query": "sqlQuery",
        },
    )
    class CustomSqlProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.InputColumnProperty", typing.Dict[builtins.str, typing.Any]]]]],
            data_source_arn: builtins.str,
            name: builtins.str,
            sql_query: builtins.str,
        ) -> None:
            '''A physical table type built from the results of the custom SQL query.

            :param columns: The column schema from the SQL query result set.
            :param data_source_arn: The Amazon Resource Name (ARN) of the data source.
            :param name: A display name for the SQL query result.
            :param sql_query: The SQL query.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_sql_property = quicksight.CfnDataSet.CustomSqlProperty(
                    columns=[quicksight.CfnDataSet.InputColumnProperty(
                        name="name",
                        type="type",
                
                        # the properties below are optional
                        sub_type="subType"
                    )],
                    data_source_arn="dataSourceArn",
                    name="name",
                    sql_query="sqlQuery"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__97e4fcb997b025bd8b8162d5528bd73bc1c489c80a53a49d2bf3f33ac9c086df)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument data_source_arn", value=data_source_arn, expected_type=type_hints["data_source_arn"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sql_query", value=sql_query, expected_type=type_hints["sql_query"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "data_source_arn": data_source_arn,
                "name": name,
                "sql_query": sql_query,
            }

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.InputColumnProperty"]]]:
            '''The column schema from the SQL query result set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html#cfn-quicksight-dataset-customsql-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.InputColumnProperty"]]], result)

        @builtins.property
        def data_source_arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html#cfn-quicksight-dataset-customsql-datasourcearn
            '''
            result = self._values.get("data_source_arn")
            assert result is not None, "Required property 'data_source_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for the SQL query result.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html#cfn-quicksight-dataset-customsql-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sql_query(self) -> builtins.str:
            '''The SQL query.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html#cfn-quicksight-dataset-customsql-sqlquery
            '''
            result = self._values.get("sql_query")
            assert result is not None, "Required property 'sql_query' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomSqlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.DataSetRefreshPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={"refresh_configuration": "refreshConfiguration"},
    )
    class DataSetRefreshPropertiesProperty:
        def __init__(
            self,
            *,
            refresh_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.RefreshConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The refresh properties of a dataset.

            :param refresh_configuration: The refresh configuration for a dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetrefreshproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_set_refresh_properties_property = quicksight.CfnDataSet.DataSetRefreshPropertiesProperty(
                    refresh_configuration=quicksight.CfnDataSet.RefreshConfigurationProperty(
                        incremental_refresh=quicksight.CfnDataSet.IncrementalRefreshProperty(
                            lookback_window=quicksight.CfnDataSet.LookbackWindowProperty(
                                column_name="columnName",
                                size=123,
                                size_unit="sizeUnit"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f8112e3ac95c271ef07e7d73f3bc230c7463e9b93fdcd125f136b968bd641daf)
                check_type(argname="argument refresh_configuration", value=refresh_configuration, expected_type=type_hints["refresh_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if refresh_configuration is not None:
                self._values["refresh_configuration"] = refresh_configuration

        @builtins.property
        def refresh_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.RefreshConfigurationProperty"]]:
            '''The refresh configuration for a dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetrefreshproperties.html#cfn-quicksight-dataset-datasetrefreshproperties-refreshconfiguration
            '''
            result = self._values.get("refresh_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.RefreshConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetRefreshPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.DataSetUsageConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "disable_use_as_direct_query_source": "disableUseAsDirectQuerySource",
            "disable_use_as_imported_source": "disableUseAsImportedSource",
        },
    )
    class DataSetUsageConfigurationProperty:
        def __init__(
            self,
            *,
            disable_use_as_direct_query_source: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
            disable_use_as_imported_source: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
        ) -> None:
            '''The usage configuration to apply to child datasets that reference this dataset as a source.

            :param disable_use_as_direct_query_source: An option that controls whether a child dataset of a direct query can use this dataset as a source.
            :param disable_use_as_imported_source: An option that controls whether a child dataset that's stored in QuickSight can use this dataset as a source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetusageconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_set_usage_configuration_property = quicksight.CfnDataSet.DataSetUsageConfigurationProperty(
                    disable_use_as_direct_query_source=False,
                    disable_use_as_imported_source=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7c2217374e9d2612c47d1985150add42b7d78a1798adb4fac5639f8defafe339)
                check_type(argname="argument disable_use_as_direct_query_source", value=disable_use_as_direct_query_source, expected_type=type_hints["disable_use_as_direct_query_source"])
                check_type(argname="argument disable_use_as_imported_source", value=disable_use_as_imported_source, expected_type=type_hints["disable_use_as_imported_source"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if disable_use_as_direct_query_source is not None:
                self._values["disable_use_as_direct_query_source"] = disable_use_as_direct_query_source
            if disable_use_as_imported_source is not None:
                self._values["disable_use_as_imported_source"] = disable_use_as_imported_source

        @builtins.property
        def disable_use_as_direct_query_source(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''An option that controls whether a child dataset of a direct query can use this dataset as a source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetusageconfiguration.html#cfn-quicksight-dataset-datasetusageconfiguration-disableuseasdirectquerysource
            '''
            result = self._values.get("disable_use_as_direct_query_source")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        @builtins.property
        def disable_use_as_imported_source(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''An option that controls whether a child dataset that's stored in QuickSight can use this dataset as a source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetusageconfiguration.html#cfn-quicksight-dataset-datasetusageconfiguration-disableuseasimportedsource
            '''
            result = self._values.get("disable_use_as_imported_source")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetUsageConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.DatasetParameterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_dataset_parameter": "dateTimeDatasetParameter",
            "decimal_dataset_parameter": "decimalDatasetParameter",
            "integer_dataset_parameter": "integerDatasetParameter",
            "string_dataset_parameter": "stringDatasetParameter",
        },
    )
    class DatasetParameterProperty:
        def __init__(
            self,
            *,
            date_time_dataset_parameter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.DateTimeDatasetParameterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            decimal_dataset_parameter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.DecimalDatasetParameterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            integer_dataset_parameter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.IntegerDatasetParameterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            string_dataset_parameter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.StringDatasetParameterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The parameter declarations of the dataset.

            :param date_time_dataset_parameter: A date time parameter that is created in the dataset.
            :param decimal_dataset_parameter: A decimal parameter that is created in the dataset.
            :param integer_dataset_parameter: An integer parameter that is created in the dataset.
            :param string_dataset_parameter: A string parameter that is created in the dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                dataset_parameter_property = quicksight.CfnDataSet.DatasetParameterProperty(
                    date_time_dataset_parameter=quicksight.CfnDataSet.DateTimeDatasetParameterProperty(
                        id="id",
                        name="name",
                        value_type="valueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnDataSet.DateTimeDatasetParameterDefaultValuesProperty(
                            static_values=["staticValues"]
                        ),
                        time_granularity="timeGranularity"
                    ),
                    decimal_dataset_parameter=quicksight.CfnDataSet.DecimalDatasetParameterProperty(
                        id="id",
                        name="name",
                        value_type="valueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnDataSet.DecimalDatasetParameterDefaultValuesProperty(
                            static_values=[123]
                        )
                    ),
                    integer_dataset_parameter=quicksight.CfnDataSet.IntegerDatasetParameterProperty(
                        id="id",
                        name="name",
                        value_type="valueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnDataSet.IntegerDatasetParameterDefaultValuesProperty(
                            static_values=[123]
                        )
                    ),
                    string_dataset_parameter=quicksight.CfnDataSet.StringDatasetParameterProperty(
                        id="id",
                        name="name",
                        value_type="valueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnDataSet.StringDatasetParameterDefaultValuesProperty(
                            static_values=["staticValues"]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ef36215242063cda2d33900c2c2fef0ac49848b20c0d6c04fcddd8979789e8ed)
                check_type(argname="argument date_time_dataset_parameter", value=date_time_dataset_parameter, expected_type=type_hints["date_time_dataset_parameter"])
                check_type(argname="argument decimal_dataset_parameter", value=decimal_dataset_parameter, expected_type=type_hints["decimal_dataset_parameter"])
                check_type(argname="argument integer_dataset_parameter", value=integer_dataset_parameter, expected_type=type_hints["integer_dataset_parameter"])
                check_type(argname="argument string_dataset_parameter", value=string_dataset_parameter, expected_type=type_hints["string_dataset_parameter"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_dataset_parameter is not None:
                self._values["date_time_dataset_parameter"] = date_time_dataset_parameter
            if decimal_dataset_parameter is not None:
                self._values["decimal_dataset_parameter"] = decimal_dataset_parameter
            if integer_dataset_parameter is not None:
                self._values["integer_dataset_parameter"] = integer_dataset_parameter
            if string_dataset_parameter is not None:
                self._values["string_dataset_parameter"] = string_dataset_parameter

        @builtins.property
        def date_time_dataset_parameter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.DateTimeDatasetParameterProperty"]]:
            '''A date time parameter that is created in the dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetparameter.html#cfn-quicksight-dataset-datasetparameter-datetimedatasetparameter
            '''
            result = self._values.get("date_time_dataset_parameter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.DateTimeDatasetParameterProperty"]], result)

        @builtins.property
        def decimal_dataset_parameter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.DecimalDatasetParameterProperty"]]:
            '''A decimal parameter that is created in the dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetparameter.html#cfn-quicksight-dataset-datasetparameter-decimaldatasetparameter
            '''
            result = self._values.get("decimal_dataset_parameter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.DecimalDatasetParameterProperty"]], result)

        @builtins.property
        def integer_dataset_parameter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.IntegerDatasetParameterProperty"]]:
            '''An integer parameter that is created in the dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetparameter.html#cfn-quicksight-dataset-datasetparameter-integerdatasetparameter
            '''
            result = self._values.get("integer_dataset_parameter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.IntegerDatasetParameterProperty"]], result)

        @builtins.property
        def string_dataset_parameter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.StringDatasetParameterProperty"]]:
            '''A string parameter that is created in the dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetparameter.html#cfn-quicksight-dataset-datasetparameter-stringdatasetparameter
            '''
            result = self._values.get("string_dataset_parameter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.StringDatasetParameterProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DatasetParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.DateTimeDatasetParameterDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={"static_values": "staticValues"},
    )
    class DateTimeDatasetParameterDefaultValuesProperty:
        def __init__(
            self,
            *,
            static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''
            Currently only static values are supported.

            :param static_values: A list of static default values for a given date time parameter. The valid format for this property is ``yyyy-MM-dd’T’HH:mm:ss’Z’`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datetimedatasetparameterdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_dataset_parameter_default_values_property = quicksight.CfnDataSet.DateTimeDatasetParameterDefaultValuesProperty(
                    static_values=["staticValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e36ba687feb666979008fc6b88da1e17e793fb11294f74256c7f8ae228cd57b6)
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of static default values for a given date time parameter.

            The valid format for this property is ``yyyy-MM-dd’T’HH:mm:ss’Z’`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datetimedatasetparameterdefaultvalues.html#cfn-quicksight-dataset-datetimedatasetparameterdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeDatasetParameterDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.DateTimeDatasetParameterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "id": "id",
            "name": "name",
            "value_type": "valueType",
            "default_values": "defaultValues",
            "time_granularity": "timeGranularity",
        },
    )
    class DateTimeDatasetParameterProperty:
        def __init__(
            self,
            *,
            id: builtins.str,
            name: builtins.str,
            value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.DateTimeDatasetParameterDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A date time parameter that is created in the dataset.

            :param id: An identifier for the parameter that is created in the dataset.
            :param name: The name of the date time parameter that is created in the dataset.
            :param value_type: The value type of the dataset parameter. Valid values are ``single value`` or ``multi value`` .
            :param default_values: A list of default values for a given date time parameter. This structure only accepts static values.
            :param time_granularity: The time granularity of the date time parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datetimedatasetparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_dataset_parameter_property = quicksight.CfnDataSet.DateTimeDatasetParameterProperty(
                    id="id",
                    name="name",
                    value_type="valueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnDataSet.DateTimeDatasetParameterDefaultValuesProperty(
                        static_values=["staticValues"]
                    ),
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__894b07f7014062eced8643f6a0d92ce5374c5693a6a7b9b8cd77720e35860c7a)
                check_type(argname="argument id", value=id, expected_type=type_hints["id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument value_type", value=value_type, expected_type=type_hints["value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "id": id,
                "name": name,
                "value_type": value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def id(self) -> builtins.str:
            '''An identifier for the parameter that is created in the dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datetimedatasetparameter.html#cfn-quicksight-dataset-datetimedatasetparameter-id
            '''
            result = self._values.get("id")
            assert result is not None, "Required property 'id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the date time parameter that is created in the dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datetimedatasetparameter.html#cfn-quicksight-dataset-datetimedatasetparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value_type(self) -> builtins.str:
            '''The value type of the dataset parameter.

            Valid values are ``single value`` or ``multi value`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datetimedatasetparameter.html#cfn-quicksight-dataset-datetimedatasetparameter-valuetype
            '''
            result = self._values.get("value_type")
            assert result is not None, "Required property 'value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.DateTimeDatasetParameterDefaultValuesProperty"]]:
            '''A list of default values for a given date time parameter.

            This structure only accepts static values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datetimedatasetparameter.html#cfn-quicksight-dataset-datetimedatasetparameter-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.DateTimeDatasetParameterDefaultValuesProperty"]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The time granularity of the date time parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datetimedatasetparameter.html#cfn-quicksight-dataset-datetimedatasetparameter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeDatasetParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.DecimalDatasetParameterDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={"static_values": "staticValues"},
    )
    class DecimalDatasetParameterDefaultValuesProperty:
        def __init__(
            self,
            *,
            static_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
        ) -> None:
            '''A list of default values for a given decimal parameter.

            This structure only accepts static values.

            :param static_values: A list of static default values for a given decimal parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-decimaldatasetparameterdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                decimal_dataset_parameter_default_values_property = quicksight.CfnDataSet.DecimalDatasetParameterDefaultValuesProperty(
                    static_values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d9418fccbc2d752e06362b56183f744c34efefaef5371339619d0242e79ff1e3)
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def static_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]]:
            '''A list of static default values for a given decimal parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-decimaldatasetparameterdefaultvalues.html#cfn-quicksight-dataset-decimaldatasetparameterdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalDatasetParameterDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.DecimalDatasetParameterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "id": "id",
            "name": "name",
            "value_type": "valueType",
            "default_values": "defaultValues",
        },
    )
    class DecimalDatasetParameterProperty:
        def __init__(
            self,
            *,
            id: builtins.str,
            name: builtins.str,
            value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.DecimalDatasetParameterDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A decimal parameter that is created in the dataset.

            :param id: An identifier for the decimal parameter created in the dataset.
            :param name: The name of the decimal parameter that is created in the dataset.
            :param value_type: The value type of the dataset parameter. Valid values are ``single value`` or ``multi value`` .
            :param default_values: A list of default values for a given decimal parameter. This structure only accepts static values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-decimaldatasetparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                decimal_dataset_parameter_property = quicksight.CfnDataSet.DecimalDatasetParameterProperty(
                    id="id",
                    name="name",
                    value_type="valueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnDataSet.DecimalDatasetParameterDefaultValuesProperty(
                        static_values=[123]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b306f04311f0c5a1df60b04c1d4fca8611ffa84e4c685592259379808aa8a8e6)
                check_type(argname="argument id", value=id, expected_type=type_hints["id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument value_type", value=value_type, expected_type=type_hints["value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "id": id,
                "name": name,
                "value_type": value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values

        @builtins.property
        def id(self) -> builtins.str:
            '''An identifier for the decimal parameter created in the dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-decimaldatasetparameter.html#cfn-quicksight-dataset-decimaldatasetparameter-id
            '''
            result = self._values.get("id")
            assert result is not None, "Required property 'id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the decimal parameter that is created in the dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-decimaldatasetparameter.html#cfn-quicksight-dataset-decimaldatasetparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value_type(self) -> builtins.str:
            '''The value type of the dataset parameter.

            Valid values are ``single value`` or ``multi value`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-decimaldatasetparameter.html#cfn-quicksight-dataset-decimaldatasetparameter-valuetype
            '''
            result = self._values.get("value_type")
            assert result is not None, "Required property 'value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.DecimalDatasetParameterDefaultValuesProperty"]]:
            '''A list of default values for a given decimal parameter.

            This structure only accepts static values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-decimaldatasetparameter.html#cfn-quicksight-dataset-decimaldatasetparameter-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.DecimalDatasetParameterDefaultValuesProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalDatasetParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.FieldFolderProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns", "description": "description"},
    )
    class FieldFolderProperty:
        def __init__(
            self,
            *,
            columns: typing.Optional[typing.Sequence[builtins.str]] = None,
            description: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A FieldFolder element is a folder that contains fields and nested subfolders.

            :param columns: A folder has a list of columns. A column can only be in one folder.
            :param description: The description for a field folder.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-fieldfolder.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                field_folder_property = quicksight.CfnDataSet.FieldFolderProperty(
                    columns=["columns"],
                    description="description"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__97cb8c9f7dc46795d3b83cc33aee13ecdc65adbbd69b727121697bc461d22b95)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if columns is not None:
                self._values["columns"] = columns
            if description is not None:
                self._values["description"] = description

        @builtins.property
        def columns(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A folder has a list of columns.

            A column can only be in one folder.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-fieldfolder.html#cfn-quicksight-dataset-fieldfolder-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''The description for a field folder.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-fieldfolder.html#cfn-quicksight-dataset-fieldfolder-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldFolderProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.FilterOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"condition_expression": "conditionExpression"},
    )
    class FilterOperationProperty:
        def __init__(self, *, condition_expression: builtins.str) -> None:
            '''A transform operation that filters rows based on a condition.

            :param condition_expression: An expression that must evaluate to a Boolean value. Rows for which the expression evaluates to true are kept in the dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-filteroperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_operation_property = quicksight.CfnDataSet.FilterOperationProperty(
                    condition_expression="conditionExpression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0c6b79c4b080379d4b3ed9c423474bdb63328a6739ddab0e95e9149b59558c0a)
                check_type(argname="argument condition_expression", value=condition_expression, expected_type=type_hints["condition_expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "condition_expression": condition_expression,
            }

        @builtins.property
        def condition_expression(self) -> builtins.str:
            '''An expression that must evaluate to a Boolean value.

            Rows for which the expression evaluates to true are kept in the dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-filteroperation.html#cfn-quicksight-dataset-filteroperation-conditionexpression
            '''
            result = self._values.get("condition_expression")
            assert result is not None, "Required property 'condition_expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.GeoSpatialColumnGroupProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "name": "name",
            "country_code": "countryCode",
        },
    )
    class GeoSpatialColumnGroupProperty:
        def __init__(
            self,
            *,
            columns: typing.Sequence[builtins.str],
            name: builtins.str,
            country_code: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Geospatial column group that denotes a hierarchy.

            :param columns: Columns in this hierarchy.
            :param name: A display name for the hierarchy.
            :param country_code: Country code.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-geospatialcolumngroup.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geo_spatial_column_group_property = quicksight.CfnDataSet.GeoSpatialColumnGroupProperty(
                    columns=["columns"],
                    name="name",
                
                    # the properties below are optional
                    country_code="countryCode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bec18505abc90d3d5642a41efec26e4f721ea187d8c10ac74e83c1b18d207db7)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument country_code", value=country_code, expected_type=type_hints["country_code"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "name": name,
            }
            if country_code is not None:
                self._values["country_code"] = country_code

        @builtins.property
        def columns(self) -> typing.List[builtins.str]:
            '''Columns in this hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-geospatialcolumngroup.html#cfn-quicksight-dataset-geospatialcolumngroup-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for the hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-geospatialcolumngroup.html#cfn-quicksight-dataset-geospatialcolumngroup-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def country_code(self) -> typing.Optional[builtins.str]:
            '''Country code.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-geospatialcolumngroup.html#cfn-quicksight-dataset-geospatialcolumngroup-countrycode
            '''
            result = self._values.get("country_code")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeoSpatialColumnGroupProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.IncrementalRefreshProperty",
        jsii_struct_bases=[],
        name_mapping={"lookback_window": "lookbackWindow"},
    )
    class IncrementalRefreshProperty:
        def __init__(
            self,
            *,
            lookback_window: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.LookbackWindowProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The incremental refresh configuration for a dataset.

            :param lookback_window: The lookback window setup for an incremental refresh configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-incrementalrefresh.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                incremental_refresh_property = quicksight.CfnDataSet.IncrementalRefreshProperty(
                    lookback_window=quicksight.CfnDataSet.LookbackWindowProperty(
                        column_name="columnName",
                        size=123,
                        size_unit="sizeUnit"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__050d6b5255b31d4ab7c73f6aafa1a5fe608236a3cccebca823246b22b90fee38)
                check_type(argname="argument lookback_window", value=lookback_window, expected_type=type_hints["lookback_window"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if lookback_window is not None:
                self._values["lookback_window"] = lookback_window

        @builtins.property
        def lookback_window(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.LookbackWindowProperty"]]:
            '''The lookback window setup for an incremental refresh configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-incrementalrefresh.html#cfn-quicksight-dataset-incrementalrefresh-lookbackwindow
            '''
            result = self._values.get("lookback_window")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.LookbackWindowProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IncrementalRefreshProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.IngestionWaitPolicyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "ingestion_wait_time_in_hours": "ingestionWaitTimeInHours",
            "wait_for_spice_ingestion": "waitForSpiceIngestion",
        },
    )
    class IngestionWaitPolicyProperty:
        def __init__(
            self,
            *,
            ingestion_wait_time_in_hours: typing.Optional[jsii.Number] = None,
            wait_for_spice_ingestion: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
        ) -> None:
            '''The wait policy to use when creating or updating a Dataset.

            The default is to wait for SPICE ingestion to finish with timeout of 36 hours.

            :param ingestion_wait_time_in_hours: The maximum time (in hours) to wait for Ingestion to complete. Default timeout is 36 hours. Applicable only when ``DataSetImportMode`` mode is set to SPICE and ``WaitForSpiceIngestion`` is set to true. Default: - 36
            :param wait_for_spice_ingestion: Wait for SPICE ingestion to finish to mark dataset creation or update as successful. Default (true). Applicable only when ``DataSetImportMode`` mode is set to SPICE. Default: - true

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-ingestionwaitpolicy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                ingestion_wait_policy_property = quicksight.CfnDataSet.IngestionWaitPolicyProperty(
                    ingestion_wait_time_in_hours=123,
                    wait_for_spice_ingestion=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8536853a045c3529e56b7bfc46c1ae5b6100a9f6cb8981313c803c9a20ff6529)
                check_type(argname="argument ingestion_wait_time_in_hours", value=ingestion_wait_time_in_hours, expected_type=type_hints["ingestion_wait_time_in_hours"])
                check_type(argname="argument wait_for_spice_ingestion", value=wait_for_spice_ingestion, expected_type=type_hints["wait_for_spice_ingestion"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if ingestion_wait_time_in_hours is not None:
                self._values["ingestion_wait_time_in_hours"] = ingestion_wait_time_in_hours
            if wait_for_spice_ingestion is not None:
                self._values["wait_for_spice_ingestion"] = wait_for_spice_ingestion

        @builtins.property
        def ingestion_wait_time_in_hours(self) -> typing.Optional[jsii.Number]:
            '''The maximum time (in hours) to wait for Ingestion to complete.

            Default timeout is 36 hours. Applicable only when ``DataSetImportMode`` mode is set to SPICE and ``WaitForSpiceIngestion`` is set to true.

            :default: - 36

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-ingestionwaitpolicy.html#cfn-quicksight-dataset-ingestionwaitpolicy-ingestionwaittimeinhours
            '''
            result = self._values.get("ingestion_wait_time_in_hours")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def wait_for_spice_ingestion(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''Wait for SPICE ingestion to finish to mark dataset creation or update as successful.

            Default (true). Applicable only when ``DataSetImportMode`` mode is set to SPICE.

            :default: - true

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-ingestionwaitpolicy.html#cfn-quicksight-dataset-ingestionwaitpolicy-waitforspiceingestion
            '''
            result = self._values.get("wait_for_spice_ingestion")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IngestionWaitPolicyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.InputColumnProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "type": "type", "sub_type": "subType"},
    )
    class InputColumnProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            type: builtins.str,
            sub_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Metadata for a column that is used as the input of a transform operation.

            :param name: The name of this column in the underlying data source.
            :param type: The data type of the column.
            :param sub_type: The sub data type of the column. Sub types are only available for decimal columns that are part of a SPICE dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-inputcolumn.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                input_column_property = quicksight.CfnDataSet.InputColumnProperty(
                    name="name",
                    type="type",
                
                    # the properties below are optional
                    sub_type="subType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a852fc3befc2e6064fd6912323731a8a0b86c3ca7f67d0d75cbbf9419d455a23)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument sub_type", value=sub_type, expected_type=type_hints["sub_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "type": type,
            }
            if sub_type is not None:
                self._values["sub_type"] = sub_type

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of this column in the underlying data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-inputcolumn.html#cfn-quicksight-dataset-inputcolumn-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The data type of the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-inputcolumn.html#cfn-quicksight-dataset-inputcolumn-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sub_type(self) -> typing.Optional[builtins.str]:
            '''The sub data type of the column.

            Sub types are only available for decimal columns that are part of a SPICE dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-inputcolumn.html#cfn-quicksight-dataset-inputcolumn-subtype
            '''
            result = self._values.get("sub_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "InputColumnProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.IntegerDatasetParameterDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={"static_values": "staticValues"},
    )
    class IntegerDatasetParameterDefaultValuesProperty:
        def __init__(
            self,
            *,
            static_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
        ) -> None:
            '''A list of default values for a given integer parameter.

            This structure only accepts static values.

            :param static_values: A list of static default values for a given integer parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-integerdatasetparameterdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                integer_dataset_parameter_default_values_property = quicksight.CfnDataSet.IntegerDatasetParameterDefaultValuesProperty(
                    static_values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3a2b84bdb27f8413d6ddc09d4db29c8d1f82dcc80a10e9a1b7c10a61ea4642d5)
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def static_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]]:
            '''A list of static default values for a given integer parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-integerdatasetparameterdefaultvalues.html#cfn-quicksight-dataset-integerdatasetparameterdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerDatasetParameterDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.IntegerDatasetParameterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "id": "id",
            "name": "name",
            "value_type": "valueType",
            "default_values": "defaultValues",
        },
    )
    class IntegerDatasetParameterProperty:
        def __init__(
            self,
            *,
            id: builtins.str,
            name: builtins.str,
            value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.IntegerDatasetParameterDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''An integer parameter that is created in the dataset.

            :param id: An identifier for the integer parameter created in the dataset.
            :param name: The name of the integer parameter that is created in the dataset.
            :param value_type: The value type of the dataset parameter. Valid values are ``single value`` or ``multi value`` .
            :param default_values: A list of default values for a given integer parameter. This structure only accepts static values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-integerdatasetparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                integer_dataset_parameter_property = quicksight.CfnDataSet.IntegerDatasetParameterProperty(
                    id="id",
                    name="name",
                    value_type="valueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnDataSet.IntegerDatasetParameterDefaultValuesProperty(
                        static_values=[123]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6cc6bd26b7cacbfaf5fce187a5a5a3f1f8276cce8a1385e49a7117be4392ebae)
                check_type(argname="argument id", value=id, expected_type=type_hints["id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument value_type", value=value_type, expected_type=type_hints["value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "id": id,
                "name": name,
                "value_type": value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values

        @builtins.property
        def id(self) -> builtins.str:
            '''An identifier for the integer parameter created in the dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-integerdatasetparameter.html#cfn-quicksight-dataset-integerdatasetparameter-id
            '''
            result = self._values.get("id")
            assert result is not None, "Required property 'id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the integer parameter that is created in the dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-integerdatasetparameter.html#cfn-quicksight-dataset-integerdatasetparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value_type(self) -> builtins.str:
            '''The value type of the dataset parameter.

            Valid values are ``single value`` or ``multi value`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-integerdatasetparameter.html#cfn-quicksight-dataset-integerdatasetparameter-valuetype
            '''
            result = self._values.get("value_type")
            assert result is not None, "Required property 'value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.IntegerDatasetParameterDefaultValuesProperty"]]:
            '''A list of default values for a given integer parameter.

            This structure only accepts static values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-integerdatasetparameter.html#cfn-quicksight-dataset-integerdatasetparameter-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.IntegerDatasetParameterDefaultValuesProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerDatasetParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.JoinInstructionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "left_operand": "leftOperand",
            "on_clause": "onClause",
            "right_operand": "rightOperand",
            "type": "type",
            "left_join_key_properties": "leftJoinKeyProperties",
            "right_join_key_properties": "rightJoinKeyProperties",
        },
    )
    class JoinInstructionProperty:
        def __init__(
            self,
            *,
            left_operand: builtins.str,
            on_clause: builtins.str,
            right_operand: builtins.str,
            type: builtins.str,
            left_join_key_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.JoinKeyPropertiesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            right_join_key_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.JoinKeyPropertiesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The instructions associated with a join.

            :param left_operand: The operand on the left side of a join.
            :param on_clause: The join instructions provided in the ``ON`` clause of a join.
            :param right_operand: The operand on the right side of a join.
            :param type: The type of join that it is.
            :param left_join_key_properties: Join key properties of the left operand.
            :param right_join_key_properties: Join key properties of the right operand.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                join_instruction_property = quicksight.CfnDataSet.JoinInstructionProperty(
                    left_operand="leftOperand",
                    on_clause="onClause",
                    right_operand="rightOperand",
                    type="type",
                
                    # the properties below are optional
                    left_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                        unique_key=False
                    ),
                    right_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                        unique_key=False
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fcd61f3ad3bf1aebb609f93c32618cfde562f536e68a0a3f9b823b3292cb52b6)
                check_type(argname="argument left_operand", value=left_operand, expected_type=type_hints["left_operand"])
                check_type(argname="argument on_clause", value=on_clause, expected_type=type_hints["on_clause"])
                check_type(argname="argument right_operand", value=right_operand, expected_type=type_hints["right_operand"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument left_join_key_properties", value=left_join_key_properties, expected_type=type_hints["left_join_key_properties"])
                check_type(argname="argument right_join_key_properties", value=right_join_key_properties, expected_type=type_hints["right_join_key_properties"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "left_operand": left_operand,
                "on_clause": on_clause,
                "right_operand": right_operand,
                "type": type,
            }
            if left_join_key_properties is not None:
                self._values["left_join_key_properties"] = left_join_key_properties
            if right_join_key_properties is not None:
                self._values["right_join_key_properties"] = right_join_key_properties

        @builtins.property
        def left_operand(self) -> builtins.str:
            '''The operand on the left side of a join.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-leftoperand
            '''
            result = self._values.get("left_operand")
            assert result is not None, "Required property 'left_operand' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def on_clause(self) -> builtins.str:
            '''The join instructions provided in the ``ON`` clause of a join.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-onclause
            '''
            result = self._values.get("on_clause")
            assert result is not None, "Required property 'on_clause' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def right_operand(self) -> builtins.str:
            '''The operand on the right side of a join.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-rightoperand
            '''
            result = self._values.get("right_operand")
            assert result is not None, "Required property 'right_operand' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The type of join that it is.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def left_join_key_properties(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.JoinKeyPropertiesProperty"]]:
            '''Join key properties of the left operand.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-leftjoinkeyproperties
            '''
            result = self._values.get("left_join_key_properties")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.JoinKeyPropertiesProperty"]], result)

        @builtins.property
        def right_join_key_properties(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.JoinKeyPropertiesProperty"]]:
            '''Join key properties of the right operand.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-rightjoinkeyproperties
            '''
            result = self._values.get("right_join_key_properties")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.JoinKeyPropertiesProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "JoinInstructionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.JoinKeyPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={"unique_key": "uniqueKey"},
    )
    class JoinKeyPropertiesProperty:
        def __init__(
            self,
            *,
            unique_key: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
        ) -> None:
            '''Properties associated with the columns participating in a join.

            :param unique_key: A value that indicates that a row in a table is uniquely identified by the columns in a join key. This is used by Amazon QuickSight to optimize query performance.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joinkeyproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                join_key_properties_property = quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                    unique_key=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6028e05db913817056fdfb25ccbeccdc09bf308fc013a40a77d78e696106d73f)
                check_type(argname="argument unique_key", value=unique_key, expected_type=type_hints["unique_key"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if unique_key is not None:
                self._values["unique_key"] = unique_key

        @builtins.property
        def unique_key(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''A value that indicates that a row in a table is uniquely identified by the columns in a join key.

            This is used by Amazon QuickSight to optimize query performance.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joinkeyproperties.html#cfn-quicksight-dataset-joinkeyproperties-uniquekey
            '''
            result = self._values.get("unique_key")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "JoinKeyPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.LogicalTableProperty",
        jsii_struct_bases=[],
        name_mapping={
            "alias": "alias",
            "source": "source",
            "data_transforms": "dataTransforms",
        },
    )
    class LogicalTableProperty:
        def __init__(
            self,
            *,
            alias: builtins.str,
            source: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.LogicalTableSourceProperty", typing.Dict[builtins.str, typing.Any]]],
            data_transforms: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.TransformOperationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''A *logical table* is a unit that joins and that data transformations operate on.

            A logical table has a source, which can be either a physical table or result of a join. When a logical table points to a physical table, the logical table acts as a mutable copy of that physical table through transform operations.

            :param alias: A display name for the logical table.
            :param source: Source of this logical table.
            :param data_transforms: Transform operations that act on this logical table. For this structure to be valid, only one of the attributes can be non-null.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltable.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                logical_table_property = quicksight.CfnDataSet.LogicalTableProperty(
                    alias="alias",
                    source=quicksight.CfnDataSet.LogicalTableSourceProperty(
                        data_set_arn="dataSetArn",
                        join_instruction=quicksight.CfnDataSet.JoinInstructionProperty(
                            left_operand="leftOperand",
                            on_clause="onClause",
                            right_operand="rightOperand",
                            type="type",
                
                            # the properties below are optional
                            left_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                                unique_key=False
                            ),
                            right_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                                unique_key=False
                            )
                        ),
                        physical_table_id="physicalTableId"
                    ),
                
                    # the properties below are optional
                    data_transforms=[quicksight.CfnDataSet.TransformOperationProperty(
                        cast_column_type_operation=quicksight.CfnDataSet.CastColumnTypeOperationProperty(
                            column_name="columnName",
                            new_column_type="newColumnType",
                
                            # the properties below are optional
                            format="format",
                            sub_type="subType"
                        ),
                        create_columns_operation=quicksight.CfnDataSet.CreateColumnsOperationProperty(
                            columns=[quicksight.CfnDataSet.CalculatedColumnProperty(
                                column_id="columnId",
                                column_name="columnName",
                                expression="expression"
                            )]
                        ),
                        filter_operation=quicksight.CfnDataSet.FilterOperationProperty(
                            condition_expression="conditionExpression"
                        ),
                        override_dataset_parameter_operation=quicksight.CfnDataSet.OverrideDatasetParameterOperationProperty(
                            parameter_name="parameterName",
                
                            # the properties below are optional
                            new_default_values=quicksight.CfnDataSet.NewDefaultValuesProperty(
                                date_time_static_values=["dateTimeStaticValues"],
                                decimal_static_values=[123],
                                integer_static_values=[123],
                                string_static_values=["stringStaticValues"]
                            ),
                            new_parameter_name="newParameterName"
                        ),
                        project_operation=quicksight.CfnDataSet.ProjectOperationProperty(
                            projected_columns=["projectedColumns"]
                        ),
                        rename_column_operation=quicksight.CfnDataSet.RenameColumnOperationProperty(
                            column_name="columnName",
                            new_column_name="newColumnName"
                        ),
                        tag_column_operation=quicksight.CfnDataSet.TagColumnOperationProperty(
                            column_name="columnName",
                            tags=[quicksight.CfnDataSet.ColumnTagProperty(
                                column_description=quicksight.CfnDataSet.ColumnDescriptionProperty(
                                    text="text"
                                ),
                                column_geographic_role="columnGeographicRole"
                            )]
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__38cd7d58d2457b1fb9072a61390c2dda39d5c68c12a8d0ccf51486b4c76134b9)
                check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
                check_type(argname="argument source", value=source, expected_type=type_hints["source"])
                check_type(argname="argument data_transforms", value=data_transforms, expected_type=type_hints["data_transforms"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "alias": alias,
                "source": source,
            }
            if data_transforms is not None:
                self._values["data_transforms"] = data_transforms

        @builtins.property
        def alias(self) -> builtins.str:
            '''A display name for the logical table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltable.html#cfn-quicksight-dataset-logicaltable-alias
            '''
            result = self._values.get("alias")
            assert result is not None, "Required property 'alias' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDataSet.LogicalTableSourceProperty"]:
            '''Source of this logical table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltable.html#cfn-quicksight-dataset-logicaltable-source
            '''
            result = self._values.get("source")
            assert result is not None, "Required property 'source' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDataSet.LogicalTableSourceProperty"], result)

        @builtins.property
        def data_transforms(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.TransformOperationProperty"]]]]:
            '''Transform operations that act on this logical table.

            For this structure to be valid, only one of the attributes can be non-null.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltable.html#cfn-quicksight-dataset-logicaltable-datatransforms
            '''
            result = self._values.get("data_transforms")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.TransformOperationProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LogicalTableProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.LogicalTableSourceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_arn": "dataSetArn",
            "join_instruction": "joinInstruction",
            "physical_table_id": "physicalTableId",
        },
    )
    class LogicalTableSourceProperty:
        def __init__(
            self,
            *,
            data_set_arn: typing.Optional[builtins.str] = None,
            join_instruction: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.JoinInstructionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            physical_table_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Information about the source of a logical table.

            This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

            :param data_set_arn: The Amazon Resource Number (ARN) of the parent dataset.
            :param join_instruction: Specifies the result of a join of two logical tables.
            :param physical_table_id: Physical table ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltablesource.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                logical_table_source_property = quicksight.CfnDataSet.LogicalTableSourceProperty(
                    data_set_arn="dataSetArn",
                    join_instruction=quicksight.CfnDataSet.JoinInstructionProperty(
                        left_operand="leftOperand",
                        on_clause="onClause",
                        right_operand="rightOperand",
                        type="type",
                
                        # the properties below are optional
                        left_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                            unique_key=False
                        ),
                        right_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                            unique_key=False
                        )
                    ),
                    physical_table_id="physicalTableId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0a293e2912f440646f6682b968c3dd42e6638d2854a474189be20da75b501e09)
                check_type(argname="argument data_set_arn", value=data_set_arn, expected_type=type_hints["data_set_arn"])
                check_type(argname="argument join_instruction", value=join_instruction, expected_type=type_hints["join_instruction"])
                check_type(argname="argument physical_table_id", value=physical_table_id, expected_type=type_hints["physical_table_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_set_arn is not None:
                self._values["data_set_arn"] = data_set_arn
            if join_instruction is not None:
                self._values["join_instruction"] = join_instruction
            if physical_table_id is not None:
                self._values["physical_table_id"] = physical_table_id

        @builtins.property
        def data_set_arn(self) -> typing.Optional[builtins.str]:
            '''The Amazon Resource Number (ARN) of the parent dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltablesource.html#cfn-quicksight-dataset-logicaltablesource-datasetarn
            '''
            result = self._values.get("data_set_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def join_instruction(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.JoinInstructionProperty"]]:
            '''Specifies the result of a join of two logical tables.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltablesource.html#cfn-quicksight-dataset-logicaltablesource-joininstruction
            '''
            result = self._values.get("join_instruction")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.JoinInstructionProperty"]], result)

        @builtins.property
        def physical_table_id(self) -> typing.Optional[builtins.str]:
            '''Physical table ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltablesource.html#cfn-quicksight-dataset-logicaltablesource-physicaltableid
            '''
            result = self._values.get("physical_table_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LogicalTableSourceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.LookbackWindowProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_name": "columnName",
            "size": "size",
            "size_unit": "sizeUnit",
        },
    )
    class LookbackWindowProperty:
        def __init__(
            self,
            *,
            column_name: typing.Optional[builtins.str] = None,
            size: typing.Optional[jsii.Number] = None,
            size_unit: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The lookback window setup of an incremental refresh configuration.

            :param column_name: The name of the lookback window column.
            :param size: The lookback window column size.
            :param size_unit: The size unit that is used for the lookback window column. Valid values for this structure are ``HOUR`` , ``DAY`` , and ``WEEK`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-lookbackwindow.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                lookback_window_property = quicksight.CfnDataSet.LookbackWindowProperty(
                    column_name="columnName",
                    size=123,
                    size_unit="sizeUnit"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a459912c2016e678aba1d9960ab86b8b700c551da63e7414e8aa04fea6e0a95e)
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
                check_type(argname="argument size_unit", value=size_unit, expected_type=type_hints["size_unit"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_name is not None:
                self._values["column_name"] = column_name
            if size is not None:
                self._values["size"] = size
            if size_unit is not None:
                self._values["size_unit"] = size_unit

        @builtins.property
        def column_name(self) -> typing.Optional[builtins.str]:
            '''The name of the lookback window column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-lookbackwindow.html#cfn-quicksight-dataset-lookbackwindow-columnname
            '''
            result = self._values.get("column_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def size(self) -> typing.Optional[jsii.Number]:
            '''The lookback window column size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-lookbackwindow.html#cfn-quicksight-dataset-lookbackwindow-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def size_unit(self) -> typing.Optional[builtins.str]:
            '''The size unit that is used for the lookback window column.

            Valid values for this structure are ``HOUR`` , ``DAY`` , and ``WEEK`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-lookbackwindow.html#cfn-quicksight-dataset-lookbackwindow-sizeunit
            '''
            result = self._values.get("size_unit")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LookbackWindowProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.NewDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_static_values": "dateTimeStaticValues",
            "decimal_static_values": "decimalStaticValues",
            "integer_static_values": "integerStaticValues",
            "string_static_values": "stringStaticValues",
        },
    )
    class NewDefaultValuesProperty:
        def __init__(
            self,
            *,
            date_time_static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            decimal_static_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
            integer_static_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
            string_static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The new default values for the parameter.

            :param date_time_static_values: A list of static default values for a given date time parameter. The valid format for this property is ``yyyy-MM-dd’T’HH:mm:ss’Z’`` .
            :param decimal_static_values: A list of static default values for a given decimal parameter.
            :param integer_static_values: A list of static default values for a given integer parameter.
            :param string_static_values: A list of static default values for a given string parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-newdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                new_default_values_property = quicksight.CfnDataSet.NewDefaultValuesProperty(
                    date_time_static_values=["dateTimeStaticValues"],
                    decimal_static_values=[123],
                    integer_static_values=[123],
                    string_static_values=["stringStaticValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a90b073999772595b969c4ca3e1f4a4a267b14053b9e5be552cdb4a3651adecf)
                check_type(argname="argument date_time_static_values", value=date_time_static_values, expected_type=type_hints["date_time_static_values"])
                check_type(argname="argument decimal_static_values", value=decimal_static_values, expected_type=type_hints["decimal_static_values"])
                check_type(argname="argument integer_static_values", value=integer_static_values, expected_type=type_hints["integer_static_values"])
                check_type(argname="argument string_static_values", value=string_static_values, expected_type=type_hints["string_static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_static_values is not None:
                self._values["date_time_static_values"] = date_time_static_values
            if decimal_static_values is not None:
                self._values["decimal_static_values"] = decimal_static_values
            if integer_static_values is not None:
                self._values["integer_static_values"] = integer_static_values
            if string_static_values is not None:
                self._values["string_static_values"] = string_static_values

        @builtins.property
        def date_time_static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of static default values for a given date time parameter.

            The valid format for this property is ``yyyy-MM-dd’T’HH:mm:ss’Z’`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-newdefaultvalues.html#cfn-quicksight-dataset-newdefaultvalues-datetimestaticvalues
            '''
            result = self._values.get("date_time_static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def decimal_static_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]]:
            '''A list of static default values for a given decimal parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-newdefaultvalues.html#cfn-quicksight-dataset-newdefaultvalues-decimalstaticvalues
            '''
            result = self._values.get("decimal_static_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]], result)

        @builtins.property
        def integer_static_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]]:
            '''A list of static default values for a given integer parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-newdefaultvalues.html#cfn-quicksight-dataset-newdefaultvalues-integerstaticvalues
            '''
            result = self._values.get("integer_static_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]], result)

        @builtins.property
        def string_static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of static default values for a given string parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-newdefaultvalues.html#cfn-quicksight-dataset-newdefaultvalues-stringstaticvalues
            '''
            result = self._values.get("string_static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NewDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.OutputColumnProperty",
        jsii_struct_bases=[],
        name_mapping={
            "description": "description",
            "name": "name",
            "sub_type": "subType",
            "type": "type",
        },
    )
    class OutputColumnProperty:
        def __init__(
            self,
            *,
            description: typing.Optional[builtins.str] = None,
            name: typing.Optional[builtins.str] = None,
            sub_type: typing.Optional[builtins.str] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Output column.

            :param description: A description for a column.
            :param name: The display name of the column..
            :param sub_type: The sub data type of the column.
            :param type: The data type of the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                output_column_property = quicksight.CfnDataSet.OutputColumnProperty(
                    description="description",
                    name="name",
                    sub_type="subType",
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d2a67afa64d9d72d2c43cc61c225d894d4da6eec0bf0190a7f8bdc51a726ab03)
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sub_type", value=sub_type, expected_type=type_hints["sub_type"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if description is not None:
                self._values["description"] = description
            if name is not None:
                self._values["name"] = name
            if sub_type is not None:
                self._values["sub_type"] = sub_type
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''A description for a column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html#cfn-quicksight-dataset-outputcolumn-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The display name of the column..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html#cfn-quicksight-dataset-outputcolumn-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sub_type(self) -> typing.Optional[builtins.str]:
            '''The sub data type of the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html#cfn-quicksight-dataset-outputcolumn-subtype
            '''
            result = self._values.get("sub_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The data type of the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html#cfn-quicksight-dataset-outputcolumn-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "OutputColumnProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.OverrideDatasetParameterOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_name": "parameterName",
            "new_default_values": "newDefaultValues",
            "new_parameter_name": "newParameterName",
        },
    )
    class OverrideDatasetParameterOperationProperty:
        def __init__(
            self,
            *,
            parameter_name: builtins.str,
            new_default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.NewDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            new_parameter_name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A transform operation that overrides the dataset parameter values that are defined in another dataset.

            :param parameter_name: The name of the parameter to be overridden with different values.
            :param new_default_values: The new default values for the parameter.
            :param new_parameter_name: The new name for the parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-overridedatasetparameteroperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                override_dataset_parameter_operation_property = quicksight.CfnDataSet.OverrideDatasetParameterOperationProperty(
                    parameter_name="parameterName",
                
                    # the properties below are optional
                    new_default_values=quicksight.CfnDataSet.NewDefaultValuesProperty(
                        date_time_static_values=["dateTimeStaticValues"],
                        decimal_static_values=[123],
                        integer_static_values=[123],
                        string_static_values=["stringStaticValues"]
                    ),
                    new_parameter_name="newParameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__05437bd66651aa702397107d20c1d1962ac4ebf0f44f61c0fb4205d3efeef39e)
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument new_default_values", value=new_default_values, expected_type=type_hints["new_default_values"])
                check_type(argname="argument new_parameter_name", value=new_parameter_name, expected_type=type_hints["new_parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_name": parameter_name,
            }
            if new_default_values is not None:
                self._values["new_default_values"] = new_default_values
            if new_parameter_name is not None:
                self._values["new_parameter_name"] = new_parameter_name

        @builtins.property
        def parameter_name(self) -> builtins.str:
            '''The name of the parameter to be overridden with different values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-overridedatasetparameteroperation.html#cfn-quicksight-dataset-overridedatasetparameteroperation-parametername
            '''
            result = self._values.get("parameter_name")
            assert result is not None, "Required property 'parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def new_default_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.NewDefaultValuesProperty"]]:
            '''The new default values for the parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-overridedatasetparameteroperation.html#cfn-quicksight-dataset-overridedatasetparameteroperation-newdefaultvalues
            '''
            result = self._values.get("new_default_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.NewDefaultValuesProperty"]], result)

        @builtins.property
        def new_parameter_name(self) -> typing.Optional[builtins.str]:
            '''The new name for the parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-overridedatasetparameteroperation.html#cfn-quicksight-dataset-overridedatasetparameteroperation-newparametername
            '''
            result = self._values.get("new_parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "OverrideDatasetParameterOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.PhysicalTableProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_sql": "customSql",
            "relational_table": "relationalTable",
            "s3_source": "s3Source",
        },
    )
    class PhysicalTableProperty:
        def __init__(
            self,
            *,
            custom_sql: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.CustomSqlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relational_table: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.RelationalTableProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            s3_source: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.S3SourceProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A view of a data source that contains information about the shape of the data in the underlying source.

            This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

            :param custom_sql: A physical table type built from the results of the custom SQL query.
            :param relational_table: A physical table type for relational data sources.
            :param s3_source: A physical table type for as S3 data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-physicaltable.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                physical_table_property = quicksight.CfnDataSet.PhysicalTableProperty(
                    custom_sql=quicksight.CfnDataSet.CustomSqlProperty(
                        columns=[quicksight.CfnDataSet.InputColumnProperty(
                            name="name",
                            type="type",
                
                            # the properties below are optional
                            sub_type="subType"
                        )],
                        data_source_arn="dataSourceArn",
                        name="name",
                        sql_query="sqlQuery"
                    ),
                    relational_table=quicksight.CfnDataSet.RelationalTableProperty(
                        data_source_arn="dataSourceArn",
                        input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                            name="name",
                            type="type",
                
                            # the properties below are optional
                            sub_type="subType"
                        )],
                        name="name",
                
                        # the properties below are optional
                        catalog="catalog",
                        schema="schema"
                    ),
                    s3_source=quicksight.CfnDataSet.S3SourceProperty(
                        data_source_arn="dataSourceArn",
                        input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                            name="name",
                            type="type",
                
                            # the properties below are optional
                            sub_type="subType"
                        )],
                
                        # the properties below are optional
                        upload_settings=quicksight.CfnDataSet.UploadSettingsProperty(
                            contains_header=False,
                            delimiter="delimiter",
                            format="format",
                            start_from_row=123,
                            text_qualifier="textQualifier"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7f588cf2770fa7b702b2e4f637de59610c15f0ce583be4cd711a33839b2a470b)
                check_type(argname="argument custom_sql", value=custom_sql, expected_type=type_hints["custom_sql"])
                check_type(argname="argument relational_table", value=relational_table, expected_type=type_hints["relational_table"])
                check_type(argname="argument s3_source", value=s3_source, expected_type=type_hints["s3_source"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_sql is not None:
                self._values["custom_sql"] = custom_sql
            if relational_table is not None:
                self._values["relational_table"] = relational_table
            if s3_source is not None:
                self._values["s3_source"] = s3_source

        @builtins.property
        def custom_sql(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.CustomSqlProperty"]]:
            '''A physical table type built from the results of the custom SQL query.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-physicaltable.html#cfn-quicksight-dataset-physicaltable-customsql
            '''
            result = self._values.get("custom_sql")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.CustomSqlProperty"]], result)

        @builtins.property
        def relational_table(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.RelationalTableProperty"]]:
            '''A physical table type for relational data sources.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-physicaltable.html#cfn-quicksight-dataset-physicaltable-relationaltable
            '''
            result = self._values.get("relational_table")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.RelationalTableProperty"]], result)

        @builtins.property
        def s3_source(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.S3SourceProperty"]]:
            '''A physical table type for as S3 data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-physicaltable.html#cfn-quicksight-dataset-physicaltable-s3source
            '''
            result = self._values.get("s3_source")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.S3SourceProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PhysicalTableProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.ProjectOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"projected_columns": "projectedColumns"},
    )
    class ProjectOperationProperty:
        def __init__(self, *, projected_columns: typing.Sequence[builtins.str]) -> None:
            '''A transform operation that projects columns.

            Operations that come after a projection can only refer to projected columns.

            :param projected_columns: Projected columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-projectoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                project_operation_property = quicksight.CfnDataSet.ProjectOperationProperty(
                    projected_columns=["projectedColumns"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f8e4e442aa58a18179ff77f915ae9041c15500b9de7cc923ee465cc5be9a021b)
                check_type(argname="argument projected_columns", value=projected_columns, expected_type=type_hints["projected_columns"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "projected_columns": projected_columns,
            }

        @builtins.property
        def projected_columns(self) -> typing.List[builtins.str]:
            '''Projected columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-projectoperation.html#cfn-quicksight-dataset-projectoperation-projectedcolumns
            '''
            result = self._values.get("projected_columns")
            assert result is not None, "Required property 'projected_columns' is missing"
            return typing.cast(typing.List[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ProjectOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.RefreshConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"incremental_refresh": "incrementalRefresh"},
    )
    class RefreshConfigurationProperty:
        def __init__(
            self,
            *,
            incremental_refresh: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.IncrementalRefreshProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The refresh configuration of a dataset.

            :param incremental_refresh: The incremental refresh for the dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-refreshconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                refresh_configuration_property = quicksight.CfnDataSet.RefreshConfigurationProperty(
                    incremental_refresh=quicksight.CfnDataSet.IncrementalRefreshProperty(
                        lookback_window=quicksight.CfnDataSet.LookbackWindowProperty(
                            column_name="columnName",
                            size=123,
                            size_unit="sizeUnit"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4f5b07a3830c8168aac61eee81da7fe4ea32166016cf2c4406b473b412992eb3)
                check_type(argname="argument incremental_refresh", value=incremental_refresh, expected_type=type_hints["incremental_refresh"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if incremental_refresh is not None:
                self._values["incremental_refresh"] = incremental_refresh

        @builtins.property
        def incremental_refresh(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.IncrementalRefreshProperty"]]:
            '''The incremental refresh for the dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-refreshconfiguration.html#cfn-quicksight-dataset-refreshconfiguration-incrementalrefresh
            '''
            result = self._values.get("incremental_refresh")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.IncrementalRefreshProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RefreshConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.RelationalTableProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_source_arn": "dataSourceArn",
            "input_columns": "inputColumns",
            "name": "name",
            "catalog": "catalog",
            "schema": "schema",
        },
    )
    class RelationalTableProperty:
        def __init__(
            self,
            *,
            data_source_arn: builtins.str,
            input_columns: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.InputColumnProperty", typing.Dict[builtins.str, typing.Any]]]]],
            name: builtins.str,
            catalog: typing.Optional[builtins.str] = None,
            schema: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A physical table type for relational data sources.

            :param data_source_arn: The Amazon Resource Name (ARN) for the data source.
            :param input_columns: The column schema of the table.
            :param name: The name of the relational table.
            :param catalog: The catalog associated with a table.
            :param schema: The schema name. This name applies to certain relational database engines.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                relational_table_property = quicksight.CfnDataSet.RelationalTableProperty(
                    data_source_arn="dataSourceArn",
                    input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                        name="name",
                        type="type",
                
                        # the properties below are optional
                        sub_type="subType"
                    )],
                    name="name",
                
                    # the properties below are optional
                    catalog="catalog",
                    schema="schema"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bc43d1be088dad877549378a89c5cca422c52436d49d6b5d4f473a7370858ebd)
                check_type(argname="argument data_source_arn", value=data_source_arn, expected_type=type_hints["data_source_arn"])
                check_type(argname="argument input_columns", value=input_columns, expected_type=type_hints["input_columns"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument catalog", value=catalog, expected_type=type_hints["catalog"])
                check_type(argname="argument schema", value=schema, expected_type=type_hints["schema"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_source_arn": data_source_arn,
                "input_columns": input_columns,
                "name": name,
            }
            if catalog is not None:
                self._values["catalog"] = catalog
            if schema is not None:
                self._values["schema"] = schema

        @builtins.property
        def data_source_arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) for the data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-datasourcearn
            '''
            result = self._values.get("data_source_arn")
            assert result is not None, "Required property 'data_source_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def input_columns(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.InputColumnProperty"]]]:
            '''The column schema of the table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-inputcolumns
            '''
            result = self._values.get("input_columns")
            assert result is not None, "Required property 'input_columns' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.InputColumnProperty"]]], result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the relational table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def catalog(self) -> typing.Optional[builtins.str]:
            '''The catalog associated with a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-catalog
            '''
            result = self._values.get("catalog")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def schema(self) -> typing.Optional[builtins.str]:
            '''The schema name.

            This name applies to certain relational database engines.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-schema
            '''
            result = self._values.get("schema")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RelationalTableProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.RenameColumnOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"column_name": "columnName", "new_column_name": "newColumnName"},
    )
    class RenameColumnOperationProperty:
        def __init__(
            self,
            *,
            column_name: builtins.str,
            new_column_name: builtins.str,
        ) -> None:
            '''A transform operation that renames a column.

            :param column_name: The name of the column to be renamed.
            :param new_column_name: The new name for the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-renamecolumnoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                rename_column_operation_property = quicksight.CfnDataSet.RenameColumnOperationProperty(
                    column_name="columnName",
                    new_column_name="newColumnName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d5b477884d5da5b0f50ad9bab47f315489aa821b4b6099b0c110eaa21199d621)
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument new_column_name", value=new_column_name, expected_type=type_hints["new_column_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_name": column_name,
                "new_column_name": new_column_name,
            }

        @builtins.property
        def column_name(self) -> builtins.str:
            '''The name of the column to be renamed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-renamecolumnoperation.html#cfn-quicksight-dataset-renamecolumnoperation-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def new_column_name(self) -> builtins.str:
            '''The new name for the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-renamecolumnoperation.html#cfn-quicksight-dataset-renamecolumnoperation-newcolumnname
            '''
            result = self._values.get("new_column_name")
            assert result is not None, "Required property 'new_column_name' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RenameColumnOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.ResourcePermissionProperty",
        jsii_struct_bases=[],
        name_mapping={"actions": "actions", "principal": "principal"},
    )
    class ResourcePermissionProperty:
        def __init__(
            self,
            *,
            actions: typing.Sequence[builtins.str],
            principal: builtins.str,
        ) -> None:
            '''Permission for the resource.

            :param actions: The IAM action to grant or revoke permisions on.
            :param principal: The Amazon Resource Name (ARN) of the principal. This can be one of the following:. - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.) - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.) - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-resourcepermission.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                resource_permission_property = quicksight.CfnDataSet.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9bb58f071bef44343c863821ef329aa5bd07933ca53b18fb0f34a115344ab505)
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "actions": actions,
                "principal": principal,
            }

        @builtins.property
        def actions(self) -> typing.List[builtins.str]:
            '''The IAM action to grant or revoke permisions on.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-resourcepermission.html#cfn-quicksight-dataset-resourcepermission-actions
            '''
            result = self._values.get("actions")
            assert result is not None, "Required property 'actions' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def principal(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the principal. This can be one of the following:.

            - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
            - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
            - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-resourcepermission.html#cfn-quicksight-dataset-resourcepermission-principal
            '''
            result = self._values.get("principal")
            assert result is not None, "Required property 'principal' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ResourcePermissionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.RowLevelPermissionDataSetProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arn": "arn",
            "permission_policy": "permissionPolicy",
            "format_version": "formatVersion",
            "namespace": "namespace",
            "status": "status",
        },
    )
    class RowLevelPermissionDataSetProperty:
        def __init__(
            self,
            *,
            arn: builtins.str,
            permission_policy: builtins.str,
            format_version: typing.Optional[builtins.str] = None,
            namespace: typing.Optional[builtins.str] = None,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Information about a dataset that contains permissions for row-level security (RLS).

            The permissions dataset maps fields to users or groups. For more information, see `Using Row-Level Security (RLS) to Restrict Access to a Dataset <https://docs.aws.amazon.com/quicksight/latest/user/restrict-access-to-a-data-set-using-row-level-security.html>`_ in the *Amazon QuickSight User Guide* .

            The option to deny permissions by setting ``PermissionPolicy`` to ``DENY_ACCESS`` is not supported for new RLS datasets.

            :param arn: The Amazon Resource Name (ARN) of the dataset that contains permissions for RLS.
            :param permission_policy: The type of permissions to use when interpreting the permissions for RLS. ``DENY_ACCESS`` is included for backward compatibility only.
            :param format_version: The user or group rules associated with the dataset that contains permissions for RLS. By default, ``FormatVersion`` is ``VERSION_1`` . When ``FormatVersion`` is ``VERSION_1`` , ``UserName`` and ``GroupName`` are required. When ``FormatVersion`` is ``VERSION_2`` , ``UserARN`` and ``GroupARN`` are required, and ``Namespace`` must not exist.
            :param namespace: The namespace associated with the dataset that contains permissions for RLS.
            :param status: The status of the row-level security permission dataset. If enabled, the status is ``ENABLED`` . If disabled, the status is ``DISABLED`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                row_level_permission_data_set_property = quicksight.CfnDataSet.RowLevelPermissionDataSetProperty(
                    arn="arn",
                    permission_policy="permissionPolicy",
                
                    # the properties below are optional
                    format_version="formatVersion",
                    namespace="namespace",
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a13ff3b14ed90f74324c82b665fb05dfc0a9a4bf781a94ddd25d089945a8396a)
                check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
                check_type(argname="argument permission_policy", value=permission_policy, expected_type=type_hints["permission_policy"])
                check_type(argname="argument format_version", value=format_version, expected_type=type_hints["format_version"])
                check_type(argname="argument namespace", value=namespace, expected_type=type_hints["namespace"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "arn": arn,
                "permission_policy": permission_policy,
            }
            if format_version is not None:
                self._values["format_version"] = format_version
            if namespace is not None:
                self._values["namespace"] = namespace
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the dataset that contains permissions for RLS.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-arn
            '''
            result = self._values.get("arn")
            assert result is not None, "Required property 'arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def permission_policy(self) -> builtins.str:
            '''The type of permissions to use when interpreting the permissions for RLS.

            ``DENY_ACCESS`` is included for backward compatibility only.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-permissionpolicy
            '''
            result = self._values.get("permission_policy")
            assert result is not None, "Required property 'permission_policy' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_version(self) -> typing.Optional[builtins.str]:
            '''The user or group rules associated with the dataset that contains permissions for RLS.

            By default, ``FormatVersion`` is ``VERSION_1`` . When ``FormatVersion`` is ``VERSION_1`` , ``UserName`` and ``GroupName`` are required. When ``FormatVersion`` is ``VERSION_2`` , ``UserARN`` and ``GroupARN`` are required, and ``Namespace`` must not exist.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-formatversion
            '''
            result = self._values.get("format_version")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def namespace(self) -> typing.Optional[builtins.str]:
            '''The namespace associated with the dataset that contains permissions for RLS.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-namespace
            '''
            result = self._values.get("namespace")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the row-level security permission dataset.

            If enabled, the status is ``ENABLED`` . If disabled, the status is ``DISABLED`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RowLevelPermissionDataSetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.RowLevelPermissionTagConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "tag_rules": "tagRules",
            "status": "status",
            "tag_rule_configurations": "tagRuleConfigurations",
        },
    )
    class RowLevelPermissionTagConfigurationProperty:
        def __init__(
            self,
            *,
            tag_rules: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.RowLevelPermissionTagRuleProperty", typing.Dict[builtins.str, typing.Any]]]]],
            status: typing.Optional[builtins.str] = None,
            tag_rule_configurations: typing.Any = None,
        ) -> None:
            '''The element you can use to define tags for row-level security.

            :param tag_rules: A set of rules associated with row-level security, such as the tag names and columns that they are assigned to.
            :param status: The status of row-level security tags. If enabled, the status is ``ENABLED`` . If disabled, the status is ``DISABLED`` .
            :param tag_rule_configurations: The configuration of tags on a dataset to set row-level security.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiontagconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # tag_rule_configurations: Any
                
                row_level_permission_tag_configuration_property = quicksight.CfnDataSet.RowLevelPermissionTagConfigurationProperty(
                    tag_rules=[quicksight.CfnDataSet.RowLevelPermissionTagRuleProperty(
                        column_name="columnName",
                        tag_key="tagKey",
                
                        # the properties below are optional
                        match_all_value="matchAllValue",
                        tag_multi_value_delimiter="tagMultiValueDelimiter"
                    )],
                
                    # the properties below are optional
                    status="status",
                    tag_rule_configurations=tag_rule_configurations
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ece2bf00916836eda450eb8cfff561ba36b89c9d49d36929ccf01d12e6459e89)
                check_type(argname="argument tag_rules", value=tag_rules, expected_type=type_hints["tag_rules"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument tag_rule_configurations", value=tag_rule_configurations, expected_type=type_hints["tag_rule_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "tag_rules": tag_rules,
            }
            if status is not None:
                self._values["status"] = status
            if tag_rule_configurations is not None:
                self._values["tag_rule_configurations"] = tag_rule_configurations

        @builtins.property
        def tag_rules(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.RowLevelPermissionTagRuleProperty"]]]:
            '''A set of rules associated with row-level security, such as the tag names and columns that they are assigned to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiontagconfiguration.html#cfn-quicksight-dataset-rowlevelpermissiontagconfiguration-tagrules
            '''
            result = self._values.get("tag_rules")
            assert result is not None, "Required property 'tag_rules' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.RowLevelPermissionTagRuleProperty"]]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of row-level security tags.

            If enabled, the status is ``ENABLED`` . If disabled, the status is ``DISABLED`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiontagconfiguration.html#cfn-quicksight-dataset-rowlevelpermissiontagconfiguration-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tag_rule_configurations(self) -> typing.Any:
            '''The configuration of tags on a dataset to set row-level security.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiontagconfiguration.html#cfn-quicksight-dataset-rowlevelpermissiontagconfiguration-tagruleconfigurations
            '''
            result = self._values.get("tag_rule_configurations")
            return typing.cast(typing.Any, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RowLevelPermissionTagConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.RowLevelPermissionTagRuleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_name": "columnName",
            "tag_key": "tagKey",
            "match_all_value": "matchAllValue",
            "tag_multi_value_delimiter": "tagMultiValueDelimiter",
        },
    )
    class RowLevelPermissionTagRuleProperty:
        def __init__(
            self,
            *,
            column_name: builtins.str,
            tag_key: builtins.str,
            match_all_value: typing.Optional[builtins.str] = None,
            tag_multi_value_delimiter: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A set of rules associated with a tag.

            :param column_name: The column name that a tag key is assigned to.
            :param tag_key: The unique key for a tag.
            :param match_all_value: A string that you want to use to filter by all the values in a column in the dataset and don’t want to list the values one by one. For example, you can use an asterisk as your match all value.
            :param tag_multi_value_delimiter: A string that you want to use to delimit the values when you pass the values at run time. For example, you can delimit the values with a comma.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiontagrule.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                row_level_permission_tag_rule_property = quicksight.CfnDataSet.RowLevelPermissionTagRuleProperty(
                    column_name="columnName",
                    tag_key="tagKey",
                
                    # the properties below are optional
                    match_all_value="matchAllValue",
                    tag_multi_value_delimiter="tagMultiValueDelimiter"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__81cfe18daaf7f1cce3330a7282c27dcdf7db3dfda4816cbbf0d13de8875a33f4)
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
                check_type(argname="argument match_all_value", value=match_all_value, expected_type=type_hints["match_all_value"])
                check_type(argname="argument tag_multi_value_delimiter", value=tag_multi_value_delimiter, expected_type=type_hints["tag_multi_value_delimiter"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_name": column_name,
                "tag_key": tag_key,
            }
            if match_all_value is not None:
                self._values["match_all_value"] = match_all_value
            if tag_multi_value_delimiter is not None:
                self._values["tag_multi_value_delimiter"] = tag_multi_value_delimiter

        @builtins.property
        def column_name(self) -> builtins.str:
            '''The column name that a tag key is assigned to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiontagrule.html#cfn-quicksight-dataset-rowlevelpermissiontagrule-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def tag_key(self) -> builtins.str:
            '''The unique key for a tag.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiontagrule.html#cfn-quicksight-dataset-rowlevelpermissiontagrule-tagkey
            '''
            result = self._values.get("tag_key")
            assert result is not None, "Required property 'tag_key' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def match_all_value(self) -> typing.Optional[builtins.str]:
            '''A string that you want to use to filter by all the values in a column in the dataset and don’t want to list the values one by one.

            For example, you can use an asterisk as your match all value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiontagrule.html#cfn-quicksight-dataset-rowlevelpermissiontagrule-matchallvalue
            '''
            result = self._values.get("match_all_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tag_multi_value_delimiter(self) -> typing.Optional[builtins.str]:
            '''A string that you want to use to delimit the values when you pass the values at run time.

            For example, you can delimit the values with a comma.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiontagrule.html#cfn-quicksight-dataset-rowlevelpermissiontagrule-tagmultivaluedelimiter
            '''
            result = self._values.get("tag_multi_value_delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RowLevelPermissionTagRuleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.S3SourceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_source_arn": "dataSourceArn",
            "input_columns": "inputColumns",
            "upload_settings": "uploadSettings",
        },
    )
    class S3SourceProperty:
        def __init__(
            self,
            *,
            data_source_arn: builtins.str,
            input_columns: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.InputColumnProperty", typing.Dict[builtins.str, typing.Any]]]]],
            upload_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.UploadSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A physical table type for an S3 data source.

            :param data_source_arn: The Amazon Resource Name (ARN) for the data source.
            :param input_columns: A physical table type for an S3 data source. .. epigraph:: For files that aren't JSON, only ``STRING`` data types are supported in input columns.
            :param upload_settings: Information about the format for the S3 source file or files.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-s3source.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                s3_source_property = quicksight.CfnDataSet.S3SourceProperty(
                    data_source_arn="dataSourceArn",
                    input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                        name="name",
                        type="type",
                
                        # the properties below are optional
                        sub_type="subType"
                    )],
                
                    # the properties below are optional
                    upload_settings=quicksight.CfnDataSet.UploadSettingsProperty(
                        contains_header=False,
                        delimiter="delimiter",
                        format="format",
                        start_from_row=123,
                        text_qualifier="textQualifier"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__79cf313addf8aafc0315b078c7ce60c5b690622f4de3e59d06a4acc66261b863)
                check_type(argname="argument data_source_arn", value=data_source_arn, expected_type=type_hints["data_source_arn"])
                check_type(argname="argument input_columns", value=input_columns, expected_type=type_hints["input_columns"])
                check_type(argname="argument upload_settings", value=upload_settings, expected_type=type_hints["upload_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_source_arn": data_source_arn,
                "input_columns": input_columns,
            }
            if upload_settings is not None:
                self._values["upload_settings"] = upload_settings

        @builtins.property
        def data_source_arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) for the data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-s3source.html#cfn-quicksight-dataset-s3source-datasourcearn
            '''
            result = self._values.get("data_source_arn")
            assert result is not None, "Required property 'data_source_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def input_columns(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.InputColumnProperty"]]]:
            '''A physical table type for an S3 data source.

            .. epigraph::

               For files that aren't JSON, only ``STRING`` data types are supported in input columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-s3source.html#cfn-quicksight-dataset-s3source-inputcolumns
            '''
            result = self._values.get("input_columns")
            assert result is not None, "Required property 'input_columns' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSet.InputColumnProperty"]]], result)

        @builtins.property
        def upload_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.UploadSettingsProperty"]]:
            '''Information about the format for the S3 source file or files.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-s3source.html#cfn-quicksight-dataset-s3source-uploadsettings
            '''
            result = self._values.get("upload_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.UploadSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "S3SourceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.StringDatasetParameterDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={"static_values": "staticValues"},
    )
    class StringDatasetParameterDefaultValuesProperty:
        def __init__(
            self,
            *,
            static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A list of default values for a given string dataset parameter type.

            This structure only accepts static values.

            :param static_values: A list of static default values for a given string parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-stringdatasetparameterdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                string_dataset_parameter_default_values_property = quicksight.CfnDataSet.StringDatasetParameterDefaultValuesProperty(
                    static_values=["staticValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7f668bce303788d496afc1ab8d65a300b75b6b9f33a139302c49944746ce693f)
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of static default values for a given string parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-stringdatasetparameterdefaultvalues.html#cfn-quicksight-dataset-stringdatasetparameterdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringDatasetParameterDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.StringDatasetParameterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "id": "id",
            "name": "name",
            "value_type": "valueType",
            "default_values": "defaultValues",
        },
    )
    class StringDatasetParameterProperty:
        def __init__(
            self,
            *,
            id: builtins.str,
            name: builtins.str,
            value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.StringDatasetParameterDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A string parameter that is created in the dataset.

            :param id: An identifier for the string parameter that is created in the dataset.
            :param name: The name of the string parameter that is created in the dataset.
            :param value_type: The value type of the dataset parameter. Valid values are ``single value`` or ``multi value`` .
            :param default_values: A list of default values for a given string dataset parameter type. This structure only accepts static values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-stringdatasetparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                string_dataset_parameter_property = quicksight.CfnDataSet.StringDatasetParameterProperty(
                    id="id",
                    name="name",
                    value_type="valueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnDataSet.StringDatasetParameterDefaultValuesProperty(
                        static_values=["staticValues"]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__56f5fcfd7982ecefc35542f2188875aef069ca10ddc427320367c2fa8840e5f5)
                check_type(argname="argument id", value=id, expected_type=type_hints["id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument value_type", value=value_type, expected_type=type_hints["value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "id": id,
                "name": name,
                "value_type": value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values

        @builtins.property
        def id(self) -> builtins.str:
            '''An identifier for the string parameter that is created in the dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-stringdatasetparameter.html#cfn-quicksight-dataset-stringdatasetparameter-id
            '''
            result = self._values.get("id")
            assert result is not None, "Required property 'id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the string parameter that is created in the dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-stringdatasetparameter.html#cfn-quicksight-dataset-stringdatasetparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value_type(self) -> builtins.str:
            '''The value type of the dataset parameter.

            Valid values are ``single value`` or ``multi value`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-stringdatasetparameter.html#cfn-quicksight-dataset-stringdatasetparameter-valuetype
            '''
            result = self._values.get("value_type")
            assert result is not None, "Required property 'value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.StringDatasetParameterDefaultValuesProperty"]]:
            '''A list of default values for a given string dataset parameter type.

            This structure only accepts static values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-stringdatasetparameter.html#cfn-quicksight-dataset-stringdatasetparameter-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.StringDatasetParameterDefaultValuesProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringDatasetParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.TagColumnOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"column_name": "columnName", "tags": "tags"},
    )
    class TagColumnOperationProperty:
        def __init__(
            self,
            *,
            column_name: builtins.str,
            tags: typing.Sequence[typing.Union["CfnDataSet.ColumnTagProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''A transform operation that tags a column with additional information.

            :param column_name: The column that this operation acts on.
            :param tags: The dataset column tag, currently only used for geospatial type tagging. .. epigraph:: This is not tags for the AWS tagging feature.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-tagcolumnoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                tag_column_operation_property = quicksight.CfnDataSet.TagColumnOperationProperty(
                    column_name="columnName",
                    tags=[quicksight.CfnDataSet.ColumnTagProperty(
                        column_description=quicksight.CfnDataSet.ColumnDescriptionProperty(
                            text="text"
                        ),
                        column_geographic_role="columnGeographicRole"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__93fc79585789eee04ffca88f090e606a6fa427e4c69b3f619a922b666c3ecd49)
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_name": column_name,
                "tags": tags,
            }

        @builtins.property
        def column_name(self) -> builtins.str:
            '''The column that this operation acts on.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-tagcolumnoperation.html#cfn-quicksight-dataset-tagcolumnoperation-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def tags(self) -> typing.List["CfnDataSet.ColumnTagProperty"]:
            '''The dataset column tag, currently only used for geospatial type tagging.

            .. epigraph::

               This is not tags for the AWS tagging feature.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-tagcolumnoperation.html#cfn-quicksight-dataset-tagcolumnoperation-tags
            '''
            result = self._values.get("tags")
            assert result is not None, "Required property 'tags' is missing"
            return typing.cast(typing.List["CfnDataSet.ColumnTagProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TagColumnOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.TransformOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cast_column_type_operation": "castColumnTypeOperation",
            "create_columns_operation": "createColumnsOperation",
            "filter_operation": "filterOperation",
            "override_dataset_parameter_operation": "overrideDatasetParameterOperation",
            "project_operation": "projectOperation",
            "rename_column_operation": "renameColumnOperation",
            "tag_column_operation": "tagColumnOperation",
        },
    )
    class TransformOperationProperty:
        def __init__(
            self,
            *,
            cast_column_type_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.CastColumnTypeOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            create_columns_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.CreateColumnsOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            filter_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.FilterOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            override_dataset_parameter_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.OverrideDatasetParameterOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            project_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.ProjectOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rename_column_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.RenameColumnOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tag_column_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSet.TagColumnOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A data transformation on a logical table.

            This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

            :param cast_column_type_operation: A transform operation that casts a column to a different type.
            :param create_columns_operation: An operation that creates calculated columns. Columns created in one such operation form a lexical closure.
            :param filter_operation: An operation that filters rows based on some condition.
            :param override_dataset_parameter_operation: 
            :param project_operation: An operation that projects columns. Operations that come after a projection can only refer to projected columns.
            :param rename_column_operation: An operation that renames a column.
            :param tag_column_operation: An operation that tags a column with additional information.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                transform_operation_property = quicksight.CfnDataSet.TransformOperationProperty(
                    cast_column_type_operation=quicksight.CfnDataSet.CastColumnTypeOperationProperty(
                        column_name="columnName",
                        new_column_type="newColumnType",
                
                        # the properties below are optional
                        format="format",
                        sub_type="subType"
                    ),
                    create_columns_operation=quicksight.CfnDataSet.CreateColumnsOperationProperty(
                        columns=[quicksight.CfnDataSet.CalculatedColumnProperty(
                            column_id="columnId",
                            column_name="columnName",
                            expression="expression"
                        )]
                    ),
                    filter_operation=quicksight.CfnDataSet.FilterOperationProperty(
                        condition_expression="conditionExpression"
                    ),
                    override_dataset_parameter_operation=quicksight.CfnDataSet.OverrideDatasetParameterOperationProperty(
                        parameter_name="parameterName",
                
                        # the properties below are optional
                        new_default_values=quicksight.CfnDataSet.NewDefaultValuesProperty(
                            date_time_static_values=["dateTimeStaticValues"],
                            decimal_static_values=[123],
                            integer_static_values=[123],
                            string_static_values=["stringStaticValues"]
                        ),
                        new_parameter_name="newParameterName"
                    ),
                    project_operation=quicksight.CfnDataSet.ProjectOperationProperty(
                        projected_columns=["projectedColumns"]
                    ),
                    rename_column_operation=quicksight.CfnDataSet.RenameColumnOperationProperty(
                        column_name="columnName",
                        new_column_name="newColumnName"
                    ),
                    tag_column_operation=quicksight.CfnDataSet.TagColumnOperationProperty(
                        column_name="columnName",
                        tags=[quicksight.CfnDataSet.ColumnTagProperty(
                            column_description=quicksight.CfnDataSet.ColumnDescriptionProperty(
                                text="text"
                            ),
                            column_geographic_role="columnGeographicRole"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c858116d8ca183e35074dc7ac22d6e02615a61e79e9558dc2d96336d92a9201e)
                check_type(argname="argument cast_column_type_operation", value=cast_column_type_operation, expected_type=type_hints["cast_column_type_operation"])
                check_type(argname="argument create_columns_operation", value=create_columns_operation, expected_type=type_hints["create_columns_operation"])
                check_type(argname="argument filter_operation", value=filter_operation, expected_type=type_hints["filter_operation"])
                check_type(argname="argument override_dataset_parameter_operation", value=override_dataset_parameter_operation, expected_type=type_hints["override_dataset_parameter_operation"])
                check_type(argname="argument project_operation", value=project_operation, expected_type=type_hints["project_operation"])
                check_type(argname="argument rename_column_operation", value=rename_column_operation, expected_type=type_hints["rename_column_operation"])
                check_type(argname="argument tag_column_operation", value=tag_column_operation, expected_type=type_hints["tag_column_operation"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cast_column_type_operation is not None:
                self._values["cast_column_type_operation"] = cast_column_type_operation
            if create_columns_operation is not None:
                self._values["create_columns_operation"] = create_columns_operation
            if filter_operation is not None:
                self._values["filter_operation"] = filter_operation
            if override_dataset_parameter_operation is not None:
                self._values["override_dataset_parameter_operation"] = override_dataset_parameter_operation
            if project_operation is not None:
                self._values["project_operation"] = project_operation
            if rename_column_operation is not None:
                self._values["rename_column_operation"] = rename_column_operation
            if tag_column_operation is not None:
                self._values["tag_column_operation"] = tag_column_operation

        @builtins.property
        def cast_column_type_operation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.CastColumnTypeOperationProperty"]]:
            '''A transform operation that casts a column to a different type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-castcolumntypeoperation
            '''
            result = self._values.get("cast_column_type_operation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.CastColumnTypeOperationProperty"]], result)

        @builtins.property
        def create_columns_operation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.CreateColumnsOperationProperty"]]:
            '''An operation that creates calculated columns.

            Columns created in one such operation form a lexical closure.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-createcolumnsoperation
            '''
            result = self._values.get("create_columns_operation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.CreateColumnsOperationProperty"]], result)

        @builtins.property
        def filter_operation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.FilterOperationProperty"]]:
            '''An operation that filters rows based on some condition.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-filteroperation
            '''
            result = self._values.get("filter_operation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.FilterOperationProperty"]], result)

        @builtins.property
        def override_dataset_parameter_operation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.OverrideDatasetParameterOperationProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-overridedatasetparameteroperation
            '''
            result = self._values.get("override_dataset_parameter_operation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.OverrideDatasetParameterOperationProperty"]], result)

        @builtins.property
        def project_operation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.ProjectOperationProperty"]]:
            '''An operation that projects columns.

            Operations that come after a projection can only refer to projected columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-projectoperation
            '''
            result = self._values.get("project_operation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.ProjectOperationProperty"]], result)

        @builtins.property
        def rename_column_operation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.RenameColumnOperationProperty"]]:
            '''An operation that renames a column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-renamecolumnoperation
            '''
            result = self._values.get("rename_column_operation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.RenameColumnOperationProperty"]], result)

        @builtins.property
        def tag_column_operation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.TagColumnOperationProperty"]]:
            '''An operation that tags a column with additional information.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-tagcolumnoperation
            '''
            result = self._values.get("tag_column_operation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSet.TagColumnOperationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TransformOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSet.UploadSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "contains_header": "containsHeader",
            "delimiter": "delimiter",
            "format": "format",
            "start_from_row": "startFromRow",
            "text_qualifier": "textQualifier",
        },
    )
    class UploadSettingsProperty:
        def __init__(
            self,
            *,
            contains_header: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
            delimiter: typing.Optional[builtins.str] = None,
            format: typing.Optional[builtins.str] = None,
            start_from_row: typing.Optional[jsii.Number] = None,
            text_qualifier: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Information about the format for a source file or files.

            :param contains_header: Whether the file has a header row, or the files each have a header row.
            :param delimiter: The delimiter between values in the file.
            :param format: File format.
            :param start_from_row: A row number to start reading data from.
            :param text_qualifier: Text qualifier.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                upload_settings_property = quicksight.CfnDataSet.UploadSettingsProperty(
                    contains_header=False,
                    delimiter="delimiter",
                    format="format",
                    start_from_row=123,
                    text_qualifier="textQualifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e2351ca9dadd3fd462a352b80b2d2c36c320b5ef214657b3f26b548908b97913)
                check_type(argname="argument contains_header", value=contains_header, expected_type=type_hints["contains_header"])
                check_type(argname="argument delimiter", value=delimiter, expected_type=type_hints["delimiter"])
                check_type(argname="argument format", value=format, expected_type=type_hints["format"])
                check_type(argname="argument start_from_row", value=start_from_row, expected_type=type_hints["start_from_row"])
                check_type(argname="argument text_qualifier", value=text_qualifier, expected_type=type_hints["text_qualifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if contains_header is not None:
                self._values["contains_header"] = contains_header
            if delimiter is not None:
                self._values["delimiter"] = delimiter
            if format is not None:
                self._values["format"] = format
            if start_from_row is not None:
                self._values["start_from_row"] = start_from_row
            if text_qualifier is not None:
                self._values["text_qualifier"] = text_qualifier

        @builtins.property
        def contains_header(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''Whether the file has a header row, or the files each have a header row.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-containsheader
            '''
            result = self._values.get("contains_header")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        @builtins.property
        def delimiter(self) -> typing.Optional[builtins.str]:
            '''The delimiter between values in the file.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-delimiter
            '''
            result = self._values.get("delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format(self) -> typing.Optional[builtins.str]:
            '''File format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-format
            '''
            result = self._values.get("format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def start_from_row(self) -> typing.Optional[jsii.Number]:
            '''A row number to start reading data from.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-startfromrow
            '''
            result = self._values.get("start_from_row")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def text_qualifier(self) -> typing.Optional[builtins.str]:
            '''Text qualifier.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-textqualifier
            '''
            result = self._values.get("text_qualifier")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UploadSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSetProps",
    jsii_struct_bases=[],
    name_mapping={
        "aws_account_id": "awsAccountId",
        "column_groups": "columnGroups",
        "column_level_permission_rules": "columnLevelPermissionRules",
        "data_set_id": "dataSetId",
        "dataset_parameters": "datasetParameters",
        "data_set_refresh_properties": "dataSetRefreshProperties",
        "data_set_usage_configuration": "dataSetUsageConfiguration",
        "field_folders": "fieldFolders",
        "import_mode": "importMode",
        "ingestion_wait_policy": "ingestionWaitPolicy",
        "logical_table_map": "logicalTableMap",
        "name": "name",
        "permissions": "permissions",
        "physical_table_map": "physicalTableMap",
        "row_level_permission_data_set": "rowLevelPermissionDataSet",
        "row_level_permission_tag_configuration": "rowLevelPermissionTagConfiguration",
        "tags": "tags",
    },
)
class CfnDataSetProps:
    def __init__(
        self,
        *,
        aws_account_id: typing.Optional[builtins.str] = None,
        column_groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.ColumnGroupProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        column_level_permission_rules: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.ColumnLevelPermissionRuleProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        data_set_id: typing.Optional[builtins.str] = None,
        dataset_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.DatasetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        data_set_refresh_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.DataSetRefreshPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        data_set_usage_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.DataSetUsageConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        field_folders: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.FieldFolderProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        import_mode: typing.Optional[builtins.str] = None,
        ingestion_wait_policy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.IngestionWaitPolicyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        logical_table_map: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.LogicalTableProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        physical_table_map: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.PhysicalTableProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        row_level_permission_data_set: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.RowLevelPermissionDataSetProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        row_level_permission_tag_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.RowLevelPermissionTagConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
    ) -> None:
        '''Properties for defining a ``CfnDataSet``.

        :param aws_account_id: The AWS account ID.
        :param column_groups: Groupings of columns that work together in certain Amazon QuickSight features. Currently, only geospatial hierarchy is supported.
        :param column_level_permission_rules: A set of one or more definitions of a ``ColumnLevelPermissionRule`` .
        :param data_set_id: An ID for the dataset that you want to create. This ID is unique per AWS Region for each AWS account.
        :param dataset_parameters: The parameters that are declared in a dataset.
        :param data_set_refresh_properties: The refresh properties of a dataset.
        :param data_set_usage_configuration: The usage configuration to apply to child datasets that reference this dataset as a source.
        :param field_folders: The folder that contains fields and nested subfolders for your dataset.
        :param import_mode: Indicates whether you want to import the data into SPICE.
        :param ingestion_wait_policy: The wait policy to use when creating or updating a Dataset. The default is to wait for SPICE ingestion to finish with timeout of 36 hours.
        :param logical_table_map: Configures the combination and transformation of the data from the physical tables.
        :param name: The display name for the dataset.
        :param permissions: A list of resource permissions on the dataset.
        :param physical_table_map: Declares the physical tables that are available in the underlying data sources.
        :param row_level_permission_data_set: The row-level security configuration for the data that you want to create.
        :param row_level_permission_tag_configuration: The element you can use to define tags for row-level security.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            from aws_cdk import aws_quicksight as quicksight
            
            # tag_rule_configurations: Any
            
            cfn_data_set_props = quicksight.CfnDataSetProps(
                aws_account_id="awsAccountId",
                column_groups=[quicksight.CfnDataSet.ColumnGroupProperty(
                    geo_spatial_column_group=quicksight.CfnDataSet.GeoSpatialColumnGroupProperty(
                        columns=["columns"],
                        name="name",
            
                        # the properties below are optional
                        country_code="countryCode"
                    )
                )],
                column_level_permission_rules=[quicksight.CfnDataSet.ColumnLevelPermissionRuleProperty(
                    column_names=["columnNames"],
                    principals=["principals"]
                )],
                data_set_id="dataSetId",
                dataset_parameters=[quicksight.CfnDataSet.DatasetParameterProperty(
                    date_time_dataset_parameter=quicksight.CfnDataSet.DateTimeDatasetParameterProperty(
                        id="id",
                        name="name",
                        value_type="valueType",
            
                        # the properties below are optional
                        default_values=quicksight.CfnDataSet.DateTimeDatasetParameterDefaultValuesProperty(
                            static_values=["staticValues"]
                        ),
                        time_granularity="timeGranularity"
                    ),
                    decimal_dataset_parameter=quicksight.CfnDataSet.DecimalDatasetParameterProperty(
                        id="id",
                        name="name",
                        value_type="valueType",
            
                        # the properties below are optional
                        default_values=quicksight.CfnDataSet.DecimalDatasetParameterDefaultValuesProperty(
                            static_values=[123]
                        )
                    ),
                    integer_dataset_parameter=quicksight.CfnDataSet.IntegerDatasetParameterProperty(
                        id="id",
                        name="name",
                        value_type="valueType",
            
                        # the properties below are optional
                        default_values=quicksight.CfnDataSet.IntegerDatasetParameterDefaultValuesProperty(
                            static_values=[123]
                        )
                    ),
                    string_dataset_parameter=quicksight.CfnDataSet.StringDatasetParameterProperty(
                        id="id",
                        name="name",
                        value_type="valueType",
            
                        # the properties below are optional
                        default_values=quicksight.CfnDataSet.StringDatasetParameterDefaultValuesProperty(
                            static_values=["staticValues"]
                        )
                    )
                )],
                data_set_refresh_properties=quicksight.CfnDataSet.DataSetRefreshPropertiesProperty(
                    refresh_configuration=quicksight.CfnDataSet.RefreshConfigurationProperty(
                        incremental_refresh=quicksight.CfnDataSet.IncrementalRefreshProperty(
                            lookback_window=quicksight.CfnDataSet.LookbackWindowProperty(
                                column_name="columnName",
                                size=123,
                                size_unit="sizeUnit"
                            )
                        )
                    )
                ),
                data_set_usage_configuration=quicksight.CfnDataSet.DataSetUsageConfigurationProperty(
                    disable_use_as_direct_query_source=False,
                    disable_use_as_imported_source=False
                ),
                field_folders={
                    "field_folders_key": quicksight.CfnDataSet.FieldFolderProperty(
                        columns=["columns"],
                        description="description"
                    )
                },
                import_mode="importMode",
                ingestion_wait_policy=quicksight.CfnDataSet.IngestionWaitPolicyProperty(
                    ingestion_wait_time_in_hours=123,
                    wait_for_spice_ingestion=False
                ),
                logical_table_map={
                    "logical_table_map_key": quicksight.CfnDataSet.LogicalTableProperty(
                        alias="alias",
                        source=quicksight.CfnDataSet.LogicalTableSourceProperty(
                            data_set_arn="dataSetArn",
                            join_instruction=quicksight.CfnDataSet.JoinInstructionProperty(
                                left_operand="leftOperand",
                                on_clause="onClause",
                                right_operand="rightOperand",
                                type="type",
            
                                # the properties below are optional
                                left_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                                    unique_key=False
                                ),
                                right_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                                    unique_key=False
                                )
                            ),
                            physical_table_id="physicalTableId"
                        ),
            
                        # the properties below are optional
                        data_transforms=[quicksight.CfnDataSet.TransformOperationProperty(
                            cast_column_type_operation=quicksight.CfnDataSet.CastColumnTypeOperationProperty(
                                column_name="columnName",
                                new_column_type="newColumnType",
            
                                # the properties below are optional
                                format="format",
                                sub_type="subType"
                            ),
                            create_columns_operation=quicksight.CfnDataSet.CreateColumnsOperationProperty(
                                columns=[quicksight.CfnDataSet.CalculatedColumnProperty(
                                    column_id="columnId",
                                    column_name="columnName",
                                    expression="expression"
                                )]
                            ),
                            filter_operation=quicksight.CfnDataSet.FilterOperationProperty(
                                condition_expression="conditionExpression"
                            ),
                            override_dataset_parameter_operation=quicksight.CfnDataSet.OverrideDatasetParameterOperationProperty(
                                parameter_name="parameterName",
            
                                # the properties below are optional
                                new_default_values=quicksight.CfnDataSet.NewDefaultValuesProperty(
                                    date_time_static_values=["dateTimeStaticValues"],
                                    decimal_static_values=[123],
                                    integer_static_values=[123],
                                    string_static_values=["stringStaticValues"]
                                ),
                                new_parameter_name="newParameterName"
                            ),
                            project_operation=quicksight.CfnDataSet.ProjectOperationProperty(
                                projected_columns=["projectedColumns"]
                            ),
                            rename_column_operation=quicksight.CfnDataSet.RenameColumnOperationProperty(
                                column_name="columnName",
                                new_column_name="newColumnName"
                            ),
                            tag_column_operation=quicksight.CfnDataSet.TagColumnOperationProperty(
                                column_name="columnName",
                                tags=[quicksight.CfnDataSet.ColumnTagProperty(
                                    column_description=quicksight.CfnDataSet.ColumnDescriptionProperty(
                                        text="text"
                                    ),
                                    column_geographic_role="columnGeographicRole"
                                )]
                            )
                        )]
                    )
                },
                name="name",
                permissions=[quicksight.CfnDataSet.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal"
                )],
                physical_table_map={
                    "physical_table_map_key": quicksight.CfnDataSet.PhysicalTableProperty(
                        custom_sql=quicksight.CfnDataSet.CustomSqlProperty(
                            columns=[quicksight.CfnDataSet.InputColumnProperty(
                                name="name",
                                type="type",
            
                                # the properties below are optional
                                sub_type="subType"
                            )],
                            data_source_arn="dataSourceArn",
                            name="name",
                            sql_query="sqlQuery"
                        ),
                        relational_table=quicksight.CfnDataSet.RelationalTableProperty(
                            data_source_arn="dataSourceArn",
                            input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                                name="name",
                                type="type",
            
                                # the properties below are optional
                                sub_type="subType"
                            )],
                            name="name",
            
                            # the properties below are optional
                            catalog="catalog",
                            schema="schema"
                        ),
                        s3_source=quicksight.CfnDataSet.S3SourceProperty(
                            data_source_arn="dataSourceArn",
                            input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                                name="name",
                                type="type",
            
                                # the properties below are optional
                                sub_type="subType"
                            )],
            
                            # the properties below are optional
                            upload_settings=quicksight.CfnDataSet.UploadSettingsProperty(
                                contains_header=False,
                                delimiter="delimiter",
                                format="format",
                                start_from_row=123,
                                text_qualifier="textQualifier"
                            )
                        )
                    )
                },
                row_level_permission_data_set=quicksight.CfnDataSet.RowLevelPermissionDataSetProperty(
                    arn="arn",
                    permission_policy="permissionPolicy",
            
                    # the properties below are optional
                    format_version="formatVersion",
                    namespace="namespace",
                    status="status"
                ),
                row_level_permission_tag_configuration=quicksight.CfnDataSet.RowLevelPermissionTagConfigurationProperty(
                    tag_rules=[quicksight.CfnDataSet.RowLevelPermissionTagRuleProperty(
                        column_name="columnName",
                        tag_key="tagKey",
            
                        # the properties below are optional
                        match_all_value="matchAllValue",
                        tag_multi_value_delimiter="tagMultiValueDelimiter"
                    )],
            
                    # the properties below are optional
                    status="status",
                    tag_rule_configurations=tag_rule_configurations
                ),
                tags=[CfnTag(
                    key="key",
                    value="value"
                )]
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__61032f5c9704bd9765ba5fe5f2862434b85348f65b701e3a44b806fef0a9d31b)
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument column_groups", value=column_groups, expected_type=type_hints["column_groups"])
            check_type(argname="argument column_level_permission_rules", value=column_level_permission_rules, expected_type=type_hints["column_level_permission_rules"])
            check_type(argname="argument data_set_id", value=data_set_id, expected_type=type_hints["data_set_id"])
            check_type(argname="argument dataset_parameters", value=dataset_parameters, expected_type=type_hints["dataset_parameters"])
            check_type(argname="argument data_set_refresh_properties", value=data_set_refresh_properties, expected_type=type_hints["data_set_refresh_properties"])
            check_type(argname="argument data_set_usage_configuration", value=data_set_usage_configuration, expected_type=type_hints["data_set_usage_configuration"])
            check_type(argname="argument field_folders", value=field_folders, expected_type=type_hints["field_folders"])
            check_type(argname="argument import_mode", value=import_mode, expected_type=type_hints["import_mode"])
            check_type(argname="argument ingestion_wait_policy", value=ingestion_wait_policy, expected_type=type_hints["ingestion_wait_policy"])
            check_type(argname="argument logical_table_map", value=logical_table_map, expected_type=type_hints["logical_table_map"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument permissions", value=permissions, expected_type=type_hints["permissions"])
            check_type(argname="argument physical_table_map", value=physical_table_map, expected_type=type_hints["physical_table_map"])
            check_type(argname="argument row_level_permission_data_set", value=row_level_permission_data_set, expected_type=type_hints["row_level_permission_data_set"])
            check_type(argname="argument row_level_permission_tag_configuration", value=row_level_permission_tag_configuration, expected_type=type_hints["row_level_permission_tag_configuration"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if aws_account_id is not None:
            self._values["aws_account_id"] = aws_account_id
        if column_groups is not None:
            self._values["column_groups"] = column_groups
        if column_level_permission_rules is not None:
            self._values["column_level_permission_rules"] = column_level_permission_rules
        if data_set_id is not None:
            self._values["data_set_id"] = data_set_id
        if dataset_parameters is not None:
            self._values["dataset_parameters"] = dataset_parameters
        if data_set_refresh_properties is not None:
            self._values["data_set_refresh_properties"] = data_set_refresh_properties
        if data_set_usage_configuration is not None:
            self._values["data_set_usage_configuration"] = data_set_usage_configuration
        if field_folders is not None:
            self._values["field_folders"] = field_folders
        if import_mode is not None:
            self._values["import_mode"] = import_mode
        if ingestion_wait_policy is not None:
            self._values["ingestion_wait_policy"] = ingestion_wait_policy
        if logical_table_map is not None:
            self._values["logical_table_map"] = logical_table_map
        if name is not None:
            self._values["name"] = name
        if permissions is not None:
            self._values["permissions"] = permissions
        if physical_table_map is not None:
            self._values["physical_table_map"] = physical_table_map
        if row_level_permission_data_set is not None:
            self._values["row_level_permission_data_set"] = row_level_permission_data_set
        if row_level_permission_tag_configuration is not None:
            self._values["row_level_permission_tag_configuration"] = row_level_permission_tag_configuration
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def column_groups(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnDataSet.ColumnGroupProperty]]]]:
        '''Groupings of columns that work together in certain Amazon QuickSight features.

        Currently, only geospatial hierarchy is supported.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-columngroups
        '''
        result = self._values.get("column_groups")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnDataSet.ColumnGroupProperty]]]], result)

    @builtins.property
    def column_level_permission_rules(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnDataSet.ColumnLevelPermissionRuleProperty]]]]:
        '''A set of one or more definitions of a ``ColumnLevelPermissionRule`` .

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-columnlevelpermissionrules
        '''
        result = self._values.get("column_level_permission_rules")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnDataSet.ColumnLevelPermissionRuleProperty]]]], result)

    @builtins.property
    def data_set_id(self) -> typing.Optional[builtins.str]:
        '''An ID for the dataset that you want to create.

        This ID is unique per AWS Region for each AWS account.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-datasetid
        '''
        result = self._values.get("data_set_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def dataset_parameters(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnDataSet.DatasetParameterProperty]]]]:
        '''The parameters that are declared in a dataset.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-datasetparameters
        '''
        result = self._values.get("dataset_parameters")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnDataSet.DatasetParameterProperty]]]], result)

    @builtins.property
    def data_set_refresh_properties(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSet.DataSetRefreshPropertiesProperty]]:
        '''The refresh properties of a dataset.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-datasetrefreshproperties
        '''
        result = self._values.get("data_set_refresh_properties")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSet.DataSetRefreshPropertiesProperty]], result)

    @builtins.property
    def data_set_usage_configuration(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSet.DataSetUsageConfigurationProperty]]:
        '''The usage configuration to apply to child datasets that reference this dataset as a source.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-datasetusageconfiguration
        '''
        result = self._values.get("data_set_usage_configuration")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSet.DataSetUsageConfigurationProperty]], result)

    @builtins.property
    def field_folders(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, CfnDataSet.FieldFolderProperty]]]]:
        '''The folder that contains fields and nested subfolders for your dataset.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-fieldfolders
        '''
        result = self._values.get("field_folders")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, CfnDataSet.FieldFolderProperty]]]], result)

    @builtins.property
    def import_mode(self) -> typing.Optional[builtins.str]:
        '''Indicates whether you want to import the data into SPICE.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-importmode
        '''
        result = self._values.get("import_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def ingestion_wait_policy(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSet.IngestionWaitPolicyProperty]]:
        '''The wait policy to use when creating or updating a Dataset.

        The default is to wait for SPICE ingestion to finish with timeout of 36 hours.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-ingestionwaitpolicy
        '''
        result = self._values.get("ingestion_wait_policy")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSet.IngestionWaitPolicyProperty]], result)

    @builtins.property
    def logical_table_map(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, CfnDataSet.LogicalTableProperty]]]]:
        '''Configures the combination and transformation of the data from the physical tables.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-logicaltablemap
        '''
        result = self._values.get("logical_table_map")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, CfnDataSet.LogicalTableProperty]]]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''The display name for the dataset.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-name
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnDataSet.ResourcePermissionProperty]]]]:
        '''A list of resource permissions on the dataset.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-permissions
        '''
        result = self._values.get("permissions")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnDataSet.ResourcePermissionProperty]]]], result)

    @builtins.property
    def physical_table_map(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, CfnDataSet.PhysicalTableProperty]]]]:
        '''Declares the physical tables that are available in the underlying data sources.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-physicaltablemap
        '''
        result = self._values.get("physical_table_map")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, CfnDataSet.PhysicalTableProperty]]]], result)

    @builtins.property
    def row_level_permission_data_set(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSet.RowLevelPermissionDataSetProperty]]:
        '''The row-level security configuration for the data that you want to create.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset
        '''
        result = self._values.get("row_level_permission_data_set")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSet.RowLevelPermissionDataSetProperty]], result)

    @builtins.property
    def row_level_permission_tag_configuration(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSet.RowLevelPermissionTagConfigurationProperty]]:
        '''The element you can use to define tags for row-level security.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-rowlevelpermissiontagconfiguration
        '''
        result = self._values.get("row_level_permission_tag_configuration")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSet.RowLevelPermissionTagConfigurationProperty]], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[_CfnTag_f6864754]]:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-tags
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[_CfnTag_f6864754]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnDataSetProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_IInspectable_c2943556, _ITaggable_36806126)
class CfnDataSource(
    _CfnResource_9df397a6,
    metaclass=jsii.JSIIMeta,
    jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource",
):
    '''Creates a data source.

    :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html
    :cloudformationResource: AWS::QuickSight::DataSource
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        from aws_cdk import aws_quicksight as quicksight
        
        cfn_data_source = quicksight.CfnDataSource(self, "MyCfnDataSource",
            alternate_data_source_parameters=[quicksight.CfnDataSource.DataSourceParametersProperty(
                amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                    domain="domain"
                ),
                amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                    domain="domain"
                ),
                athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                    role_arn="roleArn",
                    work_group="workGroup"
                ),
                aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                    host="host",
                    port=123,
                    sql_endpoint_path="sqlEndpointPath"
                ),
                maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                    catalog="catalog",
                    host="host",
                    port=123
                ),
                rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                    database="database",
                    instance_id="instanceId"
                ),
                redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                    database="database",
        
                    # the properties below are optional
                    cluster_id="clusterId",
                    host="host",
                    port=123
                ),
                s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                    manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                        bucket="bucket",
                        key="key"
                    ),
        
                    # the properties below are optional
                    role_arn="roleArn"
                ),
                snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                    database="database",
                    host="host",
                    warehouse="warehouse"
                ),
                spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                    host="host",
                    port=123
                ),
                sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                starburst_parameters=quicksight.CfnDataSource.StarburstParametersProperty(
                    catalog="catalog",
                    host="host",
                    port=123,
        
                    # the properties below are optional
                    product_type="productType"
                ),
                teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                trino_parameters=quicksight.CfnDataSource.TrinoParametersProperty(
                    catalog="catalog",
                    host="host",
                    port=123
                )
            )],
            aws_account_id="awsAccountId",
            credentials=quicksight.CfnDataSource.DataSourceCredentialsProperty(
                copy_source_arn="copySourceArn",
                credential_pair=quicksight.CfnDataSource.CredentialPairProperty(
                    password="password",
                    username="username",
        
                    # the properties below are optional
                    alternate_data_source_parameters=[quicksight.CfnDataSource.DataSourceParametersProperty(
                        amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                            domain="domain"
                        ),
                        amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                            domain="domain"
                        ),
                        athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                            role_arn="roleArn",
                            work_group="workGroup"
                        ),
                        aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                            host="host",
                            port=123,
                            sql_endpoint_path="sqlEndpointPath"
                        ),
                        maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                            catalog="catalog",
                            host="host",
                            port=123
                        ),
                        rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                            database="database",
                            instance_id="instanceId"
                        ),
                        redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                            database="database",
        
                            # the properties below are optional
                            cluster_id="clusterId",
                            host="host",
                            port=123
                        ),
                        s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                            manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                                bucket="bucket",
                                key="key"
                            ),
        
                            # the properties below are optional
                            role_arn="roleArn"
                        ),
                        snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                            database="database",
                            host="host",
                            warehouse="warehouse"
                        ),
                        spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                            host="host",
                            port=123
                        ),
                        sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        starburst_parameters=quicksight.CfnDataSource.StarburstParametersProperty(
                            catalog="catalog",
                            host="host",
                            port=123,
        
                            # the properties below are optional
                            product_type="productType"
                        ),
                        teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        trino_parameters=quicksight.CfnDataSource.TrinoParametersProperty(
                            catalog="catalog",
                            host="host",
                            port=123
                        )
                    )]
                ),
                secret_arn="secretArn"
            ),
            data_source_id="dataSourceId",
            data_source_parameters=quicksight.CfnDataSource.DataSourceParametersProperty(
                amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                    domain="domain"
                ),
                amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                    domain="domain"
                ),
                athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                    role_arn="roleArn",
                    work_group="workGroup"
                ),
                aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                    host="host",
                    port=123,
                    sql_endpoint_path="sqlEndpointPath"
                ),
                maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                    catalog="catalog",
                    host="host",
                    port=123
                ),
                rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                    database="database",
                    instance_id="instanceId"
                ),
                redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                    database="database",
        
                    # the properties below are optional
                    cluster_id="clusterId",
                    host="host",
                    port=123
                ),
                s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                    manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                        bucket="bucket",
                        key="key"
                    ),
        
                    # the properties below are optional
                    role_arn="roleArn"
                ),
                snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                    database="database",
                    host="host",
                    warehouse="warehouse"
                ),
                spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                    host="host",
                    port=123
                ),
                sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                starburst_parameters=quicksight.CfnDataSource.StarburstParametersProperty(
                    catalog="catalog",
                    host="host",
                    port=123,
        
                    # the properties below are optional
                    product_type="productType"
                ),
                teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                trino_parameters=quicksight.CfnDataSource.TrinoParametersProperty(
                    catalog="catalog",
                    host="host",
                    port=123
                )
            ),
            error_info=quicksight.CfnDataSource.DataSourceErrorInfoProperty(
                message="message",
                type="type"
            ),
            name="name",
            permissions=[quicksight.CfnDataSource.ResourcePermissionProperty(
                actions=["actions"],
                principal="principal"
            )],
            ssl_properties=quicksight.CfnDataSource.SslPropertiesProperty(
                disable_ssl=False
            ),
            tags=[CfnTag(
                key="key",
                value="value"
            )],
            type="type",
            vpc_connection_properties=quicksight.CfnDataSource.VpcConnectionPropertiesProperty(
                vpc_connection_arn="vpcConnectionArn"
            )
        )
    '''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.Construct,
        id: builtins.str,
        *,
        alternate_data_source_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.DataSourceParametersProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        aws_account_id: typing.Optional[builtins.str] = None,
        credentials: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.DataSourceCredentialsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        data_source_id: typing.Optional[builtins.str] = None,
        data_source_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.DataSourceParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        error_info: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.DataSourceErrorInfoProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.ResourcePermissionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ssl_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.SslPropertiesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
        type: typing.Optional[builtins.str] = None,
        vpc_connection_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.VpcConnectionPropertiesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
    ) -> None:
        '''
        :param scope: Scope in which this resource is defined.
        :param id: Construct identifier for this resource (unique in its scope).
        :param alternate_data_source_parameters: A set of alternate data source parameters that you want to share for the credentials stored with this data source. The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the ``DataSourceParameters`` structure that's in the request with the structures in the ``AlternateDataSourceParameters`` allow list. If the structures are an exact match, the request is allowed to use the credentials from this existing data source. If the ``AlternateDataSourceParameters`` list is null, the ``Credentials`` originally used with this ``DataSourceParameters`` are automatically allowed.
        :param aws_account_id: The AWS account ID.
        :param credentials: The credentials Amazon QuickSight that uses to connect to your underlying source. Currently, only credentials based on user name and password are supported.
        :param data_source_id: An ID for the data source. This ID is unique per AWS Region for each AWS account.
        :param data_source_parameters: The parameters that Amazon QuickSight uses to connect to your underlying source.
        :param error_info: Error information from the last update or the creation of the data source.
        :param name: A display name for the data source.
        :param permissions: A list of resource permissions on the data source.
        :param ssl_properties: Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your underlying source.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the data source.
        :param type: The type of the data source. To return a list of all data sources, use ``ListDataSources`` . Use ``AMAZON_ELASTICSEARCH`` for Amazon OpenSearch Service.
        :param vpc_connection_properties: Use this parameter only when you want Amazon QuickSight to use a VPC connection when connecting to your underlying source.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__374b42679a82ae47079989dc56d79f0d0b7c439a3c9f7e6d2725ab4c7c4ad6fd)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnDataSourceProps(
            alternate_data_source_parameters=alternate_data_source_parameters,
            aws_account_id=aws_account_id,
            credentials=credentials,
            data_source_id=data_source_id,
            data_source_parameters=data_source_parameters,
            error_info=error_info,
            name=name,
            permissions=permissions,
            ssl_properties=ssl_properties,
            tags=tags,
            type=type,
            vpc_connection_properties=vpc_connection_properties,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _TreeInspector_488e0dd5) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e8fa1e203bf4b07b7670ba58872971e5952794a17f74a3653f28a8a93005f9e7)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f8eb54a2aed0a06bc64a0703fdcc2a5b9961317d6f25e712e1f9a65307f1a7b9)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) of the dataset.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="attrCreatedTime")
    def attr_created_time(self) -> builtins.str:
        '''The time that this data source was created.

        :cloudformationAttribute: CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrLastUpdatedTime")
    def attr_last_updated_time(self) -> builtins.str:
        '''The last time that this data source was updated.

        :cloudformationAttribute: LastUpdatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastUpdatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrStatus")
    def attr_status(self) -> builtins.str:
        '''The HTTP status of the request.

        :cloudformationAttribute: Status
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrStatus"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> _TagManager_0a598cb3:
        '''Tag Manager which manages the tags for this resource.'''
        return typing.cast(_TagManager_0a598cb3, jsii.get(self, "tags"))

    @builtins.property
    @jsii.member(jsii_name="alternateDataSourceParameters")
    def alternate_data_source_parameters(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSource.DataSourceParametersProperty"]]]]:
        '''A set of alternate data source parameters that you want to share for the credentials stored with this data source.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSource.DataSourceParametersProperty"]]]], jsii.get(self, "alternateDataSourceParameters"))

    @alternate_data_source_parameters.setter
    def alternate_data_source_parameters(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSource.DataSourceParametersProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eb379c4375e37df7dc712f334701ec783760f5e486678e89408afeef7d9be1be)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "alternateDataSourceParameters", value)

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__83eec7204a5e7c9b0b6d35d76242df7c8ad9260aea2231bd8790238ea6c41808)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="credentials")
    def credentials(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.DataSourceCredentialsProperty"]]:
        '''The credentials Amazon QuickSight that uses to connect to your underlying source.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.DataSourceCredentialsProperty"]], jsii.get(self, "credentials"))

    @credentials.setter
    def credentials(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.DataSourceCredentialsProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__87f61c5ab7589e751ededa73d48183d342b2d819796cb4eb9698c13b888f19ec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "credentials", value)

    @builtins.property
    @jsii.member(jsii_name="dataSourceId")
    def data_source_id(self) -> typing.Optional[builtins.str]:
        '''An ID for the data source.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceId"))

    @data_source_id.setter
    def data_source_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f495157a0559c40a1200ce0ccad2884a38332d25013afd4d581522e9d39ac109)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSourceId", value)

    @builtins.property
    @jsii.member(jsii_name="dataSourceParameters")
    def data_source_parameters(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.DataSourceParametersProperty"]]:
        '''The parameters that Amazon QuickSight uses to connect to your underlying source.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.DataSourceParametersProperty"]], jsii.get(self, "dataSourceParameters"))

    @data_source_parameters.setter
    def data_source_parameters(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.DataSourceParametersProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d38329c0865968e6c2896e5d42f0ce5ab7b9b828f6f517d45f76625d218a8e5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSourceParameters", value)

    @builtins.property
    @jsii.member(jsii_name="errorInfo")
    def error_info(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.DataSourceErrorInfoProperty"]]:
        '''Error information from the last update or the creation of the data source.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.DataSourceErrorInfoProperty"]], jsii.get(self, "errorInfo"))

    @error_info.setter
    def error_info(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.DataSourceErrorInfoProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e8c906a2be130881812bea32c60ce64f9dd123ce92cb93ebef14967c3ee2f5db)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "errorInfo", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        '''A display name for the data source.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "name"))

    @name.setter
    def name(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__052425c353cfb69cd3d7b21804a17d34c4d718ab05be68ee000a42ec3d089d5e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSource.ResourcePermissionProperty"]]]]:
        '''A list of resource permissions on the data source.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSource.ResourcePermissionProperty"]]]], jsii.get(self, "permissions"))

    @permissions.setter
    def permissions(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSource.ResourcePermissionProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__67967cbb0c0393ec55fe203f29b3078095f17848804e7a81297e61fe75f5c3ce)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "permissions", value)

    @builtins.property
    @jsii.member(jsii_name="sslProperties")
    def ssl_properties(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.SslPropertiesProperty"]]:
        '''Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your underlying source.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.SslPropertiesProperty"]], jsii.get(self, "sslProperties"))

    @ssl_properties.setter
    def ssl_properties(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.SslPropertiesProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9c040d8fcbe7f80fd38249a6eb377548190fb36b04c193a25bb5844870cde0ee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sslProperties", value)

    @builtins.property
    @jsii.member(jsii_name="tagsRaw")
    def tags_raw(self) -> typing.Optional[typing.List[_CfnTag_f6864754]]:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the data source.'''
        return typing.cast(typing.Optional[typing.List[_CfnTag_f6864754]], jsii.get(self, "tagsRaw"))

    @tags_raw.setter
    def tags_raw(self, value: typing.Optional[typing.List[_CfnTag_f6864754]]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e0230d4ce77e973f3a7590b7ac180996f418a6d85fa113e78f28e1431f1ce924)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tagsRaw", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> typing.Optional[builtins.str]:
        '''The type of the data source.

        To return a list of all data sources, use ``ListDataSources`` .
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "type"))

    @type.setter
    def type(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a9629e48048b57721b64306d8b9ec36a4da85373ef960e1d47fd336a6048d3e7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "type", value)

    @builtins.property
    @jsii.member(jsii_name="vpcConnectionProperties")
    def vpc_connection_properties(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.VpcConnectionPropertiesProperty"]]:
        '''Use this parameter only when you want Amazon QuickSight to use a VPC connection when connecting to your underlying source.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.VpcConnectionPropertiesProperty"]], jsii.get(self, "vpcConnectionProperties"))

    @vpc_connection_properties.setter
    def vpc_connection_properties(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.VpcConnectionPropertiesProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0f6342c628ea6be2cf1fb1d8a9ac0fcd7e1758472fe1379db22be3198f00bcd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "vpcConnectionProperties", value)

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.AmazonElasticsearchParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"domain": "domain"},
    )
    class AmazonElasticsearchParametersProperty:
        def __init__(self, *, domain: builtins.str) -> None:
            '''The parameters for OpenSearch.

            :param domain: The OpenSearch domain.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-amazonelasticsearchparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                amazon_elasticsearch_parameters_property = quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                    domain="domain"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1d158e65e94acb7281e6cccc31aef5aff5e52a44d7b01f2e84b33bf228f00754)
                check_type(argname="argument domain", value=domain, expected_type=type_hints["domain"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "domain": domain,
            }

        @builtins.property
        def domain(self) -> builtins.str:
            '''The OpenSearch domain.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-amazonelasticsearchparameters.html#cfn-quicksight-datasource-amazonelasticsearchparameters-domain
            '''
            result = self._values.get("domain")
            assert result is not None, "Required property 'domain' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AmazonElasticsearchParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.AmazonOpenSearchParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"domain": "domain"},
    )
    class AmazonOpenSearchParametersProperty:
        def __init__(self, *, domain: builtins.str) -> None:
            '''The parameters for OpenSearch.

            :param domain: The OpenSearch domain.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-amazonopensearchparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                amazon_open_search_parameters_property = quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                    domain="domain"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c9fa436370baac124e212cd999680e59dee51cb3fc88dc417c84a4c5981e5015)
                check_type(argname="argument domain", value=domain, expected_type=type_hints["domain"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "domain": domain,
            }

        @builtins.property
        def domain(self) -> builtins.str:
            '''The OpenSearch domain.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-amazonopensearchparameters.html#cfn-quicksight-datasource-amazonopensearchparameters-domain
            '''
            result = self._values.get("domain")
            assert result is not None, "Required property 'domain' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AmazonOpenSearchParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.AthenaParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"role_arn": "roleArn", "work_group": "workGroup"},
    )
    class AthenaParametersProperty:
        def __init__(
            self,
            *,
            role_arn: typing.Optional[builtins.str] = None,
            work_group: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Parameters for Amazon Athena.

            :param role_arn: Use the ``RoleArn`` structure to override an account-wide role for a specific Athena data source. For example, say an account administrator has turned off all Athena access with an account-wide role. The administrator can then use ``RoleArn`` to bypass the account-wide role and allow Athena access for the single Athena data source that is specified in the structure, even if the account-wide role forbidding Athena access is still active.
            :param work_group: The workgroup that Amazon Athena uses.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-athenaparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                athena_parameters_property = quicksight.CfnDataSource.AthenaParametersProperty(
                    role_arn="roleArn",
                    work_group="workGroup"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9f9751c0f8af713f14cec50a0ea45b4d181e33d0be4649de1d52c5018ba83ee1)
                check_type(argname="argument role_arn", value=role_arn, expected_type=type_hints["role_arn"])
                check_type(argname="argument work_group", value=work_group, expected_type=type_hints["work_group"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if role_arn is not None:
                self._values["role_arn"] = role_arn
            if work_group is not None:
                self._values["work_group"] = work_group

        @builtins.property
        def role_arn(self) -> typing.Optional[builtins.str]:
            '''Use the ``RoleArn`` structure to override an account-wide role for a specific Athena data source.

            For example, say an account administrator has turned off all Athena access with an account-wide role. The administrator can then use ``RoleArn`` to bypass the account-wide role and allow Athena access for the single Athena data source that is specified in the structure, even if the account-wide role forbidding Athena access is still active.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-athenaparameters.html#cfn-quicksight-datasource-athenaparameters-rolearn
            '''
            result = self._values.get("role_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def work_group(self) -> typing.Optional[builtins.str]:
            '''The workgroup that Amazon Athena uses.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-athenaparameters.html#cfn-quicksight-datasource-athenaparameters-workgroup
            '''
            result = self._values.get("work_group")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AthenaParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.AuroraParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class AuroraParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''Parameters for Amazon Aurora.

            :param database: Database.
            :param host: Host.
            :param port: Port.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-auroraparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                aurora_parameters_property = quicksight.CfnDataSource.AuroraParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4c2a99b8deedd0833045006463a1d33c513b46aa2addc0240f5494a7cb1f68ea)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-auroraparameters.html#cfn-quicksight-datasource-auroraparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-auroraparameters.html#cfn-quicksight-datasource-auroraparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-auroraparameters.html#cfn-quicksight-datasource-auroraparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AuroraParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class AuroraPostgreSqlParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''Parameters for Amazon Aurora PostgreSQL-Compatible Edition.

            :param database: The Amazon Aurora PostgreSQL database to connect to.
            :param host: The Amazon Aurora PostgreSQL-Compatible host to connect to.
            :param port: The port that Amazon Aurora PostgreSQL is listening on.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-aurorapostgresqlparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                aurora_postgre_sql_parameters_property = quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4fea3df2f87ec4d3b988b7119749d549e5c2bd912e8dae45b7737d90a71711a8)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''The Amazon Aurora PostgreSQL database to connect to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-aurorapostgresqlparameters.html#cfn-quicksight-datasource-aurorapostgresqlparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''The Amazon Aurora PostgreSQL-Compatible host to connect to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-aurorapostgresqlparameters.html#cfn-quicksight-datasource-aurorapostgresqlparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''The port that Amazon Aurora PostgreSQL is listening on.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-aurorapostgresqlparameters.html#cfn-quicksight-datasource-aurorapostgresqlparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AuroraPostgreSqlParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.CredentialPairProperty",
        jsii_struct_bases=[],
        name_mapping={
            "password": "password",
            "username": "username",
            "alternate_data_source_parameters": "alternateDataSourceParameters",
        },
    )
    class CredentialPairProperty:
        def __init__(
            self,
            *,
            password: builtins.str,
            username: builtins.str,
            alternate_data_source_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.DataSourceParametersProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The combination of user name and password that are used as credentials.

            :param password: Password.
            :param username: User name.
            :param alternate_data_source_parameters: A set of alternate data source parameters that you want to share for these credentials. The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the ``DataSourceParameters`` structure that's in the request with the structures in the ``AlternateDataSourceParameters`` allow list. If the structures are an exact match, the request is allowed to use the new data source with the existing credentials. If the ``AlternateDataSourceParameters`` list is null, the ``DataSourceParameters`` originally used with these ``Credentials`` is automatically allowed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-credentialpair.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                credential_pair_property = quicksight.CfnDataSource.CredentialPairProperty(
                    password="password",
                    username="username",
                
                    # the properties below are optional
                    alternate_data_source_parameters=[quicksight.CfnDataSource.DataSourceParametersProperty(
                        amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                            domain="domain"
                        ),
                        amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                            domain="domain"
                        ),
                        athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                            role_arn="roleArn",
                            work_group="workGroup"
                        ),
                        aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                            host="host",
                            port=123,
                            sql_endpoint_path="sqlEndpointPath"
                        ),
                        maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                            catalog="catalog",
                            host="host",
                            port=123
                        ),
                        rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                            database="database",
                            instance_id="instanceId"
                        ),
                        redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                            database="database",
                
                            # the properties below are optional
                            cluster_id="clusterId",
                            host="host",
                            port=123
                        ),
                        s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                            manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                                bucket="bucket",
                                key="key"
                            ),
                
                            # the properties below are optional
                            role_arn="roleArn"
                        ),
                        snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                            database="database",
                            host="host",
                            warehouse="warehouse"
                        ),
                        spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                            host="host",
                            port=123
                        ),
                        sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        starburst_parameters=quicksight.CfnDataSource.StarburstParametersProperty(
                            catalog="catalog",
                            host="host",
                            port=123,
                
                            # the properties below are optional
                            product_type="productType"
                        ),
                        teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        trino_parameters=quicksight.CfnDataSource.TrinoParametersProperty(
                            catalog="catalog",
                            host="host",
                            port=123
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f99dad3b5f23ffc55f6425b1a4d35ebcb963eff5247a6a5be8fe9bc65b4fc9bd)
                check_type(argname="argument password", value=password, expected_type=type_hints["password"])
                check_type(argname="argument username", value=username, expected_type=type_hints["username"])
                check_type(argname="argument alternate_data_source_parameters", value=alternate_data_source_parameters, expected_type=type_hints["alternate_data_source_parameters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "password": password,
                "username": username,
            }
            if alternate_data_source_parameters is not None:
                self._values["alternate_data_source_parameters"] = alternate_data_source_parameters

        @builtins.property
        def password(self) -> builtins.str:
            '''Password.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-credentialpair.html#cfn-quicksight-datasource-credentialpair-password
            '''
            result = self._values.get("password")
            assert result is not None, "Required property 'password' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def username(self) -> builtins.str:
            '''User name.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-credentialpair.html#cfn-quicksight-datasource-credentialpair-username
            '''
            result = self._values.get("username")
            assert result is not None, "Required property 'username' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def alternate_data_source_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSource.DataSourceParametersProperty"]]]]:
            '''A set of alternate data source parameters that you want to share for these credentials.

            The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the ``DataSourceParameters`` structure that's in the request with the structures in the ``AlternateDataSourceParameters`` allow list. If the structures are an exact match, the request is allowed to use the new data source with the existing credentials. If the ``AlternateDataSourceParameters`` list is null, the ``DataSourceParameters`` originally used with these ``Credentials`` is automatically allowed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-credentialpair.html#cfn-quicksight-datasource-credentialpair-alternatedatasourceparameters
            '''
            result = self._values.get("alternate_data_source_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnDataSource.DataSourceParametersProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CredentialPairProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.DataSourceCredentialsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "copy_source_arn": "copySourceArn",
            "credential_pair": "credentialPair",
            "secret_arn": "secretArn",
        },
    )
    class DataSourceCredentialsProperty:
        def __init__(
            self,
            *,
            copy_source_arn: typing.Optional[builtins.str] = None,
            credential_pair: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.CredentialPairProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secret_arn: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Data source credentials.

            This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

            :param copy_source_arn: The Amazon Resource Name (ARN) of a data source that has the credential pair that you want to use. When ``CopySourceArn`` is not null, the credential pair from the data source in the ARN is used as the credentials for the ``DataSourceCredentials`` structure.
            :param credential_pair: Credential pair. For more information, see ``[CredentialPair](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CredentialPair.html)`` .
            :param secret_arn: The Amazon Resource Name (ARN) of the secret associated with the data source in AWS Secrets Manager .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourcecredentials.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_source_credentials_property = quicksight.CfnDataSource.DataSourceCredentialsProperty(
                    copy_source_arn="copySourceArn",
                    credential_pair=quicksight.CfnDataSource.CredentialPairProperty(
                        password="password",
                        username="username",
                
                        # the properties below are optional
                        alternate_data_source_parameters=[quicksight.CfnDataSource.DataSourceParametersProperty(
                            amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                                domain="domain"
                            ),
                            amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                                domain="domain"
                            ),
                            athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                                role_arn="roleArn",
                                work_group="workGroup"
                            ),
                            aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                                host="host",
                                port=123,
                                sql_endpoint_path="sqlEndpointPath"
                            ),
                            maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                                catalog="catalog",
                                host="host",
                                port=123
                            ),
                            rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                                database="database",
                                instance_id="instanceId"
                            ),
                            redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                                database="database",
                
                                # the properties below are optional
                                cluster_id="clusterId",
                                host="host",
                                port=123
                            ),
                            s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                                manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                                    bucket="bucket",
                                    key="key"
                                ),
                
                                # the properties below are optional
                                role_arn="roleArn"
                            ),
                            snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                                database="database",
                                host="host",
                                warehouse="warehouse"
                            ),
                            spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                                host="host",
                                port=123
                            ),
                            sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            starburst_parameters=quicksight.CfnDataSource.StarburstParametersProperty(
                                catalog="catalog",
                                host="host",
                                port=123,
                
                                # the properties below are optional
                                product_type="productType"
                            ),
                            teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            trino_parameters=quicksight.CfnDataSource.TrinoParametersProperty(
                                catalog="catalog",
                                host="host",
                                port=123
                            )
                        )]
                    ),
                    secret_arn="secretArn"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c8b72e1e41d38f4ceadb2a3b3eacb8937288be1b3b3365202ae7bdda7240a6f0)
                check_type(argname="argument copy_source_arn", value=copy_source_arn, expected_type=type_hints["copy_source_arn"])
                check_type(argname="argument credential_pair", value=credential_pair, expected_type=type_hints["credential_pair"])
                check_type(argname="argument secret_arn", value=secret_arn, expected_type=type_hints["secret_arn"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if copy_source_arn is not None:
                self._values["copy_source_arn"] = copy_source_arn
            if credential_pair is not None:
                self._values["credential_pair"] = credential_pair
            if secret_arn is not None:
                self._values["secret_arn"] = secret_arn

        @builtins.property
        def copy_source_arn(self) -> typing.Optional[builtins.str]:
            '''The Amazon Resource Name (ARN) of a data source that has the credential pair that you want to use.

            When ``CopySourceArn`` is not null, the credential pair from the data source in the ARN is used as the credentials for the ``DataSourceCredentials`` structure.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourcecredentials.html#cfn-quicksight-datasource-datasourcecredentials-copysourcearn
            '''
            result = self._values.get("copy_source_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def credential_pair(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.CredentialPairProperty"]]:
            '''Credential pair.

            For more information, see ``[CredentialPair](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CredentialPair.html)`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourcecredentials.html#cfn-quicksight-datasource-datasourcecredentials-credentialpair
            '''
            result = self._values.get("credential_pair")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.CredentialPairProperty"]], result)

        @builtins.property
        def secret_arn(self) -> typing.Optional[builtins.str]:
            '''The Amazon Resource Name (ARN) of the secret associated with the data source in AWS Secrets Manager .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourcecredentials.html#cfn-quicksight-datasource-datasourcecredentials-secretarn
            '''
            result = self._values.get("secret_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSourceCredentialsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.DataSourceErrorInfoProperty",
        jsii_struct_bases=[],
        name_mapping={"message": "message", "type": "type"},
    )
    class DataSourceErrorInfoProperty:
        def __init__(
            self,
            *,
            message: typing.Optional[builtins.str] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Error information for the data source creation or update.

            :param message: Error message.
            :param type: Error type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceerrorinfo.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_source_error_info_property = quicksight.CfnDataSource.DataSourceErrorInfoProperty(
                    message="message",
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__57dc1d9b0f11ad204af8757464086e51aedc2372b4ce8e48e02099623234e368)
                check_type(argname="argument message", value=message, expected_type=type_hints["message"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if message is not None:
                self._values["message"] = message
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def message(self) -> typing.Optional[builtins.str]:
            '''Error message.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceerrorinfo.html#cfn-quicksight-datasource-datasourceerrorinfo-message
            '''
            result = self._values.get("message")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''Error type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceerrorinfo.html#cfn-quicksight-datasource-datasourceerrorinfo-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSourceErrorInfoProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.DataSourceParametersProperty",
        jsii_struct_bases=[],
        name_mapping={
            "amazon_elasticsearch_parameters": "amazonElasticsearchParameters",
            "amazon_open_search_parameters": "amazonOpenSearchParameters",
            "athena_parameters": "athenaParameters",
            "aurora_parameters": "auroraParameters",
            "aurora_postgre_sql_parameters": "auroraPostgreSqlParameters",
            "databricks_parameters": "databricksParameters",
            "maria_db_parameters": "mariaDbParameters",
            "my_sql_parameters": "mySqlParameters",
            "oracle_parameters": "oracleParameters",
            "postgre_sql_parameters": "postgreSqlParameters",
            "presto_parameters": "prestoParameters",
            "rds_parameters": "rdsParameters",
            "redshift_parameters": "redshiftParameters",
            "s3_parameters": "s3Parameters",
            "snowflake_parameters": "snowflakeParameters",
            "spark_parameters": "sparkParameters",
            "sql_server_parameters": "sqlServerParameters",
            "starburst_parameters": "starburstParameters",
            "teradata_parameters": "teradataParameters",
            "trino_parameters": "trinoParameters",
        },
    )
    class DataSourceParametersProperty:
        def __init__(
            self,
            *,
            amazon_elasticsearch_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.AmazonElasticsearchParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            amazon_open_search_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.AmazonOpenSearchParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            athena_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.AthenaParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            aurora_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.AuroraParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            aurora_postgre_sql_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.AuroraPostgreSqlParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            databricks_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.DatabricksParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            maria_db_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.MariaDbParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            my_sql_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.MySqlParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            oracle_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.OracleParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            postgre_sql_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.PostgreSqlParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            presto_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.PrestoParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rds_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.RdsParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            redshift_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.RedshiftParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            s3_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.S3ParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            snowflake_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.SnowflakeParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            spark_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.SparkParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sql_server_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.SqlServerParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            starburst_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.StarburstParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            teradata_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.TeradataParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            trino_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.TrinoParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The parameters that Amazon QuickSight uses to connect to your underlying data source.

            This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

            :param amazon_elasticsearch_parameters: The parameters for OpenSearch.
            :param amazon_open_search_parameters: The parameters for OpenSearch.
            :param athena_parameters: The parameters for Amazon Athena.
            :param aurora_parameters: The parameters for Amazon Aurora MySQL.
            :param aurora_postgre_sql_parameters: The parameters for Amazon Aurora.
            :param databricks_parameters: The required parameters that are needed to connect to a Databricks data source.
            :param maria_db_parameters: The parameters for MariaDB.
            :param my_sql_parameters: The parameters for MySQL.
            :param oracle_parameters: Oracle parameters.
            :param postgre_sql_parameters: The parameters for PostgreSQL.
            :param presto_parameters: The parameters for Presto.
            :param rds_parameters: The parameters for Amazon RDS.
            :param redshift_parameters: The parameters for Amazon Redshift.
            :param s3_parameters: The parameters for S3.
            :param snowflake_parameters: The parameters for Snowflake.
            :param spark_parameters: The parameters for Spark.
            :param sql_server_parameters: The parameters for SQL Server.
            :param starburst_parameters: The parameters that are required to connect to a Starburst data source.
            :param teradata_parameters: The parameters for Teradata.
            :param trino_parameters: The parameters that are required to connect to a Trino data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_source_parameters_property = quicksight.CfnDataSource.DataSourceParametersProperty(
                    amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                        domain="domain"
                    ),
                    amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                        domain="domain"
                    ),
                    athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                        role_arn="roleArn",
                        work_group="workGroup"
                    ),
                    aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                        host="host",
                        port=123,
                        sql_endpoint_path="sqlEndpointPath"
                    ),
                    maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                        catalog="catalog",
                        host="host",
                        port=123
                    ),
                    rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                        database="database",
                        instance_id="instanceId"
                    ),
                    redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                        database="database",
                
                        # the properties below are optional
                        cluster_id="clusterId",
                        host="host",
                        port=123
                    ),
                    s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                        manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                            bucket="bucket",
                            key="key"
                        ),
                
                        # the properties below are optional
                        role_arn="roleArn"
                    ),
                    snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                        database="database",
                        host="host",
                        warehouse="warehouse"
                    ),
                    spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                        host="host",
                        port=123
                    ),
                    sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    starburst_parameters=quicksight.CfnDataSource.StarburstParametersProperty(
                        catalog="catalog",
                        host="host",
                        port=123,
                
                        # the properties below are optional
                        product_type="productType"
                    ),
                    teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    trino_parameters=quicksight.CfnDataSource.TrinoParametersProperty(
                        catalog="catalog",
                        host="host",
                        port=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dda9acee13d5eb627377ef88243d72bfd812d92c22ba8df2ddd7c7001335b871)
                check_type(argname="argument amazon_elasticsearch_parameters", value=amazon_elasticsearch_parameters, expected_type=type_hints["amazon_elasticsearch_parameters"])
                check_type(argname="argument amazon_open_search_parameters", value=amazon_open_search_parameters, expected_type=type_hints["amazon_open_search_parameters"])
                check_type(argname="argument athena_parameters", value=athena_parameters, expected_type=type_hints["athena_parameters"])
                check_type(argname="argument aurora_parameters", value=aurora_parameters, expected_type=type_hints["aurora_parameters"])
                check_type(argname="argument aurora_postgre_sql_parameters", value=aurora_postgre_sql_parameters, expected_type=type_hints["aurora_postgre_sql_parameters"])
                check_type(argname="argument databricks_parameters", value=databricks_parameters, expected_type=type_hints["databricks_parameters"])
                check_type(argname="argument maria_db_parameters", value=maria_db_parameters, expected_type=type_hints["maria_db_parameters"])
                check_type(argname="argument my_sql_parameters", value=my_sql_parameters, expected_type=type_hints["my_sql_parameters"])
                check_type(argname="argument oracle_parameters", value=oracle_parameters, expected_type=type_hints["oracle_parameters"])
                check_type(argname="argument postgre_sql_parameters", value=postgre_sql_parameters, expected_type=type_hints["postgre_sql_parameters"])
                check_type(argname="argument presto_parameters", value=presto_parameters, expected_type=type_hints["presto_parameters"])
                check_type(argname="argument rds_parameters", value=rds_parameters, expected_type=type_hints["rds_parameters"])
                check_type(argname="argument redshift_parameters", value=redshift_parameters, expected_type=type_hints["redshift_parameters"])
                check_type(argname="argument s3_parameters", value=s3_parameters, expected_type=type_hints["s3_parameters"])
                check_type(argname="argument snowflake_parameters", value=snowflake_parameters, expected_type=type_hints["snowflake_parameters"])
                check_type(argname="argument spark_parameters", value=spark_parameters, expected_type=type_hints["spark_parameters"])
                check_type(argname="argument sql_server_parameters", value=sql_server_parameters, expected_type=type_hints["sql_server_parameters"])
                check_type(argname="argument starburst_parameters", value=starburst_parameters, expected_type=type_hints["starburst_parameters"])
                check_type(argname="argument teradata_parameters", value=teradata_parameters, expected_type=type_hints["teradata_parameters"])
                check_type(argname="argument trino_parameters", value=trino_parameters, expected_type=type_hints["trino_parameters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if amazon_elasticsearch_parameters is not None:
                self._values["amazon_elasticsearch_parameters"] = amazon_elasticsearch_parameters
            if amazon_open_search_parameters is not None:
                self._values["amazon_open_search_parameters"] = amazon_open_search_parameters
            if athena_parameters is not None:
                self._values["athena_parameters"] = athena_parameters
            if aurora_parameters is not None:
                self._values["aurora_parameters"] = aurora_parameters
            if aurora_postgre_sql_parameters is not None:
                self._values["aurora_postgre_sql_parameters"] = aurora_postgre_sql_parameters
            if databricks_parameters is not None:
                self._values["databricks_parameters"] = databricks_parameters
            if maria_db_parameters is not None:
                self._values["maria_db_parameters"] = maria_db_parameters
            if my_sql_parameters is not None:
                self._values["my_sql_parameters"] = my_sql_parameters
            if oracle_parameters is not None:
                self._values["oracle_parameters"] = oracle_parameters
            if postgre_sql_parameters is not None:
                self._values["postgre_sql_parameters"] = postgre_sql_parameters
            if presto_parameters is not None:
                self._values["presto_parameters"] = presto_parameters
            if rds_parameters is not None:
                self._values["rds_parameters"] = rds_parameters
            if redshift_parameters is not None:
                self._values["redshift_parameters"] = redshift_parameters
            if s3_parameters is not None:
                self._values["s3_parameters"] = s3_parameters
            if snowflake_parameters is not None:
                self._values["snowflake_parameters"] = snowflake_parameters
            if spark_parameters is not None:
                self._values["spark_parameters"] = spark_parameters
            if sql_server_parameters is not None:
                self._values["sql_server_parameters"] = sql_server_parameters
            if starburst_parameters is not None:
                self._values["starburst_parameters"] = starburst_parameters
            if teradata_parameters is not None:
                self._values["teradata_parameters"] = teradata_parameters
            if trino_parameters is not None:
                self._values["trino_parameters"] = trino_parameters

        @builtins.property
        def amazon_elasticsearch_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.AmazonElasticsearchParametersProperty"]]:
            '''The parameters for OpenSearch.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-amazonelasticsearchparameters
            '''
            result = self._values.get("amazon_elasticsearch_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.AmazonElasticsearchParametersProperty"]], result)

        @builtins.property
        def amazon_open_search_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.AmazonOpenSearchParametersProperty"]]:
            '''The parameters for OpenSearch.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-amazonopensearchparameters
            '''
            result = self._values.get("amazon_open_search_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.AmazonOpenSearchParametersProperty"]], result)

        @builtins.property
        def athena_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.AthenaParametersProperty"]]:
            '''The parameters for Amazon Athena.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-athenaparameters
            '''
            result = self._values.get("athena_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.AthenaParametersProperty"]], result)

        @builtins.property
        def aurora_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.AuroraParametersProperty"]]:
            '''The parameters for Amazon Aurora MySQL.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-auroraparameters
            '''
            result = self._values.get("aurora_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.AuroraParametersProperty"]], result)

        @builtins.property
        def aurora_postgre_sql_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.AuroraPostgreSqlParametersProperty"]]:
            '''The parameters for Amazon Aurora.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-aurorapostgresqlparameters
            '''
            result = self._values.get("aurora_postgre_sql_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.AuroraPostgreSqlParametersProperty"]], result)

        @builtins.property
        def databricks_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.DatabricksParametersProperty"]]:
            '''The required parameters that are needed to connect to a Databricks data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-databricksparameters
            '''
            result = self._values.get("databricks_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.DatabricksParametersProperty"]], result)

        @builtins.property
        def maria_db_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.MariaDbParametersProperty"]]:
            '''The parameters for MariaDB.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-mariadbparameters
            '''
            result = self._values.get("maria_db_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.MariaDbParametersProperty"]], result)

        @builtins.property
        def my_sql_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.MySqlParametersProperty"]]:
            '''The parameters for MySQL.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-mysqlparameters
            '''
            result = self._values.get("my_sql_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.MySqlParametersProperty"]], result)

        @builtins.property
        def oracle_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.OracleParametersProperty"]]:
            '''Oracle parameters.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-oracleparameters
            '''
            result = self._values.get("oracle_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.OracleParametersProperty"]], result)

        @builtins.property
        def postgre_sql_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.PostgreSqlParametersProperty"]]:
            '''The parameters for PostgreSQL.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-postgresqlparameters
            '''
            result = self._values.get("postgre_sql_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.PostgreSqlParametersProperty"]], result)

        @builtins.property
        def presto_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.PrestoParametersProperty"]]:
            '''The parameters for Presto.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-prestoparameters
            '''
            result = self._values.get("presto_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.PrestoParametersProperty"]], result)

        @builtins.property
        def rds_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.RdsParametersProperty"]]:
            '''The parameters for Amazon RDS.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-rdsparameters
            '''
            result = self._values.get("rds_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.RdsParametersProperty"]], result)

        @builtins.property
        def redshift_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.RedshiftParametersProperty"]]:
            '''The parameters for Amazon Redshift.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-redshiftparameters
            '''
            result = self._values.get("redshift_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.RedshiftParametersProperty"]], result)

        @builtins.property
        def s3_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.S3ParametersProperty"]]:
            '''The parameters for S3.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-s3parameters
            '''
            result = self._values.get("s3_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.S3ParametersProperty"]], result)

        @builtins.property
        def snowflake_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.SnowflakeParametersProperty"]]:
            '''The parameters for Snowflake.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-snowflakeparameters
            '''
            result = self._values.get("snowflake_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.SnowflakeParametersProperty"]], result)

        @builtins.property
        def spark_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.SparkParametersProperty"]]:
            '''The parameters for Spark.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-sparkparameters
            '''
            result = self._values.get("spark_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.SparkParametersProperty"]], result)

        @builtins.property
        def sql_server_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.SqlServerParametersProperty"]]:
            '''The parameters for SQL Server.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-sqlserverparameters
            '''
            result = self._values.get("sql_server_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.SqlServerParametersProperty"]], result)

        @builtins.property
        def starburst_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.StarburstParametersProperty"]]:
            '''The parameters that are required to connect to a Starburst data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-starburstparameters
            '''
            result = self._values.get("starburst_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.StarburstParametersProperty"]], result)

        @builtins.property
        def teradata_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.TeradataParametersProperty"]]:
            '''The parameters for Teradata.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-teradataparameters
            '''
            result = self._values.get("teradata_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.TeradataParametersProperty"]], result)

        @builtins.property
        def trino_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.TrinoParametersProperty"]]:
            '''The parameters that are required to connect to a Trino data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-trinoparameters
            '''
            result = self._values.get("trino_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnDataSource.TrinoParametersProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSourceParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.DatabricksParametersProperty",
        jsii_struct_bases=[],
        name_mapping={
            "host": "host",
            "port": "port",
            "sql_endpoint_path": "sqlEndpointPath",
        },
    )
    class DatabricksParametersProperty:
        def __init__(
            self,
            *,
            host: builtins.str,
            port: jsii.Number,
            sql_endpoint_path: builtins.str,
        ) -> None:
            '''The required parameters that are needed to connect to a Databricks data source.

            :param host: The host name of the Databricks data source.
            :param port: The port for the Databricks data source.
            :param sql_endpoint_path: The HTTP path of the Databricks data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-databricksparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                databricks_parameters_property = quicksight.CfnDataSource.DatabricksParametersProperty(
                    host="host",
                    port=123,
                    sql_endpoint_path="sqlEndpointPath"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__98e6719897c204ef53c2b23b648a88d9061d63939585326b00645a40dbf1b613)
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
                check_type(argname="argument sql_endpoint_path", value=sql_endpoint_path, expected_type=type_hints["sql_endpoint_path"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "host": host,
                "port": port,
                "sql_endpoint_path": sql_endpoint_path,
            }

        @builtins.property
        def host(self) -> builtins.str:
            '''The host name of the Databricks data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-databricksparameters.html#cfn-quicksight-datasource-databricksparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''The port for the Databricks data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-databricksparameters.html#cfn-quicksight-datasource-databricksparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def sql_endpoint_path(self) -> builtins.str:
            '''The HTTP path of the Databricks data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-databricksparameters.html#cfn-quicksight-datasource-databricksparameters-sqlendpointpath
            '''
            result = self._values.get("sql_endpoint_path")
            assert result is not None, "Required property 'sql_endpoint_path' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DatabricksParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.ManifestFileLocationProperty",
        jsii_struct_bases=[],
        name_mapping={"bucket": "bucket", "key": "key"},
    )
    class ManifestFileLocationProperty:
        def __init__(self, *, bucket: builtins.str, key: builtins.str) -> None:
            '''Amazon S3 manifest file location.

            :param bucket: Amazon S3 bucket.
            :param key: Amazon S3 key that identifies an object.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-manifestfilelocation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                manifest_file_location_property = quicksight.CfnDataSource.ManifestFileLocationProperty(
                    bucket="bucket",
                    key="key"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__591da15ac3abdbcdfb930993f40dcd32733d6a857e43cec22d71f2596f387283)
                check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
                check_type(argname="argument key", value=key, expected_type=type_hints["key"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "bucket": bucket,
                "key": key,
            }

        @builtins.property
        def bucket(self) -> builtins.str:
            '''Amazon S3 bucket.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-manifestfilelocation.html#cfn-quicksight-datasource-manifestfilelocation-bucket
            '''
            result = self._values.get("bucket")
            assert result is not None, "Required property 'bucket' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def key(self) -> builtins.str:
            '''Amazon S3 key that identifies an object.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-manifestfilelocation.html#cfn-quicksight-datasource-manifestfilelocation-key
            '''
            result = self._values.get("key")
            assert result is not None, "Required property 'key' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ManifestFileLocationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.MariaDbParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class MariaDbParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''The parameters for MariaDB.

            :param database: Database.
            :param host: Host.
            :param port: Port.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mariadbparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                maria_db_parameters_property = quicksight.CfnDataSource.MariaDbParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__96fbc9251b1f3ce8d1d57413e29ad2a01fc6cf5c0f2932696069b1805836e831)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mariadbparameters.html#cfn-quicksight-datasource-mariadbparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mariadbparameters.html#cfn-quicksight-datasource-mariadbparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mariadbparameters.html#cfn-quicksight-datasource-mariadbparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MariaDbParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.MySqlParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class MySqlParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''The parameters for MySQL.

            :param database: Database.
            :param host: Host.
            :param port: Port.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mysqlparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                my_sql_parameters_property = quicksight.CfnDataSource.MySqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1e2e40985366cbbc121572739d313b83bf11f9b7c050e592ad7e02d8d8971746)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mysqlparameters.html#cfn-quicksight-datasource-mysqlparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mysqlparameters.html#cfn-quicksight-datasource-mysqlparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mysqlparameters.html#cfn-quicksight-datasource-mysqlparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MySqlParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.OracleParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class OracleParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''Oracle parameters.

            :param database: Database.
            :param host: Host.
            :param port: Port.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-oracleparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                oracle_parameters_property = quicksight.CfnDataSource.OracleParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bf876de431aaf56f73ba4abd947cffbe8be9feb3c6a773f4c8d14cbb6e3d1857)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-oracleparameters.html#cfn-quicksight-datasource-oracleparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-oracleparameters.html#cfn-quicksight-datasource-oracleparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-oracleparameters.html#cfn-quicksight-datasource-oracleparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "OracleParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.PostgreSqlParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class PostgreSqlParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''The parameters for PostgreSQL.

            :param database: Database.
            :param host: Host.
            :param port: Port.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-postgresqlparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                postgre_sql_parameters_property = quicksight.CfnDataSource.PostgreSqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5278b7494520b97a14bd648cbe0a65fa7b0de6b16432c86b003f34c7a33c684a)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-postgresqlparameters.html#cfn-quicksight-datasource-postgresqlparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-postgresqlparameters.html#cfn-quicksight-datasource-postgresqlparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-postgresqlparameters.html#cfn-quicksight-datasource-postgresqlparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PostgreSqlParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.PrestoParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"catalog": "catalog", "host": "host", "port": "port"},
    )
    class PrestoParametersProperty:
        def __init__(
            self,
            *,
            catalog: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''The parameters for Presto.

            :param catalog: Catalog.
            :param host: Host.
            :param port: Port.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-prestoparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                presto_parameters_property = quicksight.CfnDataSource.PrestoParametersProperty(
                    catalog="catalog",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f1554b3c6dc71110767c433b9379d93378c01fae501057e19dac440df752137f)
                check_type(argname="argument catalog", value=catalog, expected_type=type_hints["catalog"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "catalog": catalog,
                "host": host,
                "port": port,
            }

        @builtins.property
        def catalog(self) -> builtins.str:
            '''Catalog.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-prestoparameters.html#cfn-quicksight-datasource-prestoparameters-catalog
            '''
            result = self._values.get("catalog")
            assert result is not None, "Required property 'catalog' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-prestoparameters.html#cfn-quicksight-datasource-prestoparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-prestoparameters.html#cfn-quicksight-datasource-prestoparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PrestoParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.RdsParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "instance_id": "instanceId"},
    )
    class RdsParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            instance_id: builtins.str,
        ) -> None:
            '''The parameters for Amazon RDS.

            :param database: Database.
            :param instance_id: Instance ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-rdsparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                rds_parameters_property = quicksight.CfnDataSource.RdsParametersProperty(
                    database="database",
                    instance_id="instanceId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a30b6f28dd8cca8fc2818f609862550035863c318c920a79331e1ac25de5d68b)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "instance_id": instance_id,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-rdsparameters.html#cfn-quicksight-datasource-rdsparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def instance_id(self) -> builtins.str:
            '''Instance ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-rdsparameters.html#cfn-quicksight-datasource-rdsparameters-instanceid
            '''
            result = self._values.get("instance_id")
            assert result is not None, "Required property 'instance_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RdsParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.RedshiftParametersProperty",
        jsii_struct_bases=[],
        name_mapping={
            "database": "database",
            "cluster_id": "clusterId",
            "host": "host",
            "port": "port",
        },
    )
    class RedshiftParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            cluster_id: typing.Optional[builtins.str] = None,
            host: typing.Optional[builtins.str] = None,
            port: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The parameters for Amazon Redshift.

            The ``ClusterId`` field can be blank if ``Host`` and ``Port`` are both set. The ``Host`` and ``Port`` fields can be blank if the ``ClusterId`` field is set.

            :param database: Database.
            :param cluster_id: Cluster ID. This field can be blank if the ``Host`` and ``Port`` are provided.
            :param host: Host. This field can be blank if ``ClusterId`` is provided.
            :param port: Port. This field can be blank if the ``ClusterId`` is provided.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                redshift_parameters_property = quicksight.CfnDataSource.RedshiftParametersProperty(
                    database="database",
                
                    # the properties below are optional
                    cluster_id="clusterId",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3696c4fb0f434d94a61c7c2824c7fa2d13ab009450487f1d83d0a7116c573ce2)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument cluster_id", value=cluster_id, expected_type=type_hints["cluster_id"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
            }
            if cluster_id is not None:
                self._values["cluster_id"] = cluster_id
            if host is not None:
                self._values["host"] = host
            if port is not None:
                self._values["port"] = port

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html#cfn-quicksight-datasource-redshiftparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cluster_id(self) -> typing.Optional[builtins.str]:
            '''Cluster ID.

            This field can be blank if the ``Host`` and ``Port`` are provided.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html#cfn-quicksight-datasource-redshiftparameters-clusterid
            '''
            result = self._values.get("cluster_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def host(self) -> typing.Optional[builtins.str]:
            '''Host.

            This field can be blank if ``ClusterId`` is provided.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html#cfn-quicksight-datasource-redshiftparameters-host
            '''
            result = self._values.get("host")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def port(self) -> typing.Optional[jsii.Number]:
            '''Port.

            This field can be blank if the ``ClusterId`` is provided.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html#cfn-quicksight-datasource-redshiftparameters-port
            '''
            result = self._values.get("port")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RedshiftParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.ResourcePermissionProperty",
        jsii_struct_bases=[],
        name_mapping={"actions": "actions", "principal": "principal"},
    )
    class ResourcePermissionProperty:
        def __init__(
            self,
            *,
            actions: typing.Sequence[builtins.str],
            principal: builtins.str,
        ) -> None:
            '''Permission for the resource.

            :param actions: The IAM action to grant or revoke permissions on.
            :param principal: The Amazon Resource Name (ARN) of the principal. This can be one of the following:. - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.) - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.) - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-resourcepermission.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                resource_permission_property = quicksight.CfnDataSource.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1a0d9b8b7745b89b7ad28ec581b2f119c802dde16a26174f65e9d15a40a7ec3a)
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "actions": actions,
                "principal": principal,
            }

        @builtins.property
        def actions(self) -> typing.List[builtins.str]:
            '''The IAM action to grant or revoke permissions on.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-resourcepermission.html#cfn-quicksight-datasource-resourcepermission-actions
            '''
            result = self._values.get("actions")
            assert result is not None, "Required property 'actions' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def principal(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the principal. This can be one of the following:.

            - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
            - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
            - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-resourcepermission.html#cfn-quicksight-datasource-resourcepermission-principal
            '''
            result = self._values.get("principal")
            assert result is not None, "Required property 'principal' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ResourcePermissionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.S3ParametersProperty",
        jsii_struct_bases=[],
        name_mapping={
            "manifest_file_location": "manifestFileLocation",
            "role_arn": "roleArn",
        },
    )
    class S3ParametersProperty:
        def __init__(
            self,
            *,
            manifest_file_location: typing.Union[_IResolvable_da3f097b, typing.Union["CfnDataSource.ManifestFileLocationProperty", typing.Dict[builtins.str, typing.Any]]],
            role_arn: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The parameters for S3.

            :param manifest_file_location: Location of the Amazon S3 manifest file. This is NULL if the manifest file was uploaded into Amazon QuickSight.
            :param role_arn: Use the ``RoleArn`` structure to override an account-wide role for a specific S3 data source. For example, say an account administrator has turned off all S3 access with an account-wide role. The administrator can then use ``RoleArn`` to bypass the account-wide role and allow S3 access for the single S3 data source that is specified in the structure, even if the account-wide role forbidding S3 access is still active.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-s3parameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                s3_parameters_property = quicksight.CfnDataSource.S3ParametersProperty(
                    manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                        bucket="bucket",
                        key="key"
                    ),
                
                    # the properties below are optional
                    role_arn="roleArn"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f069a6aef4c854b0ac69ced47783e6b4984dde1bdad5255457297e062757cd23)
                check_type(argname="argument manifest_file_location", value=manifest_file_location, expected_type=type_hints["manifest_file_location"])
                check_type(argname="argument role_arn", value=role_arn, expected_type=type_hints["role_arn"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "manifest_file_location": manifest_file_location,
            }
            if role_arn is not None:
                self._values["role_arn"] = role_arn

        @builtins.property
        def manifest_file_location(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnDataSource.ManifestFileLocationProperty"]:
            '''Location of the Amazon S3 manifest file.

            This is NULL if the manifest file was uploaded into Amazon QuickSight.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-s3parameters.html#cfn-quicksight-datasource-s3parameters-manifestfilelocation
            '''
            result = self._values.get("manifest_file_location")
            assert result is not None, "Required property 'manifest_file_location' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnDataSource.ManifestFileLocationProperty"], result)

        @builtins.property
        def role_arn(self) -> typing.Optional[builtins.str]:
            '''Use the ``RoleArn`` structure to override an account-wide role for a specific S3 data source.

            For example, say an account administrator has turned off all S3 access with an account-wide role. The administrator can then use ``RoleArn`` to bypass the account-wide role and allow S3 access for the single S3 data source that is specified in the structure, even if the account-wide role forbidding S3 access is still active.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-s3parameters.html#cfn-quicksight-datasource-s3parameters-rolearn
            '''
            result = self._values.get("role_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "S3ParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.SnowflakeParametersProperty",
        jsii_struct_bases=[],
        name_mapping={
            "database": "database",
            "host": "host",
            "warehouse": "warehouse",
        },
    )
    class SnowflakeParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            warehouse: builtins.str,
        ) -> None:
            '''The parameters for Snowflake.

            :param database: Database.
            :param host: Host.
            :param warehouse: Warehouse.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-snowflakeparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                snowflake_parameters_property = quicksight.CfnDataSource.SnowflakeParametersProperty(
                    database="database",
                    host="host",
                    warehouse="warehouse"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__74a75243f71c1f458ba441efa6b1ed83942a35c740ae1f76ccb413de630bf2e6)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument warehouse", value=warehouse, expected_type=type_hints["warehouse"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "warehouse": warehouse,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-snowflakeparameters.html#cfn-quicksight-datasource-snowflakeparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-snowflakeparameters.html#cfn-quicksight-datasource-snowflakeparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def warehouse(self) -> builtins.str:
            '''Warehouse.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-snowflakeparameters.html#cfn-quicksight-datasource-snowflakeparameters-warehouse
            '''
            result = self._values.get("warehouse")
            assert result is not None, "Required property 'warehouse' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SnowflakeParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.SparkParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"host": "host", "port": "port"},
    )
    class SparkParametersProperty:
        def __init__(self, *, host: builtins.str, port: jsii.Number) -> None:
            '''The parameters for Spark.

            :param host: Host.
            :param port: Port.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sparkparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                spark_parameters_property = quicksight.CfnDataSource.SparkParametersProperty(
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e7f1b320351d2ab2e0df1b096a7232368833c11d754d5f46d8c03bab65ffee79)
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "host": host,
                "port": port,
            }

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sparkparameters.html#cfn-quicksight-datasource-sparkparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sparkparameters.html#cfn-quicksight-datasource-sparkparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SparkParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.SqlServerParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class SqlServerParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''The parameters for SQL Server.

            :param database: Database.
            :param host: Host.
            :param port: Port.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sqlserverparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sql_server_parameters_property = quicksight.CfnDataSource.SqlServerParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__78cf4474920aae5ac05faa6ea40b3898aaadc3004a70bca063f1ad8960837180)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sqlserverparameters.html#cfn-quicksight-datasource-sqlserverparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sqlserverparameters.html#cfn-quicksight-datasource-sqlserverparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sqlserverparameters.html#cfn-quicksight-datasource-sqlserverparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SqlServerParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.SslPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={"disable_ssl": "disableSsl"},
    )
    class SslPropertiesProperty:
        def __init__(
            self,
            *,
            disable_ssl: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
        ) -> None:
            '''Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your underlying data source.

            :param disable_ssl: A Boolean option to control whether SSL should be disabled.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sslproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                ssl_properties_property = quicksight.CfnDataSource.SslPropertiesProperty(
                    disable_ssl=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c0527a039fd4fe9483d9241ba57693fc4698377446bd9454feabe39377ec2629)
                check_type(argname="argument disable_ssl", value=disable_ssl, expected_type=type_hints["disable_ssl"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if disable_ssl is not None:
                self._values["disable_ssl"] = disable_ssl

        @builtins.property
        def disable_ssl(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''A Boolean option to control whether SSL should be disabled.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sslproperties.html#cfn-quicksight-datasource-sslproperties-disablessl
            '''
            result = self._values.get("disable_ssl")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SslPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.StarburstParametersProperty",
        jsii_struct_bases=[],
        name_mapping={
            "catalog": "catalog",
            "host": "host",
            "port": "port",
            "product_type": "productType",
        },
    )
    class StarburstParametersProperty:
        def __init__(
            self,
            *,
            catalog: builtins.str,
            host: builtins.str,
            port: jsii.Number,
            product_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The parameters that are required to connect to a Starburst data source.

            :param catalog: The catalog name for the Starburst data source.
            :param host: The host name of the Starburst data source.
            :param port: The port for the Starburst data source.
            :param product_type: The product type for the Starburst data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-starburstparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                starburst_parameters_property = quicksight.CfnDataSource.StarburstParametersProperty(
                    catalog="catalog",
                    host="host",
                    port=123,
                
                    # the properties below are optional
                    product_type="productType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0f2aa9471e955cd600412f1750933ac79c8c63536aa9a69f8307c8a446b61796)
                check_type(argname="argument catalog", value=catalog, expected_type=type_hints["catalog"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
                check_type(argname="argument product_type", value=product_type, expected_type=type_hints["product_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "catalog": catalog,
                "host": host,
                "port": port,
            }
            if product_type is not None:
                self._values["product_type"] = product_type

        @builtins.property
        def catalog(self) -> builtins.str:
            '''The catalog name for the Starburst data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-starburstparameters.html#cfn-quicksight-datasource-starburstparameters-catalog
            '''
            result = self._values.get("catalog")
            assert result is not None, "Required property 'catalog' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''The host name of the Starburst data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-starburstparameters.html#cfn-quicksight-datasource-starburstparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''The port for the Starburst data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-starburstparameters.html#cfn-quicksight-datasource-starburstparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def product_type(self) -> typing.Optional[builtins.str]:
            '''The product type for the Starburst data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-starburstparameters.html#cfn-quicksight-datasource-starburstparameters-producttype
            '''
            result = self._values.get("product_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StarburstParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.TeradataParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class TeradataParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''The parameters for Teradata.

            :param database: Database.
            :param host: Host.
            :param port: Port.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-teradataparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                teradata_parameters_property = quicksight.CfnDataSource.TeradataParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9aef79f2a949416c28b2a8ca1bd37dda7cd7b9cc340813e2bc2ed1364a1d8847)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-teradataparameters.html#cfn-quicksight-datasource-teradataparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-teradataparameters.html#cfn-quicksight-datasource-teradataparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-teradataparameters.html#cfn-quicksight-datasource-teradataparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TeradataParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.TrinoParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"catalog": "catalog", "host": "host", "port": "port"},
    )
    class TrinoParametersProperty:
        def __init__(
            self,
            *,
            catalog: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''The parameters that are required to connect to a Trino data source.

            :param catalog: The catalog name for the Trino data source.
            :param host: The host name of the Trino data source.
            :param port: The port for the Trino data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-trinoparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                trino_parameters_property = quicksight.CfnDataSource.TrinoParametersProperty(
                    catalog="catalog",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ae7353c1289a19f3a71f414b52a5a49760d845f3e6ec9f8b5ab78a5e9c264835)
                check_type(argname="argument catalog", value=catalog, expected_type=type_hints["catalog"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "catalog": catalog,
                "host": host,
                "port": port,
            }

        @builtins.property
        def catalog(self) -> builtins.str:
            '''The catalog name for the Trino data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-trinoparameters.html#cfn-quicksight-datasource-trinoparameters-catalog
            '''
            result = self._values.get("catalog")
            assert result is not None, "Required property 'catalog' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''The host name of the Trino data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-trinoparameters.html#cfn-quicksight-datasource-trinoparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''The port for the Trino data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-trinoparameters.html#cfn-quicksight-datasource-trinoparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TrinoParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSource.VpcConnectionPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={"vpc_connection_arn": "vpcConnectionArn"},
    )
    class VpcConnectionPropertiesProperty:
        def __init__(self, *, vpc_connection_arn: builtins.str) -> None:
            '''VPC connection properties.

            :param vpc_connection_arn: The Amazon Resource Name (ARN) for the VPC connection.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-vpcconnectionproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                vpc_connection_properties_property = quicksight.CfnDataSource.VpcConnectionPropertiesProperty(
                    vpc_connection_arn="vpcConnectionArn"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__595650930405b9b965c7b84dd2e513079a1e79f8b32e4a0f00eb530dbafae6f4)
                check_type(argname="argument vpc_connection_arn", value=vpc_connection_arn, expected_type=type_hints["vpc_connection_arn"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "vpc_connection_arn": vpc_connection_arn,
            }

        @builtins.property
        def vpc_connection_arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) for the VPC connection.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-vpcconnectionproperties.html#cfn-quicksight-datasource-vpcconnectionproperties-vpcconnectionarn
            '''
            result = self._values.get("vpc_connection_arn")
            assert result is not None, "Required property 'vpc_connection_arn' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VpcConnectionPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="aws-cdk-lib.aws_quicksight.CfnDataSourceProps",
    jsii_struct_bases=[],
    name_mapping={
        "alternate_data_source_parameters": "alternateDataSourceParameters",
        "aws_account_id": "awsAccountId",
        "credentials": "credentials",
        "data_source_id": "dataSourceId",
        "data_source_parameters": "dataSourceParameters",
        "error_info": "errorInfo",
        "name": "name",
        "permissions": "permissions",
        "ssl_properties": "sslProperties",
        "tags": "tags",
        "type": "type",
        "vpc_connection_properties": "vpcConnectionProperties",
    },
)
class CfnDataSourceProps:
    def __init__(
        self,
        *,
        alternate_data_source_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.DataSourceParametersProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        aws_account_id: typing.Optional[builtins.str] = None,
        credentials: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.DataSourceCredentialsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        data_source_id: typing.Optional[builtins.str] = None,
        data_source_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.DataSourceParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        error_info: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.DataSourceErrorInfoProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ssl_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.SslPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
        type: typing.Optional[builtins.str] = None,
        vpc_connection_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.VpcConnectionPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    ) -> None:
        '''Properties for defining a ``CfnDataSource``.

        :param alternate_data_source_parameters: A set of alternate data source parameters that you want to share for the credentials stored with this data source. The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the ``DataSourceParameters`` structure that's in the request with the structures in the ``AlternateDataSourceParameters`` allow list. If the structures are an exact match, the request is allowed to use the credentials from this existing data source. If the ``AlternateDataSourceParameters`` list is null, the ``Credentials`` originally used with this ``DataSourceParameters`` are automatically allowed.
        :param aws_account_id: The AWS account ID.
        :param credentials: The credentials Amazon QuickSight that uses to connect to your underlying source. Currently, only credentials based on user name and password are supported.
        :param data_source_id: An ID for the data source. This ID is unique per AWS Region for each AWS account.
        :param data_source_parameters: The parameters that Amazon QuickSight uses to connect to your underlying source.
        :param error_info: Error information from the last update or the creation of the data source.
        :param name: A display name for the data source.
        :param permissions: A list of resource permissions on the data source.
        :param ssl_properties: Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your underlying source.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the data source.
        :param type: The type of the data source. To return a list of all data sources, use ``ListDataSources`` . Use ``AMAZON_ELASTICSEARCH`` for Amazon OpenSearch Service.
        :param vpc_connection_properties: Use this parameter only when you want Amazon QuickSight to use a VPC connection when connecting to your underlying source.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            from aws_cdk import aws_quicksight as quicksight
            
            cfn_data_source_props = quicksight.CfnDataSourceProps(
                alternate_data_source_parameters=[quicksight.CfnDataSource.DataSourceParametersProperty(
                    amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                        domain="domain"
                    ),
                    amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                        domain="domain"
                    ),
                    athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                        role_arn="roleArn",
                        work_group="workGroup"
                    ),
                    aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                        host="host",
                        port=123,
                        sql_endpoint_path="sqlEndpointPath"
                    ),
                    maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                        catalog="catalog",
                        host="host",
                        port=123
                    ),
                    rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                        database="database",
                        instance_id="instanceId"
                    ),
                    redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                        database="database",
            
                        # the properties below are optional
                        cluster_id="clusterId",
                        host="host",
                        port=123
                    ),
                    s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                        manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                            bucket="bucket",
                            key="key"
                        ),
            
                        # the properties below are optional
                        role_arn="roleArn"
                    ),
                    snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                        database="database",
                        host="host",
                        warehouse="warehouse"
                    ),
                    spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                        host="host",
                        port=123
                    ),
                    sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    starburst_parameters=quicksight.CfnDataSource.StarburstParametersProperty(
                        catalog="catalog",
                        host="host",
                        port=123,
            
                        # the properties below are optional
                        product_type="productType"
                    ),
                    teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    trino_parameters=quicksight.CfnDataSource.TrinoParametersProperty(
                        catalog="catalog",
                        host="host",
                        port=123
                    )
                )],
                aws_account_id="awsAccountId",
                credentials=quicksight.CfnDataSource.DataSourceCredentialsProperty(
                    copy_source_arn="copySourceArn",
                    credential_pair=quicksight.CfnDataSource.CredentialPairProperty(
                        password="password",
                        username="username",
            
                        # the properties below are optional
                        alternate_data_source_parameters=[quicksight.CfnDataSource.DataSourceParametersProperty(
                            amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                                domain="domain"
                            ),
                            amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                                domain="domain"
                            ),
                            athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                                role_arn="roleArn",
                                work_group="workGroup"
                            ),
                            aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                                host="host",
                                port=123,
                                sql_endpoint_path="sqlEndpointPath"
                            ),
                            maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                                catalog="catalog",
                                host="host",
                                port=123
                            ),
                            rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                                database="database",
                                instance_id="instanceId"
                            ),
                            redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                                database="database",
            
                                # the properties below are optional
                                cluster_id="clusterId",
                                host="host",
                                port=123
                            ),
                            s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                                manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                                    bucket="bucket",
                                    key="key"
                                ),
            
                                # the properties below are optional
                                role_arn="roleArn"
                            ),
                            snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                                database="database",
                                host="host",
                                warehouse="warehouse"
                            ),
                            spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                                host="host",
                                port=123
                            ),
                            sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            starburst_parameters=quicksight.CfnDataSource.StarburstParametersProperty(
                                catalog="catalog",
                                host="host",
                                port=123,
            
                                # the properties below are optional
                                product_type="productType"
                            ),
                            teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            trino_parameters=quicksight.CfnDataSource.TrinoParametersProperty(
                                catalog="catalog",
                                host="host",
                                port=123
                            )
                        )]
                    ),
                    secret_arn="secretArn"
                ),
                data_source_id="dataSourceId",
                data_source_parameters=quicksight.CfnDataSource.DataSourceParametersProperty(
                    amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                        domain="domain"
                    ),
                    amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                        domain="domain"
                    ),
                    athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                        role_arn="roleArn",
                        work_group="workGroup"
                    ),
                    aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                        host="host",
                        port=123,
                        sql_endpoint_path="sqlEndpointPath"
                    ),
                    maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                        catalog="catalog",
                        host="host",
                        port=123
                    ),
                    rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                        database="database",
                        instance_id="instanceId"
                    ),
                    redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                        database="database",
            
                        # the properties below are optional
                        cluster_id="clusterId",
                        host="host",
                        port=123
                    ),
                    s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                        manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                            bucket="bucket",
                            key="key"
                        ),
            
                        # the properties below are optional
                        role_arn="roleArn"
                    ),
                    snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                        database="database",
                        host="host",
                        warehouse="warehouse"
                    ),
                    spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                        host="host",
                        port=123
                    ),
                    sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    starburst_parameters=quicksight.CfnDataSource.StarburstParametersProperty(
                        catalog="catalog",
                        host="host",
                        port=123,
            
                        # the properties below are optional
                        product_type="productType"
                    ),
                    teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    trino_parameters=quicksight.CfnDataSource.TrinoParametersProperty(
                        catalog="catalog",
                        host="host",
                        port=123
                    )
                ),
                error_info=quicksight.CfnDataSource.DataSourceErrorInfoProperty(
                    message="message",
                    type="type"
                ),
                name="name",
                permissions=[quicksight.CfnDataSource.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal"
                )],
                ssl_properties=quicksight.CfnDataSource.SslPropertiesProperty(
                    disable_ssl=False
                ),
                tags=[CfnTag(
                    key="key",
                    value="value"
                )],
                type="type",
                vpc_connection_properties=quicksight.CfnDataSource.VpcConnectionPropertiesProperty(
                    vpc_connection_arn="vpcConnectionArn"
                )
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9b7c8e8d2c1cd22ebd57a1044126743d7661d34244f6d106bdbdbab5f407abce)
            check_type(argname="argument alternate_data_source_parameters", value=alternate_data_source_parameters, expected_type=type_hints["alternate_data_source_parameters"])
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument credentials", value=credentials, expected_type=type_hints["credentials"])
            check_type(argname="argument data_source_id", value=data_source_id, expected_type=type_hints["data_source_id"])
            check_type(argname="argument data_source_parameters", value=data_source_parameters, expected_type=type_hints["data_source_parameters"])
            check_type(argname="argument error_info", value=error_info, expected_type=type_hints["error_info"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument permissions", value=permissions, expected_type=type_hints["permissions"])
            check_type(argname="argument ssl_properties", value=ssl_properties, expected_type=type_hints["ssl_properties"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            check_type(argname="argument vpc_connection_properties", value=vpc_connection_properties, expected_type=type_hints["vpc_connection_properties"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if alternate_data_source_parameters is not None:
            self._values["alternate_data_source_parameters"] = alternate_data_source_parameters
        if aws_account_id is not None:
            self._values["aws_account_id"] = aws_account_id
        if credentials is not None:
            self._values["credentials"] = credentials
        if data_source_id is not None:
            self._values["data_source_id"] = data_source_id
        if data_source_parameters is not None:
            self._values["data_source_parameters"] = data_source_parameters
        if error_info is not None:
            self._values["error_info"] = error_info
        if name is not None:
            self._values["name"] = name
        if permissions is not None:
            self._values["permissions"] = permissions
        if ssl_properties is not None:
            self._values["ssl_properties"] = ssl_properties
        if tags is not None:
            self._values["tags"] = tags
        if type is not None:
            self._values["type"] = type
        if vpc_connection_properties is not None:
            self._values["vpc_connection_properties"] = vpc_connection_properties

    @builtins.property
    def alternate_data_source_parameters(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnDataSource.DataSourceParametersProperty]]]]:
        '''A set of alternate data source parameters that you want to share for the credentials stored with this data source.

        The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the ``DataSourceParameters`` structure that's in the request with the structures in the ``AlternateDataSourceParameters`` allow list. If the structures are an exact match, the request is allowed to use the credentials from this existing data source. If the ``AlternateDataSourceParameters`` list is null, the ``Credentials`` originally used with this ``DataSourceParameters`` are automatically allowed.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-alternatedatasourceparameters
        '''
        result = self._values.get("alternate_data_source_parameters")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnDataSource.DataSourceParametersProperty]]]], result)

    @builtins.property
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def credentials(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSource.DataSourceCredentialsProperty]]:
        '''The credentials Amazon QuickSight that uses to connect to your underlying source.

        Currently, only credentials based on user name and password are supported.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-credentials
        '''
        result = self._values.get("credentials")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSource.DataSourceCredentialsProperty]], result)

    @builtins.property
    def data_source_id(self) -> typing.Optional[builtins.str]:
        '''An ID for the data source.

        This ID is unique per AWS Region for each AWS account.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-datasourceid
        '''
        result = self._values.get("data_source_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def data_source_parameters(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSource.DataSourceParametersProperty]]:
        '''The parameters that Amazon QuickSight uses to connect to your underlying source.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-datasourceparameters
        '''
        result = self._values.get("data_source_parameters")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSource.DataSourceParametersProperty]], result)

    @builtins.property
    def error_info(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSource.DataSourceErrorInfoProperty]]:
        '''Error information from the last update or the creation of the data source.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-errorinfo
        '''
        result = self._values.get("error_info")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSource.DataSourceErrorInfoProperty]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''A display name for the data source.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-name
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnDataSource.ResourcePermissionProperty]]]]:
        '''A list of resource permissions on the data source.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-permissions
        '''
        result = self._values.get("permissions")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnDataSource.ResourcePermissionProperty]]]], result)

    @builtins.property
    def ssl_properties(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSource.SslPropertiesProperty]]:
        '''Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your underlying source.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-sslproperties
        '''
        result = self._values.get("ssl_properties")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSource.SslPropertiesProperty]], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[_CfnTag_f6864754]]:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the data source.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-tags
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[_CfnTag_f6864754]], result)

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        '''The type of the data source. To return a list of all data sources, use ``ListDataSources`` .

        Use ``AMAZON_ELASTICSEARCH`` for Amazon OpenSearch Service.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-type
        '''
        result = self._values.get("type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def vpc_connection_properties(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSource.VpcConnectionPropertiesProperty]]:
        '''Use this parameter only when you want Amazon QuickSight to use a VPC connection when connecting to your underlying source.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-vpcconnectionproperties
        '''
        result = self._values.get("vpc_connection_properties")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSource.VpcConnectionPropertiesProperty]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnDataSourceProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_IInspectable_c2943556)
class CfnRefreshSchedule(
    _CfnResource_9df397a6,
    metaclass=jsii.JSIIMeta,
    jsii_type="aws-cdk-lib.aws_quicksight.CfnRefreshSchedule",
):
    '''Creates a refresh schedule for a dataset in Amazon QuickSight .

    :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html
    :cloudformationResource: AWS::QuickSight::RefreshSchedule
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        from aws_cdk import aws_quicksight as quicksight
        
        cfn_refresh_schedule = quicksight.CfnRefreshSchedule(self, "MyCfnRefreshSchedule",
            aws_account_id="awsAccountId",
            data_set_id="dataSetId",
            schedule=quicksight.CfnRefreshSchedule.RefreshScheduleMapProperty(
                refresh_type="refreshType",
                schedule_frequency=quicksight.CfnRefreshSchedule.ScheduleFrequencyProperty(
                    interval="interval",
                    refresh_on_day=quicksight.CfnRefreshSchedule.RefreshOnDayProperty(
                        day_of_month="dayOfMonth",
                        day_of_week="dayOfWeek"
                    ),
                    time_of_the_day="timeOfTheDay",
                    time_zone="timeZone"
                ),
                schedule_id="scheduleId",
                start_after_date_time="startAfterDateTime"
            )
        )
    '''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.Construct,
        id: builtins.str,
        *,
        aws_account_id: typing.Optional[builtins.str] = None,
        data_set_id: typing.Optional[builtins.str] = None,
        schedule: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnRefreshSchedule.RefreshScheduleMapProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
    ) -> None:
        '''
        :param scope: Scope in which this resource is defined.
        :param id: Construct identifier for this resource (unique in its scope).
        :param aws_account_id: The AWS account ID of the account that you are creating a schedule in.
        :param data_set_id: The ID of the dataset that you are creating a refresh schedule for.
        :param schedule: The refresh schedule of a dataset.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4ad4732abfe72da45af3b75a4f86e13e01f71bbd1c4cf8fd558ce9ae1e3f95b)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnRefreshScheduleProps(
            aws_account_id=aws_account_id, data_set_id=data_set_id, schedule=schedule
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _TreeInspector_488e0dd5) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__945b9e35938c7da340f7d0ada11e6418d6280968ee00dfe592ab3d96b632a08c)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__634038d6ad8a870a16dc09755a0b60c2a4fca196a10286b27404b2341942b63c)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) for the refresh schedule.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID of the account that you are creating a schedule in.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec2c57885f2f67ce627b1a42ad0426f41f7fd104fcfa5e461b3f158cf2c2ff9f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="dataSetId")
    def data_set_id(self) -> typing.Optional[builtins.str]:
        '''The ID of the dataset that you are creating a refresh schedule for.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSetId"))

    @data_set_id.setter
    def data_set_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93f377e11628ad839630ace14f55a70cc5e6ba1e63645d0eedc961f5d94d6c07)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSetId", value)

    @builtins.property
    @jsii.member(jsii_name="schedule")
    def schedule(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnRefreshSchedule.RefreshScheduleMapProperty"]]:
        '''The refresh schedule of a dataset.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnRefreshSchedule.RefreshScheduleMapProperty"]], jsii.get(self, "schedule"))

    @schedule.setter
    def schedule(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnRefreshSchedule.RefreshScheduleMapProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36dbe680f5d7d47ac225fee3430988958753aa10ccf851b25cd6306c5c5dc279)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "schedule", value)

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnRefreshSchedule.RefreshOnDayProperty",
        jsii_struct_bases=[],
        name_mapping={"day_of_month": "dayOfMonth", "day_of_week": "dayOfWeek"},
    )
    class RefreshOnDayProperty:
        def __init__(
            self,
            *,
            day_of_month: typing.Optional[builtins.str] = None,
            day_of_week: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The day that you want yout dataset to refresh.

            :param day_of_month: The day of the month that you want your dataset to refresh. This value is required for monthly refresh intervals.
            :param day_of_week: The day of the week that you want to schedule the refresh on. This value is required for weekly and monthly refresh intervals.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshonday.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                refresh_on_day_property = quicksight.CfnRefreshSchedule.RefreshOnDayProperty(
                    day_of_month="dayOfMonth",
                    day_of_week="dayOfWeek"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0467509e48f18eb095ae995864afd79deb4be252e6b3f56b97ac4d488e2e59f1)
                check_type(argname="argument day_of_month", value=day_of_month, expected_type=type_hints["day_of_month"])
                check_type(argname="argument day_of_week", value=day_of_week, expected_type=type_hints["day_of_week"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if day_of_month is not None:
                self._values["day_of_month"] = day_of_month
            if day_of_week is not None:
                self._values["day_of_week"] = day_of_week

        @builtins.property
        def day_of_month(self) -> typing.Optional[builtins.str]:
            '''The day of the month that you want your dataset to refresh.

            This value is required for monthly refresh intervals.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshonday.html#cfn-quicksight-refreshschedule-refreshonday-dayofmonth
            '''
            result = self._values.get("day_of_month")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def day_of_week(self) -> typing.Optional[builtins.str]:
            '''The day of the week that you want to schedule the refresh on.

            This value is required for weekly and monthly refresh intervals.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshonday.html#cfn-quicksight-refreshschedule-refreshonday-dayofweek
            '''
            result = self._values.get("day_of_week")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RefreshOnDayProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnRefreshSchedule.RefreshScheduleMapProperty",
        jsii_struct_bases=[],
        name_mapping={
            "refresh_type": "refreshType",
            "schedule_frequency": "scheduleFrequency",
            "schedule_id": "scheduleId",
            "start_after_date_time": "startAfterDateTime",
        },
    )
    class RefreshScheduleMapProperty:
        def __init__(
            self,
            *,
            refresh_type: typing.Optional[builtins.str] = None,
            schedule_frequency: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnRefreshSchedule.ScheduleFrequencyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            schedule_id: typing.Optional[builtins.str] = None,
            start_after_date_time: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A summary of a configured refresh schedule for a dataset.

            :param refresh_type: The type of refresh that a dataset undergoes. Valid values are as follows:. - ``FULL_REFRESH`` : A complete refresh of a dataset. - ``INCREMENTAL_REFRESH`` : A partial refresh of some rows of a dataset, based on the time window specified. For more information on full and incremental refreshes, see `Refreshing SPICE data <https://docs.aws.amazon.com/quicksight/latest/user/refreshing-imported-data.html>`_ in the *Amazon QuickSight User Guide* .
            :param schedule_frequency: The frequency for the refresh schedule.
            :param schedule_id: An identifier for the refresh schedule.
            :param start_after_date_time: Time after which the refresh schedule can be started, expressed in ``YYYY-MM-DDTHH:MM:SS`` format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshschedulemap.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                refresh_schedule_map_property = quicksight.CfnRefreshSchedule.RefreshScheduleMapProperty(
                    refresh_type="refreshType",
                    schedule_frequency=quicksight.CfnRefreshSchedule.ScheduleFrequencyProperty(
                        interval="interval",
                        refresh_on_day=quicksight.CfnRefreshSchedule.RefreshOnDayProperty(
                            day_of_month="dayOfMonth",
                            day_of_week="dayOfWeek"
                        ),
                        time_of_the_day="timeOfTheDay",
                        time_zone="timeZone"
                    ),
                    schedule_id="scheduleId",
                    start_after_date_time="startAfterDateTime"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__05a08f9e06b3c2605c0ba0ff7dfb4c380508e4b05bbec80e75ba82d7e7b430f3)
                check_type(argname="argument refresh_type", value=refresh_type, expected_type=type_hints["refresh_type"])
                check_type(argname="argument schedule_frequency", value=schedule_frequency, expected_type=type_hints["schedule_frequency"])
                check_type(argname="argument schedule_id", value=schedule_id, expected_type=type_hints["schedule_id"])
                check_type(argname="argument start_after_date_time", value=start_after_date_time, expected_type=type_hints["start_after_date_time"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if refresh_type is not None:
                self._values["refresh_type"] = refresh_type
            if schedule_frequency is not None:
                self._values["schedule_frequency"] = schedule_frequency
            if schedule_id is not None:
                self._values["schedule_id"] = schedule_id
            if start_after_date_time is not None:
                self._values["start_after_date_time"] = start_after_date_time

        @builtins.property
        def refresh_type(self) -> typing.Optional[builtins.str]:
            '''The type of refresh that a dataset undergoes. Valid values are as follows:.

            - ``FULL_REFRESH`` : A complete refresh of a dataset.
            - ``INCREMENTAL_REFRESH`` : A partial refresh of some rows of a dataset, based on the time window specified.

            For more information on full and incremental refreshes, see `Refreshing SPICE data <https://docs.aws.amazon.com/quicksight/latest/user/refreshing-imported-data.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshschedulemap.html#cfn-quicksight-refreshschedule-refreshschedulemap-refreshtype
            '''
            result = self._values.get("refresh_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def schedule_frequency(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnRefreshSchedule.ScheduleFrequencyProperty"]]:
            '''The frequency for the refresh schedule.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshschedulemap.html#cfn-quicksight-refreshschedule-refreshschedulemap-schedulefrequency
            '''
            result = self._values.get("schedule_frequency")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnRefreshSchedule.ScheduleFrequencyProperty"]], result)

        @builtins.property
        def schedule_id(self) -> typing.Optional[builtins.str]:
            '''An identifier for the refresh schedule.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshschedulemap.html#cfn-quicksight-refreshschedule-refreshschedulemap-scheduleid
            '''
            result = self._values.get("schedule_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def start_after_date_time(self) -> typing.Optional[builtins.str]:
            '''Time after which the refresh schedule can be started, expressed in ``YYYY-MM-DDTHH:MM:SS`` format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshschedulemap.html#cfn-quicksight-refreshschedule-refreshschedulemap-startafterdatetime
            '''
            result = self._values.get("start_after_date_time")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RefreshScheduleMapProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnRefreshSchedule.ScheduleFrequencyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "interval": "interval",
            "refresh_on_day": "refreshOnDay",
            "time_of_the_day": "timeOfTheDay",
            "time_zone": "timeZone",
        },
    )
    class ScheduleFrequencyProperty:
        def __init__(
            self,
            *,
            interval: typing.Optional[builtins.str] = None,
            refresh_on_day: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnRefreshSchedule.RefreshOnDayProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_of_the_day: typing.Optional[builtins.str] = None,
            time_zone: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The frequency for the refresh schedule.

            :param interval: The interval between scheduled refreshes. Valid values are as follows:. - ``MINUTE15`` : The dataset refreshes every 15 minutes. This value is only supported for incremental refreshes. This interval can only be used for one schedule per dataset. - ``MINUTE30`` : The dataset refreshes every 30 minutes. This value is only supported for incremental refreshes. This interval can only be used for one schedule per dataset. - ``HOURLY`` : The dataset refreshes every hour. This interval can only be used for one schedule per dataset. - ``DAILY`` : The dataset refreshes every day. - ``WEEKLY`` : The dataset refreshes every week. - ``MONTHLY`` : The dataset refreshes every month.
            :param refresh_on_day: The day of the week that you want to schedule the refresh on. This value is required for weekly and monthly refresh intervals.
            :param time_of_the_day: The time of day that you want the dataset to refresh. This value is expressed in HH:MM format. This field is not required for schedules that refresh hourly.
            :param time_zone: The timezone that you want the refresh schedule to use. The timezone ID must match a corresponding ID found on ``java.util.time.getAvailableIDs()`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-schedulefrequency.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                schedule_frequency_property = quicksight.CfnRefreshSchedule.ScheduleFrequencyProperty(
                    interval="interval",
                    refresh_on_day=quicksight.CfnRefreshSchedule.RefreshOnDayProperty(
                        day_of_month="dayOfMonth",
                        day_of_week="dayOfWeek"
                    ),
                    time_of_the_day="timeOfTheDay",
                    time_zone="timeZone"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__21333ac741c5e658a6c1fc0729934347733dccd666b039ee73de268a25f12467)
                check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
                check_type(argname="argument refresh_on_day", value=refresh_on_day, expected_type=type_hints["refresh_on_day"])
                check_type(argname="argument time_of_the_day", value=time_of_the_day, expected_type=type_hints["time_of_the_day"])
                check_type(argname="argument time_zone", value=time_zone, expected_type=type_hints["time_zone"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if interval is not None:
                self._values["interval"] = interval
            if refresh_on_day is not None:
                self._values["refresh_on_day"] = refresh_on_day
            if time_of_the_day is not None:
                self._values["time_of_the_day"] = time_of_the_day
            if time_zone is not None:
                self._values["time_zone"] = time_zone

        @builtins.property
        def interval(self) -> typing.Optional[builtins.str]:
            '''The interval between scheduled refreshes. Valid values are as follows:.

            - ``MINUTE15`` : The dataset refreshes every 15 minutes. This value is only supported for incremental refreshes. This interval can only be used for one schedule per dataset.
            - ``MINUTE30`` : The dataset refreshes every 30 minutes. This value is only supported for incremental refreshes. This interval can only be used for one schedule per dataset.
            - ``HOURLY`` : The dataset refreshes every hour. This interval can only be used for one schedule per dataset.
            - ``DAILY`` : The dataset refreshes every day.
            - ``WEEKLY`` : The dataset refreshes every week.
            - ``MONTHLY`` : The dataset refreshes every month.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-schedulefrequency.html#cfn-quicksight-refreshschedule-schedulefrequency-interval
            '''
            result = self._values.get("interval")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def refresh_on_day(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnRefreshSchedule.RefreshOnDayProperty"]]:
            '''The day of the week that you want to schedule the refresh on.

            This value is required for weekly and monthly refresh intervals.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-schedulefrequency.html#cfn-quicksight-refreshschedule-schedulefrequency-refreshonday
            '''
            result = self._values.get("refresh_on_day")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnRefreshSchedule.RefreshOnDayProperty"]], result)

        @builtins.property
        def time_of_the_day(self) -> typing.Optional[builtins.str]:
            '''The time of day that you want the dataset to refresh.

            This value is expressed in HH:MM format. This field is not required for schedules that refresh hourly.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-schedulefrequency.html#cfn-quicksight-refreshschedule-schedulefrequency-timeoftheday
            '''
            result = self._values.get("time_of_the_day")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time_zone(self) -> typing.Optional[builtins.str]:
            '''The timezone that you want the refresh schedule to use.

            The timezone ID must match a corresponding ID found on ``java.util.time.getAvailableIDs()`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-schedulefrequency.html#cfn-quicksight-refreshschedule-schedulefrequency-timezone
            '''
            result = self._values.get("time_zone")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScheduleFrequencyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="aws-cdk-lib.aws_quicksight.CfnRefreshScheduleProps",
    jsii_struct_bases=[],
    name_mapping={
        "aws_account_id": "awsAccountId",
        "data_set_id": "dataSetId",
        "schedule": "schedule",
    },
)
class CfnRefreshScheduleProps:
    def __init__(
        self,
        *,
        aws_account_id: typing.Optional[builtins.str] = None,
        data_set_id: typing.Optional[builtins.str] = None,
        schedule: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnRefreshSchedule.RefreshScheduleMapProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    ) -> None:
        '''Properties for defining a ``CfnRefreshSchedule``.

        :param aws_account_id: The AWS account ID of the account that you are creating a schedule in.
        :param data_set_id: The ID of the dataset that you are creating a refresh schedule for.
        :param schedule: The refresh schedule of a dataset.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            from aws_cdk import aws_quicksight as quicksight
            
            cfn_refresh_schedule_props = quicksight.CfnRefreshScheduleProps(
                aws_account_id="awsAccountId",
                data_set_id="dataSetId",
                schedule=quicksight.CfnRefreshSchedule.RefreshScheduleMapProperty(
                    refresh_type="refreshType",
                    schedule_frequency=quicksight.CfnRefreshSchedule.ScheduleFrequencyProperty(
                        interval="interval",
                        refresh_on_day=quicksight.CfnRefreshSchedule.RefreshOnDayProperty(
                            day_of_month="dayOfMonth",
                            day_of_week="dayOfWeek"
                        ),
                        time_of_the_day="timeOfTheDay",
                        time_zone="timeZone"
                    ),
                    schedule_id="scheduleId",
                    start_after_date_time="startAfterDateTime"
                )
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a670ee5c70bad484737825e5e6eada7f15d88c0b7f9999d233cec3f5709297d9)
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument data_set_id", value=data_set_id, expected_type=type_hints["data_set_id"])
            check_type(argname="argument schedule", value=schedule, expected_type=type_hints["schedule"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if aws_account_id is not None:
            self._values["aws_account_id"] = aws_account_id
        if data_set_id is not None:
            self._values["data_set_id"] = data_set_id
        if schedule is not None:
            self._values["schedule"] = schedule

    @builtins.property
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID of the account that you are creating a schedule in.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html#cfn-quicksight-refreshschedule-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def data_set_id(self) -> typing.Optional[builtins.str]:
        '''The ID of the dataset that you are creating a refresh schedule for.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html#cfn-quicksight-refreshschedule-datasetid
        '''
        result = self._values.get("data_set_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def schedule(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnRefreshSchedule.RefreshScheduleMapProperty]]:
        '''The refresh schedule of a dataset.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html#cfn-quicksight-refreshschedule-schedule
        '''
        result = self._values.get("schedule")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnRefreshSchedule.RefreshScheduleMapProperty]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnRefreshScheduleProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_IInspectable_c2943556, _ITaggable_36806126)
class CfnTemplate(
    _CfnResource_9df397a6,
    metaclass=jsii.JSIIMeta,
    jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate",
):
    '''Creates a template from an existing Amazon QuickSight analysis or template.

    You can use the resulting template to create a dashboard.

    A *template* is an entity in Amazon QuickSight that encapsulates the metadata required to create an analysis and that you can use to create s dashboard. A template adds a layer of abstraction by using placeholders to replace the dataset associated with the analysis. You can use templates to create dashboards by replacing dataset placeholders with datasets that follow the same schema that was used to create the source analysis and template.

    :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html
    :cloudformationResource: AWS::QuickSight::Template
    :exampleMetadata: fixture=_generated

    Example::

        
    '''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.Construct,
        id: builtins.str,
        *,
        aws_account_id: builtins.str,
        template_id: builtins.str,
        definition: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TemplateVersionDefinitionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ResourcePermissionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        source_entity: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TemplateSourceEntityProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
        validation_strategy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ValidationStrategyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        version_description: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param scope: Scope in which this resource is defined.
        :param id: Construct identifier for this resource (unique in its scope).
        :param aws_account_id: The ID for the AWS account that the group is in. You use the ID for the AWS account that contains your Amazon QuickSight account.
        :param template_id: An ID for the template that you want to create. This template is unique per AWS Region ; in each AWS account.
        :param definition: 
        :param name: A display name for the template.
        :param permissions: A list of resource permissions to be set on the template.
        :param source_entity: The entity that you are using as a source when you create the template. In ``SourceEntity`` , you specify the type of object you're using as source: ``SourceTemplate`` for a template or ``SourceAnalysis`` for an analysis. Both of these require an Amazon Resource Name (ARN). For ``SourceTemplate`` , specify the ARN of the source template. For ``SourceAnalysis`` , specify the ARN of the source analysis. The ``SourceTemplate`` ARN can contain any AWS account and any Amazon QuickSight-supported AWS Region . Use the ``DataSetReferences`` entity within ``SourceTemplate`` or ``SourceAnalysis`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder. Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the resource.
        :param validation_strategy: The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects. When you set this value to ``LENIENT`` , validation is skipped for specific errors.
        :param version_description: A description of the current template version being created. This API operation creates the first version of the template. Every time ``UpdateTemplate`` is called, a new version is created. Each version of the template maintains a description of the version in the ``VersionDescription`` field.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0c8e24cc78f3ad01c92781c5833871e8c3706c8182c732d67807ebd0270faca)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnTemplateProps(
            aws_account_id=aws_account_id,
            template_id=template_id,
            definition=definition,
            name=name,
            permissions=permissions,
            source_entity=source_entity,
            tags=tags,
            validation_strategy=validation_strategy,
            version_description=version_description,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _TreeInspector_488e0dd5) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ea41f284e6ee55e6da96665e32a383a979628758f6938fbc128e6408b5be1337)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8c2081be2828dc7c619e0cb33d33870093dfe07b9e5b15fd7866de0542110e6)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) of the template.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="attrCreatedTime")
    def attr_created_time(self) -> builtins.str:
        '''The time this template was created.

        :cloudformationAttribute: CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrLastUpdatedTime")
    def attr_last_updated_time(self) -> builtins.str:
        '''The time this template was last updated.

        :cloudformationAttribute: LastUpdatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastUpdatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrVersion")
    def attr_version(self) -> _IResolvable_da3f097b:
        '''The version of the template.

        :cloudformationAttribute: Version
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrVersion"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionCreatedTime")
    def attr_version_created_time(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionDataSetConfigurations")
    def attr_version_data_set_configurations(self) -> _IResolvable_da3f097b:
        '''
        :cloudformationAttribute: Version.DataSetConfigurations
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrVersionDataSetConfigurations"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionDescription")
    def attr_version_description(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Description
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionDescription"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionErrors")
    def attr_version_errors(self) -> _IResolvable_da3f097b:
        '''
        :cloudformationAttribute: Version.Errors
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrVersionErrors"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionSheets")
    def attr_version_sheets(self) -> _IResolvable_da3f097b:
        '''
        :cloudformationAttribute: Version.Sheets
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrVersionSheets"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionSourceEntityArn")
    def attr_version_source_entity_arn(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.SourceEntityArn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionSourceEntityArn"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionStatus")
    def attr_version_status(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Status
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionStatus"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionThemeArn")
    def attr_version_theme_arn(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.ThemeArn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionThemeArn"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionVersionNumber")
    def attr_version_version_number(self) -> _IResolvable_da3f097b:
        '''
        :cloudformationAttribute: Version.VersionNumber
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrVersionVersionNumber"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> _TagManager_0a598cb3:
        '''Tag Manager which manages the tags for this resource.'''
        return typing.cast(_TagManager_0a598cb3, jsii.get(self, "tags"))

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> builtins.str:
        '''The ID for the AWS account that the group is in.'''
        return typing.cast(builtins.str, jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f78480e1c1261c6794d46bf12dda9cb4cc8611907c19903b3c13269cb3d1f863)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="templateId")
    def template_id(self) -> builtins.str:
        '''An ID for the template that you want to create.'''
        return typing.cast(builtins.str, jsii.get(self, "templateId"))

    @template_id.setter
    def template_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__323dcf801b1d629158f29c0b88b39cd6b715a3f7e518ba34a005eb76cd1ae4b2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "templateId", value)

    @builtins.property
    @jsii.member(jsii_name="definition")
    def definition(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TemplateVersionDefinitionProperty"]]:
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TemplateVersionDefinitionProperty"]], jsii.get(self, "definition"))

    @definition.setter
    def definition(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TemplateVersionDefinitionProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cb5ca79f801aad4beca65f22dadde1da626309f4a75061d30e892889b9ebd670)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "definition", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        '''A display name for the template.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "name"))

    @name.setter
    def name(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__18358e54fd872d6c74a81bd0c3771c61f9d4e0a1a8b928dfb0472cfe45674647)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ResourcePermissionProperty"]]]]:
        '''A list of resource permissions to be set on the template.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ResourcePermissionProperty"]]]], jsii.get(self, "permissions"))

    @permissions.setter
    def permissions(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ResourcePermissionProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__83811617320114a1932526f92b4fc096a7a21e6f85d36cf26ba5b408a156f5fd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "permissions", value)

    @builtins.property
    @jsii.member(jsii_name="sourceEntity")
    def source_entity(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TemplateSourceEntityProperty"]]:
        '''The entity that you are using as a source when you create the template.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TemplateSourceEntityProperty"]], jsii.get(self, "sourceEntity"))

    @source_entity.setter
    def source_entity(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TemplateSourceEntityProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__95d2e2f9180ec98478cb3a1bf45085f44ba67d37a8813c116abd6df1f1079cd8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sourceEntity", value)

    @builtins.property
    @jsii.member(jsii_name="tagsRaw")
    def tags_raw(self) -> typing.Optional[typing.List[_CfnTag_f6864754]]:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the resource.'''
        return typing.cast(typing.Optional[typing.List[_CfnTag_f6864754]], jsii.get(self, "tagsRaw"))

    @tags_raw.setter
    def tags_raw(self, value: typing.Optional[typing.List[_CfnTag_f6864754]]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__45a0a6a1e0fb3cf2628a59a5f9bddca32815c39a4591ee49eace15fcce0733ae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tagsRaw", value)

    @builtins.property
    @jsii.member(jsii_name="validationStrategy")
    def validation_strategy(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ValidationStrategyProperty"]]:
        '''The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ValidationStrategyProperty"]], jsii.get(self, "validationStrategy"))

    @validation_strategy.setter
    def validation_strategy(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ValidationStrategyProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ee883791fbdc37cd8bb91a87ef0a3677d4d39fd6a8ca6218c2d9cfc28c1ae63b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "validationStrategy", value)

    @builtins.property
    @jsii.member(jsii_name="versionDescription")
    def version_description(self) -> typing.Optional[builtins.str]:
        '''A description of the current template version being created.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionDescription"))

    @version_description.setter
    def version_description(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc48791621f807f516449184e985fed858b7954a64ffb179b2a5b0b1185b9f79)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "versionDescription", value)

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.AggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "attribute_aggregation_function": "attributeAggregationFunction",
            "categorical_aggregation_function": "categoricalAggregationFunction",
            "date_aggregation_function": "dateAggregationFunction",
            "numerical_aggregation_function": "numericalAggregationFunction",
        },
    )
    class AggregationFunctionProperty:
        def __init__(
            self,
            *,
            attribute_aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AttributeAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            categorical_aggregation_function: typing.Optional[builtins.str] = None,
            date_aggregation_function: typing.Optional[builtins.str] = None,
            numerical_aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''An aggregation function aggregates values from a dimension or measure.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param attribute_aggregation_function: Aggregation for attributes.
            :param categorical_aggregation_function: Aggregation for categorical values. - ``COUNT`` : Aggregate by the total number of values, including duplicates. - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.
            :param date_aggregation_function: Aggregation for date values. - ``COUNT`` : Aggregate by the total number of values, including duplicates. - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values. - ``MIN`` : Select the smallest date value. - ``MAX`` : Select the largest date value.
            :param numerical_aggregation_function: Aggregation for numerical values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                aggregation_function_property = quicksight.CfnTemplate.AggregationFunctionProperty(
                    attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                        simple_attribute_aggregation="simpleAttributeAggregation",
                        value_for_multiple_values="valueForMultipleValues"
                    ),
                    categorical_aggregation_function="categoricalAggregationFunction",
                    date_aggregation_function="dateAggregationFunction",
                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4ae15f6a0d1c0da0b60823cdf82891d19ba1834aaacc2d72f3f95ac978cd22f5)
                check_type(argname="argument attribute_aggregation_function", value=attribute_aggregation_function, expected_type=type_hints["attribute_aggregation_function"])
                check_type(argname="argument categorical_aggregation_function", value=categorical_aggregation_function, expected_type=type_hints["categorical_aggregation_function"])
                check_type(argname="argument date_aggregation_function", value=date_aggregation_function, expected_type=type_hints["date_aggregation_function"])
                check_type(argname="argument numerical_aggregation_function", value=numerical_aggregation_function, expected_type=type_hints["numerical_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if attribute_aggregation_function is not None:
                self._values["attribute_aggregation_function"] = attribute_aggregation_function
            if categorical_aggregation_function is not None:
                self._values["categorical_aggregation_function"] = categorical_aggregation_function
            if date_aggregation_function is not None:
                self._values["date_aggregation_function"] = date_aggregation_function
            if numerical_aggregation_function is not None:
                self._values["numerical_aggregation_function"] = numerical_aggregation_function

        @builtins.property
        def attribute_aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AttributeAggregationFunctionProperty"]]:
            '''Aggregation for attributes.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html#cfn-quicksight-template-aggregationfunction-attributeaggregationfunction
            '''
            result = self._values.get("attribute_aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AttributeAggregationFunctionProperty"]], result)

        @builtins.property
        def categorical_aggregation_function(self) -> typing.Optional[builtins.str]:
            '''Aggregation for categorical values.

            - ``COUNT`` : Aggregate by the total number of values, including duplicates.
            - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html#cfn-quicksight-template-aggregationfunction-categoricalaggregationfunction
            '''
            result = self._values.get("categorical_aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def date_aggregation_function(self) -> typing.Optional[builtins.str]:
            '''Aggregation for date values.

            - ``COUNT`` : Aggregate by the total number of values, including duplicates.
            - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.
            - ``MIN`` : Select the smallest date value.
            - ``MAX`` : Select the largest date value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html#cfn-quicksight-template-aggregationfunction-dateaggregationfunction
            '''
            result = self._values.get("date_aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def numerical_aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericalAggregationFunctionProperty"]]:
            '''Aggregation for numerical values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html#cfn-quicksight-template-aggregationfunction-numericalaggregationfunction
            '''
            result = self._values.get("numerical_aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericalAggregationFunctionProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.AggregationSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "sort_direction": "sortDirection",
            "aggregation_function": "aggregationFunction",
        },
    )
    class AggregationSortConfigurationProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            sort_direction: builtins.str,
            aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration options to sort aggregated values.

            :param column: The column that determines the sort order of aggregated values.
            :param sort_direction: The sort direction of values. - ``ASC`` : Sort in ascending order. - ``DESC`` : Sort in descending order.
            :param aggregation_function: The function that aggregates the values in ``Column`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                aggregation_sort_configuration_property = quicksight.CfnTemplate.AggregationSortConfigurationProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    sort_direction="sortDirection",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                        attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                            simple_attribute_aggregation="simpleAttributeAggregation",
                            value_for_multiple_values="valueForMultipleValues"
                        ),
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__899b150396efb6193ecfc923e792cfdb69986c414162280980c319c2b3e9d89b)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument sort_direction", value=sort_direction, expected_type=type_hints["sort_direction"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "sort_direction": sort_direction,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that determines the sort order of aggregated values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationsortconfiguration.html#cfn-quicksight-template-aggregationsortconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def sort_direction(self) -> builtins.str:
            '''The sort direction of values.

            - ``ASC`` : Sort in ascending order.
            - ``DESC`` : Sort in descending order.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationsortconfiguration.html#cfn-quicksight-template-aggregationsortconfiguration-sortdirection
            '''
            result = self._values.get("sort_direction")
            assert result is not None, "Required property 'sort_direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AggregationFunctionProperty"]]:
            '''The function that aggregates the values in ``Column`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationsortconfiguration.html#cfn-quicksight-template-aggregationsortconfiguration-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AggregationFunctionProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AggregationSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.AnalysisDefaultsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "default_new_sheet_configuration": "defaultNewSheetConfiguration",
        },
    )
    class AnalysisDefaultsProperty:
        def __init__(
            self,
            *,
            default_new_sheet_configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DefaultNewSheetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The configuration for default analysis settings.

            :param default_new_sheet_configuration: The configuration for default new sheet settings.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-analysisdefaults.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                analysis_defaults_property = quicksight.CfnTemplate.AnalysisDefaultsProperty(
                    default_new_sheet_configuration=quicksight.CfnTemplate.DefaultNewSheetConfigurationProperty(
                        interactive_layout_configuration=quicksight.CfnTemplate.DefaultInteractiveLayoutConfigurationProperty(
                            free_form=quicksight.CfnTemplate.DefaultFreeFormLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid=quicksight.CfnTemplate.DefaultGridLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
                
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        ),
                        paginated_layout_configuration=quicksight.CfnTemplate.DefaultPaginatedLayoutConfigurationProperty(
                            section_based=quicksight.CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                )
                            )
                        ),
                        sheet_content_type="sheetContentType"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d88efac6a22f5aef2091eb78077eb883d5cb2bb01d3b1283d1bb943ca7d317f9)
                check_type(argname="argument default_new_sheet_configuration", value=default_new_sheet_configuration, expected_type=type_hints["default_new_sheet_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "default_new_sheet_configuration": default_new_sheet_configuration,
            }

        @builtins.property
        def default_new_sheet_configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.DefaultNewSheetConfigurationProperty"]:
            '''The configuration for default new sheet settings.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-analysisdefaults.html#cfn-quicksight-template-analysisdefaults-defaultnewsheetconfiguration
            '''
            result = self._values.get("default_new_sheet_configuration")
            assert result is not None, "Required property 'default_new_sheet_configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.DefaultNewSheetConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnalysisDefaultsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.AnchorDateConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "anchor_option": "anchorOption",
            "parameter_name": "parameterName",
        },
    )
    class AnchorDateConfigurationProperty:
        def __init__(
            self,
            *,
            anchor_option: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The date configuration of the filter.

            :param anchor_option: The options for the date configuration. Choose one of the options below:. - ``NOW``
            :param parameter_name: The name of the parameter that is used for the anchor date configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-anchordateconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                anchor_date_configuration_property = quicksight.CfnTemplate.AnchorDateConfigurationProperty(
                    anchor_option="anchorOption",
                    parameter_name="parameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f39641ee4786836892cebe29ab3156870e88f985c155a0a113eacfc7911e0160)
                check_type(argname="argument anchor_option", value=anchor_option, expected_type=type_hints["anchor_option"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if anchor_option is not None:
                self._values["anchor_option"] = anchor_option
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name

        @builtins.property
        def anchor_option(self) -> typing.Optional[builtins.str]:
            '''The options for the date configuration. Choose one of the options below:.

            - ``NOW``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-anchordateconfiguration.html#cfn-quicksight-template-anchordateconfiguration-anchoroption
            '''
            result = self._values.get("anchor_option")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The name of the parameter that is used for the anchor date configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-anchordateconfiguration.html#cfn-quicksight-template-anchordateconfiguration-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnchorDateConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ArcAxisConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"range": "range", "reserve_range": "reserveRange"},
    )
    class ArcAxisConfigurationProperty:
        def __init__(
            self,
            *,
            range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ArcAxisDisplayRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reserve_range: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The arc axis configuration of a ``GaugeChartVisual`` .

            :param range: The arc axis range of a ``GaugeChartVisual`` .
            :param reserve_range: The reserved range of the arc axis. Default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                arc_axis_configuration_property = quicksight.CfnTemplate.ArcAxisConfigurationProperty(
                    range=quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                        max=123,
                        min=123
                    ),
                    reserve_range=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5c98bfd1daf818935e1fe927405194f2f3ad49b2e6da76a3e9fc694950518238)
                check_type(argname="argument range", value=range, expected_type=type_hints["range"])
                check_type(argname="argument reserve_range", value=reserve_range, expected_type=type_hints["reserve_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if range is not None:
                self._values["range"] = range
            if reserve_range is not None:
                self._values["reserve_range"] = reserve_range

        @builtins.property
        def range(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ArcAxisDisplayRangeProperty"]]:
            '''The arc axis range of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisconfiguration.html#cfn-quicksight-template-arcaxisconfiguration-range
            '''
            result = self._values.get("range")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ArcAxisDisplayRangeProperty"]], result)

        @builtins.property
        def reserve_range(self) -> typing.Optional[jsii.Number]:
            '''The reserved range of the arc axis.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisconfiguration.html#cfn-quicksight-template-arcaxisconfiguration-reserverange
            '''
            result = self._values.get("reserve_range")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcAxisConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ArcAxisDisplayRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"max": "max", "min": "min"},
    )
    class ArcAxisDisplayRangeProperty:
        def __init__(
            self,
            *,
            max: typing.Optional[jsii.Number] = None,
            min: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The arc axis range of a ``GaugeChartVisual`` .

            :param max: The maximum value of the arc axis range.
            :param min: The minimum value of the arc axis range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisdisplayrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                arc_axis_display_range_property = quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                    max=123,
                    min=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f5ddb158c4901c1644c76119c1567b809dde75544e560045767e104c92b3828d)
                check_type(argname="argument max", value=max, expected_type=type_hints["max"])
                check_type(argname="argument min", value=min, expected_type=type_hints["min"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if max is not None:
                self._values["max"] = max
            if min is not None:
                self._values["min"] = min

        @builtins.property
        def max(self) -> typing.Optional[jsii.Number]:
            '''The maximum value of the arc axis range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisdisplayrange.html#cfn-quicksight-template-arcaxisdisplayrange-max
            '''
            result = self._values.get("max")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def min(self) -> typing.Optional[jsii.Number]:
            '''The minimum value of the arc axis range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisdisplayrange.html#cfn-quicksight-template-arcaxisdisplayrange-min
            '''
            result = self._values.get("min")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcAxisDisplayRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ArcConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"arc_angle": "arcAngle", "arc_thickness": "arcThickness"},
    )
    class ArcConfigurationProperty:
        def __init__(
            self,
            *,
            arc_angle: typing.Optional[jsii.Number] = None,
            arc_thickness: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The arc configuration of a ``GaugeChartVisual`` .

            :param arc_angle: The option that determines the arc angle of a ``GaugeChartVisual`` .
            :param arc_thickness: The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                arc_configuration_property = quicksight.CfnTemplate.ArcConfigurationProperty(
                    arc_angle=123,
                    arc_thickness="arcThickness"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__49ec559a8c18c88262c9b699271d00d95fe148f809f4d6e536e1cce9d5ccb0d3)
                check_type(argname="argument arc_angle", value=arc_angle, expected_type=type_hints["arc_angle"])
                check_type(argname="argument arc_thickness", value=arc_thickness, expected_type=type_hints["arc_thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_angle is not None:
                self._values["arc_angle"] = arc_angle
            if arc_thickness is not None:
                self._values["arc_thickness"] = arc_thickness

        @builtins.property
        def arc_angle(self) -> typing.Optional[jsii.Number]:
            '''The option that determines the arc angle of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcconfiguration.html#cfn-quicksight-template-arcconfiguration-arcangle
            '''
            result = self._values.get("arc_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def arc_thickness(self) -> typing.Optional[builtins.str]:
            '''The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcconfiguration.html#cfn-quicksight-template-arcconfiguration-arcthickness
            '''
            result = self._values.get("arc_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ArcOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"arc_thickness": "arcThickness"},
    )
    class ArcOptionsProperty:
        def __init__(
            self,
            *,
            arc_thickness: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :param arc_thickness: The arc thickness of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                arc_options_property = quicksight.CfnTemplate.ArcOptionsProperty(
                    arc_thickness="arcThickness"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2ed30d2caa9cc85ec7208853f8d5c87e739853df0073a7bc38aa817ccc5b2a16)
                check_type(argname="argument arc_thickness", value=arc_thickness, expected_type=type_hints["arc_thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_thickness is not None:
                self._values["arc_thickness"] = arc_thickness

        @builtins.property
        def arc_thickness(self) -> typing.Optional[builtins.str]:
            '''The arc thickness of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcoptions.html#cfn-quicksight-template-arcoptions-arcthickness
            '''
            result = self._values.get("arc_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.AssetOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"timezone": "timezone", "week_start": "weekStart"},
    )
    class AssetOptionsProperty:
        def __init__(
            self,
            *,
            timezone: typing.Optional[builtins.str] = None,
            week_start: typing.Optional[builtins.str] = None,
        ) -> None:
            '''An array of analysis level configurations.

            :param timezone: Determines the timezone for the analysis.
            :param week_start: Determines the week start day for an analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-assetoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                asset_options_property = quicksight.CfnTemplate.AssetOptionsProperty(
                    timezone="timezone",
                    week_start="weekStart"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__31ddeadf30bd54c1b83fce4a017f2d5347a82683359d2d7943c4b13efd506dd7)
                check_type(argname="argument timezone", value=timezone, expected_type=type_hints["timezone"])
                check_type(argname="argument week_start", value=week_start, expected_type=type_hints["week_start"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if timezone is not None:
                self._values["timezone"] = timezone
            if week_start is not None:
                self._values["week_start"] = week_start

        @builtins.property
        def timezone(self) -> typing.Optional[builtins.str]:
            '''Determines the timezone for the analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-assetoptions.html#cfn-quicksight-template-assetoptions-timezone
            '''
            result = self._values.get("timezone")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def week_start(self) -> typing.Optional[builtins.str]:
            '''Determines the week start day for an analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-assetoptions.html#cfn-quicksight-template-assetoptions-weekstart
            '''
            result = self._values.get("week_start")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AssetOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.AttributeAggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "simple_attribute_aggregation": "simpleAttributeAggregation",
            "value_for_multiple_values": "valueForMultipleValues",
        },
    )
    class AttributeAggregationFunctionProperty:
        def __init__(
            self,
            *,
            simple_attribute_aggregation: typing.Optional[builtins.str] = None,
            value_for_multiple_values: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Aggregation for attributes.

            :param simple_attribute_aggregation: The built-in aggregation functions for attributes. - ``UNIQUE_VALUE`` : Returns the unique value for a field, aggregated by the dimension fields.
            :param value_for_multiple_values: Used by the ``UNIQUE_VALUE`` aggregation function. If there are multiple values for the field used by the aggregation, the value for this property will be returned instead. Defaults to '*'.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-attributeaggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                attribute_aggregation_function_property = quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                    simple_attribute_aggregation="simpleAttributeAggregation",
                    value_for_multiple_values="valueForMultipleValues"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bfc0192b93008407246e8099dc9f5380dbf14f95482c35fa5e2075c0ccfb9b34)
                check_type(argname="argument simple_attribute_aggregation", value=simple_attribute_aggregation, expected_type=type_hints["simple_attribute_aggregation"])
                check_type(argname="argument value_for_multiple_values", value=value_for_multiple_values, expected_type=type_hints["value_for_multiple_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if simple_attribute_aggregation is not None:
                self._values["simple_attribute_aggregation"] = simple_attribute_aggregation
            if value_for_multiple_values is not None:
                self._values["value_for_multiple_values"] = value_for_multiple_values

        @builtins.property
        def simple_attribute_aggregation(self) -> typing.Optional[builtins.str]:
            '''The built-in aggregation functions for attributes.

            - ``UNIQUE_VALUE`` : Returns the unique value for a field, aggregated by the dimension fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-attributeaggregationfunction.html#cfn-quicksight-template-attributeaggregationfunction-simpleattributeaggregation
            '''
            result = self._values.get("simple_attribute_aggregation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_for_multiple_values(self) -> typing.Optional[builtins.str]:
            '''Used by the ``UNIQUE_VALUE`` aggregation function.

            If there are multiple values for the field used by the aggregation, the value for this property will be returned instead. Defaults to '*'.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-attributeaggregationfunction.html#cfn-quicksight-template-attributeaggregationfunction-valueformultiplevalues
            '''
            result = self._values.get("value_for_multiple_values")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AttributeAggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.AxisDataOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_axis_options": "dateAxisOptions",
            "numeric_axis_options": "numericAxisOptions",
        },
    )
    class AxisDataOptionsProperty:
        def __init__(
            self,
            *,
            date_axis_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DateAxisOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_axis_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumericAxisOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The data options for an axis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_axis_options: The options for an axis with a date field.
            :param numeric_axis_options: The options for an axis with a numeric field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdataoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_data_options_property = quicksight.CfnTemplate.AxisDataOptionsProperty(
                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                        missing_date_visibility="missingDateVisibility"
                    ),
                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                            data_driven=data_driven,
                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                maximum=123,
                                minimum=123
                            )
                        ),
                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                step_count=123,
                                step_size=123
                            ),
                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                base=123
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__892c2c6739dea9d4f226df0563919792795b7795083b6427f1e63c2fecbb1ef5)
                check_type(argname="argument date_axis_options", value=date_axis_options, expected_type=type_hints["date_axis_options"])
                check_type(argname="argument numeric_axis_options", value=numeric_axis_options, expected_type=type_hints["numeric_axis_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_axis_options is not None:
                self._values["date_axis_options"] = date_axis_options
            if numeric_axis_options is not None:
                self._values["numeric_axis_options"] = numeric_axis_options

        @builtins.property
        def date_axis_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateAxisOptionsProperty"]]:
            '''The options for an axis with a date field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdataoptions.html#cfn-quicksight-template-axisdataoptions-dateaxisoptions
            '''
            result = self._values.get("date_axis_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateAxisOptionsProperty"]], result)

        @builtins.property
        def numeric_axis_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericAxisOptionsProperty"]]:
            '''The options for an axis with a numeric field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdataoptions.html#cfn-quicksight-template-axisdataoptions-numericaxisoptions
            '''
            result = self._values.get("numeric_axis_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericAxisOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDataOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"maximum": "maximum", "minimum": "minimum"},
    )
    class AxisDisplayMinMaxRangeProperty:
        def __init__(
            self,
            *,
            maximum: typing.Optional[jsii.Number] = None,
            minimum: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The minimum and maximum setup for an axis display range.

            :param maximum: The maximum setup for an axis display range.
            :param minimum: The minimum setup for an axis display range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayminmaxrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                axis_display_min_max_range_property = quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                    maximum=123,
                    minimum=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__299e628c4c605e541194e9e1d129f3842271f250c689c00c1475c8ae4d703f97)
                check_type(argname="argument maximum", value=maximum, expected_type=type_hints["maximum"])
                check_type(argname="argument minimum", value=minimum, expected_type=type_hints["minimum"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if maximum is not None:
                self._values["maximum"] = maximum
            if minimum is not None:
                self._values["minimum"] = minimum

        @builtins.property
        def maximum(self) -> typing.Optional[jsii.Number]:
            '''The maximum setup for an axis display range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayminmaxrange.html#cfn-quicksight-template-axisdisplayminmaxrange-maximum
            '''
            result = self._values.get("maximum")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def minimum(self) -> typing.Optional[jsii.Number]:
            '''The minimum setup for an axis display range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayminmaxrange.html#cfn-quicksight-template-axisdisplayminmaxrange-minimum
            '''
            result = self._values.get("minimum")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayMinMaxRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.AxisDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_line_visibility": "axisLineVisibility",
            "axis_offset": "axisOffset",
            "data_options": "dataOptions",
            "grid_line_visibility": "gridLineVisibility",
            "scrollbar_options": "scrollbarOptions",
            "tick_label_options": "tickLabelOptions",
        },
    )
    class AxisDisplayOptionsProperty:
        def __init__(
            self,
            *,
            axis_line_visibility: typing.Optional[builtins.str] = None,
            axis_offset: typing.Optional[builtins.str] = None,
            data_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisDataOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            grid_line_visibility: typing.Optional[builtins.str] = None,
            scrollbar_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ScrollBarOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tick_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisTickLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options for the axis label.

            :param axis_line_visibility: Determines whether or not the axis line is visible.
            :param axis_offset: The offset value that determines the starting placement of the axis within a visual's bounds.
            :param data_options: The data options for an axis.
            :param grid_line_visibility: Determines whether or not the grid line is visible.
            :param scrollbar_options: The scroll bar options for an axis.
            :param tick_label_options: The tick label options of an axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_display_options_property = quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                    axis_line_visibility="axisLineVisibility",
                    axis_offset="axisOffset",
                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                            missing_date_visibility="missingDateVisibility"
                        ),
                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                data_driven=data_driven,
                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                    maximum=123,
                                    minimum=123
                                )
                            ),
                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                    step_count=123,
                                    step_size=123
                                ),
                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                    base=123
                                )
                            )
                        )
                    ),
                    grid_line_visibility="gridLineVisibility",
                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                        visibility="visibility",
                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                from=123,
                                to=123
                            )
                        )
                    ),
                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        rotation_angle=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__de16eb692bce6d664ba2d9c38d1d83231bc03e3350b346ce4ccc6c574dee5710)
                check_type(argname="argument axis_line_visibility", value=axis_line_visibility, expected_type=type_hints["axis_line_visibility"])
                check_type(argname="argument axis_offset", value=axis_offset, expected_type=type_hints["axis_offset"])
                check_type(argname="argument data_options", value=data_options, expected_type=type_hints["data_options"])
                check_type(argname="argument grid_line_visibility", value=grid_line_visibility, expected_type=type_hints["grid_line_visibility"])
                check_type(argname="argument scrollbar_options", value=scrollbar_options, expected_type=type_hints["scrollbar_options"])
                check_type(argname="argument tick_label_options", value=tick_label_options, expected_type=type_hints["tick_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_line_visibility is not None:
                self._values["axis_line_visibility"] = axis_line_visibility
            if axis_offset is not None:
                self._values["axis_offset"] = axis_offset
            if data_options is not None:
                self._values["data_options"] = data_options
            if grid_line_visibility is not None:
                self._values["grid_line_visibility"] = grid_line_visibility
            if scrollbar_options is not None:
                self._values["scrollbar_options"] = scrollbar_options
            if tick_label_options is not None:
                self._values["tick_label_options"] = tick_label_options

        @builtins.property
        def axis_line_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the axis line is visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-axislinevisibility
            '''
            result = self._values.get("axis_line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def axis_offset(self) -> typing.Optional[builtins.str]:
            '''The offset value that determines the starting placement of the axis within a visual's bounds.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-axisoffset
            '''
            result = self._values.get("axis_offset")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDataOptionsProperty"]]:
            '''The data options for an axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-dataoptions
            '''
            result = self._values.get("data_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDataOptionsProperty"]], result)

        @builtins.property
        def grid_line_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the grid line is visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-gridlinevisibility
            '''
            result = self._values.get("grid_line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scrollbar_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ScrollBarOptionsProperty"]]:
            '''The scroll bar options for an axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-scrollbaroptions
            '''
            result = self._values.get("scrollbar_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ScrollBarOptionsProperty"]], result)

        @builtins.property
        def tick_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisTickLabelOptionsProperty"]]:
            '''The tick label options of an axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-ticklabeloptions
            '''
            result = self._values.get("tick_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisTickLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.AxisDisplayRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"data_driven": "dataDriven", "min_max": "minMax"},
    )
    class AxisDisplayRangeProperty:
        def __init__(
            self,
            *,
            data_driven: typing.Any = None,
            min_max: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisDisplayMinMaxRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The range setup of a numeric axis display range.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_driven: The data-driven setup of an axis display range.
            :param min_max: The minimum and maximum setup of an axis display range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_display_range_property = quicksight.CfnTemplate.AxisDisplayRangeProperty(
                    data_driven=data_driven,
                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                        maximum=123,
                        minimum=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e329fad5b17cde26f47118e45d4aa94d0c850ecd22c23c8002fab8675d20c08f)
                check_type(argname="argument data_driven", value=data_driven, expected_type=type_hints["data_driven"])
                check_type(argname="argument min_max", value=min_max, expected_type=type_hints["min_max"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_driven is not None:
                self._values["data_driven"] = data_driven
            if min_max is not None:
                self._values["min_max"] = min_max

        @builtins.property
        def data_driven(self) -> typing.Any:
            '''The data-driven setup of an axis display range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayrange.html#cfn-quicksight-template-axisdisplayrange-datadriven
            '''
            result = self._values.get("data_driven")
            return typing.cast(typing.Any, result)

        @builtins.property
        def min_max(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayMinMaxRangeProperty"]]:
            '''The minimum and maximum setup of an axis display range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayrange.html#cfn-quicksight-template-axisdisplayrange-minmax
            '''
            result = self._values.get("min_max")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayMinMaxRangeProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.AxisLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "apply_to": "applyTo",
            "custom_label": "customLabel",
            "font_configuration": "fontConfiguration",
        },
    )
    class AxisLabelOptionsProperty:
        def __init__(
            self,
            *,
            apply_to: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisLabelReferenceOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_label: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The label options for a chart axis.

            You must specify the field that the label is targeted to.

            :param apply_to: The options that indicate which field the label belongs to.
            :param custom_label: The text for the axis label.
            :param font_configuration: The font configuration of the axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                axis_label_options_property = quicksight.CfnTemplate.AxisLabelOptionsProperty(
                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId"
                    ),
                    custom_label="customLabel",
                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0e99511c18ed98a732c74a27da27fef9104d2ddafb0ff322038eb4b4e4233b8f)
                check_type(argname="argument apply_to", value=apply_to, expected_type=type_hints["apply_to"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if apply_to is not None:
                self._values["apply_to"] = apply_to
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration

        @builtins.property
        def apply_to(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisLabelReferenceOptionsProperty"]]:
            '''The options that indicate which field the label belongs to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabeloptions.html#cfn-quicksight-template-axislabeloptions-applyto
            '''
            result = self._values.get("apply_to")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisLabelReferenceOptionsProperty"]], result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The text for the axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabeloptions.html#cfn-quicksight-template-axislabeloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"]]:
            '''The font configuration of the axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabeloptions.html#cfn-quicksight-template-axislabeloptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "field_id": "fieldId"},
    )
    class AxisLabelReferenceOptionsProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
        ) -> None:
            '''The reference that specifies where the axis label is applied to.

            :param column: The column that the axis label is targeted to.
            :param field_id: The field that the axis label is targeted to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabelreferenceoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                axis_label_reference_options_property = quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__24570836df727f018b47ef322dd3a61d5a8e8eb9a18c1e71f6d9a8c1859eb78d)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the axis label is targeted to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabelreferenceoptions.html#cfn-quicksight-template-axislabelreferenceoptions-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field that the axis label is targeted to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabelreferenceoptions.html#cfn-quicksight-template-axislabelreferenceoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLabelReferenceOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.AxisLinearScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"step_count": "stepCount", "step_size": "stepSize"},
    )
    class AxisLinearScaleProperty:
        def __init__(
            self,
            *,
            step_count: typing.Optional[jsii.Number] = None,
            step_size: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The liner axis scale setup.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param step_count: The step count setup of a linear axis.
            :param step_size: The step size setup of a linear axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislinearscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                axis_linear_scale_property = quicksight.CfnTemplate.AxisLinearScaleProperty(
                    step_count=123,
                    step_size=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f8a4b29505afbad0ca6b088e6c7a30d5bcbb9efb9db42a0c4109ac0b73418cad)
                check_type(argname="argument step_count", value=step_count, expected_type=type_hints["step_count"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if step_count is not None:
                self._values["step_count"] = step_count
            if step_size is not None:
                self._values["step_size"] = step_size

        @builtins.property
        def step_count(self) -> typing.Optional[jsii.Number]:
            '''The step count setup of a linear axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislinearscale.html#cfn-quicksight-template-axislinearscale-stepcount
            '''
            result = self._values.get("step_count")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def step_size(self) -> typing.Optional[jsii.Number]:
            '''The step size setup of a linear axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislinearscale.html#cfn-quicksight-template-axislinearscale-stepsize
            '''
            result = self._values.get("step_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLinearScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.AxisLogarithmicScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"base": "base"},
    )
    class AxisLogarithmicScaleProperty:
        def __init__(self, *, base: typing.Optional[jsii.Number] = None) -> None:
            '''The logarithmic axis scale setup.

            :param base: The base setup of a logarithmic axis scale.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislogarithmicscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                axis_logarithmic_scale_property = quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                    base=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__917b40a75680ae4ff5a1f96159a02ba72380fb311945bf8e24e5a75b8a18ce2d)
                check_type(argname="argument base", value=base, expected_type=type_hints["base"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if base is not None:
                self._values["base"] = base

        @builtins.property
        def base(self) -> typing.Optional[jsii.Number]:
            '''The base setup of a logarithmic axis scale.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislogarithmicscale.html#cfn-quicksight-template-axislogarithmicscale-base
            '''
            result = self._values.get("base")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLogarithmicScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.AxisScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"linear": "linear", "logarithmic": "logarithmic"},
    )
    class AxisScaleProperty:
        def __init__(
            self,
            *,
            linear: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisLinearScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            logarithmic: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisLogarithmicScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The scale setup options for a numeric axis display.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param linear: The linear axis scale setup.
            :param logarithmic: The logarithmic axis scale setup.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                axis_scale_property = quicksight.CfnTemplate.AxisScaleProperty(
                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                        step_count=123,
                        step_size=123
                    ),
                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                        base=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__721d9220a3113f9a49fe2d367328323ffb99773a62f1a6d4e7c35a90a0756903)
                check_type(argname="argument linear", value=linear, expected_type=type_hints["linear"])
                check_type(argname="argument logarithmic", value=logarithmic, expected_type=type_hints["logarithmic"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if linear is not None:
                self._values["linear"] = linear
            if logarithmic is not None:
                self._values["logarithmic"] = logarithmic

        @builtins.property
        def linear(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisLinearScaleProperty"]]:
            '''The linear axis scale setup.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisscale.html#cfn-quicksight-template-axisscale-linear
            '''
            result = self._values.get("linear")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisLinearScaleProperty"]], result)

        @builtins.property
        def logarithmic(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisLogarithmicScaleProperty"]]:
            '''The logarithmic axis scale setup.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisscale.html#cfn-quicksight-template-axisscale-logarithmic
            '''
            result = self._values.get("logarithmic")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisLogarithmicScaleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.AxisTickLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "label_options": "labelOptions",
            "rotation_angle": "rotationAngle",
        },
    )
    class AxisTickLabelOptionsProperty:
        def __init__(
            self,
            *,
            label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rotation_angle: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The tick label options of an axis.

            :param label_options: Determines whether or not the axis ticks are visible.
            :param rotation_angle: The rotation angle of the axis tick labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisticklabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                axis_tick_label_options_property = quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    ),
                    rotation_angle=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__03d82cd095e47eb37815bb93b179f3cdc725c00a999fe8e1b6ed7f8d467db3c4)
                check_type(argname="argument label_options", value=label_options, expected_type=type_hints["label_options"])
                check_type(argname="argument rotation_angle", value=rotation_angle, expected_type=type_hints["rotation_angle"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if label_options is not None:
                self._values["label_options"] = label_options
            if rotation_angle is not None:
                self._values["rotation_angle"] = rotation_angle

        @builtins.property
        def label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LabelOptionsProperty"]]:
            '''Determines whether or not the axis ticks are visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisticklabeloptions.html#cfn-quicksight-template-axisticklabeloptions-labeloptions
            '''
            result = self._values.get("label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LabelOptionsProperty"]], result)

        @builtins.property
        def rotation_angle(self) -> typing.Optional[jsii.Number]:
            '''The rotation angle of the axis tick labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisticklabeloptions.html#cfn-quicksight-template-axisticklabeloptions-rotationangle
            '''
            result = self._values.get("rotation_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisTickLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.BarChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "colors": "colors",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class BarChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a bar chart.

            :param category: The category (y-axis) field well of a bar chart.
            :param colors: The color (group/color) field well of a bar chart.
            :param small_multiples: The small multiples field well of a bar chart.
            :param values: The value field wells of a bar chart. Values are aggregated by category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6c1c547ea11ddc025bd8acf2ac59074484488e050b3a2719a3e83dec317982d7)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The category (y-axis) field well of a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html#cfn-quicksight-template-barchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The color (group/color) field well of a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html#cfn-quicksight-template-barchartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The small multiples field well of a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html#cfn-quicksight-template-barchartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The value field wells of a bar chart.

            Values are aggregated by category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html#cfn-quicksight-template-barchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.BarChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bars_arrangement": "barsArrangement",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_label_options": "colorLabelOptions",
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "orientation": "orientation",
            "reference_lines": "referenceLines",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_axis": "valueAxis",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class BarChartConfigurationProperty:
        def __init__(
            self,
            *,
            bars_arrangement: typing.Optional[builtins.str] = None,
            category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.BarChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            orientation: typing.Optional[builtins.str] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.BarChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``BarChartVisual`` .

            :param bars_arrangement: Determines the arrangement of the bars. The orientation and arrangement of bars determine the type of bar that is used in the visual.
            :param category_axis: The label display options (grid line, range, scale, axis step) for bar chart category.
            :param category_label_options: The label options (label text, label visibility and sort icon visibility) for a bar chart.
            :param color_label_options: The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.
            :param contribution_analysis_defaults: The contribution analysis (anomaly configuration) setup of the visual.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param orientation: The orientation of the bars in a bar chart visual. There are two valid values in this structure:. - ``HORIZONTAL`` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts. - ``VERTICAL`` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.
            :param reference_lines: The reference line setup of the visual.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a ``BarChartVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param value_axis: The label display options (grid line, range, scale, axis step) for a bar chart value.
            :param value_label_options: The label options (label text, label visibility and sort icon visibility) for a bar chart value.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5365f6038450b55f4f2629b83773a006ba0ca194c88b2804d31e823add586ba0)
                check_type(argname="argument bars_arrangement", value=bars_arrangement, expected_type=type_hints["bars_arrangement"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument orientation", value=orientation, expected_type=type_hints["orientation"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_axis", value=value_axis, expected_type=type_hints["value_axis"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bars_arrangement is not None:
                self._values["bars_arrangement"] = bars_arrangement
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if orientation is not None:
                self._values["orientation"] = orientation
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_axis is not None:
                self._values["value_axis"] = value_axis
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def bars_arrangement(self) -> typing.Optional[builtins.str]:
            '''Determines the arrangement of the bars.

            The orientation and arrangement of bars determine the type of bar that is used in the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-barsarrangement
            '''
            result = self._values.get("bars_arrangement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) for bar chart category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) for a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ContributionAnalysisDefaultProperty"]]]]:
            '''The contribution analysis (anomaly configuration) setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ContributionAnalysisDefaultProperty"]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BarChartFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BarChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def orientation(self) -> typing.Optional[builtins.str]:
            '''The orientation of the bars in a bar chart visual. There are two valid values in this structure:.

            - ``HORIZONTAL`` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts.
            - ``VERTICAL`` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-orientation
            '''
            result = self._values.get("orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineProperty"]]]]:
            '''The reference line setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineProperty"]]]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SmallMultiplesOptionsProperty"]]:
            '''The small multiples setup for the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SmallMultiplesOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BarChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``BarChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BarChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def value_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) for a bar chart value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-valueaxis
            '''
            result = self._values.get("value_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) for a bar chart value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.BarChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_chart_aggregated_field_wells": "barChartAggregatedFieldWells",
        },
    )
    class BarChartFieldWellsProperty:
        def __init__(
            self,
            *,
            bar_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.BarChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``BarChartVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param bar_chart_aggregated_field_wells: The aggregated field wells of a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__127ad02a45eb0822d9d86b5658043155c77cd7c8806d485816a889fa5e5c6059)
                check_type(argname="argument bar_chart_aggregated_field_wells", value=bar_chart_aggregated_field_wells, expected_type=type_hints["bar_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_chart_aggregated_field_wells is not None:
                self._values["bar_chart_aggregated_field_wells"] = bar_chart_aggregated_field_wells

        @builtins.property
        def bar_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BarChartAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartfieldwells.html#cfn-quicksight-template-barchartfieldwells-barchartaggregatedfieldwells
            '''
            result = self._values.get("bar_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BarChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.BarChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class BarChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''sort-configuration-description.

            :param category_items_limit: The limit on the number of categories displayed in a bar chart.
            :param category_sort: The sort configuration of category fields.
            :param color_items_limit: The limit on the number of values displayed in a bar chart.
            :param color_sort: The sort configuration of color fields in a bar chart.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                bar_chart_sort_configuration_property = quicksight.CfnTemplate.BarChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__968874fce4e23d6938bbdf3a77c42ff110ea9e93ffd38e96dd576fe41f8f9ee5)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories displayed in a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of values displayed in a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of color fields in a bar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of small multiples panels that are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the small multiples field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.BarChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class BarChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.BarChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A bar chart.

            The ``BarChartVisual`` structure describes a visual that is a member of the bar chart family. The following charts can be described using this structure:

            - Horizontal bar chart
            - Vertical bar chart
            - Horizontal stacked bar chart
            - Vertical stacked bar chart
            - Horizontal stacked 100% bar chart
            - Vertical stacked 100% bar chart

            For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__925db1448c529d5054d62c94edb5dcb90a3629f37641c88f267904704ea02f1b)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BarChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BarChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.BinCountOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"value": "value"},
    )
    class BinCountOptionsProperty:
        def __init__(self, *, value: typing.Optional[jsii.Number] = None) -> None:
            '''The options that determine the bin count of a histogram.

            :param value: The options that determine the bin count value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bincountoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                bin_count_options_property = quicksight.CfnTemplate.BinCountOptionsProperty(
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__190eced312de1d362e6c65a03af74c36d8f57d09e1f2513d30a323b70bde704c)
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin count value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bincountoptions.html#cfn-quicksight-template-bincountoptions-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BinCountOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.BinWidthOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"bin_count_limit": "binCountLimit", "value": "value"},
    )
    class BinWidthOptionsProperty:
        def __init__(
            self,
            *,
            bin_count_limit: typing.Optional[jsii.Number] = None,
            value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The options that determine the bin width of a histogram.

            :param bin_count_limit: The options that determine the bin count limit.
            :param value: The options that determine the bin width value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-binwidthoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                bin_width_options_property = quicksight.CfnTemplate.BinWidthOptionsProperty(
                    bin_count_limit=123,
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ad592ec5d03d0efa21db4a7baff48a76ef8f10a2dbd9333728f382fffb4d5507)
                check_type(argname="argument bin_count_limit", value=bin_count_limit, expected_type=type_hints["bin_count_limit"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_count_limit is not None:
                self._values["bin_count_limit"] = bin_count_limit
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def bin_count_limit(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin count limit.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-binwidthoptions.html#cfn-quicksight-template-binwidthoptions-bincountlimit
            '''
            result = self._values.get("bin_count_limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin width value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-binwidthoptions.html#cfn-quicksight-template-binwidthoptions-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BinWidthOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.BodySectionConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "content": "content",
            "section_id": "sectionId",
            "page_break_configuration": "pageBreakConfiguration",
            "style": "style",
        },
    )
    class BodySectionConfigurationProperty:
        def __init__(
            self,
            *,
            content: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.BodySectionContentProperty", typing.Dict[builtins.str, typing.Any]]],
            section_id: builtins.str,
            page_break_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SectionPageBreakConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SectionStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a body section.

            :param content: The configuration of content in a body section.
            :param section_id: The unique identifier of a body section.
            :param page_break_configuration: The configuration of a page break for a section.
            :param style: The style options of a body section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                body_section_configuration_property = quicksight.CfnTemplate.BodySectionConfigurationProperty(
                    content=quicksight.CfnTemplate.BodySectionContentProperty(
                        layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        )
                    ),
                    section_id="sectionId",
                
                    # the properties below are optional
                    page_break_configuration=quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                        after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                            status="status"
                        )
                    ),
                    style=quicksight.CfnTemplate.SectionStyleProperty(
                        height="height",
                        padding=quicksight.CfnTemplate.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ea55503ff61b3f3ed59cbf6c276aa33b5e5f3a127ef8624ebe8061050d9efe84)
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
                check_type(argname="argument section_id", value=section_id, expected_type=type_hints["section_id"])
                check_type(argname="argument page_break_configuration", value=page_break_configuration, expected_type=type_hints["page_break_configuration"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "content": content,
                "section_id": section_id,
            }
            if page_break_configuration is not None:
                self._values["page_break_configuration"] = page_break_configuration
            if style is not None:
                self._values["style"] = style

        @builtins.property
        def content(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.BodySectionContentProperty"]:
            '''The configuration of content in a body section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html#cfn-quicksight-template-bodysectionconfiguration-content
            '''
            result = self._values.get("content")
            assert result is not None, "Required property 'content' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.BodySectionContentProperty"], result)

        @builtins.property
        def section_id(self) -> builtins.str:
            '''The unique identifier of a body section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html#cfn-quicksight-template-bodysectionconfiguration-sectionid
            '''
            result = self._values.get("section_id")
            assert result is not None, "Required property 'section_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def page_break_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SectionPageBreakConfigurationProperty"]]:
            '''The configuration of a page break for a section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html#cfn-quicksight-template-bodysectionconfiguration-pagebreakconfiguration
            '''
            result = self._values.get("page_break_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SectionPageBreakConfigurationProperty"]], result)

        @builtins.property
        def style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SectionStyleProperty"]]:
            '''The style options of a body section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html#cfn-quicksight-template-bodysectionconfiguration-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SectionStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BodySectionConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.BodySectionContentProperty",
        jsii_struct_bases=[],
        name_mapping={"layout": "layout"},
    )
    class BodySectionContentProperty:
        def __init__(
            self,
            *,
            layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of content in a body section.

            :param layout: The layout configuration of a body section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectioncontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                body_section_content_property = quicksight.CfnTemplate.BodySectionContentProperty(
                    layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                            elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__70d71407c268cfe839fccff09a3b0bf66dfbafa150032495508c90bd430d55c5)
                check_type(argname="argument layout", value=layout, expected_type=type_hints["layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if layout is not None:
                self._values["layout"] = layout

        @builtins.property
        def layout(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SectionLayoutConfigurationProperty"]]:
            '''The layout configuration of a body section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectioncontent.html#cfn-quicksight-template-bodysectioncontent-layout
            '''
            result = self._values.get("layout")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SectionLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BodySectionContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "values": "values"},
    )
    class BoxPlotAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well for a box plot.

            :param group_by: The group by field well of a box plot chart. Values are grouped based on group by fields.
            :param values: The value field well of a box plot chart. Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                box_plot_aggregated_field_wells_property = quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cd7624ca2a8ec092df8678ee16699f1613bbaf10dee1a086828354dd5743e3c0)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The group by field well of a box plot chart.

            Values are grouped based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotaggregatedfieldwells.html#cfn-quicksight-template-boxplotaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The value field well of a box plot chart.

            Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotaggregatedfieldwells.html#cfn-quicksight-template-boxplotaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.BoxPlotChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "box_plot_options": "boxPlotOptions",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
        },
    )
    class BoxPlotChartConfigurationProperty:
        def __init__(
            self,
            *,
            box_plot_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.BoxPlotOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.BoxPlotFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.BoxPlotSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``BoxPlotVisual`` .

            :param box_plot_options: The box plot chart options for a box plot visual.
            :param category_axis: The label display options (grid line, range, scale, axis step) of a box plot category.
            :param category_label_options: The label options (label text, label visibility and sort Icon visibility) of a box plot category.
            :param field_wells: The field wells of the visual.
            :param legend: 
            :param primary_y_axis_display_options: The label display options (grid line, range, scale, axis step) of a box plot category.
            :param primary_y_axis_label_options: The label options (label text, label visibility and sort icon visibility) of a box plot value.
            :param reference_lines: The reference line setup of the visual.
            :param sort_configuration: The sort configuration of a ``BoxPlotVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8c75e3d4a502621a26088dd1dbe75785d35feb297837876c22f25727741883e5)
                check_type(argname="argument box_plot_options", value=box_plot_options, expected_type=type_hints["box_plot_options"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if box_plot_options is not None:
                self._values["box_plot_options"] = box_plot_options
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def box_plot_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BoxPlotOptionsProperty"]]:
            '''The box plot chart options for a box plot visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-boxplotoptions
            '''
            result = self._values.get("box_plot_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BoxPlotOptionsProperty"]], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) of a box plot category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort Icon visibility) of a box plot category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BoxPlotFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BoxPlotFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) of a box plot category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) of a box plot value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineProperty"]]]]:
            '''The reference line setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineProperty"]]]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BoxPlotSortConfigurationProperty"]]:
            '''The sort configuration of a ``BoxPlotVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BoxPlotSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.BoxPlotFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "box_plot_aggregated_field_wells": "boxPlotAggregatedFieldWells",
        },
    )
    class BoxPlotFieldWellsProperty:
        def __init__(
            self,
            *,
            box_plot_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.BoxPlotAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``BoxPlotVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param box_plot_aggregated_field_wells: The aggregated field wells of a box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                box_plot_field_wells_property = quicksight.CfnTemplate.BoxPlotFieldWellsProperty(
                    box_plot_aggregated_field_wells=quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6de5fedb60d8a2060a7d33b391329bf5913f84f9f78d1051be4b26f10e085073)
                check_type(argname="argument box_plot_aggregated_field_wells", value=box_plot_aggregated_field_wells, expected_type=type_hints["box_plot_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if box_plot_aggregated_field_wells is not None:
                self._values["box_plot_aggregated_field_wells"] = box_plot_aggregated_field_wells

        @builtins.property
        def box_plot_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BoxPlotAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotfieldwells.html#cfn-quicksight-template-boxplotfieldwells-boxplotaggregatedfieldwells
            '''
            result = self._values.get("box_plot_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BoxPlotAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.BoxPlotOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "all_data_points_visibility": "allDataPointsVisibility",
            "outlier_visibility": "outlierVisibility",
            "style_options": "styleOptions",
        },
    )
    class BoxPlotOptionsProperty:
        def __init__(
            self,
            *,
            all_data_points_visibility: typing.Optional[builtins.str] = None,
            outlier_visibility: typing.Optional[builtins.str] = None,
            style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.BoxPlotStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options of a box plot visual.

            :param all_data_points_visibility: Determines the visibility of all data points of the box plot.
            :param outlier_visibility: Determines the visibility of the outlier in a box plot.
            :param style_options: The style options of the box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                box_plot_options_property = quicksight.CfnTemplate.BoxPlotOptionsProperty(
                    all_data_points_visibility="allDataPointsVisibility",
                    outlier_visibility="outlierVisibility",
                    style_options=quicksight.CfnTemplate.BoxPlotStyleOptionsProperty(
                        fill_style="fillStyle"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dcef52145288cb9f4f13ce0af7da3fe3ec8657582a9fd284dfd2e3539e275cb0)
                check_type(argname="argument all_data_points_visibility", value=all_data_points_visibility, expected_type=type_hints["all_data_points_visibility"])
                check_type(argname="argument outlier_visibility", value=outlier_visibility, expected_type=type_hints["outlier_visibility"])
                check_type(argname="argument style_options", value=style_options, expected_type=type_hints["style_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if all_data_points_visibility is not None:
                self._values["all_data_points_visibility"] = all_data_points_visibility
            if outlier_visibility is not None:
                self._values["outlier_visibility"] = outlier_visibility
            if style_options is not None:
                self._values["style_options"] = style_options

        @builtins.property
        def all_data_points_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of all data points of the box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotoptions.html#cfn-quicksight-template-boxplotoptions-alldatapointsvisibility
            '''
            result = self._values.get("all_data_points_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def outlier_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the outlier in a box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotoptions.html#cfn-quicksight-template-boxplotoptions-outliervisibility
            '''
            result = self._values.get("outlier_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BoxPlotStyleOptionsProperty"]]:
            '''The style options of the box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotoptions.html#cfn-quicksight-template-boxplotoptions-styleoptions
            '''
            result = self._values.get("style_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BoxPlotStyleOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.BoxPlotSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_sort": "categorySort",
            "pagination_configuration": "paginationConfiguration",
        },
    )
    class BoxPlotSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            pagination_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PaginationConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The sort configuration of a ``BoxPlotVisual`` .

            :param category_sort: The sort configuration of a group by fields.
            :param pagination_configuration: The pagination configuration of a table visual or box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                box_plot_sort_configuration_property = quicksight.CfnTemplate.BoxPlotSortConfigurationProperty(
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                        page_number=123,
                        page_size=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dfd3569e0adb8de16a1e02dfd33e0786522d159c9e9cde3ecd8c8869fcd728d3)
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument pagination_configuration", value=pagination_configuration, expected_type=type_hints["pagination_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if pagination_configuration is not None:
                self._values["pagination_configuration"] = pagination_configuration

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of a group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotsortconfiguration.html#cfn-quicksight-template-boxplotsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def pagination_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PaginationConfigurationProperty"]]:
            '''The pagination configuration of a table visual or box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotsortconfiguration.html#cfn-quicksight-template-boxplotsortconfiguration-paginationconfiguration
            '''
            result = self._values.get("pagination_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PaginationConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.BoxPlotStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"fill_style": "fillStyle"},
    )
    class BoxPlotStyleOptionsProperty:
        def __init__(self, *, fill_style: typing.Optional[builtins.str] = None) -> None:
            '''The style options of the box plot.

            :param fill_style: The fill styles (solid, transparent) of the box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                box_plot_style_options_property = quicksight.CfnTemplate.BoxPlotStyleOptionsProperty(
                    fill_style="fillStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9c10a3b25816cb61784d81739f036143d88e5ab7a5a05fde1fac62835c366f2b)
                check_type(argname="argument fill_style", value=fill_style, expected_type=type_hints["fill_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if fill_style is not None:
                self._values["fill_style"] = fill_style

        @builtins.property
        def fill_style(self) -> typing.Optional[builtins.str]:
            '''The fill styles (solid, transparent) of the box plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotstyleoptions.html#cfn-quicksight-template-boxplotstyleoptions-fillstyle
            '''
            result = self._values.get("fill_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.BoxPlotVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class BoxPlotVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.BoxPlotChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A box plot.

            For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4cec78280cbfee63ecc31cb38d9b2e2cf3240643e10113e8ca98e925d29d30fa)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BoxPlotChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BoxPlotChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CalculatedFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "expression": "expression",
            "name": "name",
        },
    )
    class CalculatedFieldProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            expression: builtins.str,
            name: builtins.str,
        ) -> None:
            '''The calculated field of an analysis.

            :param data_set_identifier: The data set that is used in this calculated field.
            :param expression: The expression of the calculated field.
            :param name: The name of the calculated field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                calculated_field_property = quicksight.CfnTemplate.CalculatedFieldProperty(
                    data_set_identifier="dataSetIdentifier",
                    expression="expression",
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__73faab9c40099774737839775a079cf9d4749cb3ae30a70746a7656fea6d4c8a)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "expression": expression,
                "name": name,
            }

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that is used in this calculated field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedfield.html#cfn-quicksight-template-calculatedfield-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the calculated field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedfield.html#cfn-quicksight-template-calculatedfield-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the calculated field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedfield.html#cfn-quicksight-template-calculatedfield-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CalculatedFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CalculatedMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "field_id": "fieldId"},
    )
    class CalculatedMeasureFieldProperty:
        def __init__(self, *, expression: builtins.str, field_id: builtins.str) -> None:
            '''The table calculation measure field for pivot tables.

            :param expression: The expression in the table calculation.
            :param field_id: The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                calculated_measure_field_property = quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                    expression="expression",
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d319b5fd5184ce055d310fb382015eee9b4eb50946103cb49f53ab2e2257d854)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
                "field_id": field_id,
            }

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression in the table calculation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedmeasurefield.html#cfn-quicksight-template-calculatedmeasurefield-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedmeasurefield.html#cfn-quicksight-template-calculatedmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CalculatedMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CascadingControlConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"source_controls": "sourceControls"},
    )
    class CascadingControlConfigurationProperty:
        def __init__(
            self,
            *,
            source_controls: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CascadingControlSourceProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :param source_controls: A list of source controls that determine the values that are used in the current control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                cascading_control_configuration_property = quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                    source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                        column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        source_sheet_control_id="sourceSheetControlId"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2484221a273a9056386fc2362eae583d53799b9e17d5d661f9428c6b55014816)
                check_type(argname="argument source_controls", value=source_controls, expected_type=type_hints["source_controls"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if source_controls is not None:
                self._values["source_controls"] = source_controls

        @builtins.property
        def source_controls(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CascadingControlSourceProperty"]]]]:
            '''A list of source controls that determine the values that are used in the current control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolconfiguration.html#cfn-quicksight-template-cascadingcontrolconfiguration-sourcecontrols
            '''
            result = self._values.get("source_controls")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CascadingControlSourceProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CascadingControlConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CascadingControlSourceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_to_match": "columnToMatch",
            "source_sheet_control_id": "sourceSheetControlId",
        },
    )
    class CascadingControlSourceProperty:
        def __init__(
            self,
            *,
            column_to_match: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            source_sheet_control_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The source controls that are used in a ``CascadingControlConfiguration`` .

            :param column_to_match: The column identifier that determines which column to look up for the source sheet control.
            :param source_sheet_control_id: The source sheet control ID of a ``CascadingControlSource`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolsource.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                cascading_control_source_property = quicksight.CfnTemplate.CascadingControlSourceProperty(
                    column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    source_sheet_control_id="sourceSheetControlId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__00210ff2791c4d1c37569b3292c956c4aebd57844b5bfa98b064e85c2836977e)
                check_type(argname="argument column_to_match", value=column_to_match, expected_type=type_hints["column_to_match"])
                check_type(argname="argument source_sheet_control_id", value=source_sheet_control_id, expected_type=type_hints["source_sheet_control_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_to_match is not None:
                self._values["column_to_match"] = column_to_match
            if source_sheet_control_id is not None:
                self._values["source_sheet_control_id"] = source_sheet_control_id

        @builtins.property
        def column_to_match(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]]:
            '''The column identifier that determines which column to look up for the source sheet control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolsource.html#cfn-quicksight-template-cascadingcontrolsource-columntomatch
            '''
            result = self._values.get("column_to_match")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]], result)

        @builtins.property
        def source_sheet_control_id(self) -> typing.Optional[builtins.str]:
            '''The source sheet control ID of a ``CascadingControlSource`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolsource.html#cfn-quicksight-template-cascadingcontrolsource-sourcesheetcontrolid
            '''
            result = self._values.get("source_sheet_control_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CascadingControlSourceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CategoricalDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class CategoricalDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with categorical type columns..

            :param column: The column that is used in the ``CategoricalDimensionField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                categorical_dimension_field_property = quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4e8c50905be1739cfa42cbfef1c53f007904980cfc7c0cbb10999c6bdc402820)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that is used in the ``CategoricalDimensionField`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html#cfn-quicksight-template-categoricaldimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html#cfn-quicksight-template-categoricaldimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.StringFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html#cfn-quicksight-template-categoricaldimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.StringFormatConfigurationProperty"]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html#cfn-quicksight-template-categoricaldimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoricalDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CategoricalMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class CategoricalMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            aggregation_function: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure type field with categorical type columns.

            :param column: The column that is used in the ``CategoricalMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                categorical_measure_field_property = quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function="aggregationFunction",
                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8290fed180c39bbff9330a45eb3b7c279eaa298d6d25c1d656f107f3fdbda667)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that is used in the ``CategoricalMeasureField`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html#cfn-quicksight-template-categoricalmeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html#cfn-quicksight-template-categoricalmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(self) -> typing.Optional[builtins.str]:
            '''The aggregation function of the measure field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html#cfn-quicksight-template-categoricalmeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.StringFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html#cfn-quicksight-template-categoricalmeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.StringFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoricalMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CategoryDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={"category_values": "categoryValues", "column": "column"},
    )
    class CategoryDrillDownFilterProperty:
        def __init__(
            self,
            *,
            category_values: typing.Sequence[builtins.str],
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The numeric equality type drill down filter.

            :param category_values: A list of the string inputs that are the values of the category drill down filter.
            :param column: The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categorydrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                category_drill_down_filter_property = quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                    category_values=["categoryValues"],
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1fd192b5773de245c4754f9b8f53e298e77a08334c9443652f34772cd4816e17)
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category_values": category_values,
                "column": column,
            }

        @builtins.property
        def category_values(self) -> typing.List[builtins.str]:
            '''A list of the string inputs that are the values of the category drill down filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categorydrilldownfilter.html#cfn-quicksight-template-categorydrilldownfilter-categoryvalues
            '''
            result = self._values.get("category_values")
            assert result is not None, "Required property 'category_values' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categorydrilldownfilter.html#cfn-quicksight-template-categorydrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CategoryFilterConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_filter_configuration": "customFilterConfiguration",
            "custom_filter_list_configuration": "customFilterListConfiguration",
            "filter_list_configuration": "filterListConfiguration",
        },
    )
    class CategoryFilterConfigurationProperty:
        def __init__(
            self,
            *,
            custom_filter_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CustomFilterConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_filter_list_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CustomFilterListConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            filter_list_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilterListConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``CategoryFilter`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_filter_configuration: A custom filter that filters based on a single value. This filter can be partially matched.
            :param custom_filter_list_configuration: A list of custom filter values. In the Amazon QuickSight console, this filter type is called a custom filter list.
            :param filter_list_configuration: A list of filter configurations. In the Amazon QuickSight console, this filter type is called a filter list.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilterconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                category_filter_configuration_property = quicksight.CfnTemplate.CategoryFilterConfigurationProperty(
                    custom_filter_configuration=quicksight.CfnTemplate.CustomFilterConfigurationProperty(
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        category_value="categoryValue",
                        parameter_name="parameterName",
                        select_all_options="selectAllOptions"
                    ),
                    custom_filter_list_configuration=quicksight.CfnTemplate.CustomFilterListConfigurationProperty(
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        category_values=["categoryValues"],
                        select_all_options="selectAllOptions"
                    ),
                    filter_list_configuration=quicksight.CfnTemplate.FilterListConfigurationProperty(
                        match_operator="matchOperator",
                
                        # the properties below are optional
                        category_values=["categoryValues"],
                        null_option="nullOption",
                        select_all_options="selectAllOptions"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__49b0232f63d21f0936830f237364bee66c3e438be12db99c87f73417fe0343f6)
                check_type(argname="argument custom_filter_configuration", value=custom_filter_configuration, expected_type=type_hints["custom_filter_configuration"])
                check_type(argname="argument custom_filter_list_configuration", value=custom_filter_list_configuration, expected_type=type_hints["custom_filter_list_configuration"])
                check_type(argname="argument filter_list_configuration", value=filter_list_configuration, expected_type=type_hints["filter_list_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_filter_configuration is not None:
                self._values["custom_filter_configuration"] = custom_filter_configuration
            if custom_filter_list_configuration is not None:
                self._values["custom_filter_list_configuration"] = custom_filter_list_configuration
            if filter_list_configuration is not None:
                self._values["filter_list_configuration"] = filter_list_configuration

        @builtins.property
        def custom_filter_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomFilterConfigurationProperty"]]:
            '''A custom filter that filters based on a single value.

            This filter can be partially matched.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilterconfiguration.html#cfn-quicksight-template-categoryfilterconfiguration-customfilterconfiguration
            '''
            result = self._values.get("custom_filter_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomFilterConfigurationProperty"]], result)

        @builtins.property
        def custom_filter_list_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomFilterListConfigurationProperty"]]:
            '''A list of custom filter values.

            In the Amazon QuickSight console, this filter type is called a custom filter list.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilterconfiguration.html#cfn-quicksight-template-categoryfilterconfiguration-customfilterlistconfiguration
            '''
            result = self._values.get("custom_filter_list_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomFilterListConfigurationProperty"]], result)

        @builtins.property
        def filter_list_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterListConfigurationProperty"]]:
            '''A list of filter configurations.

            In the Amazon QuickSight console, this filter type is called a filter list.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilterconfiguration.html#cfn-quicksight-template-categoryfilterconfiguration-filterlistconfiguration
            '''
            result = self._values.get("filter_list_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterListConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryFilterConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CategoryFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "configuration": "configuration",
            "filter_id": "filterId",
        },
    )
    class CategoryFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CategoryFilterConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
        ) -> None:
            '''A ``CategoryFilter`` filters text values.

            For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .

            :param column: The column that the filter is applied to.
            :param configuration: The configuration for a ``CategoryFilter`` .
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                category_filter_property = quicksight.CfnTemplate.CategoryFilterProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    configuration=quicksight.CfnTemplate.CategoryFilterConfigurationProperty(
                        custom_filter_configuration=quicksight.CfnTemplate.CustomFilterConfigurationProperty(
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            category_value="categoryValue",
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions"
                        ),
                        custom_filter_list_configuration=quicksight.CfnTemplate.CustomFilterListConfigurationProperty(
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            category_values=["categoryValues"],
                            select_all_options="selectAllOptions"
                        ),
                        filter_list_configuration=quicksight.CfnTemplate.FilterListConfigurationProperty(
                            match_operator="matchOperator",
                
                            # the properties below are optional
                            category_values=["categoryValues"],
                            null_option="nullOption",
                            select_all_options="selectAllOptions"
                        )
                    ),
                    filter_id="filterId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3017eded9b1bfc6448b1469ba204c8bbc08e95788b728881eddce09680baf24e)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "configuration": configuration,
                "filter_id": filter_id,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilter.html#cfn-quicksight-template-categoryfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.CategoryFilterConfigurationProperty"]:
            '''The configuration for a ``CategoryFilter`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilter.html#cfn-quicksight-template-categoryfilter-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.CategoryFilterConfigurationProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilter.html#cfn-quicksight-template-categoryfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ChartAxisLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_label_options": "axisLabelOptions",
            "sort_icon_visibility": "sortIconVisibility",
            "visibility": "visibility",
        },
    )
    class ChartAxisLabelOptionsProperty:
        def __init__(
            self,
            *,
            axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sort_icon_visibility: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label options for an axis on a chart.

            :param axis_label_options: The label options for a chart axis.
            :param sort_icon_visibility: The visibility configuration of the sort icon on a chart's axis label.
            :param visibility: The visibility of an axis label on a chart. Choose one of the following options:. - ``VISIBLE`` : Shows the axis. - ``HIDDEN`` : Hides the axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-chartaxislabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                chart_axis_label_options_property = quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId"
                        ),
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        )
                    )],
                    sort_icon_visibility="sortIconVisibility",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cd3c711efd09d7544fe28d319f0ce82f22d9327f74110415786c318d4f8c545d)
                check_type(argname="argument axis_label_options", value=axis_label_options, expected_type=type_hints["axis_label_options"])
                check_type(argname="argument sort_icon_visibility", value=sort_icon_visibility, expected_type=type_hints["sort_icon_visibility"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_label_options is not None:
                self._values["axis_label_options"] = axis_label_options
            if sort_icon_visibility is not None:
                self._values["sort_icon_visibility"] = sort_icon_visibility
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisLabelOptionsProperty"]]]]:
            '''The label options for a chart axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-chartaxislabeloptions.html#cfn-quicksight-template-chartaxislabeloptions-axislabeloptions
            '''
            result = self._values.get("axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisLabelOptionsProperty"]]]], result)

        @builtins.property
        def sort_icon_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the sort icon on a chart's axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-chartaxislabeloptions.html#cfn-quicksight-template-chartaxislabeloptions-sorticonvisibility
            '''
            result = self._values.get("sort_icon_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of an axis label on a chart. Choose one of the following options:.

            - ``VISIBLE`` : Shows the axis.
            - ``HIDDEN`` : Hides the axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-chartaxislabeloptions.html#cfn-quicksight-template-chartaxislabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ChartAxisLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ClusterMarkerConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"cluster_marker": "clusterMarker"},
    )
    class ClusterMarkerConfigurationProperty:
        def __init__(
            self,
            *,
            cluster_marker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ClusterMarkerProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cluster marker configuration of the geospatial map selected point style.

            :param cluster_marker: The cluster marker that is a part of the cluster marker configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-clustermarkerconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                cluster_marker_configuration_property = quicksight.CfnTemplate.ClusterMarkerConfigurationProperty(
                    cluster_marker=quicksight.CfnTemplate.ClusterMarkerProperty(
                        simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a2c2f574712970589527fe6a64594e55f0fd028d0cee702c43e39314a5274a28)
                check_type(argname="argument cluster_marker", value=cluster_marker, expected_type=type_hints["cluster_marker"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cluster_marker is not None:
                self._values["cluster_marker"] = cluster_marker

        @builtins.property
        def cluster_marker(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ClusterMarkerProperty"]]:
            '''The cluster marker that is a part of the cluster marker configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-clustermarkerconfiguration.html#cfn-quicksight-template-clustermarkerconfiguration-clustermarker
            '''
            result = self._values.get("cluster_marker")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ClusterMarkerProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ClusterMarkerConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ClusterMarkerProperty",
        jsii_struct_bases=[],
        name_mapping={"simple_cluster_marker": "simpleClusterMarker"},
    )
    class ClusterMarkerProperty:
        def __init__(
            self,
            *,
            simple_cluster_marker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SimpleClusterMarkerProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cluster marker that is a part of the cluster marker configuration.

            :param simple_cluster_marker: The simple cluster marker of the cluster marker.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-clustermarker.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                cluster_marker_property = quicksight.CfnTemplate.ClusterMarkerProperty(
                    simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                        color="color"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__40e61b2a20bb12f98d7cb562c5152411c5fdad0f38cf38b7c44205e02804adc8)
                check_type(argname="argument simple_cluster_marker", value=simple_cluster_marker, expected_type=type_hints["simple_cluster_marker"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if simple_cluster_marker is not None:
                self._values["simple_cluster_marker"] = simple_cluster_marker

        @builtins.property
        def simple_cluster_marker(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SimpleClusterMarkerProperty"]]:
            '''The simple cluster marker of the cluster marker.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-clustermarker.html#cfn-quicksight-template-clustermarker-simpleclustermarker
            '''
            result = self._values.get("simple_cluster_marker")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SimpleClusterMarkerProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ClusterMarkerProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ColorScaleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_fill_type": "colorFillType",
            "colors": "colors",
            "null_value_color": "nullValueColor",
        },
    )
    class ColorScaleProperty:
        def __init__(
            self,
            *,
            color_fill_type: builtins.str,
            colors: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataColorProperty", typing.Dict[builtins.str, typing.Any]]]]],
            null_value_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Determines the color scale that is applied to the visual.

            :param color_fill_type: Determines the color fill type.
            :param colors: Determines the list of colors that are applied to the visual.
            :param null_value_color: Determines the color that is applied to null values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                color_scale_property = quicksight.CfnTemplate.ColorScaleProperty(
                    color_fill_type="colorFillType",
                    colors=[quicksight.CfnTemplate.DataColorProperty(
                        color="color",
                        data_value=123
                    )],
                
                    # the properties below are optional
                    null_value_color=quicksight.CfnTemplate.DataColorProperty(
                        color="color",
                        data_value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3c5d43e7f90822e1aa826bb9f5ab3d65685d3ef249184df4b1b0f34baadb329b)
                check_type(argname="argument color_fill_type", value=color_fill_type, expected_type=type_hints["color_fill_type"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument null_value_color", value=null_value_color, expected_type=type_hints["null_value_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color_fill_type": color_fill_type,
                "colors": colors,
            }
            if null_value_color is not None:
                self._values["null_value_color"] = null_value_color

        @builtins.property
        def color_fill_type(self) -> builtins.str:
            '''Determines the color fill type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorscale.html#cfn-quicksight-template-colorscale-colorfilltype
            '''
            result = self._values.get("color_fill_type")
            assert result is not None, "Required property 'color_fill_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataColorProperty"]]]:
            '''Determines the list of colors that are applied to the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorscale.html#cfn-quicksight-template-colorscale-colors
            '''
            result = self._values.get("colors")
            assert result is not None, "Required property 'colors' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataColorProperty"]]], result)

        @builtins.property
        def null_value_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataColorProperty"]]:
            '''Determines the color that is applied to null values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorscale.html#cfn-quicksight-template-colorscale-nullvaluecolor
            '''
            result = self._values.get("null_value_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColorScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ColorsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_colors": "customColors"},
    )
    class ColorsConfigurationProperty:
        def __init__(
            self,
            *,
            custom_colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CustomColorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The color configurations for a column.

            :param custom_colors: A list of up to 50 custom colors.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                colors_configuration_property = quicksight.CfnTemplate.ColorsConfigurationProperty(
                    custom_colors=[quicksight.CfnTemplate.CustomColorProperty(
                        color="color",
                
                        # the properties below are optional
                        field_value="fieldValue",
                        special_value="specialValue"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5922f18311fbff11cf0dbfc35c9c36329e93df64a3b6b7d15ac7dffda51f0fe6)
                check_type(argname="argument custom_colors", value=custom_colors, expected_type=type_hints["custom_colors"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_colors is not None:
                self._values["custom_colors"] = custom_colors

        @builtins.property
        def custom_colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomColorProperty"]]]]:
            '''A list of up to 50 custom colors.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorsconfiguration.html#cfn-quicksight-template-colorsconfiguration-customcolors
            '''
            result = self._values.get("custom_colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomColorProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColorsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ColumnConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "colors_configuration": "colorsConfiguration",
            "format_configuration": "formatConfiguration",
            "role": "role",
        },
    )
    class ColumnConfigurationProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            colors_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColorsConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            role: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The general configuration of a column.

            :param column: The column.
            :param colors_configuration: The color configurations of the column.
            :param format_configuration: The format configuration of a column.
            :param role: The role of the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_configuration_property = quicksight.CfnTemplate.ColumnConfigurationProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    colors_configuration=quicksight.CfnTemplate.ColorsConfigurationProperty(
                        custom_colors=[quicksight.CfnTemplate.CustomColorProperty(
                            color="color",
                
                            # the properties below are optional
                            field_value="fieldValue",
                            special_value="specialValue"
                        )]
                    ),
                    format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    role="role"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__65e6958e3f1ef4998c0a87dcdad7ce409d3cd5ac36f085eee425bcc4a56bbe6c)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument colors_configuration", value=colors_configuration, expected_type=type_hints["colors_configuration"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument role", value=role, expected_type=type_hints["role"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
            }
            if colors_configuration is not None:
                self._values["colors_configuration"] = colors_configuration
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if role is not None:
                self._values["role"] = role

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html#cfn-quicksight-template-columnconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def colors_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColorsConfigurationProperty"]]:
            '''The color configurations of the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html#cfn-quicksight-template-columnconfiguration-colorsconfiguration
            '''
            result = self._values.get("colors_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColorsConfigurationProperty"]], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FormatConfigurationProperty"]]:
            '''The format configuration of a column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html#cfn-quicksight-template-columnconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FormatConfigurationProperty"]], result)

        @builtins.property
        def role(self) -> typing.Optional[builtins.str]:
            '''The role of the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html#cfn-quicksight-template-columnconfiguration-role
            '''
            result = self._values.get("role")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ColumnGroupColumnSchemaProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name"},
    )
    class ColumnGroupColumnSchemaProperty:
        def __init__(self, *, name: typing.Optional[builtins.str] = None) -> None:
            '''A structure describing the name, data type, and geographic role of the columns.

            :param name: The name of the column group's column schema.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupcolumnschema.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_group_column_schema_property = quicksight.CfnTemplate.ColumnGroupColumnSchemaProperty(
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__90b2c13f09982755b418a9c5e58709d9a1a5f8303e1a5e5f49fd8937dbfd2555)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of the column group's column schema.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupcolumnschema.html#cfn-quicksight-template-columngroupcolumnschema-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnGroupColumnSchemaProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ColumnGroupSchemaProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_group_column_schema_list": "columnGroupColumnSchemaList",
            "name": "name",
        },
    )
    class ColumnGroupSchemaProperty:
        def __init__(
            self,
            *,
            column_group_column_schema_list: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnGroupColumnSchemaProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The column group schema.

            :param column_group_column_schema_list: A structure containing the list of schemas for column group columns.
            :param name: The name of the column group schema.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupschema.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_group_schema_property = quicksight.CfnTemplate.ColumnGroupSchemaProperty(
                    column_group_column_schema_list=[quicksight.CfnTemplate.ColumnGroupColumnSchemaProperty(
                        name="name"
                    )],
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6d0f54e560d7039d07bdd2f554612c445992d7cdee8d18c8b96786920a1da29d)
                check_type(argname="argument column_group_column_schema_list", value=column_group_column_schema_list, expected_type=type_hints["column_group_column_schema_list"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_group_column_schema_list is not None:
                self._values["column_group_column_schema_list"] = column_group_column_schema_list
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def column_group_column_schema_list(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnGroupColumnSchemaProperty"]]]]:
            '''A structure containing the list of schemas for column group columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupschema.html#cfn-quicksight-template-columngroupschema-columngroupcolumnschemalist
            '''
            result = self._values.get("column_group_column_schema_list")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnGroupColumnSchemaProperty"]]]], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of the column group schema.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupschema.html#cfn-quicksight-template-columngroupschema-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnGroupSchemaProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ColumnHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_hierarchy": "dateTimeHierarchy",
            "explicit_hierarchy": "explicitHierarchy",
            "predefined_hierarchy": "predefinedHierarchy",
        },
    )
    class ColumnHierarchyProperty:
        def __init__(
            self,
            *,
            date_time_hierarchy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DateTimeHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            explicit_hierarchy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ExplicitHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            predefined_hierarchy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PredefinedHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields for a visual element.

            :param date_time_hierarchy: The option that determines the hierarchy of any ``DateTime`` fields.
            :param explicit_hierarchy: The option that determines the hierarchy of the fields that are built within a visual's field wells. These fields can't be duplicated to other visuals.
            :param predefined_hierarchy: The option that determines the hierarchy of the fields that are defined during data preparation. These fields are available to use in any analysis that uses the data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnhierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_hierarchy_property = quicksight.CfnTemplate.ColumnHierarchyProperty(
                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    ),
                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    ),
                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e7cd94a2e28d455d3788f132c173fe3afbaef17d63118c334f1b4a8e88977d8b)
                check_type(argname="argument date_time_hierarchy", value=date_time_hierarchy, expected_type=type_hints["date_time_hierarchy"])
                check_type(argname="argument explicit_hierarchy", value=explicit_hierarchy, expected_type=type_hints["explicit_hierarchy"])
                check_type(argname="argument predefined_hierarchy", value=predefined_hierarchy, expected_type=type_hints["predefined_hierarchy"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_hierarchy is not None:
                self._values["date_time_hierarchy"] = date_time_hierarchy
            if explicit_hierarchy is not None:
                self._values["explicit_hierarchy"] = explicit_hierarchy
            if predefined_hierarchy is not None:
                self._values["predefined_hierarchy"] = predefined_hierarchy

        @builtins.property
        def date_time_hierarchy(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateTimeHierarchyProperty"]]:
            '''The option that determines the hierarchy of any ``DateTime`` fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnhierarchy.html#cfn-quicksight-template-columnhierarchy-datetimehierarchy
            '''
            result = self._values.get("date_time_hierarchy")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateTimeHierarchyProperty"]], result)

        @builtins.property
        def explicit_hierarchy(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ExplicitHierarchyProperty"]]:
            '''The option that determines the hierarchy of the fields that are built within a visual's field wells.

            These fields can't be duplicated to other visuals.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnhierarchy.html#cfn-quicksight-template-columnhierarchy-explicithierarchy
            '''
            result = self._values.get("explicit_hierarchy")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ExplicitHierarchyProperty"]], result)

        @builtins.property
        def predefined_hierarchy(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PredefinedHierarchyProperty"]]:
            '''The option that determines the hierarchy of the fields that are defined during data preparation.

            These fields are available to use in any analysis that uses the data source.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnhierarchy.html#cfn-quicksight-template-columnhierarchy-predefinedhierarchy
            '''
            result = self._values.get("predefined_hierarchy")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PredefinedHierarchyProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ColumnIdentifierProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_name": "columnName",
            "data_set_identifier": "dataSetIdentifier",
        },
    )
    class ColumnIdentifierProperty:
        def __init__(
            self,
            *,
            column_name: builtins.str,
            data_set_identifier: builtins.str,
        ) -> None:
            '''A column of a data set.

            :param column_name: The name of the column.
            :param data_set_identifier: The data set that the column belongs to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnidentifier.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_identifier_property = quicksight.CfnTemplate.ColumnIdentifierProperty(
                    column_name="columnName",
                    data_set_identifier="dataSetIdentifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__154e7348d1c24862f3f981b823ac7120e05a82d936c7b0a4101a89bc45b1ef0b)
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_name": column_name,
                "data_set_identifier": data_set_identifier,
            }

        @builtins.property
        def column_name(self) -> builtins.str:
            '''The name of the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnidentifier.html#cfn-quicksight-template-columnidentifier-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that the column belongs to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnidentifier.html#cfn-quicksight-template-columnidentifier-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnIdentifierProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ColumnSchemaProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_type": "dataType",
            "geographic_role": "geographicRole",
            "name": "name",
        },
    )
    class ColumnSchemaProperty:
        def __init__(
            self,
            *,
            data_type: typing.Optional[builtins.str] = None,
            geographic_role: typing.Optional[builtins.str] = None,
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The column schema.

            :param data_type: The data type of the column schema.
            :param geographic_role: The geographic role of the column schema.
            :param name: The name of the column schema.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnschema.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_schema_property = quicksight.CfnTemplate.ColumnSchemaProperty(
                    data_type="dataType",
                    geographic_role="geographicRole",
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2197d9d4e00ae9b0022846d0b7f500cdbbb640a1ca573edf02b61474ada568ba)
                check_type(argname="argument data_type", value=data_type, expected_type=type_hints["data_type"])
                check_type(argname="argument geographic_role", value=geographic_role, expected_type=type_hints["geographic_role"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_type is not None:
                self._values["data_type"] = data_type
            if geographic_role is not None:
                self._values["geographic_role"] = geographic_role
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def data_type(self) -> typing.Optional[builtins.str]:
            '''The data type of the column schema.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnschema.html#cfn-quicksight-template-columnschema-datatype
            '''
            result = self._values.get("data_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def geographic_role(self) -> typing.Optional[builtins.str]:
            '''The geographic role of the column schema.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnschema.html#cfn-quicksight-template-columnschema-geographicrole
            '''
            result = self._values.get("geographic_role")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of the column schema.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnschema.html#cfn-quicksight-template-columnschema-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnSchemaProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ColumnSortProperty",
        jsii_struct_bases=[],
        name_mapping={
            "direction": "direction",
            "sort_by": "sortBy",
            "aggregation_function": "aggregationFunction",
        },
    )
    class ColumnSortProperty:
        def __init__(
            self,
            *,
            direction: builtins.str,
            sort_by: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The sort configuration for a column that is not used in a field well.

            :param direction: The sort direction.
            :param sort_by: 
            :param aggregation_function: The aggregation function that is defined in the column sort.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_sort_property = quicksight.CfnTemplate.ColumnSortProperty(
                    direction="direction",
                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                        attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                            simple_attribute_aggregation="simpleAttributeAggregation",
                            value_for_multiple_values="valueForMultipleValues"
                        ),
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2ca9307fef2c1e8baa3f0981de7e28837533afb919d862725675ffee3edcb7b1)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument sort_by", value=sort_by, expected_type=type_hints["sort_by"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "sort_by": sort_by,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function

        @builtins.property
        def direction(self) -> builtins.str:
            '''The sort direction.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnsort.html#cfn-quicksight-template-columnsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_by(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnsort.html#cfn-quicksight-template-columnsort-sortby
            '''
            result = self._values.get("sort_by")
            assert result is not None, "Required property 'sort_by' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AggregationFunctionProperty"]]:
            '''The aggregation function that is defined in the column sort.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnsort.html#cfn-quicksight-template-columnsort-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AggregationFunctionProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ColumnTooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "aggregation": "aggregation",
            "label": "label",
            "visibility": "visibility",
        },
    )
    class ColumnTooltipItemProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            aggregation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The tooltip item for the columns that are not part of a field well.

            :param column: The target column of the tooltip item.
            :param aggregation: The aggregation function of the column tooltip item.
            :param label: The label of the tooltip item.
            :param visibility: The visibility of the tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                column_tooltip_item_property = quicksight.CfnTemplate.ColumnTooltipItemProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                        attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                            simple_attribute_aggregation="simpleAttributeAggregation",
                            value_for_multiple_values="valueForMultipleValues"
                        ),
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    label="label",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e72a81bfa16daea305420ebfe224e8705acae996707ffe9c3e4fca7ca67c7293)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
            }
            if aggregation is not None:
                self._values["aggregation"] = aggregation
            if label is not None:
                self._values["label"] = label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The target column of the tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html#cfn-quicksight-template-columntooltipitem-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def aggregation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AggregationFunctionProperty"]]:
            '''The aggregation function of the column tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html#cfn-quicksight-template-columntooltipitem-aggregation
            '''
            result = self._values.get("aggregation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AggregationFunctionProperty"]], result)

        @builtins.property
        def label(self) -> typing.Optional[builtins.str]:
            '''The label of the tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html#cfn-quicksight-template-columntooltipitem-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html#cfn-quicksight-template-columntooltipitem-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnTooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ComboChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_values": "barValues",
            "category": "category",
            "colors": "colors",
            "line_values": "lineValues",
        },
    )
    class ComboChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            bar_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            line_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a combo chart.

            :param bar_values: The aggregated ``BarValues`` field well of a combo chart.
            :param category: The aggregated category field wells of a combo chart.
            :param colors: The aggregated colors field well of a combo chart.
            :param line_values: The aggregated ``LineValues`` field well of a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e76002c75d8316d5a0df86666698505e975b594f3600af284e3b9030c0403455)
                check_type(argname="argument bar_values", value=bar_values, expected_type=type_hints["bar_values"])
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument line_values", value=line_values, expected_type=type_hints["line_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_values is not None:
                self._values["bar_values"] = bar_values
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if line_values is not None:
                self._values["line_values"] = line_values

        @builtins.property
        def bar_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The aggregated ``BarValues`` field well of a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html#cfn-quicksight-template-combochartaggregatedfieldwells-barvalues
            '''
            result = self._values.get("bar_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The aggregated category field wells of a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html#cfn-quicksight-template-combochartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The aggregated colors field well of a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html#cfn-quicksight-template-combochartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def line_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The aggregated ``LineValues`` field well of a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html#cfn-quicksight-template-combochartaggregatedfieldwells-linevalues
            '''
            result = self._values.get("line_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ComboChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_data_labels": "barDataLabels",
            "bars_arrangement": "barsArrangement",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_label_options": "colorLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "line_data_labels": "lineDataLabels",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "secondary_y_axis_display_options": "secondaryYAxisDisplayOptions",
            "secondary_y_axis_label_options": "secondaryYAxisLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
        },
    )
    class ComboChartConfigurationProperty:
        def __init__(
            self,
            *,
            bar_data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            bars_arrangement: typing.Optional[builtins.str] = None,
            category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ComboChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            line_data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            secondary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ComboChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``ComboChartVisual`` .

            :param bar_data_labels: The options that determine if visual data labels are displayed. The data label options for a bar in a combo chart.
            :param bars_arrangement: Determines the bar arrangement in a combo chart. The following are valid values in this structure:. - ``CLUSTERED`` : For clustered bar combo charts. - ``STACKED`` : For stacked bar combo charts. - ``STACKED_PERCENT`` : Do not use. If you use this value, the operation returns a validation error.
            :param category_axis: The category axis of a combo chart.
            :param category_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.
            :param color_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param line_data_labels: The options that determine if visual data labels are displayed. The data label options for a line in a combo chart.
            :param primary_y_axis_display_options: The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.
            :param primary_y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.
            :param reference_lines: The reference line setup of the visual.
            :param secondary_y_axis_display_options: The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.
            :param secondary_y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.
            :param sort_configuration: The sort configuration of a ``ComboChartVisual`` .
            :param tooltip: The legend display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__496e3c5d8f6852db264d3824e5f25aa9e1d76b510ca6a813cf6cfc9067dcf2dc)
                check_type(argname="argument bar_data_labels", value=bar_data_labels, expected_type=type_hints["bar_data_labels"])
                check_type(argname="argument bars_arrangement", value=bars_arrangement, expected_type=type_hints["bars_arrangement"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument line_data_labels", value=line_data_labels, expected_type=type_hints["line_data_labels"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument secondary_y_axis_display_options", value=secondary_y_axis_display_options, expected_type=type_hints["secondary_y_axis_display_options"])
                check_type(argname="argument secondary_y_axis_label_options", value=secondary_y_axis_label_options, expected_type=type_hints["secondary_y_axis_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_data_labels is not None:
                self._values["bar_data_labels"] = bar_data_labels
            if bars_arrangement is not None:
                self._values["bars_arrangement"] = bars_arrangement
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if line_data_labels is not None:
                self._values["line_data_labels"] = line_data_labels
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if secondary_y_axis_display_options is not None:
                self._values["secondary_y_axis_display_options"] = secondary_y_axis_display_options
            if secondary_y_axis_label_options is not None:
                self._values["secondary_y_axis_label_options"] = secondary_y_axis_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def bar_data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            The data label options for a bar in a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-bardatalabels
            '''
            result = self._values.get("bar_data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def bars_arrangement(self) -> typing.Optional[builtins.str]:
            '''Determines the bar arrangement in a combo chart. The following are valid values in this structure:.

            - ``CLUSTERED`` : For clustered bar combo charts.
            - ``STACKED`` : For stacked bar combo charts.
            - ``STACKED_PERCENT`` : Do not use. If you use this value, the operation returns a validation error.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-barsarrangement
            '''
            result = self._values.get("bars_arrangement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The category axis of a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ComboChartFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ComboChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def line_data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            The data label options for a line in a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-linedatalabels
            '''
            result = self._values.get("line_data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineProperty"]]]]:
            '''The reference line setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineProperty"]]]], result)

        @builtins.property
        def secondary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-secondaryyaxisdisplayoptions
            '''
            result = self._values.get("secondary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def secondary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-secondaryyaxislabeloptions
            '''
            result = self._values.get("secondary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ComboChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``ComboChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ComboChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ComboChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "combo_chart_aggregated_field_wells": "comboChartAggregatedFieldWells",
        },
    )
    class ComboChartFieldWellsProperty:
        def __init__(
            self,
            *,
            combo_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ComboChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of the visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param combo_chart_aggregated_field_wells: The aggregated field wells of a combo chart. Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3f8efdbb6f4ba41c7c726b2f199055bb65b1fdb972b6fcab3c3b7da924aa9770)
                check_type(argname="argument combo_chart_aggregated_field_wells", value=combo_chart_aggregated_field_wells, expected_type=type_hints["combo_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if combo_chart_aggregated_field_wells is not None:
                self._values["combo_chart_aggregated_field_wells"] = combo_chart_aggregated_field_wells

        @builtins.property
        def combo_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ComboChartAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a combo chart.

            Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartfieldwells.html#cfn-quicksight-template-combochartfieldwells-combochartaggregatedfieldwells
            '''
            result = self._values.get("combo_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ComboChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ComboChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
        },
    )
    class ComboChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``ComboChartVisual`` .

            :param category_items_limit: The item limit configuration for the category field well of a combo chart.
            :param category_sort: The sort configuration of the category field well in a combo chart.
            :param color_items_limit: The item limit configuration of the color field well in a combo chart.
            :param color_sort: The sort configuration of the color field well in a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                combo_chart_sort_configuration_property = quicksight.CfnTemplate.ComboChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__31f2c50709535ef151b74758ba6feab72c3b1cb5a3a4f50ce4f3df6d9547c37b)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The item limit configuration for the category field well of a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html#cfn-quicksight-template-combochartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category field well in a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html#cfn-quicksight-template-combochartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The item limit configuration of the color field well in a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html#cfn-quicksight-template-combochartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the color field well in a combo chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html#cfn-quicksight-template-combochartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ComboChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class ComboChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ComboChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A combo chart.

            The ``ComboChartVisual`` includes stacked bar combo charts and clustered bar combo charts

            For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0b05e422f6320b8c265d1060c04db301f61299a462f25ccf1d7b3a52dfb0e08f)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ComboChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ComboChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ComparisonConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "comparison_format": "comparisonFormat",
            "comparison_method": "comparisonMethod",
        },
    )
    class ComparisonConfigurationProperty:
        def __init__(
            self,
            *,
            comparison_format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ComparisonFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            comparison_method: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The comparison display configuration of a KPI or gauge chart.

            :param comparison_format: The format of the comparison.
            :param comparison_method: The method of the comparison. Choose from the following options:. - ``DIFFERENCE`` - ``PERCENT_DIFFERENCE`` - ``PERCENT``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                comparison_configuration_property = quicksight.CfnTemplate.ComparisonConfigurationProperty(
                    comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    ),
                    comparison_method="comparisonMethod"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__69c996d7434b46a89b71a4c5230e5944e6e2950d17d010a0a0784199bbdfa112)
                check_type(argname="argument comparison_format", value=comparison_format, expected_type=type_hints["comparison_format"])
                check_type(argname="argument comparison_method", value=comparison_method, expected_type=type_hints["comparison_method"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if comparison_format is not None:
                self._values["comparison_format"] = comparison_format
            if comparison_method is not None:
                self._values["comparison_method"] = comparison_method

        @builtins.property
        def comparison_format(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ComparisonFormatConfigurationProperty"]]:
            '''The format of the comparison.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonconfiguration.html#cfn-quicksight-template-comparisonconfiguration-comparisonformat
            '''
            result = self._values.get("comparison_format")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ComparisonFormatConfigurationProperty"]], result)

        @builtins.property
        def comparison_method(self) -> typing.Optional[builtins.str]:
            '''The method of the comparison. Choose from the following options:.

            - ``DIFFERENCE``
            - ``PERCENT_DIFFERENCE``
            - ``PERCENT``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonconfiguration.html#cfn-quicksight-template-comparisonconfiguration-comparisonmethod
            '''
            result = self._values.get("comparison_method")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComparisonConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ComparisonFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "number_display_format_configuration": "numberDisplayFormatConfiguration",
            "percentage_display_format_configuration": "percentageDisplayFormatConfiguration",
        },
    )
    class ComparisonFormatConfigurationProperty:
        def __init__(
            self,
            *,
            number_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumberDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            percentage_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PercentageDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The format of the comparison.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param number_display_format_configuration: The number display format.
            :param percentage_display_format_configuration: The percentage display format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                comparison_format_configuration_property = quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    ),
                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        prefix="prefix",
                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dabee068e2b731910b73a04bd94f3c61e64a93997b9b7b8e2dfc7a0247d6158b)
                check_type(argname="argument number_display_format_configuration", value=number_display_format_configuration, expected_type=type_hints["number_display_format_configuration"])
                check_type(argname="argument percentage_display_format_configuration", value=percentage_display_format_configuration, expected_type=type_hints["percentage_display_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if number_display_format_configuration is not None:
                self._values["number_display_format_configuration"] = number_display_format_configuration
            if percentage_display_format_configuration is not None:
                self._values["percentage_display_format_configuration"] = percentage_display_format_configuration

        @builtins.property
        def number_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumberDisplayFormatConfigurationProperty"]]:
            '''The number display format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonformatconfiguration.html#cfn-quicksight-template-comparisonformatconfiguration-numberdisplayformatconfiguration
            '''
            result = self._values.get("number_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumberDisplayFormatConfigurationProperty"]], result)

        @builtins.property
        def percentage_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PercentageDisplayFormatConfigurationProperty"]]:
            '''The percentage display format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonformatconfiguration.html#cfn-quicksight-template-comparisonformatconfiguration-percentagedisplayformatconfiguration
            '''
            result = self._values.get("percentage_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PercentageDisplayFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComparisonFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "forecast": "forecast",
            "growth_rate": "growthRate",
            "maximum_minimum": "maximumMinimum",
            "metric_comparison": "metricComparison",
            "period_over_period": "periodOverPeriod",
            "period_to_date": "periodToDate",
            "top_bottom_movers": "topBottomMovers",
            "top_bottom_ranked": "topBottomRanked",
            "total_aggregation": "totalAggregation",
            "unique_values": "uniqueValues",
        },
    )
    class ComputationProperty:
        def __init__(
            self,
            *,
            forecast: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ForecastComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            growth_rate: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GrowthRateComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            maximum_minimum: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MaximumMinimumComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            metric_comparison: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MetricComparisonComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            period_over_period: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PeriodOverPeriodComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            period_to_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PeriodToDateComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top_bottom_movers: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TopBottomMoversComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top_bottom_ranked: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TopBottomRankedComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            total_aggregation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TotalAggregationComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            unique_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.UniqueValuesComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The computation union that is used in an insight visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param forecast: The forecast computation configuration.
            :param growth_rate: The growth rate computation configuration.
            :param maximum_minimum: The maximum and minimum computation configuration.
            :param metric_comparison: The metric comparison computation configuration.
            :param period_over_period: The period over period computation configuration.
            :param period_to_date: The period to ``DataSetIdentifier`` computation configuration.
            :param top_bottom_movers: The top movers and bottom movers computation configuration.
            :param top_bottom_ranked: The top ranked and bottom ranked computation configuration.
            :param total_aggregation: The total aggregation computation configuration.
            :param unique_values: The unique values computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__77632b79111ed8253df8855a77a888ca9c207be91ca1e365273e54f1b7bc8059)
                check_type(argname="argument forecast", value=forecast, expected_type=type_hints["forecast"])
                check_type(argname="argument growth_rate", value=growth_rate, expected_type=type_hints["growth_rate"])
                check_type(argname="argument maximum_minimum", value=maximum_minimum, expected_type=type_hints["maximum_minimum"])
                check_type(argname="argument metric_comparison", value=metric_comparison, expected_type=type_hints["metric_comparison"])
                check_type(argname="argument period_over_period", value=period_over_period, expected_type=type_hints["period_over_period"])
                check_type(argname="argument period_to_date", value=period_to_date, expected_type=type_hints["period_to_date"])
                check_type(argname="argument top_bottom_movers", value=top_bottom_movers, expected_type=type_hints["top_bottom_movers"])
                check_type(argname="argument top_bottom_ranked", value=top_bottom_ranked, expected_type=type_hints["top_bottom_ranked"])
                check_type(argname="argument total_aggregation", value=total_aggregation, expected_type=type_hints["total_aggregation"])
                check_type(argname="argument unique_values", value=unique_values, expected_type=type_hints["unique_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if forecast is not None:
                self._values["forecast"] = forecast
            if growth_rate is not None:
                self._values["growth_rate"] = growth_rate
            if maximum_minimum is not None:
                self._values["maximum_minimum"] = maximum_minimum
            if metric_comparison is not None:
                self._values["metric_comparison"] = metric_comparison
            if period_over_period is not None:
                self._values["period_over_period"] = period_over_period
            if period_to_date is not None:
                self._values["period_to_date"] = period_to_date
            if top_bottom_movers is not None:
                self._values["top_bottom_movers"] = top_bottom_movers
            if top_bottom_ranked is not None:
                self._values["top_bottom_ranked"] = top_bottom_ranked
            if total_aggregation is not None:
                self._values["total_aggregation"] = total_aggregation
            if unique_values is not None:
                self._values["unique_values"] = unique_values

        @builtins.property
        def forecast(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ForecastComputationProperty"]]:
            '''The forecast computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-forecast
            '''
            result = self._values.get("forecast")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ForecastComputationProperty"]], result)

        @builtins.property
        def growth_rate(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GrowthRateComputationProperty"]]:
            '''The growth rate computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-growthrate
            '''
            result = self._values.get("growth_rate")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GrowthRateComputationProperty"]], result)

        @builtins.property
        def maximum_minimum(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MaximumMinimumComputationProperty"]]:
            '''The maximum and minimum computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-maximumminimum
            '''
            result = self._values.get("maximum_minimum")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MaximumMinimumComputationProperty"]], result)

        @builtins.property
        def metric_comparison(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MetricComparisonComputationProperty"]]:
            '''The metric comparison computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-metriccomparison
            '''
            result = self._values.get("metric_comparison")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MetricComparisonComputationProperty"]], result)

        @builtins.property
        def period_over_period(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PeriodOverPeriodComputationProperty"]]:
            '''The period over period computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-periodoverperiod
            '''
            result = self._values.get("period_over_period")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PeriodOverPeriodComputationProperty"]], result)

        @builtins.property
        def period_to_date(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PeriodToDateComputationProperty"]]:
            '''The period to ``DataSetIdentifier`` computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-periodtodate
            '''
            result = self._values.get("period_to_date")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PeriodToDateComputationProperty"]], result)

        @builtins.property
        def top_bottom_movers(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TopBottomMoversComputationProperty"]]:
            '''The top movers and bottom movers computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-topbottommovers
            '''
            result = self._values.get("top_bottom_movers")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TopBottomMoversComputationProperty"]], result)

        @builtins.property
        def top_bottom_ranked(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TopBottomRankedComputationProperty"]]:
            '''The top ranked and bottom ranked computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-topbottomranked
            '''
            result = self._values.get("top_bottom_ranked")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TopBottomRankedComputationProperty"]], result)

        @builtins.property
        def total_aggregation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TotalAggregationComputationProperty"]]:
            '''The total aggregation computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-totalaggregation
            '''
            result = self._values.get("total_aggregation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TotalAggregationComputationProperty"]], result)

        @builtins.property
        def unique_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.UniqueValuesComputationProperty"]]:
            '''The unique values computation configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-uniquevalues
            '''
            result = self._values.get("unique_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.UniqueValuesComputationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ConditionalFormattingColorProperty",
        jsii_struct_bases=[],
        name_mapping={"gradient": "gradient", "solid": "solid"},
    )
    class ConditionalFormattingColorProperty:
        def __init__(
            self,
            *,
            gradient: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingGradientColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            solid: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingSolidColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The formatting configuration for the color.

            :param gradient: Formatting configuration for gradient color.
            :param solid: Formatting configuration for solid color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_color_property = quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                        color=quicksight.CfnTemplate.GradientColorProperty(
                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                gradient_offset=123,
                
                                # the properties below are optional
                                color="color",
                                data_value=123
                            )]
                        ),
                        expression="expression"
                    ),
                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                        expression="expression",
                
                        # the properties below are optional
                        color="color"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5c8a6a54650c3b7a7d19a29e10350a9aa0b79747e9b258051d6ae497c5fdbb4d)
                check_type(argname="argument gradient", value=gradient, expected_type=type_hints["gradient"])
                check_type(argname="argument solid", value=solid, expected_type=type_hints["solid"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if gradient is not None:
                self._values["gradient"] = gradient
            if solid is not None:
                self._values["solid"] = solid

        @builtins.property
        def gradient(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingGradientColorProperty"]]:
            '''Formatting configuration for gradient color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcolor.html#cfn-quicksight-template-conditionalformattingcolor-gradient
            '''
            result = self._values.get("gradient")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingGradientColorProperty"]], result)

        @builtins.property
        def solid(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingSolidColorProperty"]]:
            '''Formatting configuration for solid color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcolor.html#cfn-quicksight-template-conditionalformattingcolor-solid
            '''
            result = self._values.get("solid")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingSolidColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "expression": "expression",
            "icon_options": "iconOptions",
            "color": "color",
            "display_configuration": "displayConfiguration",
        },
    )
    class ConditionalFormattingCustomIconConditionProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            icon_options: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingCustomIconOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
            color: typing.Optional[builtins.str] = None,
            display_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Determines the custom condition for an icon set.

            :param expression: The expression that determines the condition of the icon set.
            :param icon_options: Custom icon options for an icon set.
            :param color: Determines the color of the icon.
            :param display_configuration: Determines the icon display configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_custom_icon_condition_property = quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                    expression="expression",
                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                        icon="icon",
                        unicode_icon="unicodeIcon"
                    ),
                
                    # the properties below are optional
                    color="color",
                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                        icon_display_option="iconDisplayOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__96aa1eee01991551417ed2ff01717785059d604c11d48025e17bbac5a4c22072)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument icon_options", value=icon_options, expected_type=type_hints["icon_options"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument display_configuration", value=display_configuration, expected_type=type_hints["display_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
                "icon_options": icon_options,
            }
            if color is not None:
                self._values["color"] = color
            if display_configuration is not None:
                self._values["display_configuration"] = display_configuration

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the condition of the icon set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html#cfn-quicksight-template-conditionalformattingcustomiconcondition-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def icon_options(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingCustomIconOptionsProperty"]:
            '''Custom icon options for an icon set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html#cfn-quicksight-template-conditionalformattingcustomiconcondition-iconoptions
            '''
            result = self._values.get("icon_options")
            assert result is not None, "Required property 'icon_options' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingCustomIconOptionsProperty"], result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html#cfn-quicksight-template-conditionalformattingcustomiconcondition-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty"]]:
            '''Determines the icon display configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html#cfn-quicksight-template-conditionalformattingcustomiconcondition-displayconfiguration
            '''
            result = self._values.get("display_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingCustomIconConditionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "unicode_icon": "unicodeIcon"},
    )
    class ConditionalFormattingCustomIconOptionsProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[builtins.str] = None,
            unicode_icon: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Custom icon options for an icon set.

            :param icon: Determines the type of icon.
            :param unicode_icon: Determines the Unicode icon type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_custom_icon_options_property = quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                    icon="icon",
                    unicode_icon="unicodeIcon"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__af6db9db8c98022f02ac1d3dc89a99ccb5264e210b2df65c4cb84aba21ce30b9)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument unicode_icon", value=unicode_icon, expected_type=type_hints["unicode_icon"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if unicode_icon is not None:
                self._values["unicode_icon"] = unicode_icon

        @builtins.property
        def icon(self) -> typing.Optional[builtins.str]:
            '''Determines the type of icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconoptions.html#cfn-quicksight-template-conditionalformattingcustomiconoptions-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def unicode_icon(self) -> typing.Optional[builtins.str]:
            '''Determines the Unicode icon type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconoptions.html#cfn-quicksight-template-conditionalformattingcustomiconoptions-unicodeicon
            '''
            result = self._values.get("unicode_icon")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingCustomIconOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "expression": "expression"},
    )
    class ConditionalFormattingGradientColorProperty:
        def __init__(
            self,
            *,
            color: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GradientColorProperty", typing.Dict[builtins.str, typing.Any]]],
            expression: builtins.str,
        ) -> None:
            '''Formatting configuration for gradient color.

            :param color: Determines the color.
            :param expression: The expression that determines the formatting configuration for gradient color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattinggradientcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_gradient_color_property = quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                    color=quicksight.CfnTemplate.GradientColorProperty(
                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                            gradient_offset=123,
                
                            # the properties below are optional
                            color="color",
                            data_value=123
                        )]
                    ),
                    expression="expression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9f2de55f86e1ae86889d85c2e511e3072fb65a2e377f3e26d911521b8969d8e4)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
                "expression": expression,
            }

        @builtins.property
        def color(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.GradientColorProperty"]:
            '''Determines the color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattinggradientcolor.html#cfn-quicksight-template-conditionalformattinggradientcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.GradientColorProperty"], result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for gradient color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattinggradientcolor.html#cfn-quicksight-template-conditionalformattinggradientcolor-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingGradientColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"icon_display_option": "iconDisplayOption"},
    )
    class ConditionalFormattingIconDisplayConfigurationProperty:
        def __init__(
            self,
            *,
            icon_display_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the icon display configuration.

            :param icon_display_option: Determines the icon display configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicondisplayconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_icon_display_configuration_property = quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                    icon_display_option="iconDisplayOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8c9f7176c5d1ca667628430307f3e6f0cc47ccdd005902b951025196b31e4efa)
                check_type(argname="argument icon_display_option", value=icon_display_option, expected_type=type_hints["icon_display_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon_display_option is not None:
                self._values["icon_display_option"] = icon_display_option

        @builtins.property
        def icon_display_option(self) -> typing.Optional[builtins.str]:
            '''Determines the icon display configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicondisplayconfiguration.html#cfn-quicksight-template-conditionalformattingicondisplayconfiguration-icondisplayoption
            '''
            result = self._values.get("icon_display_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconDisplayConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ConditionalFormattingIconProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_condition": "customCondition", "icon_set": "iconSet"},
    )
    class ConditionalFormattingIconProperty:
        def __init__(
            self,
            *,
            custom_condition: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingCustomIconConditionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            icon_set: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingIconSetProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The formatting configuration for the icon.

            :param custom_condition: Determines the custom condition for an icon set.
            :param icon_set: Formatting configuration for icon set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicon.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_icon_property = quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                    custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                        expression="expression",
                        icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                            icon="icon",
                            unicode_icon="unicodeIcon"
                        ),
                
                        # the properties below are optional
                        color="color",
                        display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                            icon_display_option="iconDisplayOption"
                        )
                    ),
                    icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                        expression="expression",
                
                        # the properties below are optional
                        icon_set_type="iconSetType"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cf36215e467d3f2b3d313a6270a594f2c90a1fd3e0a5b35698f1b271753e5d5c)
                check_type(argname="argument custom_condition", value=custom_condition, expected_type=type_hints["custom_condition"])
                check_type(argname="argument icon_set", value=icon_set, expected_type=type_hints["icon_set"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_condition is not None:
                self._values["custom_condition"] = custom_condition
            if icon_set is not None:
                self._values["icon_set"] = icon_set

        @builtins.property
        def custom_condition(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingCustomIconConditionProperty"]]:
            '''Determines the custom condition for an icon set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicon.html#cfn-quicksight-template-conditionalformattingicon-customcondition
            '''
            result = self._values.get("custom_condition")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingCustomIconConditionProperty"]], result)

        @builtins.property
        def icon_set(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingIconSetProperty"]]:
            '''Formatting configuration for icon set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicon.html#cfn-quicksight-template-conditionalformattingicon-iconset
            '''
            result = self._values.get("icon_set")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingIconSetProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ConditionalFormattingIconSetProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "icon_set_type": "iconSetType"},
    )
    class ConditionalFormattingIconSetProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            icon_set_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Formatting configuration for icon set.

            :param expression: The expression that determines the formatting configuration for the icon set.
            :param icon_set_type: Determines the icon set type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingiconset.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_icon_set_property = quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                    expression="expression",
                
                    # the properties below are optional
                    icon_set_type="iconSetType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1cf2f5557ed2a89e93f7c6712410d0eb91d14766de9c9e7fbeccda2931c2f9ac)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument icon_set_type", value=icon_set_type, expected_type=type_hints["icon_set_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if icon_set_type is not None:
                self._values["icon_set_type"] = icon_set_type

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for the icon set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingiconset.html#cfn-quicksight-template-conditionalformattingiconset-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def icon_set_type(self) -> typing.Optional[builtins.str]:
            '''Determines the icon set type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingiconset.html#cfn-quicksight-template-conditionalformattingiconset-iconsettype
            '''
            result = self._values.get("icon_set_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconSetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "color": "color"},
    )
    class ConditionalFormattingSolidColorProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            color: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Formatting configuration for solid color.

            :param expression: The expression that determines the formatting configuration for solid color.
            :param color: Determines the color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingsolidcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                conditional_formatting_solid_color_property = quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                    expression="expression",
                
                    # the properties below are optional
                    color="color"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__71ad6505c5babab15a9ed7f209c1cf65024e1762926ca213a0235faaee0a96bc)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if color is not None:
                self._values["color"] = color

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for solid color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingsolidcolor.html#cfn-quicksight-template-conditionalformattingsolidcolor-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingsolidcolor.html#cfn-quicksight-template-conditionalformattingsolidcolor-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingSolidColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ContributionAnalysisDefaultProperty",
        jsii_struct_bases=[],
        name_mapping={
            "contributor_dimensions": "contributorDimensions",
            "measure_field_id": "measureFieldId",
        },
    )
    class ContributionAnalysisDefaultProperty:
        def __init__(
            self,
            *,
            contributor_dimensions: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]]],
            measure_field_id: builtins.str,
        ) -> None:
            '''The contribution analysis visual display for a line, pie, or bar chart.

            :param contributor_dimensions: The dimensions columns that are used in the contribution analysis, usually a list of ``ColumnIdentifiers`` .
            :param measure_field_id: The measure field that is used in the contribution analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-contributionanalysisdefault.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                contribution_analysis_default_property = quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                    contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    measure_field_id="measureFieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__66651eb3331d8765f1aa91e48973735db342945916472bc018482a57ef1fcb0b)
                check_type(argname="argument contributor_dimensions", value=contributor_dimensions, expected_type=type_hints["contributor_dimensions"])
                check_type(argname="argument measure_field_id", value=measure_field_id, expected_type=type_hints["measure_field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "contributor_dimensions": contributor_dimensions,
                "measure_field_id": measure_field_id,
            }

        @builtins.property
        def contributor_dimensions(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]]]:
            '''The dimensions columns that are used in the contribution analysis, usually a list of ``ColumnIdentifiers`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-contributionanalysisdefault.html#cfn-quicksight-template-contributionanalysisdefault-contributordimensions
            '''
            result = self._values.get("contributor_dimensions")
            assert result is not None, "Required property 'contributor_dimensions' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]]], result)

        @builtins.property
        def measure_field_id(self) -> builtins.str:
            '''The measure field that is used in the contribution analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-contributionanalysisdefault.html#cfn-quicksight-template-contributionanalysisdefault-measurefieldid
            '''
            result = self._values.get("measure_field_id")
            assert result is not None, "Required property 'measure_field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ContributionAnalysisDefaultProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "number_scale": "numberScale",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
            "symbol": "symbol",
        },
    )
    class CurrencyDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            negative_value_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_scale: typing.Optional[builtins.str] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            suffix: typing.Optional[builtins.str] = None,
            symbol: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the currency display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param number_scale: Determines the number scale value for the currency format.
            :param prefix: Determines the prefix value of the currency format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the currency format.
            :param symbol: Determines the symbol for the currency format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                currency_display_format_configuration_property = quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    number_scale="numberScale",
                    prefix="prefix",
                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix",
                    symbol="symbol"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8e28af5c95538bbeae34825f5df88224c130daf5a377edb14bbc46be99fdeea0)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument number_scale", value=number_scale, expected_type=type_hints["number_scale"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
                check_type(argname="argument symbol", value=symbol, expected_type=type_hints["symbol"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if number_scale is not None:
                self._values["number_scale"] = number_scale
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix
            if symbol is not None:
                self._values["symbol"] = symbol

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DecimalPlacesConfigurationProperty"]]:
            '''The option that determines the decimal places configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DecimalPlacesConfigurationProperty"]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NegativeValueConfigurationProperty"]]:
            '''The options that determine the negative value configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NegativeValueConfigurationProperty"]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def number_scale(self) -> typing.Optional[builtins.str]:
            '''Determines the number scale value for the currency format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-numberscale
            '''
            result = self._values.get("number_scale")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the currency format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericSeparatorConfigurationProperty"]]:
            '''The options that determine the numeric separator configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericSeparatorConfigurationProperty"]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the currency format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def symbol(self) -> typing.Optional[builtins.str]:
            '''Determines the symbol for the currency format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-symbol
            '''
            result = self._values.get("symbol")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CurrencyDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CustomActionFilterOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "selected_fields_configuration": "selectedFieldsConfiguration",
            "target_visuals_configuration": "targetVisualsConfiguration",
        },
    )
    class CustomActionFilterOperationProperty:
        def __init__(
            self,
            *,
            selected_fields_configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            target_visuals_configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilterOperationTargetVisualsConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The filter operation that filters data included in a visual or in an entire sheet.

            :param selected_fields_configuration: The configuration that chooses the fields to be filtered.
            :param target_visuals_configuration: The configuration that chooses the target visuals to be filtered.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionfilteroperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_action_filter_operation_property = quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                        selected_columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        selected_field_options="selectedFieldOptions",
                        selected_fields=["selectedFields"]
                    ),
                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                            target_visual_options="targetVisualOptions",
                            target_visuals=["targetVisuals"]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0cd1ddf41ef3de81bbc707b01eac1a10418a48d1a32c7d1d42f03d4bc8df9f36)
                check_type(argname="argument selected_fields_configuration", value=selected_fields_configuration, expected_type=type_hints["selected_fields_configuration"])
                check_type(argname="argument target_visuals_configuration", value=target_visuals_configuration, expected_type=type_hints["target_visuals_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "selected_fields_configuration": selected_fields_configuration,
                "target_visuals_configuration": target_visuals_configuration,
            }

        @builtins.property
        def selected_fields_configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty"]:
            '''The configuration that chooses the fields to be filtered.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionfilteroperation.html#cfn-quicksight-template-customactionfilteroperation-selectedfieldsconfiguration
            '''
            result = self._values.get("selected_fields_configuration")
            assert result is not None, "Required property 'selected_fields_configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty"], result)

        @builtins.property
        def target_visuals_configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterOperationTargetVisualsConfigurationProperty"]:
            '''The configuration that chooses the target visuals to be filtered.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionfilteroperation.html#cfn-quicksight-template-customactionfilteroperation-targetvisualsconfiguration
            '''
            result = self._values.get("target_visuals_configuration")
            assert result is not None, "Required property 'target_visuals_configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterOperationTargetVisualsConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionFilterOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CustomActionNavigationOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "local_navigation_configuration": "localNavigationConfiguration",
        },
    )
    class CustomActionNavigationOperationProperty:
        def __init__(
            self,
            *,
            local_navigation_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LocalNavigationConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The navigation operation that navigates between different sheets in the same analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param local_navigation_configuration: The configuration that chooses the navigation target.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionnavigationoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_action_navigation_operation_property = quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                        target_sheet_id="targetSheetId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__42c952d1cd8e1a86f54cadd2c745e98286d41b837588458d1ce75f3226818de0)
                check_type(argname="argument local_navigation_configuration", value=local_navigation_configuration, expected_type=type_hints["local_navigation_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if local_navigation_configuration is not None:
                self._values["local_navigation_configuration"] = local_navigation_configuration

        @builtins.property
        def local_navigation_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LocalNavigationConfigurationProperty"]]:
            '''The configuration that chooses the navigation target.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionnavigationoperation.html#cfn-quicksight-template-customactionnavigationoperation-localnavigationconfiguration
            '''
            result = self._values.get("local_navigation_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LocalNavigationConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionNavigationOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CustomActionSetParametersOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_value_configurations": "parameterValueConfigurations",
        },
    )
    class CustomActionSetParametersOperationProperty:
        def __init__(
            self,
            *,
            parameter_value_configurations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SetParameterValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The set parameter operation that sets parameters in custom action.

            :param parameter_value_configurations: The parameter that determines the value configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionsetparametersoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_action_set_parameters_operation_property = quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                        destination_parameter_name="destinationParameterName",
                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                    date_time_values=["dateTimeValues"],
                                    decimal_values=[123],
                                    integer_values=[123],
                                    string_values=["stringValues"]
                                ),
                
                                # the properties below are optional
                                include_null_value=False
                            ),
                            select_all_value_options="selectAllValueOptions",
                            source_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_field="sourceField",
                            source_parameter_name="sourceParameterName"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__30a146d57320d60f1ed6d23e9f2a17a8a577f2fb06356d435a5d9721c8c3a724)
                check_type(argname="argument parameter_value_configurations", value=parameter_value_configurations, expected_type=type_hints["parameter_value_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_value_configurations": parameter_value_configurations,
            }

        @builtins.property
        def parameter_value_configurations(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SetParameterValueConfigurationProperty"]]]:
            '''The parameter that determines the value configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionsetparametersoperation.html#cfn-quicksight-template-customactionsetparametersoperation-parametervalueconfigurations
            '''
            result = self._values.get("parameter_value_configurations")
            assert result is not None, "Required property 'parameter_value_configurations' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SetParameterValueConfigurationProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionSetParametersOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CustomActionURLOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"url_target": "urlTarget", "url_template": "urlTemplate"},
    )
    class CustomActionURLOperationProperty:
        def __init__(
            self,
            *,
            url_target: builtins.str,
            url_template: builtins.str,
        ) -> None:
            '''The URL operation that opens a link to another webpage.

            :param url_target: The target of the ``CustomActionURLOperation`` . Valid values are defined as follows: - ``NEW_TAB`` : Opens the target URL in a new browser tab. - ``NEW_WINDOW`` : Opens the target URL in a new browser window. - ``SAME_TAB`` : Opens the target URL in the same browser tab.
            :param url_template: THe URL link of the ``CustomActionURLOperation`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionurloperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_action_uRLOperation_property = quicksight.CfnTemplate.CustomActionURLOperationProperty(
                    url_target="urlTarget",
                    url_template="urlTemplate"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5025c653b1496d1f4f3382a8dab323fdb13f26ab4f6f5cace16022cb0a19e395)
                check_type(argname="argument url_target", value=url_target, expected_type=type_hints["url_target"])
                check_type(argname="argument url_template", value=url_template, expected_type=type_hints["url_template"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "url_target": url_target,
                "url_template": url_template,
            }

        @builtins.property
        def url_target(self) -> builtins.str:
            '''The target of the ``CustomActionURLOperation`` .

            Valid values are defined as follows:

            - ``NEW_TAB`` : Opens the target URL in a new browser tab.
            - ``NEW_WINDOW`` : Opens the target URL in a new browser window.
            - ``SAME_TAB`` : Opens the target URL in the same browser tab.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionurloperation.html#cfn-quicksight-template-customactionurloperation-urltarget
            '''
            result = self._values.get("url_target")
            assert result is not None, "Required property 'url_target' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def url_template(self) -> builtins.str:
            '''THe URL link of the ``CustomActionURLOperation`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionurloperation.html#cfn-quicksight-template-customactionurloperation-urltemplate
            '''
            result = self._values.get("url_template")
            assert result is not None, "Required property 'url_template' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionURLOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CustomColorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color": "color",
            "field_value": "fieldValue",
            "special_value": "specialValue",
        },
    )
    class CustomColorProperty:
        def __init__(
            self,
            *,
            color: builtins.str,
            field_value: typing.Optional[builtins.str] = None,
            special_value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the color that's applied to a particular data value in a column.

            :param color: The color that is applied to the data value.
            :param field_value: The data value that the color is applied to.
            :param special_value: The value of a special data value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_color_property = quicksight.CfnTemplate.CustomColorProperty(
                    color="color",
                
                    # the properties below are optional
                    field_value="fieldValue",
                    special_value="specialValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7c0a44f45a754148ed98c3c1411f5d2aaf53de63fecc91002cdf99b74c84a04a)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument special_value", value=special_value, expected_type=type_hints["special_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
            }
            if field_value is not None:
                self._values["field_value"] = field_value
            if special_value is not None:
                self._values["special_value"] = special_value

        @builtins.property
        def color(self) -> builtins.str:
            '''The color that is applied to the data value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcolor.html#cfn-quicksight-template-customcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The data value that the color is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcolor.html#cfn-quicksight-template-customcolor-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def special_value(self) -> typing.Optional[builtins.str]:
            '''The value of a special data value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcolor.html#cfn-quicksight-template-customcolor-specialvalue
            '''
            result = self._values.get("special_value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CustomContentConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "content_type": "contentType",
            "content_url": "contentUrl",
            "image_scaling": "imageScaling",
        },
    )
    class CustomContentConfigurationProperty:
        def __init__(
            self,
            *,
            content_type: typing.Optional[builtins.str] = None,
            content_url: typing.Optional[builtins.str] = None,
            image_scaling: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of a ``CustomContentVisual`` .

            :param content_type: The content type of the custom content visual. You can use this to have the visual render as an image.
            :param content_url: The input URL that links to the custom content that you want in the custom visual.
            :param image_scaling: The sizing options for the size of the custom content visual. This structure is required when the ``ContentType`` of the visual is ``'IMAGE'`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_content_configuration_property = quicksight.CfnTemplate.CustomContentConfigurationProperty(
                    content_type="contentType",
                    content_url="contentUrl",
                    image_scaling="imageScaling"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__45ecf9bd25689ad2f828879e5f20050fa80cdec18a755159b44fdb420e3e498a)
                check_type(argname="argument content_type", value=content_type, expected_type=type_hints["content_type"])
                check_type(argname="argument content_url", value=content_url, expected_type=type_hints["content_url"])
                check_type(argname="argument image_scaling", value=image_scaling, expected_type=type_hints["image_scaling"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if content_type is not None:
                self._values["content_type"] = content_type
            if content_url is not None:
                self._values["content_url"] = content_url
            if image_scaling is not None:
                self._values["image_scaling"] = image_scaling

        @builtins.property
        def content_type(self) -> typing.Optional[builtins.str]:
            '''The content type of the custom content visual.

            You can use this to have the visual render as an image.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentconfiguration.html#cfn-quicksight-template-customcontentconfiguration-contenttype
            '''
            result = self._values.get("content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def content_url(self) -> typing.Optional[builtins.str]:
            '''The input URL that links to the custom content that you want in the custom visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentconfiguration.html#cfn-quicksight-template-customcontentconfiguration-contenturl
            '''
            result = self._values.get("content_url")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def image_scaling(self) -> typing.Optional[builtins.str]:
            '''The sizing options for the size of the custom content visual.

            This structure is required when the ``ContentType`` of the visual is ``'IMAGE'`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentconfiguration.html#cfn-quicksight-template-customcontentconfiguration-imagescaling
            '''
            result = self._values.get("image_scaling")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomContentConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CustomContentVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class CustomContentVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CustomContentConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A visual that contains custom content.

            For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :param data_set_identifier: The dataset that is used to create the custom content visual. You can't create a visual without a dataset.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``CustomContentVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_content_visual_property = quicksight.CfnTemplate.CustomContentVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.CustomContentConfigurationProperty(
                        content_type="contentType",
                        content_url="contentUrl",
                        image_scaling="imageScaling"
                    ),
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c4ef672a4936a4dd2c5ac133be582537a5cb86c0d1f7b6c7f0f228f74fed16f9)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The dataset that is used to create the custom content visual.

            You can't create a visual without a dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomContentConfigurationProperty"]]:
            '''The configuration of a ``CustomContentVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomContentConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomContentVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CustomFilterConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "category_value": "categoryValue",
            "parameter_name": "parameterName",
            "select_all_options": "selectAllOptions",
        },
    )
    class CustomFilterConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            null_option: builtins.str,
            category_value: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A custom filter that filters based on a single value.

            This filter can be partially matched.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param category_value: The category value for the filter. This field is mutually exclusive to ``ParameterName`` .
            :param parameter_name: The parameter whose value should be used for the filter value. This field is mutually exclusive to ``CategoryValue`` .
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_filter_configuration_property = quicksight.CfnTemplate.CustomFilterConfigurationProperty(
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    category_value="categoryValue",
                    parameter_name="parameterName",
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9bb088dc5e7e43b3c5f9141073112054c6d229d0b043199e57d50f85999d74a2)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument category_value", value=category_value, expected_type=type_hints["category_value"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if category_value is not None:
                self._values["category_value"] = category_value
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_value(self) -> typing.Optional[builtins.str]:
            '''The category value for the filter.

            This field is mutually exclusive to ``ParameterName`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-categoryvalue
            '''
            result = self._values.get("category_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            This field is mutually exclusive to ``CategoryValue`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomFilterConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CustomFilterListConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "category_values": "categoryValues",
            "select_all_options": "selectAllOptions",
        },
    )
    class CustomFilterListConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            null_option: builtins.str,
            category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A list of custom filter values.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param category_values: The list of category values for the filter.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_filter_list_configuration_property = quicksight.CfnTemplate.CustomFilterListConfigurationProperty(
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    category_values=["categoryValues"],
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d92e42778be63999e9af811ecb5f3a5c3901b30aa3d5326181060b0a0fbd3fd1)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if category_values is not None:
                self._values["category_values"] = category_values
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html#cfn-quicksight-template-customfilterlistconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html#cfn-quicksight-template-customfilterlistconfiguration-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of category values for the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html#cfn-quicksight-template-customfilterlistconfiguration-categoryvalues
            '''
            result = self._values.get("category_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html#cfn-quicksight-template-customfilterlistconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomFilterListConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CustomNarrativeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"narrative": "narrative"},
    )
    class CustomNarrativeOptionsProperty:
        def __init__(self, *, narrative: builtins.str) -> None:
            '''The custom narrative options.

            :param narrative: The string input of custom narrative.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customnarrativeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_narrative_options_property = quicksight.CfnTemplate.CustomNarrativeOptionsProperty(
                    narrative="narrative"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__afdb262079e0e26aef37a00a3372dd7773a4f2a85af67ea3c23606c53e3157d0)
                check_type(argname="argument narrative", value=narrative, expected_type=type_hints["narrative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "narrative": narrative,
            }

        @builtins.property
        def narrative(self) -> builtins.str:
            '''The string input of custom narrative.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customnarrativeoptions.html#cfn-quicksight-template-customnarrativeoptions-narrative
            '''
            result = self._values.get("narrative")
            assert result is not None, "Required property 'narrative' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomNarrativeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CustomParameterValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_values": "dateTimeValues",
            "decimal_values": "decimalValues",
            "integer_values": "integerValues",
            "string_values": "stringValues",
        },
    )
    class CustomParameterValuesProperty:
        def __init__(
            self,
            *,
            date_time_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            decimal_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
            integer_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
            string_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The customized parameter values.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_values: A list of datetime-type parameter values.
            :param decimal_values: A list of decimal-type parameter values.
            :param integer_values: A list of integer-type parameter values.
            :param string_values: A list of string-type parameter values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_parameter_values_property = quicksight.CfnTemplate.CustomParameterValuesProperty(
                    date_time_values=["dateTimeValues"],
                    decimal_values=[123],
                    integer_values=[123],
                    string_values=["stringValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dc7a52cbcd0f391a56598bdcf7ac2a0fdcc4bace6a14bf5e49b915aa2656b7b2)
                check_type(argname="argument date_time_values", value=date_time_values, expected_type=type_hints["date_time_values"])
                check_type(argname="argument decimal_values", value=decimal_values, expected_type=type_hints["decimal_values"])
                check_type(argname="argument integer_values", value=integer_values, expected_type=type_hints["integer_values"])
                check_type(argname="argument string_values", value=string_values, expected_type=type_hints["string_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_values is not None:
                self._values["date_time_values"] = date_time_values
            if decimal_values is not None:
                self._values["decimal_values"] = decimal_values
            if integer_values is not None:
                self._values["integer_values"] = integer_values
            if string_values is not None:
                self._values["string_values"] = string_values

        @builtins.property
        def date_time_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of datetime-type parameter values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html#cfn-quicksight-template-customparametervalues-datetimevalues
            '''
            result = self._values.get("date_time_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def decimal_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]]:
            '''A list of decimal-type parameter values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html#cfn-quicksight-template-customparametervalues-decimalvalues
            '''
            result = self._values.get("decimal_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]], result)

        @builtins.property
        def integer_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]]:
            '''A list of integer-type parameter values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html#cfn-quicksight-template-customparametervalues-integervalues
            '''
            result = self._values.get("integer_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]], result)

        @builtins.property
        def string_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of string-type parameter values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html#cfn-quicksight-template-customparametervalues-stringvalues
            '''
            result = self._values.get("string_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomParameterValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.CustomValuesConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_values": "customValues",
            "include_null_value": "includeNullValue",
        },
    )
    class CustomValuesConfigurationProperty:
        def __init__(
            self,
            *,
            custom_values: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CustomParameterValuesProperty", typing.Dict[builtins.str, typing.Any]]],
            include_null_value: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
        ) -> None:
            '''The configuration of custom values for the destination parameter in ``DestinationParameterValueConfiguration`` .

            :param custom_values: 
            :param include_null_value: Includes the null value in custom action parameter values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customvaluesconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                custom_values_configuration_property = quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                        date_time_values=["dateTimeValues"],
                        decimal_values=[123],
                        integer_values=[123],
                        string_values=["stringValues"]
                    ),
                
                    # the properties below are optional
                    include_null_value=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fd84e73c60fac5d450066273e23de5dc97021788becef8a98dca537fe48b8791)
                check_type(argname="argument custom_values", value=custom_values, expected_type=type_hints["custom_values"])
                check_type(argname="argument include_null_value", value=include_null_value, expected_type=type_hints["include_null_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "custom_values": custom_values,
            }
            if include_null_value is not None:
                self._values["include_null_value"] = include_null_value

        @builtins.property
        def custom_values(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomParameterValuesProperty"]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customvaluesconfiguration.html#cfn-quicksight-template-customvaluesconfiguration-customvalues
            '''
            result = self._values.get("custom_values")
            assert result is not None, "Required property 'custom_values' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomParameterValuesProperty"], result)

        @builtins.property
        def include_null_value(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''Includes the null value in custom action parameter values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customvaluesconfiguration.html#cfn-quicksight-template-customvaluesconfiguration-includenullvalue
            '''
            result = self._values.get("include_null_value")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomValuesConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DataBarsOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "negative_color": "negativeColor",
            "positive_color": "positiveColor",
        },
    )
    class DataBarsOptionsProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            negative_color: typing.Optional[builtins.str] = None,
            positive_color: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for data bars.

            :param field_id: The field ID for the data bars options.
            :param negative_color: The color of the negative data bar.
            :param positive_color: The color of the positive data bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-databarsoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_bars_options_property = quicksight.CfnTemplate.DataBarsOptionsProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    negative_color="negativeColor",
                    positive_color="positiveColor"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1ddab4ee208bfe1b72c92ffb67b46f447f0652db33f9226ffdad9e5aadccab99)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument negative_color", value=negative_color, expected_type=type_hints["negative_color"])
                check_type(argname="argument positive_color", value=positive_color, expected_type=type_hints["positive_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if negative_color is not None:
                self._values["negative_color"] = negative_color
            if positive_color is not None:
                self._values["positive_color"] = positive_color

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for the data bars options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-databarsoptions.html#cfn-quicksight-template-databarsoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def negative_color(self) -> typing.Optional[builtins.str]:
            '''The color of the negative data bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-databarsoptions.html#cfn-quicksight-template-databarsoptions-negativecolor
            '''
            result = self._values.get("negative_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def positive_color(self) -> typing.Optional[builtins.str]:
            '''The color of the positive data bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-databarsoptions.html#cfn-quicksight-template-databarsoptions-positivecolor
            '''
            result = self._values.get("positive_color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataBarsOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DataColorProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "data_value": "dataValue"},
    )
    class DataColorProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            data_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''Determines the color that is applied to a particular data value.

            :param color: The color that is applied to the data value.
            :param data_value: The data value that the color is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datacolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_color_property = quicksight.CfnTemplate.DataColorProperty(
                    color="color",
                    data_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7a01bd5ae434eefde64b5a1c75b82798139688763e61ed565ae1bececf1ccb82)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument data_value", value=data_value, expected_type=type_hints["data_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if data_value is not None:
                self._values["data_value"] = data_value

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color that is applied to the data value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datacolor.html#cfn-quicksight-template-datacolor-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_value(self) -> typing.Optional[jsii.Number]:
            '''The data value that the color is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datacolor.html#cfn-quicksight-template-datacolor-datavalue
            '''
            result = self._values.get("data_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DataFieldSeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "field_id": "fieldId",
            "field_value": "fieldValue",
            "settings": "settings",
        },
    )
    class DataFieldSeriesItemProperty:
        def __init__(
            self,
            *,
            axis_binding: builtins.str,
            field_id: builtins.str,
            field_value: typing.Optional[builtins.str] = None,
            settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LineChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The data field series item configuration of a line chart.

            :param axis_binding: The axis that you are binding the field to.
            :param field_id: The field ID of the field that you are setting the axis binding to.
            :param field_value: The field value of the field that you are setting the axis binding to.
            :param settings: The options that determine the presentation of line series associated to the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_field_series_item_property = quicksight.CfnTemplate.DataFieldSeriesItemProperty(
                    axis_binding="axisBinding",
                    field_id="fieldId",
                
                    # the properties below are optional
                    field_value="fieldValue",
                    settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                        line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1bfe82893082073a288ce95596137993bf99e592d5868f15ffd67de88dd99f82)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument settings", value=settings, expected_type=type_hints["settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "axis_binding": axis_binding,
                "field_id": field_id,
            }
            if field_value is not None:
                self._values["field_value"] = field_value
            if settings is not None:
                self._values["settings"] = settings

        @builtins.property
        def axis_binding(self) -> builtins.str:
            '''The axis that you are binding the field to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html#cfn-quicksight-template-datafieldseriesitem-axisbinding
            '''
            result = self._values.get("axis_binding")
            assert result is not None, "Required property 'axis_binding' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field that you are setting the axis binding to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html#cfn-quicksight-template-datafieldseriesitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The field value of the field that you are setting the axis binding to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html#cfn-quicksight-template-datafieldseriesitem-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartSeriesSettingsProperty"]]:
            '''The options that determine the presentation of line series associated to the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html#cfn-quicksight-template-datafieldseriesitem-settings
            '''
            result = self._values.get("settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartSeriesSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataFieldSeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DataLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_visibility": "categoryLabelVisibility",
            "data_label_types": "dataLabelTypes",
            "label_color": "labelColor",
            "label_content": "labelContent",
            "label_font_configuration": "labelFontConfiguration",
            "measure_label_visibility": "measureLabelVisibility",
            "overlap": "overlap",
            "position": "position",
            "totals_visibility": "totalsVisibility",
            "visibility": "visibility",
        },
    )
    class DataLabelOptionsProperty:
        def __init__(
            self,
            *,
            category_label_visibility: typing.Optional[builtins.str] = None,
            data_label_types: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            label_color: typing.Optional[builtins.str] = None,
            label_content: typing.Optional[builtins.str] = None,
            label_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            measure_label_visibility: typing.Optional[builtins.str] = None,
            overlap: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of the data labels.

            :param category_label_visibility: Determines the visibility of the category field labels.
            :param data_label_types: The option that determines the data label type.
            :param label_color: Determines the color of the data labels.
            :param label_content: Determines the content of the data labels.
            :param label_font_configuration: Determines the font configuration of the data labels.
            :param measure_label_visibility: Determines the visibility of the measure field labels.
            :param overlap: Determines whether overlap is enabled or disabled for the data labels.
            :param position: Determines the position of the data labels.
            :param totals_visibility: Determines the visibility of the total.
            :param visibility: Determines the visibility of the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_label_options_property = quicksight.CfnTemplate.DataLabelOptionsProperty(
                    category_label_visibility="categoryLabelVisibility",
                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                            field_id="fieldId",
                            field_value="fieldValue",
                            visibility="visibility"
                        ),
                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                            field_id="fieldId",
                            visibility="visibility"
                        ),
                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                            visibility="visibility"
                        ),
                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                            visibility="visibility"
                        ),
                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                            visibility="visibility"
                        )
                    )],
                    label_color="labelColor",
                    label_content="labelContent",
                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    measure_label_visibility="measureLabelVisibility",
                    overlap="overlap",
                    position="position",
                    totals_visibility="totalsVisibility",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__995e7575445ef7c162160579433dc4b618b1e250b854adba56794678326c9389)
                check_type(argname="argument category_label_visibility", value=category_label_visibility, expected_type=type_hints["category_label_visibility"])
                check_type(argname="argument data_label_types", value=data_label_types, expected_type=type_hints["data_label_types"])
                check_type(argname="argument label_color", value=label_color, expected_type=type_hints["label_color"])
                check_type(argname="argument label_content", value=label_content, expected_type=type_hints["label_content"])
                check_type(argname="argument label_font_configuration", value=label_font_configuration, expected_type=type_hints["label_font_configuration"])
                check_type(argname="argument measure_label_visibility", value=measure_label_visibility, expected_type=type_hints["measure_label_visibility"])
                check_type(argname="argument overlap", value=overlap, expected_type=type_hints["overlap"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_visibility is not None:
                self._values["category_label_visibility"] = category_label_visibility
            if data_label_types is not None:
                self._values["data_label_types"] = data_label_types
            if label_color is not None:
                self._values["label_color"] = label_color
            if label_content is not None:
                self._values["label_content"] = label_content
            if label_font_configuration is not None:
                self._values["label_font_configuration"] = label_font_configuration
            if measure_label_visibility is not None:
                self._values["measure_label_visibility"] = measure_label_visibility
            if overlap is not None:
                self._values["overlap"] = overlap
            if position is not None:
                self._values["position"] = position
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def category_label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the category field labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-categorylabelvisibility
            '''
            result = self._values.get("category_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_label_types(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelTypeProperty"]]]]:
            '''The option that determines the data label type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-datalabeltypes
            '''
            result = self._values.get("data_label_types")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelTypeProperty"]]]], result)

        @builtins.property
        def label_color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-labelcolor
            '''
            result = self._values.get("label_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_content(self) -> typing.Optional[builtins.str]:
            '''Determines the content of the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-labelcontent
            '''
            result = self._values.get("label_content")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"]]:
            '''Determines the font configuration of the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-labelfontconfiguration
            '''
            result = self._values.get("label_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"]], result)

        @builtins.property
        def measure_label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the measure field labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-measurelabelvisibility
            '''
            result = self._values.get("measure_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def overlap(self) -> typing.Optional[builtins.str]:
            '''Determines whether overlap is enabled or disabled for the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-overlap
            '''
            result = self._values.get("overlap")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''Determines the position of the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the total.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DataLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_path_label_type": "dataPathLabelType",
            "field_label_type": "fieldLabelType",
            "maximum_label_type": "maximumLabelType",
            "minimum_label_type": "minimumLabelType",
            "range_ends_label_type": "rangeEndsLabelType",
        },
    )
    class DataLabelTypeProperty:
        def __init__(
            self,
            *,
            data_path_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataPathLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            maximum_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MaximumLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            minimum_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MinimumLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            range_ends_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.RangeEndsLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The option that determines the data label type.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_path_label_type: The option that specifies individual data values for labels.
            :param field_label_type: Determines the label configuration for the entire field.
            :param maximum_label_type: Determines the label configuration for the maximum value in a visual.
            :param minimum_label_type: Determines the label configuration for the minimum value in a visual.
            :param range_ends_label_type: Determines the label configuration for range end value in a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_label_type_property = quicksight.CfnTemplate.DataLabelTypeProperty(
                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                        field_id="fieldId",
                        field_value="fieldValue",
                        visibility="visibility"
                    ),
                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                        field_id="fieldId",
                        visibility="visibility"
                    ),
                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                        visibility="visibility"
                    ),
                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                        visibility="visibility"
                    ),
                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5a2c695a2624499a41473f19325db50e1542d236aed1e23797015a5b582ede7b)
                check_type(argname="argument data_path_label_type", value=data_path_label_type, expected_type=type_hints["data_path_label_type"])
                check_type(argname="argument field_label_type", value=field_label_type, expected_type=type_hints["field_label_type"])
                check_type(argname="argument maximum_label_type", value=maximum_label_type, expected_type=type_hints["maximum_label_type"])
                check_type(argname="argument minimum_label_type", value=minimum_label_type, expected_type=type_hints["minimum_label_type"])
                check_type(argname="argument range_ends_label_type", value=range_ends_label_type, expected_type=type_hints["range_ends_label_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_path_label_type is not None:
                self._values["data_path_label_type"] = data_path_label_type
            if field_label_type is not None:
                self._values["field_label_type"] = field_label_type
            if maximum_label_type is not None:
                self._values["maximum_label_type"] = maximum_label_type
            if minimum_label_type is not None:
                self._values["minimum_label_type"] = minimum_label_type
            if range_ends_label_type is not None:
                self._values["range_ends_label_type"] = range_ends_label_type

        @builtins.property
        def data_path_label_type(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataPathLabelTypeProperty"]]:
            '''The option that specifies individual data values for labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-datapathlabeltype
            '''
            result = self._values.get("data_path_label_type")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataPathLabelTypeProperty"]], result)

        @builtins.property
        def field_label_type(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldLabelTypeProperty"]]:
            '''Determines the label configuration for the entire field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-fieldlabeltype
            '''
            result = self._values.get("field_label_type")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldLabelTypeProperty"]], result)

        @builtins.property
        def maximum_label_type(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MaximumLabelTypeProperty"]]:
            '''Determines the label configuration for the maximum value in a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-maximumlabeltype
            '''
            result = self._values.get("maximum_label_type")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MaximumLabelTypeProperty"]], result)

        @builtins.property
        def minimum_label_type(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MinimumLabelTypeProperty"]]:
            '''Determines the label configuration for the minimum value in a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-minimumlabeltype
            '''
            result = self._values.get("minimum_label_type")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MinimumLabelTypeProperty"]], result)

        @builtins.property
        def range_ends_label_type(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RangeEndsLabelTypeProperty"]]:
            '''Determines the label configuration for range end value in a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-rangeendslabeltype
            '''
            result = self._values.get("range_ends_label_type")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RangeEndsLabelTypeProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DataPathColorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color": "color",
            "element": "element",
            "time_granularity": "timeGranularity",
        },
    )
    class DataPathColorProperty:
        def __init__(
            self,
            *,
            color: builtins.str,
            element: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]]],
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The color map that determines the color options for a particular element.

            :param color: The color that needs to be applied to the element.
            :param element: The element that the color needs to be applied to.
            :param time_granularity: The time granularity of the field that the color needs to be applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_path_color_property = quicksight.CfnTemplate.DataPathColorProperty(
                    color="color",
                    element=quicksight.CfnTemplate.DataPathValueProperty(
                        data_path_type=quicksight.CfnTemplate.DataPathTypeProperty(
                            pivot_table_data_path_type="pivotTableDataPathType"
                        ),
                        field_id="fieldId",
                        field_value="fieldValue"
                    ),
                
                    # the properties below are optional
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__875140c1eea1717e0dde0c6d2f35478ce481e2c6d10cb3f0f56725e8efeb3734)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument element", value=element, expected_type=type_hints["element"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
                "element": element,
            }
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def color(self) -> builtins.str:
            '''The color that needs to be applied to the element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathcolor.html#cfn-quicksight-template-datapathcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataPathValueProperty"]:
            '''The element that the color needs to be applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathcolor.html#cfn-quicksight-template-datapathcolor-element
            '''
            result = self._values.get("element")
            assert result is not None, "Required property 'element' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataPathValueProperty"], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The time granularity of the field that the color needs to be applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathcolor.html#cfn-quicksight-template-datapathcolor-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DataPathLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "field_value": "fieldValue",
            "visibility": "visibility",
        },
    )
    class DataPathLabelTypeProperty:
        def __init__(
            self,
            *,
            field_id: typing.Optional[builtins.str] = None,
            field_value: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The option that specifies individual data values for labels.

            :param field_id: The field ID of the field that the data label needs to be applied to.
            :param field_value: The actual value of the field that is labeled.
            :param visibility: The visibility of the data label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_path_label_type_property = quicksight.CfnTemplate.DataPathLabelTypeProperty(
                    field_id="fieldId",
                    field_value="fieldValue",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e915c6a3fee8f8fb17440847c56eaa67dfa6df9f11721c61457cdbec37b883c6)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id
            if field_value is not None:
                self._values["field_value"] = field_value
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the field that the data label needs to be applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathlabeltype.html#cfn-quicksight-template-datapathlabeltype-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The actual value of the field that is labeled.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathlabeltype.html#cfn-quicksight-template-datapathlabeltype-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the data label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathlabeltype.html#cfn-quicksight-template-datapathlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DataPathSortProperty",
        jsii_struct_bases=[],
        name_mapping={"direction": "direction", "sort_paths": "sortPaths"},
    )
    class DataPathSortProperty:
        def __init__(
            self,
            *,
            direction: builtins.str,
            sort_paths: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''Allows data paths to be sorted by a specific data value.

            :param direction: Determines the sort direction.
            :param sort_paths: The list of data paths that need to be sorted.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_path_sort_property = quicksight.CfnTemplate.DataPathSortProperty(
                    direction="direction",
                    sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                        data_path_type=quicksight.CfnTemplate.DataPathTypeProperty(
                            pivot_table_data_path_type="pivotTableDataPathType"
                        ),
                        field_id="fieldId",
                        field_value="fieldValue"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__396225c307eed402475b3bab5089677883d3bb87f212d4d5da055e034115855b)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument sort_paths", value=sort_paths, expected_type=type_hints["sort_paths"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "sort_paths": sort_paths,
            }

        @builtins.property
        def direction(self) -> builtins.str:
            '''Determines the sort direction.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathsort.html#cfn-quicksight-template-datapathsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_paths(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataPathValueProperty"]]]:
            '''The list of data paths that need to be sorted.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathsort.html#cfn-quicksight-template-datapathsort-sortpaths
            '''
            result = self._values.get("sort_paths")
            assert result is not None, "Required property 'sort_paths' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataPathValueProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DataPathTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"pivot_table_data_path_type": "pivotTableDataPathType"},
    )
    class DataPathTypeProperty:
        def __init__(
            self,
            *,
            pivot_table_data_path_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The type of the data path value.

            :param pivot_table_data_path_type: The type of data path value utilized in a pivot table. Choose one of the following options:. - ``HIERARCHY_ROWS_LAYOUT_COLUMN`` - The type of data path for the rows layout column, when ``RowsLayout`` is set to ``HIERARCHY`` . - ``MULTIPLE_ROW_METRICS_COLUMN`` - The type of data path for the metric column when the row is set to Metric Placement. - ``EMPTY_COLUMN_HEADER`` - The type of data path for the column with empty column header, when there is no field in ``ColumnsFieldWell`` and the row is set to Metric Placement. - ``COUNT_METRIC_COLUMN`` - The type of data path for the column with ``COUNT`` as the metric, when there is no field in the ``ValuesFieldWell`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathtype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_path_type_property = quicksight.CfnTemplate.DataPathTypeProperty(
                    pivot_table_data_path_type="pivotTableDataPathType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ed5da29da1a549486e1dd3203d56e63d68b2ee2d0ff2cbaa0dceb7262206bca0)
                check_type(argname="argument pivot_table_data_path_type", value=pivot_table_data_path_type, expected_type=type_hints["pivot_table_data_path_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pivot_table_data_path_type is not None:
                self._values["pivot_table_data_path_type"] = pivot_table_data_path_type

        @builtins.property
        def pivot_table_data_path_type(self) -> typing.Optional[builtins.str]:
            '''The type of data path value utilized in a pivot table. Choose one of the following options:.

            - ``HIERARCHY_ROWS_LAYOUT_COLUMN`` - The type of data path for the rows layout column, when ``RowsLayout`` is set to ``HIERARCHY`` .
            - ``MULTIPLE_ROW_METRICS_COLUMN`` - The type of data path for the metric column when the row is set to Metric Placement.
            - ``EMPTY_COLUMN_HEADER`` - The type of data path for the column with empty column header, when there is no field in ``ColumnsFieldWell`` and the row is set to Metric Placement.
            - ``COUNT_METRIC_COLUMN`` - The type of data path for the column with ``COUNT`` as the metric, when there is no field in the ``ValuesFieldWell`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathtype.html#cfn-quicksight-template-datapathtype-pivottabledatapathtype
            '''
            result = self._values.get("pivot_table_data_path_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DataPathValueProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_path_type": "dataPathType",
            "field_id": "fieldId",
            "field_value": "fieldValue",
        },
    )
    class DataPathValueProperty:
        def __init__(
            self,
            *,
            data_path_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataPathTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_id: typing.Optional[builtins.str] = None,
            field_value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The data path that needs to be sorted.

            :param data_path_type: The type configuration of the field.
            :param field_id: The field ID of the field that needs to be sorted.
            :param field_value: The actual value of the field that needs to be sorted.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathvalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_path_value_property = quicksight.CfnTemplate.DataPathValueProperty(
                    data_path_type=quicksight.CfnTemplate.DataPathTypeProperty(
                        pivot_table_data_path_type="pivotTableDataPathType"
                    ),
                    field_id="fieldId",
                    field_value="fieldValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9e04bfec14b8d51fc22ec61aabb0b7e1834dccf8ebad59c991cb5c7766c3182f)
                check_type(argname="argument data_path_type", value=data_path_type, expected_type=type_hints["data_path_type"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_path_type is not None:
                self._values["data_path_type"] = data_path_type
            if field_id is not None:
                self._values["field_id"] = field_id
            if field_value is not None:
                self._values["field_value"] = field_value

        @builtins.property
        def data_path_type(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataPathTypeProperty"]]:
            '''The type configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathvalue.html#cfn-quicksight-template-datapathvalue-datapathtype
            '''
            result = self._values.get("data_path_type")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataPathTypeProperty"]], result)

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the field that needs to be sorted.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathvalue.html#cfn-quicksight-template-datapathvalue-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The actual value of the field that needs to be sorted.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathvalue.html#cfn-quicksight-template-datapathvalue-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DataSetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_group_schema_list": "columnGroupSchemaList",
            "data_set_schema": "dataSetSchema",
            "placeholder": "placeholder",
        },
    )
    class DataSetConfigurationProperty:
        def __init__(
            self,
            *,
            column_group_schema_list: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnGroupSchemaProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_set_schema: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataSetSchemaProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            placeholder: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Dataset configuration.

            :param column_group_schema_list: A structure containing the list of column group schemas.
            :param data_set_schema: Dataset schema.
            :param placeholder: Placeholder.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_set_configuration_property = quicksight.CfnTemplate.DataSetConfigurationProperty(
                    column_group_schema_list=[quicksight.CfnTemplate.ColumnGroupSchemaProperty(
                        column_group_column_schema_list=[quicksight.CfnTemplate.ColumnGroupColumnSchemaProperty(
                            name="name"
                        )],
                        name="name"
                    )],
                    data_set_schema=quicksight.CfnTemplate.DataSetSchemaProperty(
                        column_schema_list=[quicksight.CfnTemplate.ColumnSchemaProperty(
                            data_type="dataType",
                            geographic_role="geographicRole",
                            name="name"
                        )]
                    ),
                    placeholder="placeholder"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a1883bfbe02ab6abc3619f987f1929794734a4c1721bdb4b1889c825c189b119)
                check_type(argname="argument column_group_schema_list", value=column_group_schema_list, expected_type=type_hints["column_group_schema_list"])
                check_type(argname="argument data_set_schema", value=data_set_schema, expected_type=type_hints["data_set_schema"])
                check_type(argname="argument placeholder", value=placeholder, expected_type=type_hints["placeholder"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_group_schema_list is not None:
                self._values["column_group_schema_list"] = column_group_schema_list
            if data_set_schema is not None:
                self._values["data_set_schema"] = data_set_schema
            if placeholder is not None:
                self._values["placeholder"] = placeholder

        @builtins.property
        def column_group_schema_list(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnGroupSchemaProperty"]]]]:
            '''A structure containing the list of column group schemas.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetconfiguration.html#cfn-quicksight-template-datasetconfiguration-columngroupschemalist
            '''
            result = self._values.get("column_group_schema_list")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnGroupSchemaProperty"]]]], result)

        @builtins.property
        def data_set_schema(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataSetSchemaProperty"]]:
            '''Dataset schema.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetconfiguration.html#cfn-quicksight-template-datasetconfiguration-datasetschema
            '''
            result = self._values.get("data_set_schema")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataSetSchemaProperty"]], result)

        @builtins.property
        def placeholder(self) -> typing.Optional[builtins.str]:
            '''Placeholder.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetconfiguration.html#cfn-quicksight-template-datasetconfiguration-placeholder
            '''
            result = self._values.get("placeholder")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DataSetReferenceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_arn": "dataSetArn",
            "data_set_placeholder": "dataSetPlaceholder",
        },
    )
    class DataSetReferenceProperty:
        def __init__(
            self,
            *,
            data_set_arn: builtins.str,
            data_set_placeholder: builtins.str,
        ) -> None:
            '''Dataset reference.

            :param data_set_arn: Dataset Amazon Resource Name (ARN).
            :param data_set_placeholder: Dataset placeholder.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetreference.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_set_reference_property = quicksight.CfnTemplate.DataSetReferenceProperty(
                    data_set_arn="dataSetArn",
                    data_set_placeholder="dataSetPlaceholder"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__34cd250355f66ef094f8bf4236684b609cc82a0ab91d166a45fcd715895d9213)
                check_type(argname="argument data_set_arn", value=data_set_arn, expected_type=type_hints["data_set_arn"])
                check_type(argname="argument data_set_placeholder", value=data_set_placeholder, expected_type=type_hints["data_set_placeholder"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_arn": data_set_arn,
                "data_set_placeholder": data_set_placeholder,
            }

        @builtins.property
        def data_set_arn(self) -> builtins.str:
            '''Dataset Amazon Resource Name (ARN).

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetreference.html#cfn-quicksight-template-datasetreference-datasetarn
            '''
            result = self._values.get("data_set_arn")
            assert result is not None, "Required property 'data_set_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_placeholder(self) -> builtins.str:
            '''Dataset placeholder.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetreference.html#cfn-quicksight-template-datasetreference-datasetplaceholder
            '''
            result = self._values.get("data_set_placeholder")
            assert result is not None, "Required property 'data_set_placeholder' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetReferenceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DataSetSchemaProperty",
        jsii_struct_bases=[],
        name_mapping={"column_schema_list": "columnSchemaList"},
    )
    class DataSetSchemaProperty:
        def __init__(
            self,
            *,
            column_schema_list: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnSchemaProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''Dataset schema.

            :param column_schema_list: A structure containing the list of column schemas.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetschema.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_set_schema_property = quicksight.CfnTemplate.DataSetSchemaProperty(
                    column_schema_list=[quicksight.CfnTemplate.ColumnSchemaProperty(
                        data_type="dataType",
                        geographic_role="geographicRole",
                        name="name"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__10cdddf57a0e8c0c6d38148ff644fd1761ea7e573a8bf58d1c5f843806763533)
                check_type(argname="argument column_schema_list", value=column_schema_list, expected_type=type_hints["column_schema_list"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_schema_list is not None:
                self._values["column_schema_list"] = column_schema_list

        @builtins.property
        def column_schema_list(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnSchemaProperty"]]]]:
            '''A structure containing the list of column schemas.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetschema.html#cfn-quicksight-template-datasetschema-columnschemalist
            '''
            result = self._values.get("column_schema_list")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnSchemaProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetSchemaProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DateAxisOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"missing_date_visibility": "missingDateVisibility"},
    )
    class DateAxisOptionsProperty:
        def __init__(
            self,
            *,
            missing_date_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine how a date axis is displayed.

            :param missing_date_visibility: Determines whether or not missing dates are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dateaxisoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_axis_options_property = quicksight.CfnTemplate.DateAxisOptionsProperty(
                    missing_date_visibility="missingDateVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f8b27489657993a2a6782e22027de3b6151ece013bdbf8b293ea6ad0d97a9ca5)
                check_type(argname="argument missing_date_visibility", value=missing_date_visibility, expected_type=type_hints["missing_date_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if missing_date_visibility is not None:
                self._values["missing_date_visibility"] = missing_date_visibility

        @builtins.property
        def missing_date_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not missing dates are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dateaxisoptions.html#cfn-quicksight-template-dateaxisoptions-missingdatevisibility
            '''
            result = self._values.get("missing_date_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateAxisOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DateDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "date_granularity": "dateGranularity",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class DateDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            date_granularity: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with date type columns.

            :param column: The column that is used in the ``DateDimensionField`` .
            :param field_id: The custom field ID.
            :param date_granularity: The date granularity of the ``DateDimensionField`` . Choose one of the following options:. - ``YEAR`` - ``QUARTER`` - ``MONTH`` - ``WEEK`` - ``DAY`` - ``HOUR`` - ``MINUTE`` - ``SECOND`` - ``MILLISECOND``
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_dimension_field_property = quicksight.CfnTemplate.DateDimensionFieldProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    date_granularity="dateGranularity",
                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__31435b58c08934e7951a43c6c56ee1fcd395dde36a0f48329da06d3830b326d7)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument date_granularity", value=date_granularity, expected_type=type_hints["date_granularity"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if date_granularity is not None:
                self._values["date_granularity"] = date_granularity
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that is used in the ``DateDimensionField`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def date_granularity(self) -> typing.Optional[builtins.str]:
            '''The date granularity of the ``DateDimensionField`` . Choose one of the following options:.

            - ``YEAR``
            - ``QUARTER``
            - ``MONTH``
            - ``WEEK``
            - ``DAY``
            - ``HOUR``
            - ``MINUTE``
            - ``SECOND``
            - ``MILLISECOND``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-dategranularity
            '''
            result = self._values.get("date_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateTimeFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateTimeFormatConfigurationProperty"]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DateMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class DateMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            aggregation_function: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure type field with date type columns.

            :param column: The column that is used in the ``DateMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_measure_field_property = quicksight.CfnTemplate.DateMeasureFieldProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function="aggregationFunction",
                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1560ba41f7285670910c317ea264e0b72a9dc7e42e9e4ad580d57634e2f7194c)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that is used in the ``DateMeasureField`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html#cfn-quicksight-template-datemeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html#cfn-quicksight-template-datemeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(self) -> typing.Optional[builtins.str]:
            '''The aggregation function of the measure field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html#cfn-quicksight-template-datemeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateTimeFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html#cfn-quicksight-template-datemeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateTimeFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DateTimeDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "rolling_date": "rollingDate",
            "static_values": "staticValues",
        },
    )
    class DateTimeDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rolling_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.RollingDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The default values of the ``DateTimeParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``DataTimeDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param rolling_date: The rolling date of the ``DataTimeDefaultValues`` . The date is determined from the dataset based on input expression.
            :param static_values: The static values of the ``DataTimeDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimedefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_default_values_property = quicksight.CfnTemplate.DateTimeDefaultValuesProperty(
                    dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                        expression="expression",
                
                        # the properties below are optional
                        data_set_identifier="dataSetIdentifier"
                    ),
                    static_values=["staticValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f32fc19f4c057c2a2cbe06f9b32ff5b6625ca952a5caac9b5677fddfac39ce7b)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument rolling_date", value=rolling_date, expected_type=type_hints["rolling_date"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if rolling_date is not None:
                self._values["rolling_date"] = rolling_date
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``DataTimeDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimedefaultvalues.html#cfn-quicksight-template-datetimedefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def rolling_date(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RollingDateConfigurationProperty"]]:
            '''The rolling date of the ``DataTimeDefaultValues`` .

            The date is determined from the dataset based on input expression.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimedefaultvalues.html#cfn-quicksight-template-datetimedefaultvalues-rollingdate
            '''
            result = self._values.get("rolling_date")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RollingDateConfigurationProperty"]], result)

        @builtins.property
        def static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The static values of the ``DataTimeDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimedefaultvalues.html#cfn-quicksight-template-datetimedefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DateTimeFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "numeric_format_configuration": "numericFormatConfiguration",
        },
    )
    class DateTimeFormatConfigurationProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Formatting configuration for ``DateTime`` fields.

            :param date_time_format: Determines the ``DateTime`` format.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param numeric_format_configuration: The formatting configuration for numeric ``DateTime`` fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_format_configuration_property = quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                    date_time_format="dateTimeFormat",
                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__387218ed9131df4da4fcec10b97b56411a8744d9a8aca0113505e7554ce63bb8)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument numeric_format_configuration", value=numeric_format_configuration, expected_type=type_hints["numeric_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if numeric_format_configuration is not None:
                self._values["numeric_format_configuration"] = numeric_format_configuration

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Determines the ``DateTime`` format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeformatconfiguration.html#cfn-quicksight-template-datetimeformatconfiguration-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeformatconfiguration.html#cfn-quicksight-template-datetimeformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def numeric_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericFormatConfigurationProperty"]]:
            '''The formatting configuration for numeric ``DateTime`` fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeformatconfiguration.html#cfn-quicksight-template-datetimeformatconfiguration-numericformatconfiguration
            '''
            result = self._values.get("numeric_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DateTimeHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class DateTimeHierarchyProperty:
        def __init__(
            self,
            *,
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of any ``DateTime`` fields.

            :param hierarchy_id: The hierarchy ID of the ``DateTime`` hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the ``DateTime`` hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimehierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_hierarchy_property = quicksight.CfnTemplate.DateTimeHierarchyProperty(
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__600db28efb4756d643dc84db6d6354a66d6ac2b3b8d315e5cea7bf832e5109e3)
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the ``DateTime`` hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimehierarchy.html#cfn-quicksight-template-datetimehierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DrillDownFilterProperty"]]]]:
            '''The option that determines the drill down filters for the ``DateTime`` hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimehierarchy.html#cfn-quicksight-template-datetimehierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DrillDownFilterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DateTimeParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "time_granularity": "timeGranularity",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class DateTimeParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DateTimeDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
            value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``DateTime`` data type.

            :param name: The name of the parameter that is being declared.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: 
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param value_when_unset: The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_parameter_declaration_property = quicksight.CfnTemplate.DateTimeParameterDeclarationProperty(
                    name="name",
                
                    # the properties below are optional
                    default_values=quicksight.CfnTemplate.DateTimeDefaultValuesProperty(
                        dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_values=["staticValues"]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    time_granularity="timeGranularity",
                    value_when_unset=quicksight.CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty(
                        custom_value="customValue",
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7bb94cd6032e3f0506aff5592e90e5d72b9057c51c0d9a67a286464b6014282e)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateTimeDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateTimeDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MappedDataSetParameterProperty"]]]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty"]]:
            '''The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "info_icon_label_options": "infoIconLabelOptions",
            "title_options": "titleOptions",
        },
    )
    class DateTimePickerControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SheetControlInfoIconLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param date_time_format: Customize how dates are formatted in controls.
            :param info_icon_label_options: The configuration of info icon label options.
            :param title_options: The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimepickercontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_picker_control_display_options_property = quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                    date_time_format="dateTimeFormat",
                    info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                        info_icon_text="infoIconText",
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__400fad16d79e9b1c8c236281649c4f38d0175ad36cdf6096c1aed88d8dcb7ec4)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument info_icon_label_options", value=info_icon_label_options, expected_type=type_hints["info_icon_label_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if info_icon_label_options is not None:
                self._values["info_icon_label_options"] = info_icon_label_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Customize how dates are formatted in controls.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimepickercontroldisplayoptions.html#cfn-quicksight-template-datetimepickercontroldisplayoptions-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def info_icon_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetControlInfoIconLabelOptionsProperty"]]:
            '''The configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimepickercontroldisplayoptions.html#cfn-quicksight-template-datetimepickercontroldisplayoptions-infoiconlabeloptions
            '''
            result = self._values.get("info_icon_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetControlInfoIconLabelOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimepickercontroldisplayoptions.html#cfn-quicksight-template-datetimepickercontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimePickerControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class DateTimeValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[builtins.str] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimevaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                date_time_value_when_unset_configuration_property = quicksight.CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty(
                    custom_value="customValue",
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0254d2d507667662407f4476fb9cbdd31864d55ad69a3ddf1a8a132fc4c239d2)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[builtins.str]:
            '''A custom value that's used when the value of a parameter isn't set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-template-datetimevaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-template-datetimevaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DecimalDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class DecimalDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
        ) -> None:
            '''The default values of the ``DecimalParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``DecimalDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``DecimalDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimaldefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                decimal_default_values_property = quicksight.CfnTemplate.DecimalDefaultValuesProperty(
                    dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__45c7bd4f87aaf9d9ad0cd787bf00b8b8217df5ca1f83b1f04d64acd006150015)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``DecimalDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimaldefaultvalues.html#cfn-quicksight-template-decimaldefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def static_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]]:
            '''The static values of the ``DecimalDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimaldefaultvalues.html#cfn-quicksight-template-decimaldefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DecimalParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class DecimalParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DecimalDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DecimalValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``Decimal`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: 
            :param value_when_unset: The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                decimal_parameter_declaration_property = quicksight.CfnTemplate.DecimalParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnTemplate.DecimalDefaultValuesProperty(
                        dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=[123]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnTemplate.DecimalValueWhenUnsetConfigurationProperty(
                        custom_value=123,
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__595364948f9e14a42bc42f9d12a4ef1943a83410f2b89a407e171d4ccaf9bb89)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DecimalDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DecimalDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MappedDataSetParameterProperty"]]]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DecimalValueWhenUnsetConfigurationProperty"]]:
            '''The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DecimalValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DecimalPlacesConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"decimal_places": "decimalPlaces"},
    )
    class DecimalPlacesConfigurationProperty:
        def __init__(self, *, decimal_places: jsii.Number) -> None:
            '''The option that determines the decimal places configuration.

            :param decimal_places: The values of the decimal places.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalplacesconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                decimal_places_configuration_property = quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                    decimal_places=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a36a9620eb65337911b054129318b32487f923ee6fdd603b127c4635f300a72c)
                check_type(argname="argument decimal_places", value=decimal_places, expected_type=type_hints["decimal_places"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "decimal_places": decimal_places,
            }

        @builtins.property
        def decimal_places(self) -> jsii.Number:
            '''The values of the decimal places.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalplacesconfiguration.html#cfn-quicksight-template-decimalplacesconfiguration-decimalplaces
            '''
            result = self._values.get("decimal_places")
            assert result is not None, "Required property 'decimal_places' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalPlacesConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DecimalValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class DecimalValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[jsii.Number] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalvaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                decimal_value_when_unset_configuration_property = quicksight.CfnTemplate.DecimalValueWhenUnsetConfigurationProperty(
                    custom_value=123,
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9078977010fb2b1821bab1c11791be7229453b880f6a7a115450ac49a63061a7)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[jsii.Number]:
            '''A custom value that's used when the value of a parameter isn't set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-template-decimalvaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-template-decimalvaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DefaultFreeFormLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultFreeFormLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The options that determine the default settings of a free-form layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultfreeformlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                default_free_form_layout_configuration_property = quicksight.CfnTemplate.DefaultFreeFormLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6311f9cbc866df56f8e45d5a24ebc39e460605ec4cb5a25a249eba4411cf4a11)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty"]:
            '''Determines the screen canvas size options for a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultfreeformlayoutconfiguration.html#cfn-quicksight-template-defaultfreeformlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultFreeFormLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DefaultGridLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultGridLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GridLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The options that determine the default settings for a grid layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a grid layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultgridlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                default_grid_layout_configuration_property = quicksight.CfnTemplate.DefaultGridLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                            resize_option="resizeOption",
                
                            # the properties below are optional
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4e175e3d68e389ce0a28a8c0c694123c6f30db22c4842f99ef70f2e09a22fca3)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.GridLayoutCanvasSizeOptionsProperty"]:
            '''Determines the screen canvas size options for a grid layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultgridlayoutconfiguration.html#cfn-quicksight-template-defaultgridlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.GridLayoutCanvasSizeOptionsProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultGridLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DefaultInteractiveLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"free_form": "freeForm", "grid": "grid"},
    )
    class DefaultInteractiveLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DefaultFreeFormLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            grid: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DefaultGridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the default settings for interactive layout configuration.

            :param free_form: The options that determine the default settings of a free-form layout configuration.
            :param grid: The options that determine the default settings for a grid layout configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultinteractivelayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                default_interactive_layout_configuration_property = quicksight.CfnTemplate.DefaultInteractiveLayoutConfigurationProperty(
                    free_form=quicksight.CfnTemplate.DefaultFreeFormLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    grid=quicksight.CfnTemplate.DefaultGridLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dc0e4bcc549de7ff742e72d1a317d01c1ac1a833d76c9964255ca15a86d34f9e)
                check_type(argname="argument free_form", value=free_form, expected_type=type_hints["free_form"])
                check_type(argname="argument grid", value=grid, expected_type=type_hints["grid"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if free_form is not None:
                self._values["free_form"] = free_form
            if grid is not None:
                self._values["grid"] = grid

        @builtins.property
        def free_form(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DefaultFreeFormLayoutConfigurationProperty"]]:
            '''The options that determine the default settings of a free-form layout configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultinteractivelayoutconfiguration.html#cfn-quicksight-template-defaultinteractivelayoutconfiguration-freeform
            '''
            result = self._values.get("free_form")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DefaultFreeFormLayoutConfigurationProperty"]], result)

        @builtins.property
        def grid(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DefaultGridLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for a grid layout configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultinteractivelayoutconfiguration.html#cfn-quicksight-template-defaultinteractivelayoutconfiguration-grid
            '''
            result = self._values.get("grid")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DefaultGridLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultInteractiveLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DefaultNewSheetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "interactive_layout_configuration": "interactiveLayoutConfiguration",
            "paginated_layout_configuration": "paginatedLayoutConfiguration",
            "sheet_content_type": "sheetContentType",
        },
    )
    class DefaultNewSheetConfigurationProperty:
        def __init__(
            self,
            *,
            interactive_layout_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DefaultInteractiveLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paginated_layout_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DefaultPaginatedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sheet_content_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration for default new sheet settings.

            :param interactive_layout_configuration: The options that determine the default settings for interactive layout configuration.
            :param paginated_layout_configuration: The options that determine the default settings for a paginated layout configuration.
            :param sheet_content_type: The option that determines the sheet content type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultnewsheetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                default_new_sheet_configuration_property = quicksight.CfnTemplate.DefaultNewSheetConfigurationProperty(
                    interactive_layout_configuration=quicksight.CfnTemplate.DefaultInteractiveLayoutConfigurationProperty(
                        free_form=quicksight.CfnTemplate.DefaultFreeFormLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        grid=quicksight.CfnTemplate.DefaultGridLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        )
                    ),
                    paginated_layout_configuration=quicksight.CfnTemplate.DefaultPaginatedLayoutConfigurationProperty(
                        section_based=quicksight.CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                    paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    ),
                                    paper_orientation="paperOrientation",
                                    paper_size="paperSize"
                                )
                            )
                        )
                    ),
                    sheet_content_type="sheetContentType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bfbd48cfb6718d17dcabb693158d2c948bd3c00fc1e034a03154a5ab48ccec67)
                check_type(argname="argument interactive_layout_configuration", value=interactive_layout_configuration, expected_type=type_hints["interactive_layout_configuration"])
                check_type(argname="argument paginated_layout_configuration", value=paginated_layout_configuration, expected_type=type_hints["paginated_layout_configuration"])
                check_type(argname="argument sheet_content_type", value=sheet_content_type, expected_type=type_hints["sheet_content_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if interactive_layout_configuration is not None:
                self._values["interactive_layout_configuration"] = interactive_layout_configuration
            if paginated_layout_configuration is not None:
                self._values["paginated_layout_configuration"] = paginated_layout_configuration
            if sheet_content_type is not None:
                self._values["sheet_content_type"] = sheet_content_type

        @builtins.property
        def interactive_layout_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DefaultInteractiveLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for interactive layout configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultnewsheetconfiguration.html#cfn-quicksight-template-defaultnewsheetconfiguration-interactivelayoutconfiguration
            '''
            result = self._values.get("interactive_layout_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DefaultInteractiveLayoutConfigurationProperty"]], result)

        @builtins.property
        def paginated_layout_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DefaultPaginatedLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for a paginated layout configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultnewsheetconfiguration.html#cfn-quicksight-template-defaultnewsheetconfiguration-paginatedlayoutconfiguration
            '''
            result = self._values.get("paginated_layout_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DefaultPaginatedLayoutConfigurationProperty"]], result)

        @builtins.property
        def sheet_content_type(self) -> typing.Optional[builtins.str]:
            '''The option that determines the sheet content type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultnewsheetconfiguration.html#cfn-quicksight-template-defaultnewsheetconfiguration-sheetcontenttype
            '''
            result = self._values.get("sheet_content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultNewSheetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DefaultPaginatedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"section_based": "sectionBased"},
    )
    class DefaultPaginatedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            section_based: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the default settings for a paginated layout configuration.

            :param section_based: The options that determine the default settings for a section-based layout configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultpaginatedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                default_paginated_layout_configuration_property = quicksight.CfnTemplate.DefaultPaginatedLayoutConfigurationProperty(
                    section_based=quicksight.CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                            paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                ),
                                paper_orientation="paperOrientation",
                                paper_size="paperSize"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c131b4d9a2aa5b67ba6b274e56c0d1988d073ae28c95adf8fa0d6ff4701859c3)
                check_type(argname="argument section_based", value=section_based, expected_type=type_hints["section_based"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if section_based is not None:
                self._values["section_based"] = section_based

        @builtins.property
        def section_based(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for a section-based layout configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultpaginatedlayoutconfiguration.html#cfn-quicksight-template-defaultpaginatedlayoutconfiguration-sectionbased
            '''
            result = self._values.get("section_based")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultPaginatedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultSectionBasedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The options that determine the default settings for a section-based layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a section-based layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultsectionbasedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                default_section_based_layout_configuration_property = quicksight.CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                        paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                            paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            ),
                            paper_orientation="paperOrientation",
                            paper_size="paperSize"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e8f9186cb96df41c5b157940c7c99eaaa2ea37b15cc111e51340895cad7eda06)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty"]:
            '''Determines the screen canvas size options for a section-based layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultsectionbasedlayoutconfiguration.html#cfn-quicksight-template-defaultsectionbasedlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultSectionBasedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_values_configuration": "customValuesConfiguration",
            "select_all_value_options": "selectAllValueOptions",
            "source_column": "sourceColumn",
            "source_field": "sourceField",
            "source_parameter_name": "sourceParameterName",
        },
    )
    class DestinationParameterValueConfigurationProperty:
        def __init__(
            self,
            *,
            custom_values_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CustomValuesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            select_all_value_options: typing.Optional[builtins.str] = None,
            source_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            source_field: typing.Optional[builtins.str] = None,
            source_parameter_name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of destination parameter values.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_values_configuration: The configuration of custom values for destination parameter in ``DestinationParameterValueConfiguration`` .
            :param select_all_value_options: The configuration that selects all options.
            :param source_column: 
            :param source_field: The source field ID of the destination parameter.
            :param source_parameter_name: The source parameter name of the destination parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                destination_parameter_value_configuration_property = quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                            date_time_values=["dateTimeValues"],
                            decimal_values=[123],
                            integer_values=[123],
                            string_values=["stringValues"]
                        ),
                
                        # the properties below are optional
                        include_null_value=False
                    ),
                    select_all_value_options="selectAllValueOptions",
                    source_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    source_field="sourceField",
                    source_parameter_name="sourceParameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aba08da7d814b258ff3e2e6d34cda7b9dddd4b57f89d611e1c57af10391aaaa4)
                check_type(argname="argument custom_values_configuration", value=custom_values_configuration, expected_type=type_hints["custom_values_configuration"])
                check_type(argname="argument select_all_value_options", value=select_all_value_options, expected_type=type_hints["select_all_value_options"])
                check_type(argname="argument source_column", value=source_column, expected_type=type_hints["source_column"])
                check_type(argname="argument source_field", value=source_field, expected_type=type_hints["source_field"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_values_configuration is not None:
                self._values["custom_values_configuration"] = custom_values_configuration
            if select_all_value_options is not None:
                self._values["select_all_value_options"] = select_all_value_options
            if source_column is not None:
                self._values["source_column"] = source_column
            if source_field is not None:
                self._values["source_field"] = source_field
            if source_parameter_name is not None:
                self._values["source_parameter_name"] = source_parameter_name

        @builtins.property
        def custom_values_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomValuesConfigurationProperty"]]:
            '''The configuration of custom values for destination parameter in ``DestinationParameterValueConfiguration`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-customvaluesconfiguration
            '''
            result = self._values.get("custom_values_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomValuesConfigurationProperty"]], result)

        @builtins.property
        def select_all_value_options(self) -> typing.Optional[builtins.str]:
            '''The configuration that selects all options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-selectallvalueoptions
            '''
            result = self._values.get("select_all_value_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def source_column(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-sourcecolumn
            '''
            result = self._values.get("source_column")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]], result)

        @builtins.property
        def source_field(self) -> typing.Optional[builtins.str]:
            '''The source field ID of the destination parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-sourcefield
            '''
            result = self._values.get("source_field")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def source_parameter_name(self) -> typing.Optional[builtins.str]:
            '''The source parameter name of the destination parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DestinationParameterValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "categorical_dimension_field": "categoricalDimensionField",
            "date_dimension_field": "dateDimensionField",
            "numerical_dimension_field": "numericalDimensionField",
        },
    )
    class DimensionFieldProperty:
        def __init__(
            self,
            *,
            categorical_dimension_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CategoricalDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            date_dimension_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DateDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numerical_dimension_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumericalDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The dimension type field.

            :param categorical_dimension_field: The dimension type field with categorical type columns.
            :param date_dimension_field: The dimension type field with date type columns.
            :param numerical_dimension_field: The dimension type field with numerical type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                dimension_field_property = quicksight.CfnTemplate.DimensionFieldProperty(
                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    ),
                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        date_granularity="dateGranularity",
                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    ),
                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b8c02c72897035f8e1fca272cd87bf2ea0a4a02c584ea26677bf58a3ce1e72f8)
                check_type(argname="argument categorical_dimension_field", value=categorical_dimension_field, expected_type=type_hints["categorical_dimension_field"])
                check_type(argname="argument date_dimension_field", value=date_dimension_field, expected_type=type_hints["date_dimension_field"])
                check_type(argname="argument numerical_dimension_field", value=numerical_dimension_field, expected_type=type_hints["numerical_dimension_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if categorical_dimension_field is not None:
                self._values["categorical_dimension_field"] = categorical_dimension_field
            if date_dimension_field is not None:
                self._values["date_dimension_field"] = date_dimension_field
            if numerical_dimension_field is not None:
                self._values["numerical_dimension_field"] = numerical_dimension_field

        @builtins.property
        def categorical_dimension_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CategoricalDimensionFieldProperty"]]:
            '''The dimension type field with categorical type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dimensionfield.html#cfn-quicksight-template-dimensionfield-categoricaldimensionfield
            '''
            result = self._values.get("categorical_dimension_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CategoricalDimensionFieldProperty"]], result)

        @builtins.property
        def date_dimension_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateDimensionFieldProperty"]]:
            '''The dimension type field with date type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dimensionfield.html#cfn-quicksight-template-dimensionfield-datedimensionfield
            '''
            result = self._values.get("date_dimension_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateDimensionFieldProperty"]], result)

        @builtins.property
        def numerical_dimension_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericalDimensionFieldProperty"]]:
            '''The dimension type field with numerical type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dimensionfield.html#cfn-quicksight-template-dimensionfield-numericaldimensionfield
            '''
            result = self._values.get("numerical_dimension_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericalDimensionFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DonutCenterOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"label_visibility": "labelVisibility"},
    )
    class DonutCenterOptionsProperty:
        def __init__(
            self,
            *,
            label_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label options of the label that is displayed in the center of a donut chart.

            This option isn't available for pie charts.

            :param label_visibility: Determines the visibility of the label in a donut chart. In the Amazon QuickSight console, this option is called ``'Show total'`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutcenteroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                donut_center_options_property = quicksight.CfnTemplate.DonutCenterOptionsProperty(
                    label_visibility="labelVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a2d100bdafc76427866ae8213c38f91a2ac406357a5a3b4abec6643d68778ec0)
                check_type(argname="argument label_visibility", value=label_visibility, expected_type=type_hints["label_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if label_visibility is not None:
                self._values["label_visibility"] = label_visibility

        @builtins.property
        def label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the label in a donut chart.

            In the Amazon QuickSight console, this option is called ``'Show total'`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutcenteroptions.html#cfn-quicksight-template-donutcenteroptions-labelvisibility
            '''
            result = self._values.get("label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DonutCenterOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DonutOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arc_options": "arcOptions",
            "donut_center_options": "donutCenterOptions",
        },
    )
    class DonutOptionsProperty:
        def __init__(
            self,
            *,
            arc_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ArcOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            donut_center_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DonutCenterOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options for configuring a donut chart or pie chart.

            :param arc_options: The option for define the arc of the chart shape. Valid values are as follows:. - ``WHOLE`` - A pie chart - ``SMALL`` - A small-sized donut chart - ``MEDIUM`` - A medium-sized donut chart - ``LARGE`` - A large-sized donut chart
            :param donut_center_options: The label options of the label that is displayed in the center of a donut chart. This option isn't available for pie charts.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                donut_options_property = quicksight.CfnTemplate.DonutOptionsProperty(
                    arc_options=quicksight.CfnTemplate.ArcOptionsProperty(
                        arc_thickness="arcThickness"
                    ),
                    donut_center_options=quicksight.CfnTemplate.DonutCenterOptionsProperty(
                        label_visibility="labelVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c393b70dce31f5ff171ea97ce085d14fd9f0ab5ce5b054f145ceeff13ae0115f)
                check_type(argname="argument arc_options", value=arc_options, expected_type=type_hints["arc_options"])
                check_type(argname="argument donut_center_options", value=donut_center_options, expected_type=type_hints["donut_center_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_options is not None:
                self._values["arc_options"] = arc_options
            if donut_center_options is not None:
                self._values["donut_center_options"] = donut_center_options

        @builtins.property
        def arc_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ArcOptionsProperty"]]:
            '''The option for define the arc of the chart shape. Valid values are as follows:.

            - ``WHOLE`` - A pie chart
            - ``SMALL`` - A small-sized donut chart
            - ``MEDIUM`` - A medium-sized donut chart
            - ``LARGE`` - A large-sized donut chart

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutoptions.html#cfn-quicksight-template-donutoptions-arcoptions
            '''
            result = self._values.get("arc_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ArcOptionsProperty"]], result)

        @builtins.property
        def donut_center_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DonutCenterOptionsProperty"]]:
            '''The label options of the label that is displayed in the center of a donut chart.

            This option isn't available for pie charts.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutoptions.html#cfn-quicksight-template-donutoptions-donutcenteroptions
            '''
            result = self._values.get("donut_center_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DonutCenterOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DonutOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_filter": "categoryFilter",
            "numeric_equality_filter": "numericEqualityFilter",
            "time_range_filter": "timeRangeFilter",
        },
    )
    class DrillDownFilterProperty:
        def __init__(
            self,
            *,
            category_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CategoryDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_equality_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumericEqualityDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TimeRangeDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The drill down filter for the column hierarchies.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param category_filter: The category type drill down filter. This filter is used for string type columns.
            :param numeric_equality_filter: The numeric equality type drill down filter. This filter is used for number type columns.
            :param time_range_filter: The time range drill down filter. This filter is used for date time columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-drilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                drill_down_filter_property = quicksight.CfnTemplate.DrillDownFilterProperty(
                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                        category_values=["categoryValues"],
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        value=123
                    ),
                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        range_maximum="rangeMaximum",
                        range_minimum="rangeMinimum",
                        time_granularity="timeGranularity"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0b087350cd5169d11c01b910bfb40bae0cce5811b1dfe5656a5c56c36e021017)
                check_type(argname="argument category_filter", value=category_filter, expected_type=type_hints["category_filter"])
                check_type(argname="argument numeric_equality_filter", value=numeric_equality_filter, expected_type=type_hints["numeric_equality_filter"])
                check_type(argname="argument time_range_filter", value=time_range_filter, expected_type=type_hints["time_range_filter"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_filter is not None:
                self._values["category_filter"] = category_filter
            if numeric_equality_filter is not None:
                self._values["numeric_equality_filter"] = numeric_equality_filter
            if time_range_filter is not None:
                self._values["time_range_filter"] = time_range_filter

        @builtins.property
        def category_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CategoryDrillDownFilterProperty"]]:
            '''The category type drill down filter.

            This filter is used for string type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-drilldownfilter.html#cfn-quicksight-template-drilldownfilter-categoryfilter
            '''
            result = self._values.get("category_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CategoryDrillDownFilterProperty"]], result)

        @builtins.property
        def numeric_equality_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericEqualityDrillDownFilterProperty"]]:
            '''The numeric equality type drill down filter.

            This filter is used for number type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-drilldownfilter.html#cfn-quicksight-template-drilldownfilter-numericequalityfilter
            '''
            result = self._values.get("numeric_equality_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericEqualityDrillDownFilterProperty"]], result)

        @builtins.property
        def time_range_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TimeRangeDrillDownFilterProperty"]]:
            '''The time range drill down filter.

            This filter is used for date time columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-drilldownfilter.html#cfn-quicksight-template-drilldownfilter-timerangefilter
            '''
            result = self._values.get("time_range_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TimeRangeDrillDownFilterProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "info_icon_label_options": "infoIconLabelOptions",
            "select_all_options": "selectAllOptions",
            "title_options": "titleOptions",
        },
    )
    class DropDownControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SheetControlInfoIconLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            select_all_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ListControlSelectAllOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param info_icon_label_options: The configuration of info icon label options.
            :param select_all_options: The configuration of the ``Select all`` options in a dropdown control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dropdowncontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                drop_down_control_display_options_property = quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                    info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                        info_icon_text="infoIconText",
                        visibility="visibility"
                    ),
                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__063246ac8fd75fc93cf7d4ee5b4eade385b65be86925075f9cf31fc664213706)
                check_type(argname="argument info_icon_label_options", value=info_icon_label_options, expected_type=type_hints["info_icon_label_options"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if info_icon_label_options is not None:
                self._values["info_icon_label_options"] = info_icon_label_options
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def info_icon_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetControlInfoIconLabelOptionsProperty"]]:
            '''The configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dropdowncontroldisplayoptions.html#cfn-quicksight-template-dropdowncontroldisplayoptions-infoiconlabeloptions
            '''
            result = self._values.get("info_icon_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetControlInfoIconLabelOptionsProperty"]], result)

        @builtins.property
        def select_all_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ListControlSelectAllOptionsProperty"]]:
            '''The configuration of the ``Select all`` options in a dropdown control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dropdowncontroldisplayoptions.html#cfn-quicksight-template-dropdowncontroldisplayoptions-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ListControlSelectAllOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dropdowncontroldisplayoptions.html#cfn-quicksight-template-dropdowncontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DropDownControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.DynamicDefaultValueProperty",
        jsii_struct_bases=[],
        name_mapping={
            "default_value_column": "defaultValueColumn",
            "group_name_column": "groupNameColumn",
            "user_name_column": "userNameColumn",
        },
    )
    class DynamicDefaultValueProperty:
        def __init__(
            self,
            *,
            default_value_column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            group_name_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            user_name_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Defines different defaults to the users or groups based on mapping.

            :param default_value_column: The column that contains the default value of each user or group.
            :param group_name_column: The column that contains the group name.
            :param user_name_column: The column that contains the username.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dynamicdefaultvalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                dynamic_default_value_property = quicksight.CfnTemplate.DynamicDefaultValueProperty(
                    default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a4d28086b7a8945bf67ff7c05c555a817f15bef22809cf1f3b510436dee4866c)
                check_type(argname="argument default_value_column", value=default_value_column, expected_type=type_hints["default_value_column"])
                check_type(argname="argument group_name_column", value=group_name_column, expected_type=type_hints["group_name_column"])
                check_type(argname="argument user_name_column", value=user_name_column, expected_type=type_hints["user_name_column"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "default_value_column": default_value_column,
            }
            if group_name_column is not None:
                self._values["group_name_column"] = group_name_column
            if user_name_column is not None:
                self._values["user_name_column"] = user_name_column

        @builtins.property
        def default_value_column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that contains the default value of each user or group.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dynamicdefaultvalue.html#cfn-quicksight-template-dynamicdefaultvalue-defaultvaluecolumn
            '''
            result = self._values.get("default_value_column")
            assert result is not None, "Required property 'default_value_column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def group_name_column(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]]:
            '''The column that contains the group name.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dynamicdefaultvalue.html#cfn-quicksight-template-dynamicdefaultvalue-groupnamecolumn
            '''
            result = self._values.get("group_name_column")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]], result)

        @builtins.property
        def user_name_column(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]]:
            '''The column that contains the username.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dynamicdefaultvalue.html#cfn-quicksight-template-dynamicdefaultvalue-usernamecolumn
            '''
            result = self._values.get("user_name_column")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DynamicDefaultValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.EmptyVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
        },
    )
    class EmptyVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''An empty visual.

            Empty visuals are used in layouts but have not been configured to show any data. A new visual created in the Amazon QuickSight console is considered an ``EmptyVisual`` until a visual type is selected.

            :param data_set_identifier: The data set that is used in the empty visual. Every visual requires a dataset to render.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-emptyvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                empty_visual_property = quicksight.CfnTemplate.EmptyVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a1ce82fab3120ccb09d446a7e5d3e7c4741884668d69c461a58548da297ed25e)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that is used in the empty visual.

            Every visual requires a dataset to render.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-emptyvisual.html#cfn-quicksight-template-emptyvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-emptyvisual.html#cfn-quicksight-template-emptyvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-emptyvisual.html#cfn-quicksight-template-emptyvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "EmptyVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.EntityProperty",
        jsii_struct_bases=[],
        name_mapping={"path": "path"},
    )
    class EntityProperty:
        def __init__(self, *, path: typing.Optional[builtins.str] = None) -> None:
            '''An object, structure, or sub-structure of an analysis, template, or dashboard.

            :param path: The hierarchical path of the entity within the analysis, template, or dashboard definition tree.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-entity.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                entity_property = quicksight.CfnTemplate.EntityProperty(
                    path="path"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7945b229d13e7f6413e3973305f7232329bb6be04db562f4dd466a94568af172)
                check_type(argname="argument path", value=path, expected_type=type_hints["path"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if path is not None:
                self._values["path"] = path

        @builtins.property
        def path(self) -> typing.Optional[builtins.str]:
            '''The hierarchical path of the entity within the analysis, template, or dashboard definition tree.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-entity.html#cfn-quicksight-template-entity-path
            '''
            result = self._values.get("path")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "EntityProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ExcludePeriodConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "amount": "amount",
            "granularity": "granularity",
            "status": "status",
        },
    )
    class ExcludePeriodConfigurationProperty:
        def __init__(
            self,
            *,
            amount: jsii.Number,
            granularity: builtins.str,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The exclude period of ``TimeRangeFilter`` or ``RelativeDatesFilter`` .

            :param amount: The amount or number of the exclude period.
            :param granularity: The granularity or unit (day, month, year) of the exclude period.
            :param status: The status of the exclude period. Choose from the following options:. - ``ENABLED`` - ``DISABLED``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-excludeperiodconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                exclude_period_configuration_property = quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                    amount=123,
                    granularity="granularity",
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__de2cf26916aea6d152855499da4a5882c69fcc4a6c4d442e71f66acce5b87716)
                check_type(argname="argument amount", value=amount, expected_type=type_hints["amount"])
                check_type(argname="argument granularity", value=granularity, expected_type=type_hints["granularity"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "amount": amount,
                "granularity": granularity,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def amount(self) -> jsii.Number:
            '''The amount or number of the exclude period.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-excludeperiodconfiguration.html#cfn-quicksight-template-excludeperiodconfiguration-amount
            '''
            result = self._values.get("amount")
            assert result is not None, "Required property 'amount' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def granularity(self) -> builtins.str:
            '''The granularity or unit (day, month, year) of the exclude period.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-excludeperiodconfiguration.html#cfn-quicksight-template-excludeperiodconfiguration-granularity
            '''
            result = self._values.get("granularity")
            assert result is not None, "Required property 'granularity' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the exclude period. Choose from the following options:.

            - ``ENABLED``
            - ``DISABLED``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-excludeperiodconfiguration.html#cfn-quicksight-template-excludeperiodconfiguration-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExcludePeriodConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ExplicitHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class ExplicitHierarchyProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]]],
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields that are built within a visual's field wells.

            These fields can't be duplicated to other visuals.

            :param columns: The list of columns that define the explicit hierarchy.
            :param hierarchy_id: The hierarchy ID of the explicit hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the explicit hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-explicithierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                explicit_hierarchy_property = quicksight.CfnTemplate.ExplicitHierarchyProperty(
                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e01d9b6a41f2cfa1a0ebe11134c4b304e55ca36a00723a86f03d87d0420ca4e1)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]]]:
            '''The list of columns that define the explicit hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-explicithierarchy.html#cfn-quicksight-template-explicithierarchy-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]]], result)

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the explicit hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-explicithierarchy.html#cfn-quicksight-template-explicithierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DrillDownFilterProperty"]]]]:
            '''The option that determines the drill down filters for the explicit hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-explicithierarchy.html#cfn-quicksight-template-explicithierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DrillDownFilterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExplicitHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FieldBasedTooltipProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_visibility": "aggregationVisibility",
            "tooltip_fields": "tooltipFields",
            "tooltip_title_type": "tooltipTitleType",
        },
    )
    class FieldBasedTooltipProperty:
        def __init__(
            self,
            *,
            aggregation_visibility: typing.Optional[builtins.str] = None,
            tooltip_fields: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TooltipItemProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            tooltip_title_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The setup for the detailed tooltip.

            :param aggregation_visibility: The visibility of ``Show aggregations`` .
            :param tooltip_fields: The fields configuration in the tooltip.
            :param tooltip_title_type: The type for the >tooltip title. Choose one of the following options:. - ``NONE`` : Doesn't use the primary value as the title. - ``PRIMARY_VALUE`` : Uses primary value as the title.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldbasedtooltip.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                field_based_tooltip_property = quicksight.CfnTemplate.FieldBasedTooltipProperty(
                    aggregation_visibility="aggregationVisibility",
                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            label="label",
                            visibility="visibility"
                        ),
                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            label="label",
                            visibility="visibility"
                        )
                    )],
                    tooltip_title_type="tooltipTitleType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e02c1c64a4fc22c0fc0c54cbcef1d363794af1a2617ce66824e72d68c469461a)
                check_type(argname="argument aggregation_visibility", value=aggregation_visibility, expected_type=type_hints["aggregation_visibility"])
                check_type(argname="argument tooltip_fields", value=tooltip_fields, expected_type=type_hints["tooltip_fields"])
                check_type(argname="argument tooltip_title_type", value=tooltip_title_type, expected_type=type_hints["tooltip_title_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if aggregation_visibility is not None:
                self._values["aggregation_visibility"] = aggregation_visibility
            if tooltip_fields is not None:
                self._values["tooltip_fields"] = tooltip_fields
            if tooltip_title_type is not None:
                self._values["tooltip_title_type"] = tooltip_title_type

        @builtins.property
        def aggregation_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of ``Show aggregations`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldbasedtooltip.html#cfn-quicksight-template-fieldbasedtooltip-aggregationvisibility
            '''
            result = self._values.get("aggregation_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tooltip_fields(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipItemProperty"]]]]:
            '''The fields configuration in the tooltip.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldbasedtooltip.html#cfn-quicksight-template-fieldbasedtooltip-tooltipfields
            '''
            result = self._values.get("tooltip_fields")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipItemProperty"]]]], result)

        @builtins.property
        def tooltip_title_type(self) -> typing.Optional[builtins.str]:
            '''The type for the >tooltip title. Choose one of the following options:.

            - ``NONE`` : Doesn't use the primary value as the title.
            - ``PRIMARY_VALUE`` : Uses primary value as the title.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldbasedtooltip.html#cfn-quicksight-template-fieldbasedtooltip-tooltiptitletype
            '''
            result = self._values.get("tooltip_title_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldBasedTooltipProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FieldLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "visibility": "visibility"},
    )
    class FieldLabelTypeProperty:
        def __init__(
            self,
            *,
            field_id: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The field label type.

            :param field_id: Indicates the field that is targeted by the field label.
            :param visibility: The visibility of the field label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                field_label_type_property = quicksight.CfnTemplate.FieldLabelTypeProperty(
                    field_id="fieldId",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d324dce70fc25603c5d85a251b1734468f0c0b145424d4885254a72685306e47)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''Indicates the field that is targeted by the field label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldlabeltype.html#cfn-quicksight-template-fieldlabeltype-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the field label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldlabeltype.html#cfn-quicksight-template-fieldlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FieldSeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "field_id": "fieldId",
            "settings": "settings",
        },
    )
    class FieldSeriesItemProperty:
        def __init__(
            self,
            *,
            axis_binding: builtins.str,
            field_id: builtins.str,
            settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LineChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field series item configuration of a line chart.

            :param axis_binding: The axis that you are binding the field to.
            :param field_id: The field ID of the field for which you are setting the axis binding.
            :param settings: The options that determine the presentation of line series associated to the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldseriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                field_series_item_property = quicksight.CfnTemplate.FieldSeriesItemProperty(
                    axis_binding="axisBinding",
                    field_id="fieldId",
                
                    # the properties below are optional
                    settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                        line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__14c844d9acddaf2240111640aa98c6500fdcec36bbb80cf5c7b0f4e25bc32a35)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument settings", value=settings, expected_type=type_hints["settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "axis_binding": axis_binding,
                "field_id": field_id,
            }
            if settings is not None:
                self._values["settings"] = settings

        @builtins.property
        def axis_binding(self) -> builtins.str:
            '''The axis that you are binding the field to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldseriesitem.html#cfn-quicksight-template-fieldseriesitem-axisbinding
            '''
            result = self._values.get("axis_binding")
            assert result is not None, "Required property 'axis_binding' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field for which you are setting the axis binding.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldseriesitem.html#cfn-quicksight-template-fieldseriesitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartSeriesSettingsProperty"]]:
            '''The options that determine the presentation of line series associated to the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldseriesitem.html#cfn-quicksight-template-fieldseriesitem-settings
            '''
            result = self._values.get("settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartSeriesSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FieldSortOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"column_sort": "columnSort", "field_sort": "fieldSort"},
    )
    class FieldSortOptionsProperty:
        def __init__(
            self,
            *,
            column_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field sort options in a chart configuration.

            :param column_sort: The sort configuration for a column that is not used in a field well.
            :param field_sort: The sort configuration for a field in a field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsortoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                field_sort_options_property = quicksight.CfnTemplate.FieldSortOptionsProperty(
                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                        direction="direction",
                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                            attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                simple_attribute_aggregation="simpleAttributeAggregation",
                                value_for_multiple_values="valueForMultipleValues"
                            ),
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                        direction="direction",
                        field_id="fieldId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__96c89da174b3d15590d444e938a68fbef9762448db2dc5c78991102f82aceef1)
                check_type(argname="argument column_sort", value=column_sort, expected_type=type_hints["column_sort"])
                check_type(argname="argument field_sort", value=field_sort, expected_type=type_hints["field_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_sort is not None:
                self._values["column_sort"] = column_sort
            if field_sort is not None:
                self._values["field_sort"] = field_sort

        @builtins.property
        def column_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnSortProperty"]]:
            '''The sort configuration for a column that is not used in a field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsortoptions.html#cfn-quicksight-template-fieldsortoptions-columnsort
            '''
            result = self._values.get("column_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnSortProperty"]], result)

        @builtins.property
        def field_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortProperty"]]:
            '''The sort configuration for a field in a field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsortoptions.html#cfn-quicksight-template-fieldsortoptions-fieldsort
            '''
            result = self._values.get("field_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSortOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FieldSortProperty",
        jsii_struct_bases=[],
        name_mapping={"direction": "direction", "field_id": "fieldId"},
    )
    class FieldSortProperty:
        def __init__(self, *, direction: builtins.str, field_id: builtins.str) -> None:
            '''The sort configuration for a field in a field well.

            :param direction: The sort direction. Choose one of the following options:. - ``ASC`` : Ascending - ``DESC`` : Descending
            :param field_id: The sort configuration target field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                field_sort_property = quicksight.CfnTemplate.FieldSortProperty(
                    direction="direction",
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__85c581ae9abf255fb48266bb24a81c07deff5ab8bfb1729d4f3efddf58034f13)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "field_id": field_id,
            }

        @builtins.property
        def direction(self) -> builtins.str:
            '''The sort direction. Choose one of the following options:.

            - ``ASC`` : Ascending
            - ``DESC`` : Descending

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsort.html#cfn-quicksight-template-fieldsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The sort configuration target field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsort.html#cfn-quicksight-template-fieldsort-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FieldTooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "label": "label",
            "visibility": "visibility",
        },
    )
    class FieldTooltipItemProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The tooltip item for the fields.

            :param field_id: The unique ID of the field that is targeted by the tooltip.
            :param label: The label of the tooltip item.
            :param visibility: The visibility of the tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldtooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                field_tooltip_item_property = quicksight.CfnTemplate.FieldTooltipItemProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    label="label",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__297ede735671a624776585becdbf3f66ab88b4a2caeee3f00dd4b384c2e8dc58)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if label is not None:
                self._values["label"] = label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The unique ID of the field that is targeted by the tooltip.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldtooltipitem.html#cfn-quicksight-template-fieldtooltipitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def label(self) -> typing.Optional[builtins.str]:
            '''The label of the tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldtooltipitem.html#cfn-quicksight-template-fieldtooltipitem-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the tooltip item.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldtooltipitem.html#cfn-quicksight-template-fieldtooltipitem-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldTooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"geospatial": "geospatial", "values": "values"},
    )
    class FilledMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            geospatial: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well of the filled map.

            :param geospatial: The aggregated location field well of the filled map. Values are grouped by location fields.
            :param values: The aggregated color field well of a filled map. Values are aggregated based on location fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filled_map_aggregated_field_wells_property = quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty(
                    geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ce7d943404d9c4487ea9e5503b7c80bd6ff1741384dfde148b364fbd479a133f)
                check_type(argname="argument geospatial", value=geospatial, expected_type=type_hints["geospatial"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if geospatial is not None:
                self._values["geospatial"] = geospatial
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def geospatial(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The aggregated location field well of the filled map.

            Values are grouped by location fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapaggregatedfieldwells.html#cfn-quicksight-template-filledmapaggregatedfieldwells-geospatial
            '''
            result = self._values.get("geospatial")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The aggregated color field well of a filled map.

            Values are aggregated based on location fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapaggregatedfieldwells.html#cfn-quicksight-template-filledmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilledMapConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"shape": "shape"},
    )
    class FilledMapConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            shape: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilledMapShapeConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''Conditional formatting options of a ``FilledMapVisual`` .

            :param shape: The conditional formatting that determines the shape of the filled map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filled_map_conditional_formatting_option_property = quicksight.CfnTemplate.FilledMapConditionalFormattingOptionProperty(
                    shape=quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        format=quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__02ebf1bf7a85a1d96bde2d6c1703fc1397d0f0311a234101190c3c558b46c84b)
                check_type(argname="argument shape", value=shape, expected_type=type_hints["shape"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "shape": shape,
            }

        @builtins.property
        def shape(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilledMapShapeConditionalFormattingProperty"]:
            '''The conditional formatting that determines the shape of the filled map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconditionalformattingoption.html#cfn-quicksight-template-filledmapconditionalformattingoption-shape
            '''
            result = self._values.get("shape")
            assert result is not None, "Required property 'shape' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilledMapShapeConditionalFormattingProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilledMapConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class FilledMapConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilledMapConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The conditional formatting of a ``FilledMapVisual`` .

            :param conditional_formatting_options: Conditional formatting options of a ``FilledMapVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filled_map_conditional_formatting_property = quicksight.CfnTemplate.FilledMapConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnTemplate.FilledMapConditionalFormattingOptionProperty(
                        shape=quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            format=quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__df3826794046129ebc4d625e9b39ef7f2725b27c256a82dda0cdfaddabf692a6)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "conditional_formatting_options": conditional_formatting_options,
            }

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilledMapConditionalFormattingOptionProperty"]]]:
            '''Conditional formatting options of a ``FilledMapVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconditionalformatting.html#cfn-quicksight-template-filledmapconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            assert result is not None, "Required property 'conditional_formatting_options' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilledMapConditionalFormattingOptionProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilledMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "legend": "legend",
            "map_style_options": "mapStyleOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "window_options": "windowOptions",
        },
    )
    class FilledMapConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilledMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            map_style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GeospatialMapStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilledMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            window_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GeospatialWindowOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``FilledMapVisual`` .

            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param map_style_options: The map style options of the filled map visual.
            :param sort_configuration: The sort configuration of a ``FilledMapVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param window_options: The window options of the filled map visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2e04f7abc1692fee86faeb19440ee5471fb5ad802c888a0ea25d3935c6dad873)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument map_style_options", value=map_style_options, expected_type=type_hints["map_style_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument window_options", value=window_options, expected_type=type_hints["window_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if map_style_options is not None:
                self._values["map_style_options"] = map_style_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if window_options is not None:
                self._values["window_options"] = window_options

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilledMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilledMapFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def map_style_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialMapStyleOptionsProperty"]]:
            '''The map style options of the filled map visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-mapstyleoptions
            '''
            result = self._values.get("map_style_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialMapStyleOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilledMapSortConfigurationProperty"]]:
            '''The sort configuration of a ``FilledMapVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilledMapSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def window_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialWindowOptionsProperty"]]:
            '''The window options of the filled map visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-windowoptions
            '''
            result = self._values.get("window_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialWindowOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilledMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filled_map_aggregated_field_wells": "filledMapAggregatedFieldWells",
        },
    )
    class FilledMapFieldWellsProperty:
        def __init__(
            self,
            *,
            filled_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilledMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``FilledMapVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param filled_map_aggregated_field_wells: The aggregated field well of the filled map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filled_map_field_wells_property = quicksight.CfnTemplate.FilledMapFieldWellsProperty(
                    filled_map_aggregated_field_wells=quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty(
                        geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a0087a39747e1867ca27880bb626ed9e93d21e7a7eae2e0fb3c2f03744b1d969)
                check_type(argname="argument filled_map_aggregated_field_wells", value=filled_map_aggregated_field_wells, expected_type=type_hints["filled_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if filled_map_aggregated_field_wells is not None:
                self._values["filled_map_aggregated_field_wells"] = filled_map_aggregated_field_wells

        @builtins.property
        def filled_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilledMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field well of the filled map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapfieldwells.html#cfn-quicksight-template-filledmapfieldwells-filledmapaggregatedfieldwells
            '''
            result = self._values.get("filled_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilledMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "format": "format"},
    )
    class FilledMapShapeConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ShapeConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting that determines the shape of the filled map.

            :param field_id: The field ID of the filled map shape.
            :param format: The conditional formatting that determines the background color of a filled map's shape.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapshapeconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filled_map_shape_conditional_formatting_property = quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    format=quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7c21337cb52b8bbebbb570a4086a66643672d1468aeaf742277621de100bad21)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format", value=format, expected_type=type_hints["format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if format is not None:
                self._values["format"] = format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the filled map shape.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapshapeconditionalformatting.html#cfn-quicksight-template-filledmapshapeconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ShapeConditionalFormatProperty"]]:
            '''The conditional formatting that determines the background color of a filled map's shape.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapshapeconditionalformatting.html#cfn-quicksight-template-filledmapshapeconditionalformatting-format
            '''
            result = self._values.get("format")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ShapeConditionalFormatProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapShapeConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilledMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"category_sort": "categorySort"},
    )
    class FilledMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``FilledMapVisual`` .

            :param category_sort: The sort configuration of the location fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filled_map_sort_configuration_property = quicksight.CfnTemplate.FilledMapSortConfigurationProperty(
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__433bb89fcafe7552154706cbdcbea46758758c8750794f0e9c8e64178b0e432e)
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the location fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapsortconfiguration.html#cfn-quicksight-template-filledmapsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilledMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class FilledMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilledMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilledMapConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A filled map.

            For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param conditional_formatting: The conditional formatting of a ``FilledMapVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__20b159b9596e4213827becba8daa6be2855e3ab9c4f383574a15398d838c9630)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilledMapConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilledMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilledMapConditionalFormattingProperty"]]:
            '''The conditional formatting of a ``FilledMapVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilledMapConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilterControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_picker": "dateTimePicker",
            "dropdown": "dropdown",
            "list": "list",
            "relative_date_time": "relativeDateTime",
            "slider": "slider",
            "text_area": "textArea",
            "text_field": "textField",
        },
    )
    class FilterControlProperty:
        def __init__(
            self,
            *,
            date_time_picker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilterDateTimePickerControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            dropdown: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilterDropDownControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            list: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilterListControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relative_date_time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilterRelativeDateTimeControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            slider: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilterSliderControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_area: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilterTextAreaControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilterTextFieldControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The control of a filter that is used to interact with a dashboard or an analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_picker: A control from a date filter that is used to specify date and time.
            :param dropdown: A control to display a dropdown list with buttons that are used to select a single value.
            :param list: A control to display a list of buttons or boxes. This is used to select either a single value or multiple values.
            :param relative_date_time: A control from a date filter that is used to specify the relative date.
            :param slider: A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
            :param text_area: A control to display a text box that is used to enter multiple entries.
            :param text_field: A control to display a text box that is used to enter a single entry.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_control_property = quicksight.CfnTemplate.FilterControlProperty(
                    date_time_picker=quicksight.CfnTemplate.FilterDateTimePickerControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        type="type"
                    ),
                    dropdown=quicksight.CfnTemplate.FilterDropDownControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                            values=["values"]
                        ),
                        type="type"
                    ),
                    list=quicksight.CfnTemplate.FilterListControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                            values=["values"]
                        ),
                        type="type"
                    ),
                    relative_date_time=quicksight.CfnTemplate.FilterRelativeDateTimeControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    slider=quicksight.CfnTemplate.FilterSliderControlProperty(
                        filter_control_id="filterControlId",
                        maximum_value=123,
                        minimum_value=123,
                        source_filter_id="sourceFilterId",
                        step_size=123,
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        type="type"
                    ),
                    text_area=quicksight.CfnTemplate.FilterTextAreaControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        delimiter="delimiter",
                        display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_field=quicksight.CfnTemplate.FilterTextFieldControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__17c85186d7b47b18464b3e0c6561277bf174ea650ce639d4ce9028e1e46d9553)
                check_type(argname="argument date_time_picker", value=date_time_picker, expected_type=type_hints["date_time_picker"])
                check_type(argname="argument dropdown", value=dropdown, expected_type=type_hints["dropdown"])
                check_type(argname="argument list", value=list, expected_type=type_hints["list"])
                check_type(argname="argument relative_date_time", value=relative_date_time, expected_type=type_hints["relative_date_time"])
                check_type(argname="argument slider", value=slider, expected_type=type_hints["slider"])
                check_type(argname="argument text_area", value=text_area, expected_type=type_hints["text_area"])
                check_type(argname="argument text_field", value=text_field, expected_type=type_hints["text_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_picker is not None:
                self._values["date_time_picker"] = date_time_picker
            if dropdown is not None:
                self._values["dropdown"] = dropdown
            if list is not None:
                self._values["list"] = list
            if relative_date_time is not None:
                self._values["relative_date_time"] = relative_date_time
            if slider is not None:
                self._values["slider"] = slider
            if text_area is not None:
                self._values["text_area"] = text_area
            if text_field is not None:
                self._values["text_field"] = text_field

        @builtins.property
        def date_time_picker(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterDateTimePickerControlProperty"]]:
            '''A control from a date filter that is used to specify date and time.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-datetimepicker
            '''
            result = self._values.get("date_time_picker")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterDateTimePickerControlProperty"]], result)

        @builtins.property
        def dropdown(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterDropDownControlProperty"]]:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-dropdown
            '''
            result = self._values.get("dropdown")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterDropDownControlProperty"]], result)

        @builtins.property
        def list(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterListControlProperty"]]:
            '''A control to display a list of buttons or boxes.

            This is used to select either a single value or multiple values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-list
            '''
            result = self._values.get("list")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterListControlProperty"]], result)

        @builtins.property
        def relative_date_time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterRelativeDateTimeControlProperty"]]:
            '''A control from a date filter that is used to specify the relative date.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-relativedatetime
            '''
            result = self._values.get("relative_date_time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterRelativeDateTimeControlProperty"]], result)

        @builtins.property
        def slider(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterSliderControlProperty"]]:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-slider
            '''
            result = self._values.get("slider")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterSliderControlProperty"]], result)

        @builtins.property
        def text_area(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterTextAreaControlProperty"]]:
            '''A control to display a text box that is used to enter multiple entries.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-textarea
            '''
            result = self._values.get("text_area")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterTextAreaControlProperty"]], result)

        @builtins.property
        def text_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterTextFieldControlProperty"]]:
            '''A control to display a text box that is used to enter a single entry.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-textfield
            '''
            result = self._values.get("text_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterTextFieldControlProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilterDateTimePickerControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
            "type": "type",
        },
    )
    class FilterDateTimePickerControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DateTimePickerControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control from a date filter that is used to specify date and time.

            :param filter_control_id: The ID of the ``FilterDateTimePickerControl`` .
            :param source_filter_id: The source filter ID of the ``FilterDateTimePickerControl`` .
            :param title: The title of the ``FilterDateTimePickerControl`` .
            :param display_options: The display options of a control.
            :param type: The date time picker type of a ``FilterDateTimePickerControl`` . Choose one of the following options:. - ``SINGLE_VALUED`` : The filter condition is a fixed date. - ``DATE_RANGE`` : The filter condition is a date time range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_date_time_picker_control_property = quicksight.CfnTemplate.FilterDateTimePickerControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6dcb3713c6fee5fa1f08d0cb0f2027bf0f0d073e2ad8cf57da9058b54a81c95b)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterDateTimePickerControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterDateTimePickerControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterDateTimePickerControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateTimePickerControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateTimePickerControlDisplayOptionsProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The date time picker type of a ``FilterDateTimePickerControl`` . Choose one of the following options:.

            - ``SINGLE_VALUED`` : The filter condition is a fixed date.
            - ``DATE_RANGE`` : The filter condition is a date time range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterDateTimePickerControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilterDropDownControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class FilterDropDownControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DropDownControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :param filter_control_id: The ID of the ``FilterDropDownControl`` .
            :param source_filter_id: The source filter ID of the ``FilterDropDownControl`` .
            :param title: The title of the ``FilterDropDownControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of the ``FilterDropDownControl`` .
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of the ``FilterDropDownControl`` . Choose one of the following options:. - ``MULTI_SELECT`` : The user can select multiple entries from a dropdown menu. - ``SINGLE_SELECT`` : The user can select a single entry from a dropdown menu.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_drop_down_control_property = quicksight.CfnTemplate.FilterDropDownControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f6746085d5cb80d1bab46d5212600b8db63b0f525d4f0afb856c441b62009214)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DropDownControlDisplayOptionsProperty"]]:
            '''The display options of the ``FilterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DropDownControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of the ``FilterDropDownControl`` . Choose one of the following options:.

            - ``MULTI_SELECT`` : The user can select multiple entries from a dropdown menu.
            - ``SINGLE_SELECT`` : The user can select a single entry from a dropdown menu.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterDropDownControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilterGroupProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cross_dataset": "crossDataset",
            "filter_group_id": "filterGroupId",
            "filters": "filters",
            "scope_configuration": "scopeConfiguration",
            "status": "status",
        },
    )
    class FilterGroupProperty:
        def __init__(
            self,
            *,
            cross_dataset: builtins.str,
            filter_group_id: builtins.str,
            filters: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilterProperty", typing.Dict[builtins.str, typing.Any]]]]],
            scope_configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilterScopeConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A grouping of individual filters. Filter groups are applied to the same group of visuals.

            For more information, see `Adding filter conditions (group filters) with AND and OR operators <https://docs.aws.amazon.com/quicksight/latest/user/add-a-compound-filter.html>`_ in the *Amazon QuickSight User Guide* .

            :param cross_dataset: The filter new feature which can apply filter group to all data sets. Choose one of the following options:. - ``ALL_DATASETS`` - ``SINGLE_DATASET``
            :param filter_group_id: The value that uniquely identifies a ``FilterGroup`` within a dashboard, template, or analysis.
            :param filters: The list of filters that are present in a ``FilterGroup`` .
            :param scope_configuration: The configuration that specifies what scope to apply to a ``FilterGroup`` . This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
            :param status: The status of the ``FilterGroup`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # all_sheets: Any
                
                filter_group_property = quicksight.CfnTemplate.FilterGroupProperty(
                    cross_dataset="crossDataset",
                    filter_group_id="filterGroupId",
                    filters=[quicksight.CfnTemplate.FilterProperty(
                        category_filter=quicksight.CfnTemplate.CategoryFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            configuration=quicksight.CfnTemplate.CategoryFilterConfigurationProperty(
                                custom_filter_configuration=quicksight.CfnTemplate.CustomFilterConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
                
                                    # the properties below are optional
                                    category_value="categoryValue",
                                    parameter_name="parameterName",
                                    select_all_options="selectAllOptions"
                                ),
                                custom_filter_list_configuration=quicksight.CfnTemplate.CustomFilterListConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
                
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                ),
                                filter_list_configuration=quicksight.CfnTemplate.FilterListConfigurationProperty(
                                    match_operator="matchOperator",
                
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    null_option="nullOption",
                                    select_all_options="selectAllOptions"
                                )
                            ),
                            filter_id="filterId"
                        ),
                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions",
                            value=123
                        ),
                        numeric_range_filter=quicksight.CfnTemplate.NumericRangeFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            range_minimum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            select_all_options="selectAllOptions"
                        ),
                        relative_dates_filter=quicksight.CfnTemplate.RelativeDatesFilterProperty(
                            anchor_date_configuration=quicksight.CfnTemplate.AnchorDateConfigurationProperty(
                                anchor_option="anchorOption",
                                parameter_name="parameterName"
                            ),
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                            relative_date_type="relativeDateType",
                            time_granularity="timeGranularity",
                
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
                
                                # the properties below are optional
                                status="status"
                            ),
                            minimum_granularity="minimumGranularity",
                            parameter_name="parameterName",
                            relative_date_value=123
                        ),
                        time_equality_filter=quicksight.CfnTemplate.TimeEqualityFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                
                            # the properties below are optional
                            parameter_name="parameterName",
                            rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            time_granularity="timeGranularity",
                            value="value"
                        ),
                        time_range_filter=quicksight.CfnTemplate.TimeRangeFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
                
                                # the properties below are optional
                                status="status"
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            range_minimum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            time_granularity="timeGranularity"
                        ),
                        top_bottom_filter=quicksight.CfnTemplate.TopBottomFilterProperty(
                            aggregation_sort_configurations=[quicksight.CfnTemplate.AggregationSortConfigurationProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                sort_direction="sortDirection",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                        simple_attribute_aggregation="simpleAttributeAggregation",
                                        value_for_multiple_values="valueForMultipleValues"
                                    ),
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            )],
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                
                            # the properties below are optional
                            limit=123,
                            parameter_name="parameterName",
                            time_granularity="timeGranularity"
                        )
                    )],
                    scope_configuration=quicksight.CfnTemplate.FilterScopeConfigurationProperty(
                        all_sheets=all_sheets,
                        selected_sheets=quicksight.CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty(
                            sheet_visual_scoping_configurations=[quicksight.CfnTemplate.SheetVisualScopingConfigurationProperty(
                                scope="scope",
                                sheet_id="sheetId",
                
                                # the properties below are optional
                                visual_ids=["visualIds"]
                            )]
                        )
                    ),
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0d006f785e58af6b52d38a79b763948bfd9a9cc46f049c94d82e0d8a7ba3f911)
                check_type(argname="argument cross_dataset", value=cross_dataset, expected_type=type_hints["cross_dataset"])
                check_type(argname="argument filter_group_id", value=filter_group_id, expected_type=type_hints["filter_group_id"])
                check_type(argname="argument filters", value=filters, expected_type=type_hints["filters"])
                check_type(argname="argument scope_configuration", value=scope_configuration, expected_type=type_hints["scope_configuration"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "cross_dataset": cross_dataset,
                "filter_group_id": filter_group_id,
                "filters": filters,
                "scope_configuration": scope_configuration,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def cross_dataset(self) -> builtins.str:
            '''The filter new feature which can apply filter group to all data sets. Choose one of the following options:.

            - ``ALL_DATASETS``
            - ``SINGLE_DATASET``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-crossdataset
            '''
            result = self._values.get("cross_dataset")
            assert result is not None, "Required property 'cross_dataset' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def filter_group_id(self) -> builtins.str:
            '''The value that uniquely identifies a ``FilterGroup`` within a dashboard, template, or analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-filtergroupid
            '''
            result = self._values.get("filter_group_id")
            assert result is not None, "Required property 'filter_group_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def filters(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterProperty"]]]:
            '''The list of filters that are present in a ``FilterGroup`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-filters
            '''
            result = self._values.get("filters")
            assert result is not None, "Required property 'filters' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterProperty"]]], result)

        @builtins.property
        def scope_configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterScopeConfigurationProperty"]:
            '''The configuration that specifies what scope to apply to a ``FilterGroup`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-scopeconfiguration
            '''
            result = self._values.get("scope_configuration")
            assert result is not None, "Required property 'scope_configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterScopeConfigurationProperty"], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the ``FilterGroup`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterGroupProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilterListConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "category_values": "categoryValues",
            "null_option": "nullOption",
            "select_all_options": "selectAllOptions",
        },
    )
    class FilterListConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            null_option: typing.Optional[builtins.str] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A list of filter configurations.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param category_values: The list of category values for the filter.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_list_configuration_property = quicksight.CfnTemplate.FilterListConfigurationProperty(
                    match_operator="matchOperator",
                
                    # the properties below are optional
                    category_values=["categoryValues"],
                    null_option="nullOption",
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0a2d40da847e970d8867a6188195be0f5ee377e79e9b8d73253d8fbfcfc78de5)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
            }
            if category_values is not None:
                self._values["category_values"] = category_values
            if null_option is not None:
                self._values["null_option"] = null_option
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html#cfn-quicksight-template-filterlistconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of category values for the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html#cfn-quicksight-template-filterlistconfiguration-categoryvalues
            '''
            result = self._values.get("category_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def null_option(self) -> typing.Optional[builtins.str]:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html#cfn-quicksight-template-filterlistconfiguration-nulloption
            '''
            result = self._values.get("null_option")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html#cfn-quicksight-template-filterlistconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterListConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilterListControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class FilterListControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ListControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a list of buttons or boxes.

            This is used to select either a single value or multiple values.

            :param filter_control_id: The ID of the ``FilterListControl`` .
            :param source_filter_id: The source filter ID of the ``FilterListControl`` .
            :param title: The title of the ``FilterListControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of ``FilterListControl`` . Choose one of the following options:. - ``MULTI_SELECT`` : The user can select multiple entries from the list. - ``SINGLE_SELECT`` : The user can select a single entry from the list.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_list_control_property = quicksight.CfnTemplate.FilterListControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f7fcd1280333091b90bcb153b1e8e0751159d5e57dd92667b95e74a9f9cdfcf0)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ListControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ListControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``FilterListControl`` . Choose one of the following options:.

            - ``MULTI_SELECT`` : The user can select multiple entries from the list.
            - ``SINGLE_SELECT`` : The user can select a single entry from the list.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterListControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "selected_columns": "selectedColumns",
            "selected_field_options": "selectedFieldOptions",
            "selected_fields": "selectedFields",
        },
    )
    class FilterOperationSelectedFieldsConfigurationProperty:
        def __init__(
            self,
            *,
            selected_columns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            selected_field_options: typing.Optional[builtins.str] = None,
            selected_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The configuration of selected fields in the ``CustomActionFilterOperation`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param selected_columns: The selected columns of a dataset.
            :param selected_field_options: A structure that contains the options that choose which fields are filtered in the ``CustomActionFilterOperation`` . Valid values are defined as follows: - ``ALL_FIELDS`` : Applies the filter operation to all fields.
            :param selected_fields: Chooses the fields that are filtered in ``CustomActionFilterOperation`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationselectedfieldsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_operation_selected_fields_configuration_property = quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                    selected_columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    selected_field_options="selectedFieldOptions",
                    selected_fields=["selectedFields"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__99c48630a4143e91c66097748bf20c5581cc437a1d8aa8adaf0b018817107cac)
                check_type(argname="argument selected_columns", value=selected_columns, expected_type=type_hints["selected_columns"])
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
                check_type(argname="argument selected_fields", value=selected_fields, expected_type=type_hints["selected_fields"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if selected_columns is not None:
                self._values["selected_columns"] = selected_columns
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options
            if selected_fields is not None:
                self._values["selected_fields"] = selected_fields

        @builtins.property
        def selected_columns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]]]]:
            '''The selected columns of a dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-template-filteroperationselectedfieldsconfiguration-selectedcolumns
            '''
            result = self._values.get("selected_columns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]]]], result)

        @builtins.property
        def selected_field_options(self) -> typing.Optional[builtins.str]:
            '''A structure that contains the options that choose which fields are filtered in the ``CustomActionFilterOperation`` .

            Valid values are defined as follows:

            - ``ALL_FIELDS`` : Applies the filter operation to all fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-template-filteroperationselectedfieldsconfiguration-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def selected_fields(self) -> typing.Optional[typing.List[builtins.str]]:
            '''Chooses the fields that are filtered in ``CustomActionFilterOperation`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-template-filteroperationselectedfieldsconfiguration-selectedfields
            '''
            result = self._values.get("selected_fields")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterOperationSelectedFieldsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "same_sheet_target_visual_configuration": "sameSheetTargetVisualConfiguration",
        },
    )
    class FilterOperationTargetVisualsConfigurationProperty:
        def __init__(
            self,
            *,
            same_sheet_target_visual_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SameSheetTargetVisualConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of target visuals that you want to be filtered.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param same_sheet_target_visual_configuration: The configuration of the same-sheet target visuals that you want to be filtered.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationtargetvisualsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_operation_target_visuals_configuration_property = quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                        target_visual_options="targetVisualOptions",
                        target_visuals=["targetVisuals"]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5b57cf8043ee4ba481fbb66efe48b5c56ba864f070b676ad8c0a30c31db8d3bf)
                check_type(argname="argument same_sheet_target_visual_configuration", value=same_sheet_target_visual_configuration, expected_type=type_hints["same_sheet_target_visual_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if same_sheet_target_visual_configuration is not None:
                self._values["same_sheet_target_visual_configuration"] = same_sheet_target_visual_configuration

        @builtins.property
        def same_sheet_target_visual_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SameSheetTargetVisualConfigurationProperty"]]:
            '''The configuration of the same-sheet target visuals that you want to be filtered.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationtargetvisualsconfiguration.html#cfn-quicksight-template-filteroperationtargetvisualsconfiguration-samesheettargetvisualconfiguration
            '''
            result = self._values.get("same_sheet_target_visual_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SameSheetTargetVisualConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterOperationTargetVisualsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_filter": "categoryFilter",
            "numeric_equality_filter": "numericEqualityFilter",
            "numeric_range_filter": "numericRangeFilter",
            "relative_dates_filter": "relativeDatesFilter",
            "time_equality_filter": "timeEqualityFilter",
            "time_range_filter": "timeRangeFilter",
            "top_bottom_filter": "topBottomFilter",
        },
    )
    class FilterProperty:
        def __init__(
            self,
            *,
            category_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CategoryFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_equality_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumericEqualityFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumericRangeFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relative_dates_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.RelativeDatesFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_equality_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TimeEqualityFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TimeRangeFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top_bottom_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TopBottomFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''With a ``Filter`` , you can remove portions of data from a particular visual or view.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param category_filter: A ``CategoryFilter`` filters text values. For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .
            :param numeric_equality_filter: A ``NumericEqualityFilter`` filters numeric values that equal or do not equal a given numeric value.
            :param numeric_range_filter: A ``NumericRangeFilter`` filters numeric values that are either inside or outside a given numeric range.
            :param relative_dates_filter: A ``RelativeDatesFilter`` filters date values that are relative to a given date.
            :param time_equality_filter: A ``TimeEqualityFilter`` filters date-time values that equal or do not equal a given date/time value.
            :param time_range_filter: A ``TimeRangeFilter`` filters date-time values that are either inside or outside a given date/time range.
            :param top_bottom_filter: A ``TopBottomFilter`` filters data to the top or bottom values for a given column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_property = quicksight.CfnTemplate.FilterProperty(
                    category_filter=quicksight.CfnTemplate.CategoryFilterProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        configuration=quicksight.CfnTemplate.CategoryFilterConfigurationProperty(
                            custom_filter_configuration=quicksight.CfnTemplate.CustomFilterConfigurationProperty(
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                category_value="categoryValue",
                                parameter_name="parameterName",
                                select_all_options="selectAllOptions"
                            ),
                            custom_filter_list_configuration=quicksight.CfnTemplate.CustomFilterListConfigurationProperty(
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                category_values=["categoryValues"],
                                select_all_options="selectAllOptions"
                            ),
                            filter_list_configuration=quicksight.CfnTemplate.FilterListConfigurationProperty(
                                match_operator="matchOperator",
                
                                # the properties below are optional
                                category_values=["categoryValues"],
                                null_option="nullOption",
                                select_all_options="selectAllOptions"
                            )
                        ),
                        filter_id="filterId"
                    ),
                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityFilterProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                            attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                simple_attribute_aggregation="simpleAttributeAggregation",
                                value_for_multiple_values="valueForMultipleValues"
                            ),
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        parameter_name="parameterName",
                        select_all_options="selectAllOptions",
                        value=123
                    ),
                    numeric_range_filter=quicksight.CfnTemplate.NumericRangeFilterProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                            attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                simple_attribute_aggregation="simpleAttributeAggregation",
                                value_for_multiple_values="valueForMultipleValues"
                            ),
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        include_maximum=False,
                        include_minimum=False,
                        range_maximum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                            parameter="parameter",
                            static_value=123
                        ),
                        range_minimum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                            parameter="parameter",
                            static_value=123
                        ),
                        select_all_options="selectAllOptions"
                    ),
                    relative_dates_filter=quicksight.CfnTemplate.RelativeDatesFilterProperty(
                        anchor_date_configuration=quicksight.CfnTemplate.AnchorDateConfigurationProperty(
                            anchor_option="anchorOption",
                            parameter_name="parameterName"
                        ),
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                        relative_date_type="relativeDateType",
                        time_granularity="timeGranularity",
                
                        # the properties below are optional
                        exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                            amount=123,
                            granularity="granularity",
                
                            # the properties below are optional
                            status="status"
                        ),
                        minimum_granularity="minimumGranularity",
                        parameter_name="parameterName",
                        relative_date_value=123
                    ),
                    time_equality_filter=quicksight.CfnTemplate.TimeEqualityFilterProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                
                        # the properties below are optional
                        parameter_name="parameterName",
                        rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        time_granularity="timeGranularity",
                        value="value"
                    ),
                    time_range_filter=quicksight.CfnTemplate.TimeRangeFilterProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                
                        # the properties below are optional
                        exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                            amount=123,
                            granularity="granularity",
                
                            # the properties below are optional
                            status="status"
                        ),
                        include_maximum=False,
                        include_minimum=False,
                        range_maximum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                            parameter="parameter",
                            rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_value="staticValue"
                        ),
                        range_minimum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                            parameter="parameter",
                            rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_value="staticValue"
                        ),
                        time_granularity="timeGranularity"
                    ),
                    top_bottom_filter=quicksight.CfnTemplate.TopBottomFilterProperty(
                        aggregation_sort_configurations=[quicksight.CfnTemplate.AggregationSortConfigurationProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            sort_direction="sortDirection",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        )],
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                
                        # the properties below are optional
                        limit=123,
                        parameter_name="parameterName",
                        time_granularity="timeGranularity"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__88122957d84b62e3e46e2cbb5339eea38b7214fb962331dc061a86be966da1f1)
                check_type(argname="argument category_filter", value=category_filter, expected_type=type_hints["category_filter"])
                check_type(argname="argument numeric_equality_filter", value=numeric_equality_filter, expected_type=type_hints["numeric_equality_filter"])
                check_type(argname="argument numeric_range_filter", value=numeric_range_filter, expected_type=type_hints["numeric_range_filter"])
                check_type(argname="argument relative_dates_filter", value=relative_dates_filter, expected_type=type_hints["relative_dates_filter"])
                check_type(argname="argument time_equality_filter", value=time_equality_filter, expected_type=type_hints["time_equality_filter"])
                check_type(argname="argument time_range_filter", value=time_range_filter, expected_type=type_hints["time_range_filter"])
                check_type(argname="argument top_bottom_filter", value=top_bottom_filter, expected_type=type_hints["top_bottom_filter"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_filter is not None:
                self._values["category_filter"] = category_filter
            if numeric_equality_filter is not None:
                self._values["numeric_equality_filter"] = numeric_equality_filter
            if numeric_range_filter is not None:
                self._values["numeric_range_filter"] = numeric_range_filter
            if relative_dates_filter is not None:
                self._values["relative_dates_filter"] = relative_dates_filter
            if time_equality_filter is not None:
                self._values["time_equality_filter"] = time_equality_filter
            if time_range_filter is not None:
                self._values["time_range_filter"] = time_range_filter
            if top_bottom_filter is not None:
                self._values["top_bottom_filter"] = top_bottom_filter

        @builtins.property
        def category_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CategoryFilterProperty"]]:
            '''A ``CategoryFilter`` filters text values.

            For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-categoryfilter
            '''
            result = self._values.get("category_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CategoryFilterProperty"]], result)

        @builtins.property
        def numeric_equality_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericEqualityFilterProperty"]]:
            '''A ``NumericEqualityFilter`` filters numeric values that equal or do not equal a given numeric value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-numericequalityfilter
            '''
            result = self._values.get("numeric_equality_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericEqualityFilterProperty"]], result)

        @builtins.property
        def numeric_range_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericRangeFilterProperty"]]:
            '''A ``NumericRangeFilter`` filters numeric values that are either inside or outside a given numeric range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-numericrangefilter
            '''
            result = self._values.get("numeric_range_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericRangeFilterProperty"]], result)

        @builtins.property
        def relative_dates_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RelativeDatesFilterProperty"]]:
            '''A ``RelativeDatesFilter`` filters date values that are relative to a given date.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-relativedatesfilter
            '''
            result = self._values.get("relative_dates_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RelativeDatesFilterProperty"]], result)

        @builtins.property
        def time_equality_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TimeEqualityFilterProperty"]]:
            '''A ``TimeEqualityFilter`` filters date-time values that equal or do not equal a given date/time value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-timeequalityfilter
            '''
            result = self._values.get("time_equality_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TimeEqualityFilterProperty"]], result)

        @builtins.property
        def time_range_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TimeRangeFilterProperty"]]:
            '''A ``TimeRangeFilter`` filters date-time values that are either inside or outside a given date/time range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-timerangefilter
            '''
            result = self._values.get("time_range_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TimeRangeFilterProperty"]], result)

        @builtins.property
        def top_bottom_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TopBottomFilterProperty"]]:
            '''A ``TopBottomFilter`` filters data to the top or bottom values for a given column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-topbottomfilter
            '''
            result = self._values.get("top_bottom_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TopBottomFilterProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilterRelativeDateTimeControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class FilterRelativeDateTimeControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control from a date filter that is used to specify the relative date.

            :param filter_control_id: The ID of the ``FilterTextAreaControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextAreaControl`` .
            :param title: The title of the ``FilterTextAreaControl`` .
            :param display_options: The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_relative_date_time_control_property = quicksight.CfnTemplate.FilterRelativeDateTimeControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__eb1c600dbeff75cffaf00fb3a32280ca5bbe390a750d74f195c117ad62829b0b)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html#cfn-quicksight-template-filterrelativedatetimecontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html#cfn-quicksight-template-filterrelativedatetimecontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html#cfn-quicksight-template-filterrelativedatetimecontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html#cfn-quicksight-template-filterrelativedatetimecontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterRelativeDateTimeControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilterScopeConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"all_sheets": "allSheets", "selected_sheets": "selectedSheets"},
    )
    class FilterScopeConfigurationProperty:
        def __init__(
            self,
            *,
            all_sheets: typing.Any = None,
            selected_sheets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The scope configuration for a ``FilterGroup`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param all_sheets: The configuration for applying a filter to all sheets.
            :param selected_sheets: The configuration for applying a filter to specific sheets.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterscopeconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # all_sheets: Any
                
                filter_scope_configuration_property = quicksight.CfnTemplate.FilterScopeConfigurationProperty(
                    all_sheets=all_sheets,
                    selected_sheets=quicksight.CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty(
                        sheet_visual_scoping_configurations=[quicksight.CfnTemplate.SheetVisualScopingConfigurationProperty(
                            scope="scope",
                            sheet_id="sheetId",
                
                            # the properties below are optional
                            visual_ids=["visualIds"]
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ca54961ef8f7ff0fa30d3349b60168a444bd2ecc63a1e3543e0d4d8f9021fd39)
                check_type(argname="argument all_sheets", value=all_sheets, expected_type=type_hints["all_sheets"])
                check_type(argname="argument selected_sheets", value=selected_sheets, expected_type=type_hints["selected_sheets"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if all_sheets is not None:
                self._values["all_sheets"] = all_sheets
            if selected_sheets is not None:
                self._values["selected_sheets"] = selected_sheets

        @builtins.property
        def all_sheets(self) -> typing.Any:
            '''The configuration for applying a filter to all sheets.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterscopeconfiguration.html#cfn-quicksight-template-filterscopeconfiguration-allsheets
            '''
            result = self._values.get("all_sheets")
            return typing.cast(typing.Any, result)

        @builtins.property
        def selected_sheets(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty"]]:
            '''The configuration for applying a filter to specific sheets.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterscopeconfiguration.html#cfn-quicksight-template-filterscopeconfiguration-selectedsheets
            '''
            result = self._values.get("selected_sheets")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterScopeConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilterSelectableValuesProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class FilterSelectableValuesProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A list of selectable values that are used in a control.

            :param values: The values that are used in the ``FilterSelectableValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterselectablevalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_selectable_values_property = quicksight.CfnTemplate.FilterSelectableValuesProperty(
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0a10ef4a35c7db75c0d20ea5166cf2b4d2f17bc776713086d69c39337a2e5372)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The values that are used in the ``FilterSelectableValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterselectablevalues.html#cfn-quicksight-template-filterselectablevalues-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterSelectableValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilterSliderControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "maximum_value": "maximumValue",
            "minimum_value": "minimumValue",
            "source_filter_id": "sourceFilterId",
            "step_size": "stepSize",
            "title": "title",
            "display_options": "displayOptions",
            "type": "type",
        },
    )
    class FilterSliderControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            maximum_value: jsii.Number,
            minimum_value: jsii.Number,
            source_filter_id: builtins.str,
            step_size: jsii.Number,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SliderControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :param filter_control_id: The ID of the ``FilterSliderControl`` .
            :param maximum_value: The smaller value that is displayed at the left of the slider. Default: - 0
            :param minimum_value: The larger value that is displayed at the right of the slider. Default: - 0
            :param source_filter_id: The source filter ID of the ``FilterSliderControl`` .
            :param step_size: The number of increments that the slider bar is divided into. Default: - 0
            :param title: The title of the ``FilterSliderControl`` .
            :param display_options: The display options of a control.
            :param type: The type of ``FilterSliderControl`` . Choose one of the following options:. - ``SINGLE_POINT`` : Filter against(equals) a single data point. - ``RANGE`` : Filter data that is in a specified range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_slider_control_property = quicksight.CfnTemplate.FilterSliderControlProperty(
                    filter_control_id="filterControlId",
                    maximum_value=123,
                    minimum_value=123,
                    source_filter_id="sourceFilterId",
                    step_size=123,
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__59d4d25e91fd0d533f6bb1bd01396691d6607dcfb129a172d5ef6f81bff34752)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument maximum_value", value=maximum_value, expected_type=type_hints["maximum_value"])
                check_type(argname="argument minimum_value", value=minimum_value, expected_type=type_hints["minimum_value"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "maximum_value": maximum_value,
                "minimum_value": minimum_value,
                "source_filter_id": source_filter_id,
                "step_size": step_size,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterSliderControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def maximum_value(self) -> jsii.Number:
            '''The smaller value that is displayed at the left of the slider.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-maximumvalue
            '''
            result = self._values.get("maximum_value")
            assert result is not None, "Required property 'maximum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def minimum_value(self) -> jsii.Number:
            '''The larger value that is displayed at the right of the slider.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-minimumvalue
            '''
            result = self._values.get("minimum_value")
            assert result is not None, "Required property 'minimum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterSliderControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def step_size(self) -> jsii.Number:
            '''The number of increments that the slider bar is divided into.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-stepsize
            '''
            result = self._values.get("step_size")
            assert result is not None, "Required property 'step_size' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterSliderControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SliderControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SliderControlDisplayOptionsProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``FilterSliderControl`` . Choose one of the following options:.

            - ``SINGLE_POINT`` : Filter against(equals) a single data point.
            - ``RANGE`` : Filter data that is in a specified range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterSliderControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilterTextAreaControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "delimiter": "delimiter",
            "display_options": "displayOptions",
        },
    )
    class FilterTextAreaControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            delimiter: typing.Optional[builtins.str] = None,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TextAreaControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter multiple entries.

            :param filter_control_id: The ID of the ``FilterTextAreaControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextAreaControl`` .
            :param title: The title of the ``FilterTextAreaControl`` .
            :param delimiter: The delimiter that is used to separate the lines in text.
            :param display_options: The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_text_area_control_property = quicksight.CfnTemplate.FilterTextAreaControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    delimiter="delimiter",
                    display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6b5ffc0a588507ef89ff8b034495114519b749283e4d61e1b9073fa3a542e032)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument delimiter", value=delimiter, expected_type=type_hints["delimiter"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if delimiter is not None:
                self._values["delimiter"] = delimiter
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def delimiter(self) -> typing.Optional[builtins.str]:
            '''The delimiter that is used to separate the lines in text.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-delimiter
            '''
            result = self._values.get("delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TextAreaControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TextAreaControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterTextAreaControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FilterTextFieldControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class FilterTextFieldControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TextFieldControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter a single entry.

            :param filter_control_id: The ID of the ``FilterTextFieldControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextFieldControl`` .
            :param title: The title of the ``FilterTextFieldControl`` .
            :param display_options: The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                filter_text_field_control_property = quicksight.CfnTemplate.FilterTextFieldControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__91cd23b096753aa5d23f510cff715dc438567b0d757007b15459db5af0ce2ba5)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextFieldControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html#cfn-quicksight-template-filtertextfieldcontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextFieldControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html#cfn-quicksight-template-filtertextfieldcontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextFieldControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html#cfn-quicksight-template-filtertextfieldcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TextFieldControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html#cfn-quicksight-template-filtertextfieldcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TextFieldControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterTextFieldControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FontConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "font_color": "fontColor",
            "font_decoration": "fontDecoration",
            "font_size": "fontSize",
            "font_style": "fontStyle",
            "font_weight": "fontWeight",
        },
    )
    class FontConfigurationProperty:
        def __init__(
            self,
            *,
            font_color: typing.Optional[builtins.str] = None,
            font_decoration: typing.Optional[builtins.str] = None,
            font_size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FontSizeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            font_style: typing.Optional[builtins.str] = None,
            font_weight: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FontWeightProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Configures the display properties of the given text.

            :param font_color: Determines the color of the text.
            :param font_decoration: Determines the appearance of decorative lines on the text.
            :param font_size: The option that determines the text display size.
            :param font_style: Determines the text display face that is inherited by the given font family.
            :param font_weight: The option that determines the text display weight, or boldness.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                font_configuration_property = quicksight.CfnTemplate.FontConfigurationProperty(
                    font_color="fontColor",
                    font_decoration="fontDecoration",
                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                        relative="relative"
                    ),
                    font_style="fontStyle",
                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                        name="name"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b3469b62ba533651a28a78b890d4deee38bc93ca1181de1f427d8c2ed4ee2f7c)
                check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
                check_type(argname="argument font_decoration", value=font_decoration, expected_type=type_hints["font_decoration"])
                check_type(argname="argument font_size", value=font_size, expected_type=type_hints["font_size"])
                check_type(argname="argument font_style", value=font_style, expected_type=type_hints["font_style"])
                check_type(argname="argument font_weight", value=font_weight, expected_type=type_hints["font_weight"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_color is not None:
                self._values["font_color"] = font_color
            if font_decoration is not None:
                self._values["font_decoration"] = font_decoration
            if font_size is not None:
                self._values["font_size"] = font_size
            if font_style is not None:
                self._values["font_style"] = font_style
            if font_weight is not None:
                self._values["font_weight"] = font_weight

        @builtins.property
        def font_color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the text.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontcolor
            '''
            result = self._values.get("font_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_decoration(self) -> typing.Optional[builtins.str]:
            '''Determines the appearance of decorative lines on the text.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontdecoration
            '''
            result = self._values.get("font_decoration")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_size(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontSizeProperty"]]:
            '''The option that determines the text display size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontsize
            '''
            result = self._values.get("font_size")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontSizeProperty"]], result)

        @builtins.property
        def font_style(self) -> typing.Optional[builtins.str]:
            '''Determines the text display face that is inherited by the given font family.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontstyle
            '''
            result = self._values.get("font_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_weight(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontWeightProperty"]]:
            '''The option that determines the text display weight, or boldness.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontweight
            '''
            result = self._values.get("font_weight")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontWeightProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FontSizeProperty",
        jsii_struct_bases=[],
        name_mapping={"relative": "relative"},
    )
    class FontSizeProperty:
        def __init__(self, *, relative: typing.Optional[builtins.str] = None) -> None:
            '''The option that determines the text display size.

            :param relative: The lexical name for the text size, proportional to its surrounding context.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontsize.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                font_size_property = quicksight.CfnTemplate.FontSizeProperty(
                    relative="relative"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__96a1a2797f4159ba4fd559ac100ca3dd9d695503a82e5babb2c27c636550f204)
                check_type(argname="argument relative", value=relative, expected_type=type_hints["relative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if relative is not None:
                self._values["relative"] = relative

        @builtins.property
        def relative(self) -> typing.Optional[builtins.str]:
            '''The lexical name for the text size, proportional to its surrounding context.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontsize.html#cfn-quicksight-template-fontsize-relative
            '''
            result = self._values.get("relative")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontSizeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FontWeightProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name"},
    )
    class FontWeightProperty:
        def __init__(self, *, name: typing.Optional[builtins.str] = None) -> None:
            '''The option that determines the text display weight, or boldness.

            :param name: The lexical name for the level of boldness of the text display.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontweight.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                font_weight_property = quicksight.CfnTemplate.FontWeightProperty(
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__15121e71351856eb590573e619b4b9bab28f8d3501aa2324291f86ef4af3db52)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The lexical name for the level of boldness of the text display.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontweight.html#cfn-quicksight-template-fontweight-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontWeightProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ForecastComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "custom_seasonality_value": "customSeasonalityValue",
            "lower_boundary": "lowerBoundary",
            "name": "name",
            "periods_backward": "periodsBackward",
            "periods_forward": "periodsForward",
            "prediction_interval": "predictionInterval",
            "seasonality": "seasonality",
            "time": "time",
            "upper_boundary": "upperBoundary",
            "value": "value",
        },
    )
    class ForecastComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            custom_seasonality_value: typing.Optional[jsii.Number] = None,
            lower_boundary: typing.Optional[jsii.Number] = None,
            name: typing.Optional[builtins.str] = None,
            periods_backward: typing.Optional[jsii.Number] = None,
            periods_forward: typing.Optional[jsii.Number] = None,
            prediction_interval: typing.Optional[jsii.Number] = None,
            seasonality: typing.Optional[builtins.str] = None,
            time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            upper_boundary: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The forecast computation configuration.

            :param computation_id: The ID for a computation.
            :param custom_seasonality_value: The custom seasonality value setup of a forecast computation.
            :param lower_boundary: The lower boundary setup of a forecast computation.
            :param name: The name of a computation.
            :param periods_backward: The periods backward setup of a forecast computation.
            :param periods_forward: The periods forward setup of a forecast computation.
            :param prediction_interval: The prediction interval setup of a forecast computation.
            :param seasonality: The seasonality setup of a forecast computation. Choose one of the following options:. - ``AUTOMATIC`` - ``CUSTOM`` : Checks the custom seasonality value.
            :param time: The time field that is used in a computation.
            :param upper_boundary: The upper boundary setup of a forecast computation.
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4b268a89adfb2419a179e2d39f72efde8c0e4db3a1ed16bdb473a924b4f54be0)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument custom_seasonality_value", value=custom_seasonality_value, expected_type=type_hints["custom_seasonality_value"])
                check_type(argname="argument lower_boundary", value=lower_boundary, expected_type=type_hints["lower_boundary"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument periods_backward", value=periods_backward, expected_type=type_hints["periods_backward"])
                check_type(argname="argument periods_forward", value=periods_forward, expected_type=type_hints["periods_forward"])
                check_type(argname="argument prediction_interval", value=prediction_interval, expected_type=type_hints["prediction_interval"])
                check_type(argname="argument seasonality", value=seasonality, expected_type=type_hints["seasonality"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument upper_boundary", value=upper_boundary, expected_type=type_hints["upper_boundary"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
            }
            if custom_seasonality_value is not None:
                self._values["custom_seasonality_value"] = custom_seasonality_value
            if lower_boundary is not None:
                self._values["lower_boundary"] = lower_boundary
            if name is not None:
                self._values["name"] = name
            if periods_backward is not None:
                self._values["periods_backward"] = periods_backward
            if periods_forward is not None:
                self._values["periods_forward"] = periods_forward
            if prediction_interval is not None:
                self._values["prediction_interval"] = prediction_interval
            if seasonality is not None:
                self._values["seasonality"] = seasonality
            if time is not None:
                self._values["time"] = time
            if upper_boundary is not None:
                self._values["upper_boundary"] = upper_boundary
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def custom_seasonality_value(self) -> typing.Optional[jsii.Number]:
            '''The custom seasonality value setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-customseasonalityvalue
            '''
            result = self._values.get("custom_seasonality_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def lower_boundary(self) -> typing.Optional[jsii.Number]:
            '''The lower boundary setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-lowerboundary
            '''
            result = self._values.get("lower_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def periods_backward(self) -> typing.Optional[jsii.Number]:
            '''The periods backward setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-periodsbackward
            '''
            result = self._values.get("periods_backward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_forward(self) -> typing.Optional[jsii.Number]:
            '''The periods forward setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-periodsforward
            '''
            result = self._values.get("periods_forward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def prediction_interval(self) -> typing.Optional[jsii.Number]:
            '''The prediction interval setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-predictioninterval
            '''
            result = self._values.get("prediction_interval")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def seasonality(self) -> typing.Optional[builtins.str]:
            '''The seasonality setup of a forecast computation. Choose one of the following options:.

            - ``AUTOMATIC``
            - ``CUSTOM`` : Checks the custom seasonality value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-seasonality
            '''
            result = self._values.get("seasonality")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]:
            '''The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-time
            '''
            result = self._values.get("time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]], result)

        @builtins.property
        def upper_boundary(self) -> typing.Optional[jsii.Number]:
            '''The upper boundary setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-upperboundary
            '''
            result = self._values.get("upper_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ForecastConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "forecast_properties": "forecastProperties",
            "scenario": "scenario",
        },
    )
    class ForecastConfigurationProperty:
        def __init__(
            self,
            *,
            forecast_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TimeBasedForecastPropertiesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scenario: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ForecastScenarioProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The forecast configuration that is used in a line chart's display properties.

            :param forecast_properties: The forecast properties setup of a forecast in the line chart.
            :param scenario: The forecast scenario of a forecast in the line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                forecast_configuration_property = quicksight.CfnTemplate.ForecastConfigurationProperty(
                    forecast_properties=quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty(
                        lower_boundary=123,
                        periods_backward=123,
                        periods_forward=123,
                        prediction_interval=123,
                        seasonality=123,
                        upper_boundary=123
                    ),
                    scenario=quicksight.CfnTemplate.ForecastScenarioProperty(
                        what_if_point_scenario=quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                            date="date",
                            value=123
                        ),
                        what_if_range_scenario=quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                            end_date="endDate",
                            start_date="startDate",
                            value=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a1b6fc5c895b13eaec515b23f4f8a4692c6d4f5014112a41f729fe4eb5256acd)
                check_type(argname="argument forecast_properties", value=forecast_properties, expected_type=type_hints["forecast_properties"])
                check_type(argname="argument scenario", value=scenario, expected_type=type_hints["scenario"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if forecast_properties is not None:
                self._values["forecast_properties"] = forecast_properties
            if scenario is not None:
                self._values["scenario"] = scenario

        @builtins.property
        def forecast_properties(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TimeBasedForecastPropertiesProperty"]]:
            '''The forecast properties setup of a forecast in the line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastconfiguration.html#cfn-quicksight-template-forecastconfiguration-forecastproperties
            '''
            result = self._values.get("forecast_properties")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TimeBasedForecastPropertiesProperty"]], result)

        @builtins.property
        def scenario(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ForecastScenarioProperty"]]:
            '''The forecast scenario of a forecast in the line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastconfiguration.html#cfn-quicksight-template-forecastconfiguration-scenario
            '''
            result = self._values.get("scenario")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ForecastScenarioProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ForecastScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={
            "what_if_point_scenario": "whatIfPointScenario",
            "what_if_range_scenario": "whatIfRangeScenario",
        },
    )
    class ForecastScenarioProperty:
        def __init__(
            self,
            *,
            what_if_point_scenario: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.WhatIfPointScenarioProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            what_if_range_scenario: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.WhatIfRangeScenarioProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The forecast scenario of a forecast in the line chart.

            :param what_if_point_scenario: The what-if analysis forecast setup with the target date.
            :param what_if_range_scenario: The what-if analysis forecast setup with the date range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastscenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                forecast_scenario_property = quicksight.CfnTemplate.ForecastScenarioProperty(
                    what_if_point_scenario=quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                        date="date",
                        value=123
                    ),
                    what_if_range_scenario=quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                        end_date="endDate",
                        start_date="startDate",
                        value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bb886964e5d61c15d79cc1aa4baa8d8bcdbd6ae6472ac35351ee5ede86476e27)
                check_type(argname="argument what_if_point_scenario", value=what_if_point_scenario, expected_type=type_hints["what_if_point_scenario"])
                check_type(argname="argument what_if_range_scenario", value=what_if_range_scenario, expected_type=type_hints["what_if_range_scenario"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if what_if_point_scenario is not None:
                self._values["what_if_point_scenario"] = what_if_point_scenario
            if what_if_range_scenario is not None:
                self._values["what_if_range_scenario"] = what_if_range_scenario

        @builtins.property
        def what_if_point_scenario(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WhatIfPointScenarioProperty"]]:
            '''The what-if analysis forecast setup with the target date.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastscenario.html#cfn-quicksight-template-forecastscenario-whatifpointscenario
            '''
            result = self._values.get("what_if_point_scenario")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WhatIfPointScenarioProperty"]], result)

        @builtins.property
        def what_if_range_scenario(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WhatIfRangeScenarioProperty"]]:
            '''The what-if analysis forecast setup with the date range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastscenario.html#cfn-quicksight-template-forecastscenario-whatifrangescenario
            '''
            result = self._values.get("what_if_range_scenario")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WhatIfRangeScenarioProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format_configuration": "dateTimeFormatConfiguration",
            "number_format_configuration": "numberFormatConfiguration",
            "string_format_configuration": "stringFormatConfiguration",
        },
    )
    class FormatConfigurationProperty:
        def __init__(
            self,
            *,
            date_time_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            string_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The formatting configuration for all types of field.

            :param date_time_format_configuration: Formatting configuration for ``DateTime`` fields.
            :param number_format_configuration: Formatting configuration for number fields.
            :param string_format_configuration: Formatting configuration for string fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-formatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                format_configuration_property = quicksight.CfnTemplate.FormatConfigurationProperty(
                    date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__acdc6b41040857bec7b41583d6aa2ca903d7c372d0fd7b65e57f47207b1b2ed1)
                check_type(argname="argument date_time_format_configuration", value=date_time_format_configuration, expected_type=type_hints["date_time_format_configuration"])
                check_type(argname="argument number_format_configuration", value=number_format_configuration, expected_type=type_hints["number_format_configuration"])
                check_type(argname="argument string_format_configuration", value=string_format_configuration, expected_type=type_hints["string_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format_configuration is not None:
                self._values["date_time_format_configuration"] = date_time_format_configuration
            if number_format_configuration is not None:
                self._values["number_format_configuration"] = number_format_configuration
            if string_format_configuration is not None:
                self._values["string_format_configuration"] = string_format_configuration

        @builtins.property
        def date_time_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateTimeFormatConfigurationProperty"]]:
            '''Formatting configuration for ``DateTime`` fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-formatconfiguration.html#cfn-quicksight-template-formatconfiguration-datetimeformatconfiguration
            '''
            result = self._values.get("date_time_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateTimeFormatConfigurationProperty"]], result)

        @builtins.property
        def number_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumberFormatConfigurationProperty"]]:
            '''Formatting configuration for number fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-formatconfiguration.html#cfn-quicksight-template-formatconfiguration-numberformatconfiguration
            '''
            result = self._values.get("number_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumberFormatConfigurationProperty"]], result)

        @builtins.property
        def string_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.StringFormatConfigurationProperty"]]:
            '''Formatting configuration for string fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-formatconfiguration.html#cfn-quicksight-template-formatconfiguration-stringformatconfiguration
            '''
            result = self._values.get("string_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.StringFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"screen_canvas_size_options": "screenCanvasSizeOptions"},
    )
    class FreeFormLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            screen_canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Configuration options for the canvas of a free-form layout.

            :param screen_canvas_size_options: The options that determine the sizing of the canvas used in a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                free_form_layout_canvas_size_options_property = quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                    screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                        optimized_view_port_width="optimizedViewPortWidth"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__578614b125fa78db8c3ebb5abac4c2182b919c173af35ff2427c33aeb5edb423)
                check_type(argname="argument screen_canvas_size_options", value=screen_canvas_size_options, expected_type=type_hints["screen_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if screen_canvas_size_options is not None:
                self._values["screen_canvas_size_options"] = screen_canvas_size_options

        @builtins.property
        def screen_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty"]]:
            '''The options that determine the sizing of the canvas used in a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutcanvassizeoptions.html#cfn-quicksight-template-freeformlayoutcanvassizeoptions-screencanvassizeoptions
            '''
            result = self._values.get("screen_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FreeFormLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "elements": "elements",
            "canvas_size_options": "canvasSizeOptions",
        },
    )
    class FreeFormLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FreeFormLayoutElementProperty", typing.Dict[builtins.str, typing.Any]]]]],
            canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a free-form layout.

            :param elements: The elements that are included in a free-form layout.
            :param canvas_size_options: 

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                free_form_layout_configuration_property = quicksight.CfnTemplate.FreeFormLayoutConfigurationProperty(
                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                        element_id="elementId",
                        element_type="elementType",
                        height="height",
                        width="width",
                        x_axis_location="xAxisLocation",
                        y_axis_location="yAxisLocation",
                
                        # the properties below are optional
                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                            visibility="visibility"
                        ),
                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                visibility="visibility"
                            ),
                            expression="expression"
                        )],
                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        visibility="visibility"
                    )],
                
                    # the properties below are optional
                    canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d4cac125aca61112d564bc6e57da7fa96c4ae6e3550c01d3b1d6caceb0d8e1ba)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }
            if canvas_size_options is not None:
                self._values["canvas_size_options"] = canvas_size_options

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FreeFormLayoutElementProperty"]]]:
            '''The elements that are included in a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutconfiguration.html#cfn-quicksight-template-freeformlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FreeFormLayoutElementProperty"]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutconfiguration.html#cfn-quicksight-template-freeformlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "visibility": "visibility"},
    )
    class FreeFormLayoutElementBackgroundStyleProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The background style configuration of a free-form layout element.

            :param color: The background color of a free-form layout element.
            :param visibility: The background visibility of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementbackgroundstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                free_form_layout_element_background_style_property = quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                    color="color",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c5c2a2026e2d524c7e248d3811cd8d5b8eaf86ff1dcece91281d063c70baf7dc)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The background color of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-template-freeformlayoutelementbackgroundstyle-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The background visibility of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-template-freeformlayoutelementbackgroundstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementBackgroundStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "visibility": "visibility"},
    )
    class FreeFormLayoutElementBorderStyleProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The background style configuration of a free-form layout element.

            :param color: The border color of a free-form layout element.
            :param visibility: The border visibility of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementborderstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                free_form_layout_element_border_style_property = quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                    color="color",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f56b915d4e5cc7d588d0f18eb9fd3d08c59522395df40438804d9d4bbeb58248)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The border color of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementborderstyle.html#cfn-quicksight-template-freeformlayoutelementborderstyle-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The border visibility of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementborderstyle.html#cfn-quicksight-template-freeformlayoutelementborderstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementBorderStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FreeFormLayoutElementProperty",
        jsii_struct_bases=[],
        name_mapping={
            "element_id": "elementId",
            "element_type": "elementType",
            "height": "height",
            "width": "width",
            "x_axis_location": "xAxisLocation",
            "y_axis_location": "yAxisLocation",
            "background_style": "backgroundStyle",
            "border_style": "borderStyle",
            "loading_animation": "loadingAnimation",
            "rendering_rules": "renderingRules",
            "selected_border_style": "selectedBorderStyle",
            "visibility": "visibility",
        },
    )
    class FreeFormLayoutElementProperty:
        def __init__(
            self,
            *,
            element_id: builtins.str,
            element_type: builtins.str,
            height: builtins.str,
            width: builtins.str,
            x_axis_location: builtins.str,
            y_axis_location: builtins.str,
            background_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            border_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FreeFormLayoutElementBorderStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            loading_animation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LoadingAnimationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rendering_rules: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SheetElementRenderingRuleProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            selected_border_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FreeFormLayoutElementBorderStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''An element within a free-form layout.

            :param element_id: A unique identifier for an element within a free-form layout.
            :param element_type: The type of element.
            :param height: The height of an element within a free-form layout.
            :param width: The width of an element within a free-form layout.
            :param x_axis_location: The x-axis coordinate of the element.
            :param y_axis_location: The y-axis coordinate of the element.
            :param background_style: The background style configuration of a free-form layout element.
            :param border_style: The border style configuration of a free-form layout element.
            :param loading_animation: The loading animation configuration of a free-form layout element.
            :param rendering_rules: The rendering rules that determine when an element should be displayed within a free-form layout.
            :param selected_border_style: The border style configuration of a free-form layout element. This border style is used when the element is selected.
            :param visibility: The visibility of an element within a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                free_form_layout_element_property = quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                    element_id="elementId",
                    element_type="elementType",
                    height="height",
                    width="width",
                    x_axis_location="xAxisLocation",
                    y_axis_location="yAxisLocation",
                
                    # the properties below are optional
                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                        visibility="visibility"
                    ),
                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                            visibility="visibility"
                        ),
                        expression="expression"
                    )],
                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__25cb30344f75b27e4dad55332b21f1de2d8134f89b0322a8c2001b30746f08cb)
                check_type(argname="argument element_id", value=element_id, expected_type=type_hints["element_id"])
                check_type(argname="argument element_type", value=element_type, expected_type=type_hints["element_type"])
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
                check_type(argname="argument x_axis_location", value=x_axis_location, expected_type=type_hints["x_axis_location"])
                check_type(argname="argument y_axis_location", value=y_axis_location, expected_type=type_hints["y_axis_location"])
                check_type(argname="argument background_style", value=background_style, expected_type=type_hints["background_style"])
                check_type(argname="argument border_style", value=border_style, expected_type=type_hints["border_style"])
                check_type(argname="argument loading_animation", value=loading_animation, expected_type=type_hints["loading_animation"])
                check_type(argname="argument rendering_rules", value=rendering_rules, expected_type=type_hints["rendering_rules"])
                check_type(argname="argument selected_border_style", value=selected_border_style, expected_type=type_hints["selected_border_style"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "element_id": element_id,
                "element_type": element_type,
                "height": height,
                "width": width,
                "x_axis_location": x_axis_location,
                "y_axis_location": y_axis_location,
            }
            if background_style is not None:
                self._values["background_style"] = background_style
            if border_style is not None:
                self._values["border_style"] = border_style
            if loading_animation is not None:
                self._values["loading_animation"] = loading_animation
            if rendering_rules is not None:
                self._values["rendering_rules"] = rendering_rules
            if selected_border_style is not None:
                self._values["selected_border_style"] = selected_border_style
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def element_id(self) -> builtins.str:
            '''A unique identifier for an element within a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-elementid
            '''
            result = self._values.get("element_id")
            assert result is not None, "Required property 'element_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element_type(self) -> builtins.str:
            '''The type of element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-elementtype
            '''
            result = self._values.get("element_type")
            assert result is not None, "Required property 'element_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def height(self) -> builtins.str:
            '''The height of an element within a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-height
            '''
            result = self._values.get("height")
            assert result is not None, "Required property 'height' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def width(self) -> builtins.str:
            '''The width of an element within a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-width
            '''
            result = self._values.get("width")
            assert result is not None, "Required property 'width' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def x_axis_location(self) -> builtins.str:
            '''The x-axis coordinate of the element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-xaxislocation
            '''
            result = self._values.get("x_axis_location")
            assert result is not None, "Required property 'x_axis_location' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def y_axis_location(self) -> builtins.str:
            '''The y-axis coordinate of the element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-yaxislocation
            '''
            result = self._values.get("y_axis_location")
            assert result is not None, "Required property 'y_axis_location' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def background_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty"]]:
            '''The background style configuration of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-backgroundstyle
            '''
            result = self._values.get("background_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty"]], result)

        @builtins.property
        def border_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FreeFormLayoutElementBorderStyleProperty"]]:
            '''The border style configuration of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-borderstyle
            '''
            result = self._values.get("border_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FreeFormLayoutElementBorderStyleProperty"]], result)

        @builtins.property
        def loading_animation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LoadingAnimationProperty"]]:
            '''The loading animation configuration of a free-form layout element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-loadinganimation
            '''
            result = self._values.get("loading_animation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LoadingAnimationProperty"]], result)

        @builtins.property
        def rendering_rules(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetElementRenderingRuleProperty"]]]]:
            '''The rendering rules that determine when an element should be displayed within a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-renderingrules
            '''
            result = self._values.get("rendering_rules")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetElementRenderingRuleProperty"]]]], result)

        @builtins.property
        def selected_border_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FreeFormLayoutElementBorderStyleProperty"]]:
            '''The border style configuration of a free-form layout element.

            This border style is used when the element is selected.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-selectedborderstyle
            '''
            result = self._values.get("selected_border_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FreeFormLayoutElementBorderStyleProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of an element within a free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"optimized_view_port_width": "optimizedViewPortWidth"},
    )
    class FreeFormLayoutScreenCanvasSizeOptionsProperty:
        def __init__(self, *, optimized_view_port_width: builtins.str) -> None:
            '''The options that determine the sizing of the canvas used in a free-form layout.

            :param optimized_view_port_width: The width that the view port will be optimized for when the layout renders.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutscreencanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                free_form_layout_screen_canvas_size_options_property = quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                    optimized_view_port_width="optimizedViewPortWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4627784e9a82be5a483f9fee328533ba95d23dbbf4afd5ee1fff8bd408376a01)
                check_type(argname="argument optimized_view_port_width", value=optimized_view_port_width, expected_type=type_hints["optimized_view_port_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "optimized_view_port_width": optimized_view_port_width,
            }

        @builtins.property
        def optimized_view_port_width(self) -> builtins.str:
            '''The width that the view port will be optimized for when the layout renders.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutscreencanvassizeoptions.html#cfn-quicksight-template-freeformlayoutscreencanvassizeoptions-optimizedviewportwidth
            '''
            result = self._values.get("optimized_view_port_width")
            assert result is not None, "Required property 'optimized_view_port_width' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutScreenCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"elements": "elements"},
    )
    class FreeFormSectionLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FreeFormLayoutElementProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The free-form layout configuration of a section.

            :param elements: The elements that are included in the free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformsectionlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                free_form_section_layout_configuration_property = quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                        element_id="elementId",
                        element_type="elementType",
                        height="height",
                        width="width",
                        x_axis_location="xAxisLocation",
                        y_axis_location="yAxisLocation",
                
                        # the properties below are optional
                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                            visibility="visibility"
                        ),
                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                visibility="visibility"
                            ),
                            expression="expression"
                        )],
                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        visibility="visibility"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fb8df5f871659ca72d6d13167d406149f8d88621342aeb61ff2ff094a4651b91)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FreeFormLayoutElementProperty"]]]:
            '''The elements that are included in the free-form layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformsectionlayoutconfiguration.html#cfn-quicksight-template-freeformsectionlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FreeFormLayoutElementProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormSectionLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"category": "category", "values": "values"},
    )
    class FunnelChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :param category: The category field wells of a funnel chart. Values are grouped by category fields.
            :param values: The value field wells of a funnel chart. Values are aggregated based on categories.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                funnel_chart_aggregated_field_wells_property = quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a7bd6bb6806b5fddb8ca871b0b0c39956897753f18b6c16d5c6e23a6cefe5ead)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The category field wells of a funnel chart.

            Values are grouped by category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartaggregatedfieldwells.html#cfn-quicksight-template-funnelchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The value field wells of a funnel chart.

            Values are aggregated based on categories.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartaggregatedfieldwells.html#cfn-quicksight-template-funnelchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FunnelChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "data_label_options": "dataLabelOptions",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class FunnelChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FunnelChartDataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FunnelChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FunnelChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``FunnelChartVisual`` .

            :param category_label_options: The label options of the categories that are displayed in a ``FunnelChartVisual`` .
            :param data_label_options: The options that determine the presentation of the data labels.
            :param field_wells: The field well configuration of a ``FunnelChartVisual`` .
            :param sort_configuration: The sort configuration of a ``FunnelChartVisual`` .
            :param tooltip: The tooltip configuration of a ``FunnelChartVisual`` .
            :param value_label_options: The label options for the values that are displayed in a ``FunnelChartVisual`` .
            :param visual_palette: The visual palette configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e476041f68cbbf567dd0859194b5d26f6a98f02f72e5998caef5736c738d7324)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument data_label_options", value=data_label_options, expected_type=type_hints["data_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if data_label_options is not None:
                self._values["data_label_options"] = data_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the categories that are displayed in a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def data_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FunnelChartDataLabelOptionsProperty"]]:
            '''The options that determine the presentation of the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-datalabeloptions
            '''
            result = self._values.get("data_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FunnelChartDataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FunnelChartFieldWellsProperty"]]:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FunnelChartFieldWellsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FunnelChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FunnelChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options for the values that are displayed in a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]]:
            '''The visual palette configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FunnelChartDataLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_visibility": "categoryLabelVisibility",
            "label_color": "labelColor",
            "label_font_configuration": "labelFontConfiguration",
            "measure_data_label_style": "measureDataLabelStyle",
            "measure_label_visibility": "measureLabelVisibility",
            "position": "position",
            "visibility": "visibility",
        },
    )
    class FunnelChartDataLabelOptionsProperty:
        def __init__(
            self,
            *,
            category_label_visibility: typing.Optional[builtins.str] = None,
            label_color: typing.Optional[builtins.str] = None,
            label_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            measure_data_label_style: typing.Optional[builtins.str] = None,
            measure_label_visibility: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of the data labels.

            :param category_label_visibility: The visibility of the category labels within the data labels.
            :param label_color: The color of the data label text.
            :param label_font_configuration: The font configuration for the data labels. Only the ``FontSize`` attribute of the font configuration is used for data labels.
            :param measure_data_label_style: Determines the style of the metric labels.
            :param measure_label_visibility: The visibility of the measure labels within the data labels.
            :param position: Determines the positioning of the data label relative to a section of the funnel.
            :param visibility: The visibility option that determines if data labels are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                funnel_chart_data_label_options_property = quicksight.CfnTemplate.FunnelChartDataLabelOptionsProperty(
                    category_label_visibility="categoryLabelVisibility",
                    label_color="labelColor",
                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    measure_data_label_style="measureDataLabelStyle",
                    measure_label_visibility="measureLabelVisibility",
                    position="position",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__12be43077e9b40ff95dcd923411975cf5f8242d6f3b4857924875d52bf02fbfa)
                check_type(argname="argument category_label_visibility", value=category_label_visibility, expected_type=type_hints["category_label_visibility"])
                check_type(argname="argument label_color", value=label_color, expected_type=type_hints["label_color"])
                check_type(argname="argument label_font_configuration", value=label_font_configuration, expected_type=type_hints["label_font_configuration"])
                check_type(argname="argument measure_data_label_style", value=measure_data_label_style, expected_type=type_hints["measure_data_label_style"])
                check_type(argname="argument measure_label_visibility", value=measure_label_visibility, expected_type=type_hints["measure_label_visibility"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_visibility is not None:
                self._values["category_label_visibility"] = category_label_visibility
            if label_color is not None:
                self._values["label_color"] = label_color
            if label_font_configuration is not None:
                self._values["label_font_configuration"] = label_font_configuration
            if measure_data_label_style is not None:
                self._values["measure_data_label_style"] = measure_data_label_style
            if measure_label_visibility is not None:
                self._values["measure_label_visibility"] = measure_label_visibility
            if position is not None:
                self._values["position"] = position
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def category_label_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the category labels within the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-categorylabelvisibility
            '''
            result = self._values.get("category_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_color(self) -> typing.Optional[builtins.str]:
            '''The color of the data label text.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-labelcolor
            '''
            result = self._values.get("label_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"]]:
            '''The font configuration for the data labels.

            Only the ``FontSize`` attribute of the font configuration is used for data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-labelfontconfiguration
            '''
            result = self._values.get("label_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"]], result)

        @builtins.property
        def measure_data_label_style(self) -> typing.Optional[builtins.str]:
            '''Determines the style of the metric labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-measuredatalabelstyle
            '''
            result = self._values.get("measure_data_label_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def measure_label_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the measure labels within the data labels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-measurelabelvisibility
            '''
            result = self._values.get("measure_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''Determines the positioning of the data label relative to a section of the funnel.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility option that determines if data labels are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartDataLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FunnelChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "funnel_chart_aggregated_field_wells": "funnelChartAggregatedFieldWells",
        },
    )
    class FunnelChartFieldWellsProperty:
        def __init__(
            self,
            *,
            funnel_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FunnelChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a ``FunnelChartVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param funnel_chart_aggregated_field_wells: The field well configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                funnel_chart_field_wells_property = quicksight.CfnTemplate.FunnelChartFieldWellsProperty(
                    funnel_chart_aggregated_field_wells=quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__471f8fdec66cf65d5903c99b6be5980372b1618781ebf0e5b062408fd2b22bd8)
                check_type(argname="argument funnel_chart_aggregated_field_wells", value=funnel_chart_aggregated_field_wells, expected_type=type_hints["funnel_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if funnel_chart_aggregated_field_wells is not None:
                self._values["funnel_chart_aggregated_field_wells"] = funnel_chart_aggregated_field_wells

        @builtins.property
        def funnel_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FunnelChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartfieldwells.html#cfn-quicksight-template-funnelchartfieldwells-funnelchartaggregatedfieldwells
            '''
            result = self._values.get("funnel_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FunnelChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FunnelChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class FunnelChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``FunnelChartVisual`` .

            :param category_items_limit: The limit on the number of categories displayed.
            :param category_sort: The sort configuration of the category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                funnel_chart_sort_configuration_property = quicksight.CfnTemplate.FunnelChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aef80e1ad1d3108bae0d0ea9e9a03fbd222dffe680b6fb323c6f8f02eb75d914)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartsortconfiguration.html#cfn-quicksight-template-funnelchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartsortconfiguration.html#cfn-quicksight-template-funnelchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.FunnelChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class FunnelChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FunnelChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A funnel chart.

            For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``FunnelChartVisual`` .
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__88c327ab778f2f7154850fbba1d3978086640da4a25649e5bea6b8b06c90f458)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FunnelChartConfigurationProperty"]]:
            '''The configuration of a ``FunnelChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FunnelChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"foreground_color": "foregroundColor"},
    )
    class GaugeChartArcConditionalFormattingProperty:
        def __init__(
            self,
            *,
            foreground_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of the arc of a ``GaugeChartVisual`` .

            :param foreground_color: The conditional formatting of the arc foreground color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartarcconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gauge_chart_arc_conditional_formatting_property = quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty(
                    foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__436ef0ce4c9cb6675bcb93e940ebfb1ec177942857d43bd23aaf9aaa170a5d80)
                check_type(argname="argument foreground_color", value=foreground_color, expected_type=type_hints["foreground_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if foreground_color is not None:
                self._values["foreground_color"] = foreground_color

        @builtins.property
        def foreground_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the arc foreground color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartarcconditionalformatting.html#cfn-quicksight-template-gaugechartarcconditionalformatting-foregroundcolor
            '''
            result = self._values.get("foreground_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartArcConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GaugeChartConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"arc": "arc", "primary_value": "primaryValue"},
    )
    class GaugeChartConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            arc: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GaugeChartArcConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Conditional formatting options of a ``GaugeChartVisual`` .

            :param arc: The options that determine the presentation of the arc of a ``GaugeChartVisual`` .
            :param primary_value: The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gauge_chart_conditional_formatting_option_property = quicksight.CfnTemplate.GaugeChartConditionalFormattingOptionProperty(
                    arc=quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty(
                        foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    primary_value=quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty(
                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5112906a24edd8e035bb15545d6cd7dd1b156e881499b860838a93532ee13e4b)
                check_type(argname="argument arc", value=arc, expected_type=type_hints["arc"])
                check_type(argname="argument primary_value", value=primary_value, expected_type=type_hints["primary_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc is not None:
                self._values["arc"] = arc
            if primary_value is not None:
                self._values["primary_value"] = primary_value

        @builtins.property
        def arc(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GaugeChartArcConditionalFormattingProperty"]]:
            '''The options that determine the presentation of the arc of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformattingoption.html#cfn-quicksight-template-gaugechartconditionalformattingoption-arc
            '''
            result = self._values.get("arc")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GaugeChartArcConditionalFormattingProperty"]], result)

        @builtins.property
        def primary_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty"]]:
            '''The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformattingoption.html#cfn-quicksight-template-gaugechartconditionalformattingoption-primaryvalue
            '''
            result = self._values.get("primary_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GaugeChartConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class GaugeChartConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GaugeChartConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting of a ``GaugeChartVisual`` .

            :param conditional_formatting_options: Conditional formatting options of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gauge_chart_conditional_formatting_property = quicksight.CfnTemplate.GaugeChartConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnTemplate.GaugeChartConditionalFormattingOptionProperty(
                        arc=quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty(
                            foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        primary_value=quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty(
                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2aae0062f023b94b466eeae30f381f8dfd52660e394b4fe0b9d7da3f755935d3)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GaugeChartConditionalFormattingOptionProperty"]]]]:
            '''Conditional formatting options of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformatting.html#cfn-quicksight-template-gaugechartconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GaugeChartConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GaugeChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "gauge_chart_options": "gaugeChartOptions",
            "tooltip_options": "tooltipOptions",
            "visual_palette": "visualPalette",
        },
    )
    class GaugeChartConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GaugeChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            gauge_chart_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GaugeChartOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``GaugeChartVisual`` .

            :param data_labels: The data label configuration of a ``GaugeChartVisual`` .
            :param field_wells: The field well configuration of a ``GaugeChartVisual`` .
            :param gauge_chart_options: The options that determine the presentation of the ``GaugeChartVisual`` .
            :param tooltip_options: The tooltip configuration of a ``GaugeChartVisual`` .
            :param visual_palette: The visual palette configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__31660e5ea9cf2cbc922be62c6cada90255349936dda5d364ea4c7bb12ee13fb2)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument gauge_chart_options", value=gauge_chart_options, expected_type=type_hints["gauge_chart_options"])
                check_type(argname="argument tooltip_options", value=tooltip_options, expected_type=type_hints["tooltip_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if gauge_chart_options is not None:
                self._values["gauge_chart_options"] = gauge_chart_options
            if tooltip_options is not None:
                self._values["tooltip_options"] = tooltip_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The data label configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GaugeChartFieldWellsProperty"]]:
            '''The field well configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GaugeChartFieldWellsProperty"]], result)

        @builtins.property
        def gauge_chart_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GaugeChartOptionsProperty"]]:
            '''The options that determine the presentation of the ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-gaugechartoptions
            '''
            result = self._values.get("gauge_chart_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GaugeChartOptionsProperty"]], result)

        @builtins.property
        def tooltip_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-tooltipoptions
            '''
            result = self._values.get("tooltip_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]]:
            '''The visual palette configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GaugeChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"target_values": "targetValues", "values": "values"},
    )
    class GaugeChartFieldWellsProperty:
        def __init__(
            self,
            *,
            target_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a ``GaugeChartVisual`` .

            :param target_values: The target value field wells of a ``GaugeChartVisual`` .
            :param values: The value field wells of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__51f564322d2b7236e526362ce70069f02d33a5dd91614daa635235ce5cc7ed53)
                check_type(argname="argument target_values", value=target_values, expected_type=type_hints["target_values"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_values is not None:
                self._values["target_values"] = target_values
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def target_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The target value field wells of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartfieldwells.html#cfn-quicksight-template-gaugechartfieldwells-targetvalues
            '''
            result = self._values.get("target_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The value field wells of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartfieldwells.html#cfn-quicksight-template-gaugechartfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GaugeChartOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arc": "arc",
            "arc_axis": "arcAxis",
            "comparison": "comparison",
            "primary_value_display_type": "primaryValueDisplayType",
            "primary_value_font_configuration": "primaryValueFontConfiguration",
        },
    )
    class GaugeChartOptionsProperty:
        def __init__(
            self,
            *,
            arc: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ArcConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            arc_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ArcAxisConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            comparison: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ComparisonConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_value_display_type: typing.Optional[builtins.str] = None,
            primary_value_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of the ``GaugeChartVisual`` .

            :param arc: The arc configuration of a ``GaugeChartVisual`` .
            :param arc_axis: The arc axis configuration of a ``GaugeChartVisual`` .
            :param comparison: The comparison configuration of a ``GaugeChartVisual`` .
            :param primary_value_display_type: The options that determine the primary value display type.
            :param primary_value_font_configuration: The options that determine the primary value font configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gauge_chart_options_property = quicksight.CfnTemplate.GaugeChartOptionsProperty(
                    arc=quicksight.CfnTemplate.ArcConfigurationProperty(
                        arc_angle=123,
                        arc_thickness="arcThickness"
                    ),
                    arc_axis=quicksight.CfnTemplate.ArcAxisConfigurationProperty(
                        range=quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                            max=123,
                            min=123
                        ),
                        reserve_range=123
                    ),
                    comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                        comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        comparison_method="comparisonMethod"
                    ),
                    primary_value_display_type="primaryValueDisplayType",
                    primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7496bf2790efb8bb0918a64ba138509ffeeedab22e886649e39297d2ff212196)
                check_type(argname="argument arc", value=arc, expected_type=type_hints["arc"])
                check_type(argname="argument arc_axis", value=arc_axis, expected_type=type_hints["arc_axis"])
                check_type(argname="argument comparison", value=comparison, expected_type=type_hints["comparison"])
                check_type(argname="argument primary_value_display_type", value=primary_value_display_type, expected_type=type_hints["primary_value_display_type"])
                check_type(argname="argument primary_value_font_configuration", value=primary_value_font_configuration, expected_type=type_hints["primary_value_font_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc is not None:
                self._values["arc"] = arc
            if arc_axis is not None:
                self._values["arc_axis"] = arc_axis
            if comparison is not None:
                self._values["comparison"] = comparison
            if primary_value_display_type is not None:
                self._values["primary_value_display_type"] = primary_value_display_type
            if primary_value_font_configuration is not None:
                self._values["primary_value_font_configuration"] = primary_value_font_configuration

        @builtins.property
        def arc(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ArcConfigurationProperty"]]:
            '''The arc configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-arc
            '''
            result = self._values.get("arc")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ArcConfigurationProperty"]], result)

        @builtins.property
        def arc_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ArcAxisConfigurationProperty"]]:
            '''The arc axis configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-arcaxis
            '''
            result = self._values.get("arc_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ArcAxisConfigurationProperty"]], result)

        @builtins.property
        def comparison(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ComparisonConfigurationProperty"]]:
            '''The comparison configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-comparison
            '''
            result = self._values.get("comparison")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ComparisonConfigurationProperty"]], result)

        @builtins.property
        def primary_value_display_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the primary value display type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-primaryvaluedisplaytype
            '''
            result = self._values.get("primary_value_display_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"]]:
            '''The options that determine the primary value font configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-primaryvaluefontconfiguration
            '''
            result = self._values.get("primary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class GaugeChartPrimaryValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :param icon: The conditional formatting of the primary value icon.
            :param text_color: The conditional formatting of the primary value text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartprimaryvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gauge_chart_primary_value_conditional_formatting_property = quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty(
                    icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0d5330716651cc74d353267430eddc96f133a2deb8edf9c27c2037953bd31eac)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting of the primary value icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-template-gaugechartprimaryvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the primary value text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-template-gaugechartprimaryvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartPrimaryValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GaugeChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class GaugeChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GaugeChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GaugeChartConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A gauge chart.

            For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``GaugeChartVisual`` .
            :param conditional_formatting: The conditional formatting of a ``GaugeChartVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9911ce5c489454303eb190a9103b593ed6610d87bdd3d22d992f3b5e0134d617)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GaugeChartConfigurationProperty"]]:
            '''The configuration of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GaugeChartConfigurationProperty"]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GaugeChartConditionalFormattingProperty"]]:
            '''The conditional formatting of a ``GaugeChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GaugeChartConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "east": "east",
            "north": "north",
            "south": "south",
            "west": "west",
        },
    )
    class GeospatialCoordinateBoundsProperty:
        def __init__(
            self,
            *,
            east: jsii.Number,
            north: jsii.Number,
            south: jsii.Number,
            west: jsii.Number,
        ) -> None:
            '''The bound options (north, south, west, east) of the geospatial window options.

            :param east: The longitude of the east bound of the geospatial coordinate bounds.
            :param north: The latitude of the north bound of the geospatial coordinate bounds.
            :param south: The latitude of the south bound of the geospatial coordinate bounds.
            :param west: The longitude of the west bound of the geospatial coordinate bounds.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geospatial_coordinate_bounds_property = quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                    east=123,
                    north=123,
                    south=123,
                    west=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e0618b503ed66a7115e609c691ee63ca56267ff9fcc56f5a2d7505e1bb6d5dc6)
                check_type(argname="argument east", value=east, expected_type=type_hints["east"])
                check_type(argname="argument north", value=north, expected_type=type_hints["north"])
                check_type(argname="argument south", value=south, expected_type=type_hints["south"])
                check_type(argname="argument west", value=west, expected_type=type_hints["west"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "east": east,
                "north": north,
                "south": south,
                "west": west,
            }

        @builtins.property
        def east(self) -> jsii.Number:
            '''The longitude of the east bound of the geospatial coordinate bounds.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html#cfn-quicksight-template-geospatialcoordinatebounds-east
            '''
            result = self._values.get("east")
            assert result is not None, "Required property 'east' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def north(self) -> jsii.Number:
            '''The latitude of the north bound of the geospatial coordinate bounds.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html#cfn-quicksight-template-geospatialcoordinatebounds-north
            '''
            result = self._values.get("north")
            assert result is not None, "Required property 'north' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def south(self) -> jsii.Number:
            '''The latitude of the south bound of the geospatial coordinate bounds.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html#cfn-quicksight-template-geospatialcoordinatebounds-south
            '''
            result = self._values.get("south")
            assert result is not None, "Required property 'south' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def west(self) -> jsii.Number:
            '''The longitude of the west bound of the geospatial coordinate bounds.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html#cfn-quicksight-template-geospatialcoordinatebounds-west
            '''
            result = self._values.get("west")
            assert result is not None, "Required property 'west' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialCoordinateBoundsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GeospatialHeatmapColorScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"colors": "colors"},
    )
    class GeospatialHeatmapColorScaleProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GeospatialHeatmapDataColorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The color scale specification for the heatmap point style.

            :param colors: The list of colors to be used in heatmap point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialheatmapcolorscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geospatial_heatmap_color_scale_property = quicksight.CfnTemplate.GeospatialHeatmapColorScaleProperty(
                    colors=[quicksight.CfnTemplate.GeospatialHeatmapDataColorProperty(
                        color="color"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__97f4e71fe84a69e8594d5a40d3c3565168672613da4e1197fa5a3ba3228d3823)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialHeatmapDataColorProperty"]]]]:
            '''The list of colors to be used in heatmap point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialheatmapcolorscale.html#cfn-quicksight-template-geospatialheatmapcolorscale-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialHeatmapDataColorProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialHeatmapColorScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GeospatialHeatmapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"heatmap_color": "heatmapColor"},
    )
    class GeospatialHeatmapConfigurationProperty:
        def __init__(
            self,
            *,
            heatmap_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GeospatialHeatmapColorScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The heatmap configuration of the geospatial point style.

            :param heatmap_color: The color scale specification for the heatmap point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialheatmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geospatial_heatmap_configuration_property = quicksight.CfnTemplate.GeospatialHeatmapConfigurationProperty(
                    heatmap_color=quicksight.CfnTemplate.GeospatialHeatmapColorScaleProperty(
                        colors=[quicksight.CfnTemplate.GeospatialHeatmapDataColorProperty(
                            color="color"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8d9d0a9eae4bec20f2a35fd69381cbcbb6593ed91307368c75c57b775387bae8)
                check_type(argname="argument heatmap_color", value=heatmap_color, expected_type=type_hints["heatmap_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if heatmap_color is not None:
                self._values["heatmap_color"] = heatmap_color

        @builtins.property
        def heatmap_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialHeatmapColorScaleProperty"]]:
            '''The color scale specification for the heatmap point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialheatmapconfiguration.html#cfn-quicksight-template-geospatialheatmapconfiguration-heatmapcolor
            '''
            result = self._values.get("heatmap_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialHeatmapColorScaleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialHeatmapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GeospatialHeatmapDataColorProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color"},
    )
    class GeospatialHeatmapDataColorProperty:
        def __init__(self, *, color: builtins.str) -> None:
            '''The color to be used in the heatmap point style.

            :param color: The hex color to be used in the heatmap point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialheatmapdatacolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geospatial_heatmap_data_color_property = quicksight.CfnTemplate.GeospatialHeatmapDataColorProperty(
                    color="color"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__68c180291553dcefd48063c6a1fbcb141cd6df09cc6e9b3afee8302f4f93feb3)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
            }

        @builtins.property
        def color(self) -> builtins.str:
            '''The hex color to be used in the heatmap point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialheatmapdatacolor.html#cfn-quicksight-template-geospatialheatmapdatacolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialHeatmapDataColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GeospatialMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "colors": "colors",
            "geospatial": "geospatial",
            "values": "values",
        },
    )
    class GeospatialMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            geospatial: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells for a geospatial map.

            :param colors: The color field wells of a geospatial map.
            :param geospatial: The geospatial field wells of a geospatial map. Values are grouped by geospatial fields.
            :param values: The size field wells of a geospatial map. Values are aggregated based on geospatial fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4078270ae0d1f0826052a34ba441c52f3fe6b93c16d193c5e80a8cb9797c99d5)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument geospatial", value=geospatial, expected_type=type_hints["geospatial"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors
            if geospatial is not None:
                self._values["geospatial"] = geospatial
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The color field wells of a geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapaggregatedfieldwells.html#cfn-quicksight-template-geospatialmapaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def geospatial(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The geospatial field wells of a geospatial map.

            Values are grouped by geospatial fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapaggregatedfieldwells.html#cfn-quicksight-template-geospatialmapaggregatedfieldwells-geospatial
            '''
            result = self._values.get("geospatial")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The size field wells of a geospatial map.

            Values are aggregated based on geospatial fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapaggregatedfieldwells.html#cfn-quicksight-template-geospatialmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GeospatialMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "legend": "legend",
            "map_style_options": "mapStyleOptions",
            "point_style_options": "pointStyleOptions",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "window_options": "windowOptions",
        },
    )
    class GeospatialMapConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GeospatialMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            map_style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GeospatialMapStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            point_style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GeospatialPointStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            window_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GeospatialWindowOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``GeospatialMapVisual`` .

            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param map_style_options: The map style options of the geospatial map.
            :param point_style_options: The point style options of the geospatial map.
            :param tooltip: The tooltip display setup of the visual.
            :param visual_palette: 
            :param window_options: The window options of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dc257a355d98660cc467f4dde2d7433949be71dda663428f3f7a77c40098f56e)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument map_style_options", value=map_style_options, expected_type=type_hints["map_style_options"])
                check_type(argname="argument point_style_options", value=point_style_options, expected_type=type_hints["point_style_options"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument window_options", value=window_options, expected_type=type_hints["window_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if map_style_options is not None:
                self._values["map_style_options"] = map_style_options
            if point_style_options is not None:
                self._values["point_style_options"] = point_style_options
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if window_options is not None:
                self._values["window_options"] = window_options

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialMapFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def map_style_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialMapStyleOptionsProperty"]]:
            '''The map style options of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-mapstyleoptions
            '''
            result = self._values.get("map_style_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialMapStyleOptionsProperty"]], result)

        @builtins.property
        def point_style_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialPointStyleOptionsProperty"]]:
            '''The point style options of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-pointstyleoptions
            '''
            result = self._values.get("point_style_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialPointStyleOptionsProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]], result)

        @builtins.property
        def window_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialWindowOptionsProperty"]]:
            '''The window options of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-windowoptions
            '''
            result = self._values.get("window_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialWindowOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GeospatialMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "geospatial_map_aggregated_field_wells": "geospatialMapAggregatedFieldWells",
        },
    )
    class GeospatialMapFieldWellsProperty:
        def __init__(
            self,
            *,
            geospatial_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GeospatialMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``GeospatialMapVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param geospatial_map_aggregated_field_wells: The aggregated field well for a geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__900c4bd8978e855594c12f2d2a001ac72365ed9de1052ed0c5397c8d7781ead6)
                check_type(argname="argument geospatial_map_aggregated_field_wells", value=geospatial_map_aggregated_field_wells, expected_type=type_hints["geospatial_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if geospatial_map_aggregated_field_wells is not None:
                self._values["geospatial_map_aggregated_field_wells"] = geospatial_map_aggregated_field_wells

        @builtins.property
        def geospatial_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field well for a geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapfieldwells.html#cfn-quicksight-template-geospatialmapfieldwells-geospatialmapaggregatedfieldwells
            '''
            result = self._values.get("geospatial_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"base_map_style": "baseMapStyle"},
    )
    class GeospatialMapStyleOptionsProperty:
        def __init__(
            self,
            *,
            base_map_style: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The map style options of the geospatial map.

            :param base_map_style: The base map style of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geospatial_map_style_options_property = quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                    base_map_style="baseMapStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__243f3d486b014da7bc3129533b25ed3166fc37e43bf1c28e2c278a8513e2299f)
                check_type(argname="argument base_map_style", value=base_map_style, expected_type=type_hints["base_map_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if base_map_style is not None:
                self._values["base_map_style"] = base_map_style

        @builtins.property
        def base_map_style(self) -> typing.Optional[builtins.str]:
            '''The base map style of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapstyleoptions.html#cfn-quicksight-template-geospatialmapstyleoptions-basemapstyle
            '''
            result = self._values.get("base_map_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GeospatialMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class GeospatialMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GeospatialMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A geospatial map or a points on map visual.

            For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5befc48a60f2c98e0a66d26e02857cead97b29898f87167c6dce7fa06b246e0a)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialMapConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GeospatialPointStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cluster_marker_configuration": "clusterMarkerConfiguration",
            "heatmap_configuration": "heatmapConfiguration",
            "selected_point_style": "selectedPointStyle",
        },
    )
    class GeospatialPointStyleOptionsProperty:
        def __init__(
            self,
            *,
            cluster_marker_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ClusterMarkerConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            heatmap_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GeospatialHeatmapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selected_point_style: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The point style of the geospatial map.

            :param cluster_marker_configuration: The cluster marker configuration of the geospatial point style.
            :param heatmap_configuration: The heatmap configuration of the geospatial point style.
            :param selected_point_style: The selected point styles (point, cluster) of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialpointstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geospatial_point_style_options_property = quicksight.CfnTemplate.GeospatialPointStyleOptionsProperty(
                    cluster_marker_configuration=quicksight.CfnTemplate.ClusterMarkerConfigurationProperty(
                        cluster_marker=quicksight.CfnTemplate.ClusterMarkerProperty(
                            simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                                color="color"
                            )
                        )
                    ),
                    heatmap_configuration=quicksight.CfnTemplate.GeospatialHeatmapConfigurationProperty(
                        heatmap_color=quicksight.CfnTemplate.GeospatialHeatmapColorScaleProperty(
                            colors=[quicksight.CfnTemplate.GeospatialHeatmapDataColorProperty(
                                color="color"
                            )]
                        )
                    ),
                    selected_point_style="selectedPointStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7250866c1e062e814d7bc295f99ef4045964f162e73b7504e4bb6d09cf6ecaea)
                check_type(argname="argument cluster_marker_configuration", value=cluster_marker_configuration, expected_type=type_hints["cluster_marker_configuration"])
                check_type(argname="argument heatmap_configuration", value=heatmap_configuration, expected_type=type_hints["heatmap_configuration"])
                check_type(argname="argument selected_point_style", value=selected_point_style, expected_type=type_hints["selected_point_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cluster_marker_configuration is not None:
                self._values["cluster_marker_configuration"] = cluster_marker_configuration
            if heatmap_configuration is not None:
                self._values["heatmap_configuration"] = heatmap_configuration
            if selected_point_style is not None:
                self._values["selected_point_style"] = selected_point_style

        @builtins.property
        def cluster_marker_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ClusterMarkerConfigurationProperty"]]:
            '''The cluster marker configuration of the geospatial point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialpointstyleoptions.html#cfn-quicksight-template-geospatialpointstyleoptions-clustermarkerconfiguration
            '''
            result = self._values.get("cluster_marker_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ClusterMarkerConfigurationProperty"]], result)

        @builtins.property
        def heatmap_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialHeatmapConfigurationProperty"]]:
            '''The heatmap configuration of the geospatial point style.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialpointstyleoptions.html#cfn-quicksight-template-geospatialpointstyleoptions-heatmapconfiguration
            '''
            result = self._values.get("heatmap_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialHeatmapConfigurationProperty"]], result)

        @builtins.property
        def selected_point_style(self) -> typing.Optional[builtins.str]:
            '''The selected point styles (point, cluster) of the geospatial map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialpointstyleoptions.html#cfn-quicksight-template-geospatialpointstyleoptions-selectedpointstyle
            '''
            result = self._values.get("selected_point_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialPointStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GeospatialWindowOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"bounds": "bounds", "map_zoom_mode": "mapZoomMode"},
    )
    class GeospatialWindowOptionsProperty:
        def __init__(
            self,
            *,
            bounds: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GeospatialCoordinateBoundsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            map_zoom_mode: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The window options of the geospatial map visual.

            :param bounds: The bounds options (north, south, west, east) of the geospatial window options.
            :param map_zoom_mode: The map zoom modes (manual, auto) of the geospatial window options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialwindowoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                geospatial_window_options_property = quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                    bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                        east=123,
                        north=123,
                        south=123,
                        west=123
                    ),
                    map_zoom_mode="mapZoomMode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f9b20c1f2b079db907121d78fdb1a3b1cb7085825284d6698626d9c2ee256fab)
                check_type(argname="argument bounds", value=bounds, expected_type=type_hints["bounds"])
                check_type(argname="argument map_zoom_mode", value=map_zoom_mode, expected_type=type_hints["map_zoom_mode"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bounds is not None:
                self._values["bounds"] = bounds
            if map_zoom_mode is not None:
                self._values["map_zoom_mode"] = map_zoom_mode

        @builtins.property
        def bounds(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialCoordinateBoundsProperty"]]:
            '''The bounds options (north, south, west, east) of the geospatial window options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialwindowoptions.html#cfn-quicksight-template-geospatialwindowoptions-bounds
            '''
            result = self._values.get("bounds")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialCoordinateBoundsProperty"]], result)

        @builtins.property
        def map_zoom_mode(self) -> typing.Optional[builtins.str]:
            '''The map zoom modes (manual, auto) of the geospatial window options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialwindowoptions.html#cfn-quicksight-template-geospatialwindowoptions-mapzoommode
            '''
            result = self._values.get("map_zoom_mode")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialWindowOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GlobalTableBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "side_specific_border": "sideSpecificBorder",
            "uniform_border": "uniformBorder",
        },
    )
    class GlobalTableBorderOptionsProperty:
        def __init__(
            self,
            *,
            side_specific_border: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableSideBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            uniform_border: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Determines the border options for a table visual.

            :param side_specific_border: Determines the options for side specific border.
            :param uniform_border: Determines the options for uniform border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-globaltableborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                global_table_border_options_property = quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        )
                    ),
                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2b8dab5ec645a241806e0c0fe4b80c09c77db8527e25c1fa693e6a861cb35231)
                check_type(argname="argument side_specific_border", value=side_specific_border, expected_type=type_hints["side_specific_border"])
                check_type(argname="argument uniform_border", value=uniform_border, expected_type=type_hints["uniform_border"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if side_specific_border is not None:
                self._values["side_specific_border"] = side_specific_border
            if uniform_border is not None:
                self._values["uniform_border"] = uniform_border

        @builtins.property
        def side_specific_border(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableSideBorderOptionsProperty"]]:
            '''Determines the options for side specific border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-globaltableborderoptions.html#cfn-quicksight-template-globaltableborderoptions-sidespecificborder
            '''
            result = self._values.get("side_specific_border")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableSideBorderOptionsProperty"]], result)

        @builtins.property
        def uniform_border(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableBorderOptionsProperty"]]:
            '''Determines the options for uniform border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-globaltableborderoptions.html#cfn-quicksight-template-globaltableborderoptions-uniformborder
            '''
            result = self._values.get("uniform_border")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableBorderOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GlobalTableBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GradientColorProperty",
        jsii_struct_bases=[],
        name_mapping={"stops": "stops"},
    )
    class GradientColorProperty:
        def __init__(
            self,
            *,
            stops: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GradientStopProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''Determines the gradient color settings.

            :param stops: The list of gradient color stops.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gradient_color_property = quicksight.CfnTemplate.GradientColorProperty(
                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                        gradient_offset=123,
                
                        # the properties below are optional
                        color="color",
                        data_value=123
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__324594fd3eb246dff0062859e62e8359eec861fdef2d9a4c638018855885098e)
                check_type(argname="argument stops", value=stops, expected_type=type_hints["stops"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if stops is not None:
                self._values["stops"] = stops

        @builtins.property
        def stops(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GradientStopProperty"]]]]:
            '''The list of gradient color stops.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientcolor.html#cfn-quicksight-template-gradientcolor-stops
            '''
            result = self._values.get("stops")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GradientStopProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GradientColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GradientStopProperty",
        jsii_struct_bases=[],
        name_mapping={
            "gradient_offset": "gradientOffset",
            "color": "color",
            "data_value": "dataValue",
        },
    )
    class GradientStopProperty:
        def __init__(
            self,
            *,
            gradient_offset: jsii.Number,
            color: typing.Optional[builtins.str] = None,
            data_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''Determines the gradient stop configuration.

            :param gradient_offset: Determines gradient offset value. Default: - 0
            :param color: Determines the color.
            :param data_value: Determines the data value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientstop.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gradient_stop_property = quicksight.CfnTemplate.GradientStopProperty(
                    gradient_offset=123,
                
                    # the properties below are optional
                    color="color",
                    data_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b1cad120cd737f86590ac108db01fec92be4a595434342ab7d5979f7593270ea)
                check_type(argname="argument gradient_offset", value=gradient_offset, expected_type=type_hints["gradient_offset"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument data_value", value=data_value, expected_type=type_hints["data_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "gradient_offset": gradient_offset,
            }
            if color is not None:
                self._values["color"] = color
            if data_value is not None:
                self._values["data_value"] = data_value

        @builtins.property
        def gradient_offset(self) -> jsii.Number:
            '''Determines gradient offset value.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientstop.html#cfn-quicksight-template-gradientstop-gradientoffset
            '''
            result = self._values.get("gradient_offset")
            assert result is not None, "Required property 'gradient_offset' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientstop.html#cfn-quicksight-template-gradientstop-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_value(self) -> typing.Optional[jsii.Number]:
            '''Determines the data value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientstop.html#cfn-quicksight-template-gradientstop-datavalue
            '''
            result = self._values.get("data_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GradientStopProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"screen_canvas_size_options": "screenCanvasSizeOptions"},
    )
    class GridLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            screen_canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Configuration options for the canvas of a grid layout.

            :param screen_canvas_size_options: The options that determine the sizing of the canvas used in a grid layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                grid_layout_canvas_size_options_property = quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                    screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                        resize_option="resizeOption",
                
                        # the properties below are optional
                        optimized_view_port_width="optimizedViewPortWidth"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9b538f92423ed565546fbf5fa1af8beb1ebae8fae8b3f594a77ceb6d65a3981d)
                check_type(argname="argument screen_canvas_size_options", value=screen_canvas_size_options, expected_type=type_hints["screen_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if screen_canvas_size_options is not None:
                self._values["screen_canvas_size_options"] = screen_canvas_size_options

        @builtins.property
        def screen_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty"]]:
            '''The options that determine the sizing of the canvas used in a grid layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutcanvassizeoptions.html#cfn-quicksight-template-gridlayoutcanvassizeoptions-screencanvassizeoptions
            '''
            result = self._values.get("screen_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GridLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "elements": "elements",
            "canvas_size_options": "canvasSizeOptions",
        },
    )
    class GridLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GridLayoutElementProperty", typing.Dict[builtins.str, typing.Any]]]]],
            canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GridLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a grid layout. Also called a tiled layout.

            Visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size.

            :param elements: The elements that are included in a grid layout.
            :param canvas_size_options: 

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                grid_layout_configuration_property = quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                    elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                        column_span=123,
                        element_id="elementId",
                        element_type="elementType",
                        row_span=123,
                
                        # the properties below are optional
                        column_index=123,
                        row_index=123
                    )],
                
                    # the properties below are optional
                    canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                            resize_option="resizeOption",
                
                            # the properties below are optional
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fb6821d9ce0cd248060c5d69c86be08d139652c15fc7c9146ff709923a9e7938)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }
            if canvas_size_options is not None:
                self._values["canvas_size_options"] = canvas_size_options

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GridLayoutElementProperty"]]]:
            '''The elements that are included in a grid layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutconfiguration.html#cfn-quicksight-template-gridlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GridLayoutElementProperty"]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GridLayoutCanvasSizeOptionsProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutconfiguration.html#cfn-quicksight-template-gridlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GridLayoutCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GridLayoutElementProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_span": "columnSpan",
            "element_id": "elementId",
            "element_type": "elementType",
            "row_span": "rowSpan",
            "column_index": "columnIndex",
            "row_index": "rowIndex",
        },
    )
    class GridLayoutElementProperty:
        def __init__(
            self,
            *,
            column_span: jsii.Number,
            element_id: builtins.str,
            element_type: builtins.str,
            row_span: jsii.Number,
            column_index: typing.Optional[jsii.Number] = None,
            row_index: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''An element within a grid layout.

            :param column_span: The width of a grid element expressed as a number of grid columns.
            :param element_id: A unique identifier for an element within a grid layout.
            :param element_type: The type of element.
            :param row_span: The height of a grid element expressed as a number of grid rows.
            :param column_index: The column index for the upper left corner of an element.
            :param row_index: The row index for the upper left corner of an element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                grid_layout_element_property = quicksight.CfnTemplate.GridLayoutElementProperty(
                    column_span=123,
                    element_id="elementId",
                    element_type="elementType",
                    row_span=123,
                
                    # the properties below are optional
                    column_index=123,
                    row_index=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0476bb9be385036ba1ded41436c1d18d98418591f5604c24add296e6a7082ac3)
                check_type(argname="argument column_span", value=column_span, expected_type=type_hints["column_span"])
                check_type(argname="argument element_id", value=element_id, expected_type=type_hints["element_id"])
                check_type(argname="argument element_type", value=element_type, expected_type=type_hints["element_type"])
                check_type(argname="argument row_span", value=row_span, expected_type=type_hints["row_span"])
                check_type(argname="argument column_index", value=column_index, expected_type=type_hints["column_index"])
                check_type(argname="argument row_index", value=row_index, expected_type=type_hints["row_index"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_span": column_span,
                "element_id": element_id,
                "element_type": element_type,
                "row_span": row_span,
            }
            if column_index is not None:
                self._values["column_index"] = column_index
            if row_index is not None:
                self._values["row_index"] = row_index

        @builtins.property
        def column_span(self) -> jsii.Number:
            '''The width of a grid element expressed as a number of grid columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-columnspan
            '''
            result = self._values.get("column_span")
            assert result is not None, "Required property 'column_span' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def element_id(self) -> builtins.str:
            '''A unique identifier for an element within a grid layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-elementid
            '''
            result = self._values.get("element_id")
            assert result is not None, "Required property 'element_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element_type(self) -> builtins.str:
            '''The type of element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-elementtype
            '''
            result = self._values.get("element_type")
            assert result is not None, "Required property 'element_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def row_span(self) -> jsii.Number:
            '''The height of a grid element expressed as a number of grid rows.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-rowspan
            '''
            result = self._values.get("row_span")
            assert result is not None, "Required property 'row_span' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def column_index(self) -> typing.Optional[jsii.Number]:
            '''The column index for the upper left corner of an element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-columnindex
            '''
            result = self._values.get("column_index")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def row_index(self) -> typing.Optional[jsii.Number]:
            '''The row index for the upper left corner of an element.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-rowindex
            '''
            result = self._values.get("row_index")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutElementProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "resize_option": "resizeOption",
            "optimized_view_port_width": "optimizedViewPortWidth",
        },
    )
    class GridLayoutScreenCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            resize_option: builtins.str,
            optimized_view_port_width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the sizing of the canvas used in a grid layout.

            :param resize_option: This value determines the layout behavior when the viewport is resized. - ``FIXED`` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called ``Classic`` . - ``RESPONSIVE`` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called ``Tiled`` .
            :param optimized_view_port_width: The width that the view port will be optimized for when the layout renders.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutscreencanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                grid_layout_screen_canvas_size_options_property = quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                    resize_option="resizeOption",
                
                    # the properties below are optional
                    optimized_view_port_width="optimizedViewPortWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__666e086df81d6ddf24a4db1db8727dc8fc96ccff2f22d4991ad47540df006ff1)
                check_type(argname="argument resize_option", value=resize_option, expected_type=type_hints["resize_option"])
                check_type(argname="argument optimized_view_port_width", value=optimized_view_port_width, expected_type=type_hints["optimized_view_port_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "resize_option": resize_option,
            }
            if optimized_view_port_width is not None:
                self._values["optimized_view_port_width"] = optimized_view_port_width

        @builtins.property
        def resize_option(self) -> builtins.str:
            '''This value determines the layout behavior when the viewport is resized.

            - ``FIXED`` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called ``Classic`` .
            - ``RESPONSIVE`` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called ``Tiled`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-template-gridlayoutscreencanvassizeoptions-resizeoption
            '''
            result = self._values.get("resize_option")
            assert result is not None, "Required property 'resize_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def optimized_view_port_width(self) -> typing.Optional[builtins.str]:
            '''The width that the view port will be optimized for when the layout renders.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-template-gridlayoutscreencanvassizeoptions-optimizedviewportwidth
            '''
            result = self._values.get("optimized_view_port_width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutScreenCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.GrowthRateComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "name": "name",
            "period_size": "periodSize",
            "time": "time",
            "value": "value",
        },
    )
    class GrowthRateComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            name: typing.Optional[builtins.str] = None,
            period_size: typing.Optional[jsii.Number] = None,
            time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The growth rate computation configuration.

            :param computation_id: The ID for a computation.
            :param name: The name of a computation.
            :param period_size: The period size setup of a growth rate computation. Default: - 0
            :param time: The time field that is used in a computation.
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                growth_rate_computation_property = quicksight.CfnTemplate.GrowthRateComputationProperty(
                    computation_id="computationId",
                
                    # the properties below are optional
                    name="name",
                    period_size=123,
                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1e23629184cc8bcc77e48bfad82c0395bd45f57fae4a87a1903c384ec9b7e938)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument period_size", value=period_size, expected_type=type_hints["period_size"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
            }
            if name is not None:
                self._values["name"] = name
            if period_size is not None:
                self._values["period_size"] = period_size
            if time is not None:
                self._values["time"] = time
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def period_size(self) -> typing.Optional[jsii.Number]:
            '''The period size setup of a growth rate computation.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-periodsize
            '''
            result = self._values.get("period_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]:
            '''The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-time
            '''
            result = self._values.get("time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GrowthRateComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"layout": "layout", "section_id": "sectionId", "style": "style"},
    )
    class HeaderFooterSectionConfigurationProperty:
        def __init__(
            self,
            *,
            layout: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            section_id: builtins.str,
            style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SectionStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a header or footer section.

            :param layout: The layout configuration of the header or footer section.
            :param section_id: The unique identifier of the header or footer section.
            :param style: The style options of a header or footer section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-headerfootersectionconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                header_footer_section_configuration_property = quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                    layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                            elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )]
                        )
                    ),
                    section_id="sectionId",
                
                    # the properties below are optional
                    style=quicksight.CfnTemplate.SectionStyleProperty(
                        height="height",
                        padding=quicksight.CfnTemplate.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5eedffe8b1923c1b4959afcc98d580c04810c5a5a7136fb3104eb8ea10892ac5)
                check_type(argname="argument layout", value=layout, expected_type=type_hints["layout"])
                check_type(argname="argument section_id", value=section_id, expected_type=type_hints["section_id"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "layout": layout,
                "section_id": section_id,
            }
            if style is not None:
                self._values["style"] = style

        @builtins.property
        def layout(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.SectionLayoutConfigurationProperty"]:
            '''The layout configuration of the header or footer section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-headerfootersectionconfiguration.html#cfn-quicksight-template-headerfootersectionconfiguration-layout
            '''
            result = self._values.get("layout")
            assert result is not None, "Required property 'layout' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.SectionLayoutConfigurationProperty"], result)

        @builtins.property
        def section_id(self) -> builtins.str:
            '''The unique identifier of the header or footer section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-headerfootersectionconfiguration.html#cfn-quicksight-template-headerfootersectionconfiguration-sectionid
            '''
            result = self._values.get("section_id")
            assert result is not None, "Required property 'section_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SectionStyleProperty"]]:
            '''The style options of a header or footer section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-headerfootersectionconfiguration.html#cfn-quicksight-template-headerfootersectionconfiguration-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SectionStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeaderFooterSectionConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.HeatMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns", "rows": "rows", "values": "values"},
    )
    class HeatMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            columns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            rows: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a heat map.

            :param columns: The columns field well of a heat map.
            :param rows: The rows field well of a heat map.
            :param values: The values field well of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bb2f335086420535886b7b890cb7334bdd85b67c36b9582107b1577391ad537f)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument rows", value=rows, expected_type=type_hints["rows"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if columns is not None:
                self._values["columns"] = columns
            if rows is not None:
                self._values["rows"] = rows
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def columns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The columns field well of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapaggregatedfieldwells.html#cfn-quicksight-template-heatmapaggregatedfieldwells-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def rows(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The rows field well of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapaggregatedfieldwells.html#cfn-quicksight-template-heatmapaggregatedfieldwells-rows
            '''
            result = self._values.get("rows")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The values field well of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapaggregatedfieldwells.html#cfn-quicksight-template-heatmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.HeatMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_scale": "colorScale",
            "column_label_options": "columnLabelOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "row_label_options": "rowLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
        },
    )
    class HeatMapConfigurationProperty:
        def __init__(
            self,
            *,
            color_scale: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColorScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.HeatMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.HeatMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a heat map.

            :param color_scale: The color options (gradient color, point of divergence) in a heat map.
            :param column_label_options: The label options of the column that is displayed in a heat map.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param row_label_options: The label options of the row that is displayed in a ``heat map`` .
            :param sort_configuration: The sort configuration of a heat map.
            :param tooltip: The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__edfb12f03d10b80f1864da2a88fc64bae09071d1826b0c67bde492b2c55b7bb0)
                check_type(argname="argument color_scale", value=color_scale, expected_type=type_hints["color_scale"])
                check_type(argname="argument column_label_options", value=column_label_options, expected_type=type_hints["column_label_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument row_label_options", value=row_label_options, expected_type=type_hints["row_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color_scale is not None:
                self._values["color_scale"] = color_scale
            if column_label_options is not None:
                self._values["column_label_options"] = column_label_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if row_label_options is not None:
                self._values["row_label_options"] = row_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip

        @builtins.property
        def color_scale(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColorScaleProperty"]]:
            '''The color options (gradient color, point of divergence) in a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-colorscale
            '''
            result = self._values.get("color_scale")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColorScaleProperty"]], result)

        @builtins.property
        def column_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the column that is displayed in a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-columnlabeloptions
            '''
            result = self._values.get("column_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HeatMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HeatMapFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def row_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the row that is displayed in a ``heat map`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-rowlabeloptions
            '''
            result = self._values.get("row_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HeatMapSortConfigurationProperty"]]:
            '''The sort configuration of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HeatMapSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.HeatMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "heat_map_aggregated_field_wells": "heatMapAggregatedFieldWells",
        },
    )
    class HeatMapFieldWellsProperty:
        def __init__(
            self,
            *,
            heat_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.HeatMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a heat map.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param heat_map_aggregated_field_wells: The aggregated field wells of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0bc87f4ac11a24f2f0019220d7db037b8a62737500be9e8c8b116418b6088e80)
                check_type(argname="argument heat_map_aggregated_field_wells", value=heat_map_aggregated_field_wells, expected_type=type_hints["heat_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if heat_map_aggregated_field_wells is not None:
                self._values["heat_map_aggregated_field_wells"] = heat_map_aggregated_field_wells

        @builtins.property
        def heat_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HeatMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapfieldwells.html#cfn-quicksight-template-heatmapfieldwells-heatmapaggregatedfieldwells
            '''
            result = self._values.get("heat_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HeatMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.HeatMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "heat_map_column_items_limit_configuration": "heatMapColumnItemsLimitConfiguration",
            "heat_map_column_sort": "heatMapColumnSort",
            "heat_map_row_items_limit_configuration": "heatMapRowItemsLimitConfiguration",
            "heat_map_row_sort": "heatMapRowSort",
        },
    )
    class HeatMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            heat_map_column_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            heat_map_column_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            heat_map_row_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            heat_map_row_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a heat map.

            :param heat_map_column_items_limit_configuration: The limit on the number of columns that are displayed in a heat map.
            :param heat_map_column_sort: The column sort configuration for heat map for columns that aren't a part of a field well.
            :param heat_map_row_items_limit_configuration: The limit on the number of rows that are displayed in a heat map.
            :param heat_map_row_sort: The field sort configuration of the rows fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                heat_map_sort_configuration_property = quicksight.CfnTemplate.HeatMapSortConfigurationProperty(
                    heat_map_column_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    heat_map_column_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    heat_map_row_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    heat_map_row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__55062ffc9247875871d29b8980ee36d9298aaa0a058adf79cc80ec698a954e9b)
                check_type(argname="argument heat_map_column_items_limit_configuration", value=heat_map_column_items_limit_configuration, expected_type=type_hints["heat_map_column_items_limit_configuration"])
                check_type(argname="argument heat_map_column_sort", value=heat_map_column_sort, expected_type=type_hints["heat_map_column_sort"])
                check_type(argname="argument heat_map_row_items_limit_configuration", value=heat_map_row_items_limit_configuration, expected_type=type_hints["heat_map_row_items_limit_configuration"])
                check_type(argname="argument heat_map_row_sort", value=heat_map_row_sort, expected_type=type_hints["heat_map_row_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if heat_map_column_items_limit_configuration is not None:
                self._values["heat_map_column_items_limit_configuration"] = heat_map_column_items_limit_configuration
            if heat_map_column_sort is not None:
                self._values["heat_map_column_sort"] = heat_map_column_sort
            if heat_map_row_items_limit_configuration is not None:
                self._values["heat_map_row_items_limit_configuration"] = heat_map_row_items_limit_configuration
            if heat_map_row_sort is not None:
                self._values["heat_map_row_sort"] = heat_map_row_sort

        @builtins.property
        def heat_map_column_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of columns that are displayed in a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html#cfn-quicksight-template-heatmapsortconfiguration-heatmapcolumnitemslimitconfiguration
            '''
            result = self._values.get("heat_map_column_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def heat_map_column_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The column sort configuration for heat map for columns that aren't a part of a field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html#cfn-quicksight-template-heatmapsortconfiguration-heatmapcolumnsort
            '''
            result = self._values.get("heat_map_column_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def heat_map_row_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of rows that are displayed in a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html#cfn-quicksight-template-heatmapsortconfiguration-heatmaprowitemslimitconfiguration
            '''
            result = self._values.get("heat_map_row_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def heat_map_row_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The field sort configuration of the rows fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html#cfn-quicksight-template-heatmapsortconfiguration-heatmaprowsort
            '''
            result = self._values.get("heat_map_row_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.HeatMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class HeatMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.HeatMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A heat map.

            For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a heat map.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__51db201590a51b4b46194728f07968555086c7604ae37997cc981e1b65a70620)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HeatMapConfigurationProperty"]]:
            '''The configuration of a heat map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HeatMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class HistogramAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a histogram.

            :param values: The value field wells of a histogram. Values are aggregated by ``COUNT`` or ``DISTINCT_COUNT`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                histogram_aggregated_field_wells_property = quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty(
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fa06b8fff735d5b0c496941e0d1f46d6b1d9107ccde96ef32ff9cf0ef95b977e)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The value field wells of a histogram.

            Values are aggregated by ``COUNT`` or ``DISTINCT_COUNT`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramaggregatedfieldwells.html#cfn-quicksight-template-histogramaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.HistogramBinOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bin_count": "binCount",
            "bin_width": "binWidth",
            "selected_bin_type": "selectedBinType",
            "start_value": "startValue",
        },
    )
    class HistogramBinOptionsProperty:
        def __init__(
            self,
            *,
            bin_count: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.BinCountOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            bin_width: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.BinWidthOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selected_bin_type: typing.Optional[builtins.str] = None,
            start_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The options that determine the presentation of histogram bins.

            :param bin_count: The options that determine the bin count of a histogram.
            :param bin_width: The options that determine the bin width of a histogram.
            :param selected_bin_type: The options that determine the selected bin type.
            :param start_value: The options that determine the bin start value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                histogram_bin_options_property = quicksight.CfnTemplate.HistogramBinOptionsProperty(
                    bin_count=quicksight.CfnTemplate.BinCountOptionsProperty(
                        value=123
                    ),
                    bin_width=quicksight.CfnTemplate.BinWidthOptionsProperty(
                        bin_count_limit=123,
                        value=123
                    ),
                    selected_bin_type="selectedBinType",
                    start_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8109468b73b8c175e7bb158ebb357f62ccde320883059c7580950d2a49191968)
                check_type(argname="argument bin_count", value=bin_count, expected_type=type_hints["bin_count"])
                check_type(argname="argument bin_width", value=bin_width, expected_type=type_hints["bin_width"])
                check_type(argname="argument selected_bin_type", value=selected_bin_type, expected_type=type_hints["selected_bin_type"])
                check_type(argname="argument start_value", value=start_value, expected_type=type_hints["start_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_count is not None:
                self._values["bin_count"] = bin_count
            if bin_width is not None:
                self._values["bin_width"] = bin_width
            if selected_bin_type is not None:
                self._values["selected_bin_type"] = selected_bin_type
            if start_value is not None:
                self._values["start_value"] = start_value

        @builtins.property
        def bin_count(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BinCountOptionsProperty"]]:
            '''The options that determine the bin count of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html#cfn-quicksight-template-histogrambinoptions-bincount
            '''
            result = self._values.get("bin_count")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BinCountOptionsProperty"]], result)

        @builtins.property
        def bin_width(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BinWidthOptionsProperty"]]:
            '''The options that determine the bin width of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html#cfn-quicksight-template-histogrambinoptions-binwidth
            '''
            result = self._values.get("bin_width")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BinWidthOptionsProperty"]], result)

        @builtins.property
        def selected_bin_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the selected bin type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html#cfn-quicksight-template-histogrambinoptions-selectedbintype
            '''
            result = self._values.get("selected_bin_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def start_value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin start value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html#cfn-quicksight-template-histogrambinoptions-startvalue
            '''
            result = self._values.get("start_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramBinOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.HistogramConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bin_options": "binOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
            "y_axis_display_options": "yAxisDisplayOptions",
        },
    )
    class HistogramConfigurationProperty:
        def __init__(
            self,
            *,
            bin_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.HistogramBinOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.HistogramFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``HistogramVisual`` .

            :param bin_options: The options that determine the presentation of histogram bins.
            :param data_labels: The data label configuration of a histogram.
            :param field_wells: The field well configuration of a histogram.
            :param tooltip: The tooltip configuration of a histogram.
            :param visual_palette: The visual palette configuration of a histogram.
            :param x_axis_display_options: The options that determine the presentation of the x-axis.
            :param x_axis_label_options: The options that determine the presentation of the x-axis label.
            :param y_axis_display_options: The options that determine the presentation of the y-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3f664855874f20d709d8a65d458c6265073033475c63a3a0a7bb1ea3839c30bf)
                check_type(argname="argument bin_options", value=bin_options, expected_type=type_hints["bin_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
                check_type(argname="argument y_axis_display_options", value=y_axis_display_options, expected_type=type_hints["y_axis_display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_options is not None:
                self._values["bin_options"] = bin_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options
            if y_axis_display_options is not None:
                self._values["y_axis_display_options"] = y_axis_display_options

        @builtins.property
        def bin_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HistogramBinOptionsProperty"]]:
            '''The options that determine the presentation of histogram bins.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-binoptions
            '''
            result = self._values.get("bin_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HistogramBinOptionsProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The data label configuration of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HistogramFieldWellsProperty"]]:
            '''The field well configuration of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HistogramFieldWellsProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]]:
            '''The visual palette configuration of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-yaxisdisplayoptions
            '''
            result = self._values.get("y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.HistogramFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "histogram_aggregated_field_wells": "histogramAggregatedFieldWells",
        },
    )
    class HistogramFieldWellsProperty:
        def __init__(
            self,
            *,
            histogram_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.HistogramAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a histogram.

            :param histogram_aggregated_field_wells: The field well configuration of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                histogram_field_wells_property = quicksight.CfnTemplate.HistogramFieldWellsProperty(
                    histogram_aggregated_field_wells=quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty(
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5e5ca3b8c77ba7e660696d744e6654b4550fd6a8639a9924be9c8906a93a8ebc)
                check_type(argname="argument histogram_aggregated_field_wells", value=histogram_aggregated_field_wells, expected_type=type_hints["histogram_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if histogram_aggregated_field_wells is not None:
                self._values["histogram_aggregated_field_wells"] = histogram_aggregated_field_wells

        @builtins.property
        def histogram_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HistogramAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a histogram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramfieldwells.html#cfn-quicksight-template-histogramfieldwells-histogramaggregatedfieldwells
            '''
            result = self._values.get("histogram_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HistogramAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.HistogramVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class HistogramVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.HistogramConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A histogram.

            For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration for a ``HistogramVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ab527615f6b21e9430a86b65d119a808df9a319645b768620dc48e1435719fdd)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HistogramConfigurationProperty"]]:
            '''The configuration for a ``HistogramVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HistogramConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.InsightConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computations": "computations",
            "custom_narrative": "customNarrative",
        },
    )
    class InsightConfigurationProperty:
        def __init__(
            self,
            *,
            computations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ComputationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            custom_narrative: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CustomNarrativeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of an insight visual.

            :param computations: The computations configurations of the insight visual.
            :param custom_narrative: The custom narrative of the insight visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__de5ac8843b10f13c98afb9192d6451f0f353ef81e8a1df734101a8111749fc37)
                check_type(argname="argument computations", value=computations, expected_type=type_hints["computations"])
                check_type(argname="argument custom_narrative", value=custom_narrative, expected_type=type_hints["custom_narrative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if computations is not None:
                self._values["computations"] = computations
            if custom_narrative is not None:
                self._values["custom_narrative"] = custom_narrative

        @builtins.property
        def computations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ComputationProperty"]]]]:
            '''The computations configurations of the insight visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightconfiguration.html#cfn-quicksight-template-insightconfiguration-computations
            '''
            result = self._values.get("computations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ComputationProperty"]]]], result)

        @builtins.property
        def custom_narrative(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomNarrativeOptionsProperty"]]:
            '''The custom narrative of the insight visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightconfiguration.html#cfn-quicksight-template-insightconfiguration-customnarrative
            '''
            result = self._values.get("custom_narrative")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomNarrativeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "InsightConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.InsightVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
            "insight_configuration": "insightConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class InsightVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            insight_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.InsightConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''An insight visual.

            For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .

            :param data_set_identifier: The dataset that is used in the insight visual.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param insight_configuration: The configuration of an insight visual.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8256e5a80490f1dd152d5cf322d9537f166c7ccd6874c322ea73fe341cac3898)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument insight_configuration", value=insight_configuration, expected_type=type_hints["insight_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if insight_configuration is not None:
                self._values["insight_configuration"] = insight_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The dataset that is used in the insight visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def insight_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.InsightConfigurationProperty"]]:
            '''The configuration of an insight visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-insightconfiguration
            '''
            result = self._values.get("insight_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.InsightConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "InsightVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.IntegerDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class IntegerDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
        ) -> None:
            '''The default values of the ``IntegerParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``IntegerDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``IntegerDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                integer_default_values_property = quicksight.CfnTemplate.IntegerDefaultValuesProperty(
                    dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__79c0c995261a52fa2d3c8e7d958cfd9b62c06e970f6667960a5147834a7e7b8d)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``IntegerDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerdefaultvalues.html#cfn-quicksight-template-integerdefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def static_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]]:
            '''The static values of the ``IntegerDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerdefaultvalues.html#cfn-quicksight-template-integerdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[jsii.Number]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.IntegerParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class IntegerParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.IntegerDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.IntegerValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``Integer`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: 
            :param value_when_unset: A parameter declaration for the ``Integer`` data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                integer_parameter_declaration_property = quicksight.CfnTemplate.IntegerParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnTemplate.IntegerDefaultValuesProperty(
                        dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=[123]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnTemplate.IntegerValueWhenUnsetConfigurationProperty(
                        custom_value=123,
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d7ddb6f8183831a28a8aa246d5fda74b1c818950c976a659b5544bb38c333bf8)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.IntegerDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.IntegerDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MappedDataSetParameterProperty"]]]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.IntegerValueWhenUnsetConfigurationProperty"]]:
            '''A parameter declaration for the ``Integer`` data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.IntegerValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.IntegerValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class IntegerValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[jsii.Number] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A parameter declaration for the ``Integer`` data type.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integervaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                integer_value_when_unset_configuration_property = quicksight.CfnTemplate.IntegerValueWhenUnsetConfigurationProperty(
                    custom_value=123,
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__75ff7f588d57c9e801a21bed4bd3061b461d5e16cdf4e009fdbef448ef1adc39)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[jsii.Number]:
            '''A custom value that's used when the value of a parameter isn't set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integervaluewhenunsetconfiguration.html#cfn-quicksight-template-integervaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integervaluewhenunsetconfiguration.html#cfn-quicksight-template-integervaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ItemsLimitConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "items_limit": "itemsLimit",
            "other_categories": "otherCategories",
        },
    )
    class ItemsLimitConfigurationProperty:
        def __init__(
            self,
            *,
            items_limit: typing.Optional[jsii.Number] = None,
            other_categories: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The limit configuration of the visual display for an axis.

            :param items_limit: The limit on how many items of a field are showed in the chart. For example, the number of slices that are displayed in a pie chart.
            :param other_categories: The ``Show other`` of an axis in the chart. Choose one of the following options:. - ``INCLUDE`` - ``EXCLUDE``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-itemslimitconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                items_limit_configuration_property = quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                    items_limit=123,
                    other_categories="otherCategories"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__84a93917bca10c20c9e72df34deb76834cb5aa1fd09a4b6e524e4b2457f02703)
                check_type(argname="argument items_limit", value=items_limit, expected_type=type_hints["items_limit"])
                check_type(argname="argument other_categories", value=other_categories, expected_type=type_hints["other_categories"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if items_limit is not None:
                self._values["items_limit"] = items_limit
            if other_categories is not None:
                self._values["other_categories"] = other_categories

        @builtins.property
        def items_limit(self) -> typing.Optional[jsii.Number]:
            '''The limit on how many items of a field are showed in the chart.

            For example, the number of slices that are displayed in a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-itemslimitconfiguration.html#cfn-quicksight-template-itemslimitconfiguration-itemslimit
            '''
            result = self._values.get("items_limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def other_categories(self) -> typing.Optional[builtins.str]:
            '''The ``Show other`` of an axis in the chart. Choose one of the following options:.

            - ``INCLUDE``
            - ``EXCLUDE``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-itemslimitconfiguration.html#cfn-quicksight-template-itemslimitconfiguration-othercategories
            '''
            result = self._values.get("other_categories")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ItemsLimitConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.KPIActualValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class KPIActualValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the actual value of a KPI visual.

            :param icon: The conditional formatting of the actual value's icon.
            :param text_color: The conditional formatting of the actual value's text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiactualvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIActual_value_conditional_formatting_property = quicksight.CfnTemplate.KPIActualValueConditionalFormattingProperty(
                    icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2dffb3b08c0efb00a2dd126ef1eecafaa340228f3b5732b6f1d50f773826188a)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting of the actual value's icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiactualvalueconditionalformatting.html#cfn-quicksight-template-kpiactualvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the actual value's text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiactualvalueconditionalformatting.html#cfn-quicksight-template-kpiactualvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIActualValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.KPIComparisonValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class KPIComparisonValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the comparison value of a KPI visual.

            :param icon: The conditional formatting of the comparison value's icon.
            :param text_color: The conditional formatting of the comparison value's text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpicomparisonvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIComparison_value_conditional_formatting_property = quicksight.CfnTemplate.KPIComparisonValueConditionalFormattingProperty(
                    icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d9eb1b23ffff0116e21e69887a057315fe696819cec0f84f46f7e640234cd30d)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting of the comparison value's icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpicomparisonvalueconditionalformatting.html#cfn-quicksight-template-kpicomparisonvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the comparison value's text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpicomparisonvalueconditionalformatting.html#cfn-quicksight-template-kpicomparisonvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIComparisonValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.KPIConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "actual_value": "actualValue",
            "comparison_value": "comparisonValue",
            "primary_value": "primaryValue",
            "progress_bar": "progressBar",
        },
    )
    class KPIConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            actual_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.KPIActualValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            comparison_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.KPIComparisonValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.KPIPrimaryValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            progress_bar: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.KPIProgressBarConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting options of a KPI visual.

            :param actual_value: The conditional formatting for the actual value of a KPI visual.
            :param comparison_value: The conditional formatting for the comparison value of a KPI visual.
            :param primary_value: The conditional formatting for the primary value of a KPI visual.
            :param progress_bar: The conditional formatting for the progress bar of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIConditional_formatting_option_property = quicksight.CfnTemplate.KPIConditionalFormattingOptionProperty(
                    actual_value=quicksight.CfnTemplate.KPIActualValueConditionalFormattingProperty(
                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    comparison_value=quicksight.CfnTemplate.KPIComparisonValueConditionalFormattingProperty(
                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    primary_value=quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty(
                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    progress_bar=quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty(
                        foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__339f1d2a70fcfa43c5d28bf4f6c1fd73d3f069c24d0058071e781bec0defed3c)
                check_type(argname="argument actual_value", value=actual_value, expected_type=type_hints["actual_value"])
                check_type(argname="argument comparison_value", value=comparison_value, expected_type=type_hints["comparison_value"])
                check_type(argname="argument primary_value", value=primary_value, expected_type=type_hints["primary_value"])
                check_type(argname="argument progress_bar", value=progress_bar, expected_type=type_hints["progress_bar"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if actual_value is not None:
                self._values["actual_value"] = actual_value
            if comparison_value is not None:
                self._values["comparison_value"] = comparison_value
            if primary_value is not None:
                self._values["primary_value"] = primary_value
            if progress_bar is not None:
                self._values["progress_bar"] = progress_bar

        @builtins.property
        def actual_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIActualValueConditionalFormattingProperty"]]:
            '''The conditional formatting for the actual value of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformattingoption.html#cfn-quicksight-template-kpiconditionalformattingoption-actualvalue
            '''
            result = self._values.get("actual_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIActualValueConditionalFormattingProperty"]], result)

        @builtins.property
        def comparison_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIComparisonValueConditionalFormattingProperty"]]:
            '''The conditional formatting for the comparison value of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformattingoption.html#cfn-quicksight-template-kpiconditionalformattingoption-comparisonvalue
            '''
            result = self._values.get("comparison_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIComparisonValueConditionalFormattingProperty"]], result)

        @builtins.property
        def primary_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIPrimaryValueConditionalFormattingProperty"]]:
            '''The conditional formatting for the primary value of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformattingoption.html#cfn-quicksight-template-kpiconditionalformattingoption-primaryvalue
            '''
            result = self._values.get("primary_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIPrimaryValueConditionalFormattingProperty"]], result)

        @builtins.property
        def progress_bar(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIProgressBarConditionalFormattingProperty"]]:
            '''The conditional formatting for the progress bar of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformattingoption.html#cfn-quicksight-template-kpiconditionalformattingoption-progressbar
            '''
            result = self._values.get("progress_bar")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIProgressBarConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.KPIConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class KPIConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.KPIConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting of a KPI visual.

            :param conditional_formatting_options: The conditional formatting options of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIConditional_formatting_property = quicksight.CfnTemplate.KPIConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnTemplate.KPIConditionalFormattingOptionProperty(
                        actual_value=quicksight.CfnTemplate.KPIActualValueConditionalFormattingProperty(
                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        comparison_value=quicksight.CfnTemplate.KPIComparisonValueConditionalFormattingProperty(
                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        primary_value=quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty(
                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        progress_bar=quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty(
                            foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__83d6fa0f7ed288b5a525a299e1675e97c59e1d6d8b235fdd2c5f863984ec0f67)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIConditionalFormattingOptionProperty"]]]]:
            '''The conditional formatting options of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformatting.html#cfn-quicksight-template-kpiconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.KPIConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "kpi_options": "kpiOptions",
            "sort_configuration": "sortConfiguration",
        },
    )
    class KPIConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.KPIFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            kpi_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.KPIOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.KPISortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a KPI visual.

            :param field_wells: The field well configuration of a KPI visual.
            :param kpi_options: The options that determine the presentation of a KPI visual.
            :param sort_configuration: The sort configuration of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e55893839361c4728001fbde8d39d86cedebff69aebc787aa4a187a8a74444cf)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument kpi_options", value=kpi_options, expected_type=type_hints["kpi_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if kpi_options is not None:
                self._values["kpi_options"] = kpi_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIFieldWellsProperty"]]:
            '''The field well configuration of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconfiguration.html#cfn-quicksight-template-kpiconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIFieldWellsProperty"]], result)

        @builtins.property
        def kpi_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIOptionsProperty"]]:
            '''The options that determine the presentation of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconfiguration.html#cfn-quicksight-template-kpiconfiguration-kpioptions
            '''
            result = self._values.get("kpi_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPISortConfigurationProperty"]]:
            '''The sort configuration of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconfiguration.html#cfn-quicksight-template-kpiconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPISortConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.KPIFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "target_values": "targetValues",
            "trend_groups": "trendGroups",
            "values": "values",
        },
    )
    class KPIFieldWellsProperty:
        def __init__(
            self,
            *,
            target_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            trend_groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a KPI visual.

            :param target_values: The target value field wells of a KPI visual.
            :param trend_groups: The trend group field wells of a KPI visual.
            :param values: The value field wells of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpifieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b2ae2a5817a435d9920364dd415989561d0ec363f433f1401a5732d7bf7be4fe)
                check_type(argname="argument target_values", value=target_values, expected_type=type_hints["target_values"])
                check_type(argname="argument trend_groups", value=trend_groups, expected_type=type_hints["trend_groups"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_values is not None:
                self._values["target_values"] = target_values
            if trend_groups is not None:
                self._values["trend_groups"] = trend_groups
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def target_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The target value field wells of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpifieldwells.html#cfn-quicksight-template-kpifieldwells-targetvalues
            '''
            result = self._values.get("target_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        @builtins.property
        def trend_groups(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The trend group field wells of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpifieldwells.html#cfn-quicksight-template-kpifieldwells-trendgroups
            '''
            result = self._values.get("trend_groups")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The value field wells of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpifieldwells.html#cfn-quicksight-template-kpifieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.KPIOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "comparison": "comparison",
            "primary_value_display_type": "primaryValueDisplayType",
            "primary_value_font_configuration": "primaryValueFontConfiguration",
            "progress_bar": "progressBar",
            "secondary_value": "secondaryValue",
            "secondary_value_font_configuration": "secondaryValueFontConfiguration",
            "sparkline": "sparkline",
            "trend_arrows": "trendArrows",
            "visual_layout_options": "visualLayoutOptions",
        },
    )
    class KPIOptionsProperty:
        def __init__(
            self,
            *,
            comparison: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ComparisonConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_value_display_type: typing.Optional[builtins.str] = None,
            primary_value_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            progress_bar: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ProgressBarOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SecondaryValueOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_value_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sparkline: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.KPISparklineOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            trend_arrows: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TrendArrowOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_layout_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.KPIVisualLayoutOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of a KPI visual.

            :param comparison: The comparison configuration of a KPI visual.
            :param primary_value_display_type: The options that determine the primary value display type.
            :param primary_value_font_configuration: The options that determine the primary value font configuration.
            :param progress_bar: The options that determine the presentation of the progress bar of a KPI visual.
            :param secondary_value: The options that determine the presentation of the secondary value of a KPI visual.
            :param secondary_value_font_configuration: The options that determine the secondary value font configuration.
            :param sparkline: The options that determine the visibility, color, type, and tooltip visibility of the sparkline of a KPI visual.
            :param trend_arrows: The options that determine the presentation of trend arrows in a KPI visual.
            :param visual_layout_options: The options that determine the layout a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIOptions_property = quicksight.CfnTemplate.KPIOptionsProperty(
                    comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                        comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        comparison_method="comparisonMethod"
                    ),
                    primary_value_display_type="primaryValueDisplayType",
                    primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    progress_bar=quicksight.CfnTemplate.ProgressBarOptionsProperty(
                        visibility="visibility"
                    ),
                    secondary_value=quicksight.CfnTemplate.SecondaryValueOptionsProperty(
                        visibility="visibility"
                    ),
                    secondary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    sparkline=quicksight.CfnTemplate.KPISparklineOptionsProperty(
                        type="type",
                
                        # the properties below are optional
                        color="color",
                        tooltip_visibility="tooltipVisibility",
                        visibility="visibility"
                    ),
                    trend_arrows=quicksight.CfnTemplate.TrendArrowOptionsProperty(
                        visibility="visibility"
                    ),
                    visual_layout_options=quicksight.CfnTemplate.KPIVisualLayoutOptionsProperty(
                        standard_layout=quicksight.CfnTemplate.KPIVisualStandardLayoutProperty(
                            type="type"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2dfbd0856000c8b9e8e7a25558c9b5d729907669af77294b37213426b6978baa)
                check_type(argname="argument comparison", value=comparison, expected_type=type_hints["comparison"])
                check_type(argname="argument primary_value_display_type", value=primary_value_display_type, expected_type=type_hints["primary_value_display_type"])
                check_type(argname="argument primary_value_font_configuration", value=primary_value_font_configuration, expected_type=type_hints["primary_value_font_configuration"])
                check_type(argname="argument progress_bar", value=progress_bar, expected_type=type_hints["progress_bar"])
                check_type(argname="argument secondary_value", value=secondary_value, expected_type=type_hints["secondary_value"])
                check_type(argname="argument secondary_value_font_configuration", value=secondary_value_font_configuration, expected_type=type_hints["secondary_value_font_configuration"])
                check_type(argname="argument sparkline", value=sparkline, expected_type=type_hints["sparkline"])
                check_type(argname="argument trend_arrows", value=trend_arrows, expected_type=type_hints["trend_arrows"])
                check_type(argname="argument visual_layout_options", value=visual_layout_options, expected_type=type_hints["visual_layout_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if comparison is not None:
                self._values["comparison"] = comparison
            if primary_value_display_type is not None:
                self._values["primary_value_display_type"] = primary_value_display_type
            if primary_value_font_configuration is not None:
                self._values["primary_value_font_configuration"] = primary_value_font_configuration
            if progress_bar is not None:
                self._values["progress_bar"] = progress_bar
            if secondary_value is not None:
                self._values["secondary_value"] = secondary_value
            if secondary_value_font_configuration is not None:
                self._values["secondary_value_font_configuration"] = secondary_value_font_configuration
            if sparkline is not None:
                self._values["sparkline"] = sparkline
            if trend_arrows is not None:
                self._values["trend_arrows"] = trend_arrows
            if visual_layout_options is not None:
                self._values["visual_layout_options"] = visual_layout_options

        @builtins.property
        def comparison(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ComparisonConfigurationProperty"]]:
            '''The comparison configuration of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-comparison
            '''
            result = self._values.get("comparison")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ComparisonConfigurationProperty"]], result)

        @builtins.property
        def primary_value_display_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the primary value display type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-primaryvaluedisplaytype
            '''
            result = self._values.get("primary_value_display_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"]]:
            '''The options that determine the primary value font configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-primaryvaluefontconfiguration
            '''
            result = self._values.get("primary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"]], result)

        @builtins.property
        def progress_bar(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ProgressBarOptionsProperty"]]:
            '''The options that determine the presentation of the progress bar of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-progressbar
            '''
            result = self._values.get("progress_bar")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ProgressBarOptionsProperty"]], result)

        @builtins.property
        def secondary_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SecondaryValueOptionsProperty"]]:
            '''The options that determine the presentation of the secondary value of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-secondaryvalue
            '''
            result = self._values.get("secondary_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SecondaryValueOptionsProperty"]], result)

        @builtins.property
        def secondary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"]]:
            '''The options that determine the secondary value font configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-secondaryvaluefontconfiguration
            '''
            result = self._values.get("secondary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"]], result)

        @builtins.property
        def sparkline(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPISparklineOptionsProperty"]]:
            '''The options that determine the visibility, color, type, and tooltip visibility of the sparkline of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-sparkline
            '''
            result = self._values.get("sparkline")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPISparklineOptionsProperty"]], result)

        @builtins.property
        def trend_arrows(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TrendArrowOptionsProperty"]]:
            '''The options that determine the presentation of trend arrows in a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-trendarrows
            '''
            result = self._values.get("trend_arrows")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TrendArrowOptionsProperty"]], result)

        @builtins.property
        def visual_layout_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIVisualLayoutOptionsProperty"]]:
            '''The options that determine the layout a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-visuallayoutoptions
            '''
            result = self._values.get("visual_layout_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIVisualLayoutOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class KPIPrimaryValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the primary value of a KPI visual.

            :param icon: The conditional formatting of the primary value's icon.
            :param text_color: The conditional formatting of the primary value's text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprimaryvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIPrimary_value_conditional_formatting_property = quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty(
                    icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__71079005fc8aa875e9f07e6ec40fd725dd0b13f0c0b9532feb777fffd050e39c)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting of the primary value's icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-template-kpiprimaryvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the primary value's text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-template-kpiprimaryvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIPrimaryValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"foreground_color": "foregroundColor"},
    )
    class KPIProgressBarConditionalFormattingProperty:
        def __init__(
            self,
            *,
            foreground_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the progress bar of a KPI visual.

            :param foreground_color: The conditional formatting of the progress bar's foreground color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprogressbarconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIProgress_bar_conditional_formatting_property = quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty(
                    foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__611a890ed03201d98fc7af48b56ddc52c0a3ace963baa20e6254ad47740c1e34)
                check_type(argname="argument foreground_color", value=foreground_color, expected_type=type_hints["foreground_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if foreground_color is not None:
                self._values["foreground_color"] = foreground_color

        @builtins.property
        def foreground_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the progress bar's foreground color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprogressbarconditionalformatting.html#cfn-quicksight-template-kpiprogressbarconditionalformatting-foregroundcolor
            '''
            result = self._values.get("foreground_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIProgressBarConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.KPISortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"trend_group_sort": "trendGroupSort"},
    )
    class KPISortConfigurationProperty:
        def __init__(
            self,
            *,
            trend_group_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a KPI visual.

            :param trend_group_sort: The sort configuration of the trend group fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpisortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pISort_configuration_property = quicksight.CfnTemplate.KPISortConfigurationProperty(
                    trend_group_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f4b39ef55b680cbb12fafd91103298c38998b9e927dab4376ad6265175dacf94)
                check_type(argname="argument trend_group_sort", value=trend_group_sort, expected_type=type_hints["trend_group_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if trend_group_sort is not None:
                self._values["trend_group_sort"] = trend_group_sort

        @builtins.property
        def trend_group_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the trend group fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpisortconfiguration.html#cfn-quicksight-template-kpisortconfiguration-trendgroupsort
            '''
            result = self._values.get("trend_group_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPISortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.KPISparklineOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "type": "type",
            "color": "color",
            "tooltip_visibility": "tooltipVisibility",
            "visibility": "visibility",
        },
    )
    class KPISparklineOptionsProperty:
        def __init__(
            self,
            *,
            type: builtins.str,
            color: typing.Optional[builtins.str] = None,
            tooltip_visibility: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the visibility, color, type, and tooltip visibility of the sparkline of a KPI visual.

            :param type: The type of the sparkline.
            :param color: The color of the sparkline.
            :param tooltip_visibility: The tooltip visibility of the sparkline.
            :param visibility: The visibility of the sparkline.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpisparklineoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pISparkline_options_property = quicksight.CfnTemplate.KPISparklineOptionsProperty(
                    type="type",
                
                    # the properties below are optional
                    color="color",
                    tooltip_visibility="tooltipVisibility",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6183b3ba8f4515a9d5b9bc06343a7a906895257c322dfbb96589aad73a5ca5fc)
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument tooltip_visibility", value=tooltip_visibility, expected_type=type_hints["tooltip_visibility"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "type": type,
            }
            if color is not None:
                self._values["color"] = color
            if tooltip_visibility is not None:
                self._values["tooltip_visibility"] = tooltip_visibility
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def type(self) -> builtins.str:
            '''The type of the sparkline.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpisparklineoptions.html#cfn-quicksight-template-kpisparklineoptions-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color of the sparkline.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpisparklineoptions.html#cfn-quicksight-template-kpisparklineoptions-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tooltip_visibility(self) -> typing.Optional[builtins.str]:
            '''The tooltip visibility of the sparkline.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpisparklineoptions.html#cfn-quicksight-template-kpisparklineoptions-tooltipvisibility
            '''
            result = self._values.get("tooltip_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the sparkline.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpisparklineoptions.html#cfn-quicksight-template-kpisparklineoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPISparklineOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.KPIVisualLayoutOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"standard_layout": "standardLayout"},
    )
    class KPIVisualLayoutOptionsProperty:
        def __init__(
            self,
            *,
            standard_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.KPIVisualStandardLayoutProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the layout a KPI visual.

            :param standard_layout: The standard layout of the KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisuallayoutoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIVisual_layout_options_property = quicksight.CfnTemplate.KPIVisualLayoutOptionsProperty(
                    standard_layout=quicksight.CfnTemplate.KPIVisualStandardLayoutProperty(
                        type="type"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1cfb28ab26a94a06d33f496c4a03e8d245c5004dbd2a4f95e49c9cb17ee76386)
                check_type(argname="argument standard_layout", value=standard_layout, expected_type=type_hints["standard_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if standard_layout is not None:
                self._values["standard_layout"] = standard_layout

        @builtins.property
        def standard_layout(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIVisualStandardLayoutProperty"]]:
            '''The standard layout of the KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisuallayoutoptions.html#cfn-quicksight-template-kpivisuallayoutoptions-standardlayout
            '''
            result = self._values.get("standard_layout")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIVisualStandardLayoutProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIVisualLayoutOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.KPIVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class KPIVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.KPIConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.KPIConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A key performance indicator (KPI).

            For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a KPI visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param conditional_formatting: The conditional formatting of a KPI visual.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d4d8219c64814a915b6f55ee6fbea36745a1eb67e9d3762944f7a1dc303f8d24)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIConfigurationProperty"]]:
            '''The configuration of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIConditionalFormattingProperty"]]:
            '''The conditional formatting of a KPI visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.KPIVisualStandardLayoutProperty",
        jsii_struct_bases=[],
        name_mapping={"type": "type"},
    )
    class KPIVisualStandardLayoutProperty:
        def __init__(self, *, type: builtins.str) -> None:
            '''The standard layout of the KPI visual.

            :param type: The standard layout type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisualstandardlayout.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                k_pIVisual_standard_layout_property = quicksight.CfnTemplate.KPIVisualStandardLayoutProperty(
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__267de0f3e92d4c6362e4104fe04fde215f6781fc0ddaebad08ac75372afe8c30)
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "type": type,
            }

        @builtins.property
        def type(self) -> builtins.str:
            '''The standard layout type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisualstandardlayout.html#cfn-quicksight-template-kpivisualstandardlayout-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIVisualStandardLayoutProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.LabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "font_configuration": "fontConfiguration",
            "visibility": "visibility",
        },
    )
    class LabelOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The share label options for the labels.

            :param custom_label: The text for the label.
            :param font_configuration: The font configuration of the label.
            :param visibility: Determines whether or not the label is visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-labeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                label_options_property = quicksight.CfnTemplate.LabelOptionsProperty(
                    custom_label="customLabel",
                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3fd818a7c255c79287bf84b2a124248eb218f11289ab7fb4a22c849ded8e80a8)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The text for the label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-labeloptions.html#cfn-quicksight-template-labeloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"]]:
            '''The font configuration of the label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-labeloptions.html#cfn-quicksight-template-labeloptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the label is visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-labeloptions.html#cfn-quicksight-template-labeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.LayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "free_form_layout": "freeFormLayout",
            "grid_layout": "gridLayout",
            "section_based_layout": "sectionBasedLayout",
        },
    )
    class LayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FreeFormLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            grid_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            section_based_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SectionBasedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration that determines what the type of layout will be used on a sheet.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param free_form_layout: A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.
            :param grid_layout: A type of layout that can be used on a sheet. In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: ``FIXED`` or ``RESPONSIVE`` .
            :param section_based_layout: A section based layout organizes visuals into multiple sections and has customized header, footer and page break.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                layout_configuration_property = quicksight.CfnTemplate.LayoutConfigurationProperty(
                    free_form_layout=quicksight.CfnTemplate.FreeFormLayoutConfigurationProperty(
                        elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                            element_id="elementId",
                            element_type="elementType",
                            height="height",
                            width="width",
                            x_axis_location="xAxisLocation",
                            y_axis_location="yAxisLocation",
                
                            # the properties below are optional
                            background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                visibility="visibility"
                            ),
                            rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                    visibility="visibility"
                                ),
                                expression="expression"
                            )],
                            selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            visibility="visibility"
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                        elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                            column_span=123,
                            element_id="elementId",
                            element_type="elementType",
                            row_span=123,
                
                            # the properties below are optional
                            column_index=123,
                            row_index=123
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    section_based_layout=quicksight.CfnTemplate.SectionBasedLayoutConfigurationProperty(
                        body_sections=[quicksight.CfnTemplate.BodySectionConfigurationProperty(
                            content=quicksight.CfnTemplate.BodySectionContentProperty(
                                layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            page_break_configuration=quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                                after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                                    status="status"
                                )
                            ),
                            style=quicksight.CfnTemplate.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnTemplate.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )],
                        canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                            paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                ),
                                paper_orientation="paperOrientation",
                                paper_size="paperSize"
                            )
                        ),
                        footer_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                            layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            style=quicksight.CfnTemplate.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnTemplate.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )],
                        header_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                            layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            style=quicksight.CfnTemplate.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnTemplate.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b525a1aaad5609f117a600ffed9d6c618d1e78b9132a41d45c2a39f07f0a24af)
                check_type(argname="argument free_form_layout", value=free_form_layout, expected_type=type_hints["free_form_layout"])
                check_type(argname="argument grid_layout", value=grid_layout, expected_type=type_hints["grid_layout"])
                check_type(argname="argument section_based_layout", value=section_based_layout, expected_type=type_hints["section_based_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if free_form_layout is not None:
                self._values["free_form_layout"] = free_form_layout
            if grid_layout is not None:
                self._values["grid_layout"] = grid_layout
            if section_based_layout is not None:
                self._values["section_based_layout"] = section_based_layout

        @builtins.property
        def free_form_layout(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FreeFormLayoutConfigurationProperty"]]:
            '''A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layoutconfiguration.html#cfn-quicksight-template-layoutconfiguration-freeformlayout
            '''
            result = self._values.get("free_form_layout")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FreeFormLayoutConfigurationProperty"]], result)

        @builtins.property
        def grid_layout(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GridLayoutConfigurationProperty"]]:
            '''A type of layout that can be used on a sheet.

            In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: ``FIXED`` or ``RESPONSIVE`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layoutconfiguration.html#cfn-quicksight-template-layoutconfiguration-gridlayout
            '''
            result = self._values.get("grid_layout")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GridLayoutConfigurationProperty"]], result)

        @builtins.property
        def section_based_layout(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SectionBasedLayoutConfigurationProperty"]]:
            '''A section based layout organizes visuals into multiple sections and has customized header, footer and page break.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layoutconfiguration.html#cfn-quicksight-template-layoutconfiguration-sectionbasedlayout
            '''
            result = self._values.get("section_based_layout")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SectionBasedLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.LayoutProperty",
        jsii_struct_bases=[],
        name_mapping={"configuration": "configuration"},
    )
    class LayoutProperty:
        def __init__(
            self,
            *,
            configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''A ``Layout`` defines the placement of elements within a sheet.

            For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param configuration: The configuration that determines what the type of layout for a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layout.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                layout_property = quicksight.CfnTemplate.LayoutProperty(
                    configuration=quicksight.CfnTemplate.LayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnTemplate.FreeFormLayoutConfigurationProperty(
                            elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                            elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                column_span=123,
                                element_id="elementId",
                                element_type="elementType",
                                row_span=123,
                
                                # the properties below are optional
                                column_index=123,
                                row_index=123
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        section_based_layout=quicksight.CfnTemplate.SectionBasedLayoutConfigurationProperty(
                            body_sections=[quicksight.CfnTemplate.BodySectionConfigurationProperty(
                                content=quicksight.CfnTemplate.BodySectionContentProperty(
                                    layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
                
                                                # the properties below are optional
                                                background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                page_break_configuration=quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                                    after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                                        status="status"
                                    )
                                ),
                                style=quicksight.CfnTemplate.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnTemplate.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )],
                            canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                    paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    ),
                                    paper_orientation="paperOrientation",
                                    paper_size="paperSize"
                                )
                            ),
                            footer_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                style=quicksight.CfnTemplate.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnTemplate.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )],
                            header_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                style=quicksight.CfnTemplate.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnTemplate.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__33a24a96d0ad68626e1112b855ca8dd98a11abb380e1c0876a0ac1f814328e69)
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration": configuration,
            }

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.LayoutConfigurationProperty"]:
            '''The configuration that determines what the type of layout for a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layout.html#cfn-quicksight-template-layout-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.LayoutConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LayoutProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.LegendOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "height": "height",
            "position": "position",
            "title": "title",
            "visibility": "visibility",
            "width": "width",
        },
    )
    class LegendOptionsProperty:
        def __init__(
            self,
            *,
            height: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for the legend setup of a visual.

            :param height: The height of the legend. If this value is omitted, a default height is used when rendering.
            :param position: The positions for the legend. Choose one of the following options:. - ``AUTO`` - ``RIGHT`` - ``BOTTOM`` - ``LEFT``
            :param title: The custom title for the legend.
            :param visibility: Determines whether or not the legend is visible.
            :param width: The width of the legend. If this value is omitted, a default width is used when rendering.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                legend_options_property = quicksight.CfnTemplate.LegendOptionsProperty(
                    height="height",
                    position="position",
                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    ),
                    visibility="visibility",
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8673c92d2f96698e2403e46aa2954b7739f2970492853314dcc1ffa3db8a2c45)
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if height is not None:
                self._values["height"] = height
            if position is not None:
                self._values["position"] = position
            if title is not None:
                self._values["title"] = title
            if visibility is not None:
                self._values["visibility"] = visibility
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def height(self) -> typing.Optional[builtins.str]:
            '''The height of the legend.

            If this value is omitted, a default height is used when rendering.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''The positions for the legend. Choose one of the following options:.

            - ``AUTO``
            - ``RIGHT``
            - ``BOTTOM``
            - ``LEFT``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LabelOptionsProperty"]]:
            '''The custom title for the legend.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LabelOptionsProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the legend is visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width of the legend.

            If this value is omitted, a default width is used when rendering.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LegendOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.LineChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "colors": "colors",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class LineChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a line chart.

            :param category: The category field wells of a line chart. Values are grouped by category fields.
            :param colors: The color field wells of a line chart. Values are grouped by category fields.
            :param small_multiples: The small multiples field well of a line chart.
            :param values: The value field wells of a line chart. Values are aggregated based on categories.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c317d36d4b278b652f3242d8b2de5a8347800f39c2fb751bfbbcceaf3a379f81)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The category field wells of a line chart.

            Values are grouped by category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html#cfn-quicksight-template-linechartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The color field wells of a line chart.

            Values are grouped by category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html#cfn-quicksight-template-linechartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The small multiples field well of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html#cfn-quicksight-template-linechartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The value field wells of a line chart.

            Values are aggregated based on categories.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html#cfn-quicksight-template-linechartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.LineChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "default_series_settings": "defaultSeriesSettings",
            "field_wells": "fieldWells",
            "forecast_configurations": "forecastConfigurations",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "secondary_y_axis_display_options": "secondaryYAxisDisplayOptions",
            "secondary_y_axis_label_options": "secondaryYAxisLabelOptions",
            "series": "series",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "type": "type",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
        },
    )
    class LineChartConfigurationProperty:
        def __init__(
            self,
            *,
            contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            default_series_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LineChartDefaultSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LineChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            forecast_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ForecastConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LineSeriesAxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            secondary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LineSeriesAxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            series: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SeriesItemProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LineChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a line chart.

            :param contribution_analysis_defaults: The default configuration of a line chart's contribution analysis.
            :param data_labels: The data label configuration of a line chart.
            :param default_series_settings: The options that determine the default presentation of all line series in ``LineChartVisual`` .
            :param field_wells: The field well configuration of a line chart.
            :param forecast_configurations: The forecast configuration of a line chart.
            :param legend: The legend configuration of a line chart.
            :param primary_y_axis_display_options: The series axis configuration of a line chart.
            :param primary_y_axis_label_options: The options that determine the presentation of the y-axis label.
            :param reference_lines: The reference lines configuration of a line chart.
            :param secondary_y_axis_display_options: The series axis configuration of a line chart.
            :param secondary_y_axis_label_options: The options that determine the presentation of the secondary y-axis label.
            :param series: The series item configuration of a line chart.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a line chart.
            :param tooltip: The tooltip configuration of a line chart.
            :param type: Determines the type of the line chart.
            :param visual_palette: The visual palette configuration of a line chart.
            :param x_axis_display_options: The options that determine the presentation of the x-axis.
            :param x_axis_label_options: The options that determine the presentation of the x-axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5512c77f2e4a1702a8c594533133d44abba69e618642372c6dbeccc102cf3d54)
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument default_series_settings", value=default_series_settings, expected_type=type_hints["default_series_settings"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument forecast_configurations", value=forecast_configurations, expected_type=type_hints["forecast_configurations"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument secondary_y_axis_display_options", value=secondary_y_axis_display_options, expected_type=type_hints["secondary_y_axis_display_options"])
                check_type(argname="argument secondary_y_axis_label_options", value=secondary_y_axis_label_options, expected_type=type_hints["secondary_y_axis_label_options"])
                check_type(argname="argument series", value=series, expected_type=type_hints["series"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if default_series_settings is not None:
                self._values["default_series_settings"] = default_series_settings
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if forecast_configurations is not None:
                self._values["forecast_configurations"] = forecast_configurations
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if secondary_y_axis_display_options is not None:
                self._values["secondary_y_axis_display_options"] = secondary_y_axis_display_options
            if secondary_y_axis_label_options is not None:
                self._values["secondary_y_axis_label_options"] = secondary_y_axis_label_options
            if series is not None:
                self._values["series"] = series
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if type is not None:
                self._values["type"] = type
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ContributionAnalysisDefaultProperty"]]]]:
            '''The default configuration of a line chart's contribution analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ContributionAnalysisDefaultProperty"]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The data label configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def default_series_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartDefaultSeriesSettingsProperty"]]:
            '''The options that determine the default presentation of all line series in ``LineChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-defaultseriessettings
            '''
            result = self._values.get("default_series_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartDefaultSeriesSettingsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartFieldWellsProperty"]]:
            '''The field well configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartFieldWellsProperty"]], result)

        @builtins.property
        def forecast_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ForecastConfigurationProperty"]]]]:
            '''The forecast configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-forecastconfigurations
            '''
            result = self._values.get("forecast_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ForecastConfigurationProperty"]]]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineSeriesAxisDisplayOptionsProperty"]]:
            '''The series axis configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineSeriesAxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineProperty"]]]]:
            '''The reference lines configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineProperty"]]]], result)

        @builtins.property
        def secondary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineSeriesAxisDisplayOptionsProperty"]]:
            '''The series axis configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-secondaryyaxisdisplayoptions
            '''
            result = self._values.get("secondary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineSeriesAxisDisplayOptionsProperty"]], result)

        @builtins.property
        def secondary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the secondary y-axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-secondaryyaxislabeloptions
            '''
            result = self._values.get("secondary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def series(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SeriesItemProperty"]]]]:
            '''The series item configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-series
            '''
            result = self._values.get("series")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SeriesItemProperty"]]]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SmallMultiplesOptionsProperty"]]:
            '''The small multiples setup for the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SmallMultiplesOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartSortConfigurationProperty"]]:
            '''The sort configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''Determines the type of the line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]]:
            '''The visual palette configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.LineChartDefaultSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "line_style_settings": "lineStyleSettings",
            "marker_style_settings": "markerStyleSettings",
        },
    )
    class LineChartDefaultSeriesSettingsProperty:
        def __init__(
            self,
            *,
            axis_binding: typing.Optional[builtins.str] = None,
            line_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LineChartLineStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            marker_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LineChartMarkerStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the default presentation of all line series in ``LineChartVisual`` .

            :param axis_binding: The axis to which you are binding all line series to.
            :param line_style_settings: Line styles options for all line series in the visual.
            :param marker_style_settings: Marker styles options for all line series in the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartdefaultseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                line_chart_default_series_settings_property = quicksight.CfnTemplate.LineChartDefaultSeriesSettingsProperty(
                    axis_binding="axisBinding",
                    line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                        line_interpolation="lineInterpolation",
                        line_style="lineStyle",
                        line_visibility="lineVisibility",
                        line_width="lineWidth"
                    ),
                    marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                        marker_color="markerColor",
                        marker_shape="markerShape",
                        marker_size="markerSize",
                        marker_visibility="markerVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__92044b7be0ca37011a03642dd917371b696c8a4ac918d17b9c960de67598af40)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument line_style_settings", value=line_style_settings, expected_type=type_hints["line_style_settings"])
                check_type(argname="argument marker_style_settings", value=marker_style_settings, expected_type=type_hints["marker_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_binding is not None:
                self._values["axis_binding"] = axis_binding
            if line_style_settings is not None:
                self._values["line_style_settings"] = line_style_settings
            if marker_style_settings is not None:
                self._values["marker_style_settings"] = marker_style_settings

        @builtins.property
        def axis_binding(self) -> typing.Optional[builtins.str]:
            '''The axis to which you are binding all line series to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartdefaultseriessettings.html#cfn-quicksight-template-linechartdefaultseriessettings-axisbinding
            '''
            result = self._values.get("axis_binding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartLineStyleSettingsProperty"]]:
            '''Line styles options for all line series in the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartdefaultseriessettings.html#cfn-quicksight-template-linechartdefaultseriessettings-linestylesettings
            '''
            result = self._values.get("line_style_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartLineStyleSettingsProperty"]], result)

        @builtins.property
        def marker_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartMarkerStyleSettingsProperty"]]:
            '''Marker styles options for all line series in the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartdefaultseriessettings.html#cfn-quicksight-template-linechartdefaultseriessettings-markerstylesettings
            '''
            result = self._values.get("marker_style_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartMarkerStyleSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartDefaultSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.LineChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_chart_aggregated_field_wells": "lineChartAggregatedFieldWells",
        },
    )
    class LineChartFieldWellsProperty:
        def __init__(
            self,
            *,
            line_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LineChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a line chart.

            :param line_chart_aggregated_field_wells: The field well configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__022c66ee2a6f952d5efb3250eaf32c3f0babd14415f6722a5113bdbf0264decf)
                check_type(argname="argument line_chart_aggregated_field_wells", value=line_chart_aggregated_field_wells, expected_type=type_hints["line_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_chart_aggregated_field_wells is not None:
                self._values["line_chart_aggregated_field_wells"] = line_chart_aggregated_field_wells

        @builtins.property
        def line_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartfieldwells.html#cfn-quicksight-template-linechartfieldwells-linechartaggregatedfieldwells
            '''
            result = self._values.get("line_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.LineChartLineStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_interpolation": "lineInterpolation",
            "line_style": "lineStyle",
            "line_visibility": "lineVisibility",
            "line_width": "lineWidth",
        },
    )
    class LineChartLineStyleSettingsProperty:
        def __init__(
            self,
            *,
            line_interpolation: typing.Optional[builtins.str] = None,
            line_style: typing.Optional[builtins.str] = None,
            line_visibility: typing.Optional[builtins.str] = None,
            line_width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Line styles options for a line series in ``LineChartVisual`` .

            :param line_interpolation: Interpolation style for line series. - ``LINEAR`` : Show as default, linear style. - ``SMOOTH`` : Show as a smooth curve. - ``STEPPED`` : Show steps in line.
            :param line_style: Line style for line series. - ``SOLID`` : Show as a solid line. - ``DOTTED`` : Show as a dotted line. - ``DASHED`` : Show as a dashed line.
            :param line_visibility: Configuration option that determines whether to show the line for the series.
            :param line_width: Width that determines the line thickness.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                line_chart_line_style_settings_property = quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                    line_interpolation="lineInterpolation",
                    line_style="lineStyle",
                    line_visibility="lineVisibility",
                    line_width="lineWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aae75a71d83e54e3b20a2643ba8871a3ae5264f9d8b7e9bcae8ddaa89deda19e)
                check_type(argname="argument line_interpolation", value=line_interpolation, expected_type=type_hints["line_interpolation"])
                check_type(argname="argument line_style", value=line_style, expected_type=type_hints["line_style"])
                check_type(argname="argument line_visibility", value=line_visibility, expected_type=type_hints["line_visibility"])
                check_type(argname="argument line_width", value=line_width, expected_type=type_hints["line_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_interpolation is not None:
                self._values["line_interpolation"] = line_interpolation
            if line_style is not None:
                self._values["line_style"] = line_style
            if line_visibility is not None:
                self._values["line_visibility"] = line_visibility
            if line_width is not None:
                self._values["line_width"] = line_width

        @builtins.property
        def line_interpolation(self) -> typing.Optional[builtins.str]:
            '''Interpolation style for line series.

            - ``LINEAR`` : Show as default, linear style.
            - ``SMOOTH`` : Show as a smooth curve.
            - ``STEPPED`` : Show steps in line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html#cfn-quicksight-template-linechartlinestylesettings-lineinterpolation
            '''
            result = self._values.get("line_interpolation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_style(self) -> typing.Optional[builtins.str]:
            '''Line style for line series.

            - ``SOLID`` : Show as a solid line.
            - ``DOTTED`` : Show as a dotted line.
            - ``DASHED`` : Show as a dashed line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html#cfn-quicksight-template-linechartlinestylesettings-linestyle
            '''
            result = self._values.get("line_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_visibility(self) -> typing.Optional[builtins.str]:
            '''Configuration option that determines whether to show the line for the series.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html#cfn-quicksight-template-linechartlinestylesettings-linevisibility
            '''
            result = self._values.get("line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_width(self) -> typing.Optional[builtins.str]:
            '''Width that determines the line thickness.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html#cfn-quicksight-template-linechartlinestylesettings-linewidth
            '''
            result = self._values.get("line_width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartLineStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "marker_color": "markerColor",
            "marker_shape": "markerShape",
            "marker_size": "markerSize",
            "marker_visibility": "markerVisibility",
        },
    )
    class LineChartMarkerStyleSettingsProperty:
        def __init__(
            self,
            *,
            marker_color: typing.Optional[builtins.str] = None,
            marker_shape: typing.Optional[builtins.str] = None,
            marker_size: typing.Optional[builtins.str] = None,
            marker_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Marker styles options for a line series in ``LineChartVisual`` .

            :param marker_color: Color of marker in the series.
            :param marker_shape: Shape option for markers in the series. - ``CIRCLE`` : Show marker as a circle. - ``TRIANGLE`` : Show marker as a triangle. - ``SQUARE`` : Show marker as a square. - ``DIAMOND`` : Show marker as a diamond. - ``ROUNDED_SQUARE`` : Show marker as a rounded square.
            :param marker_size: Size of marker in the series.
            :param marker_visibility: Configuration option that determines whether to show the markers in the series.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                line_chart_marker_style_settings_property = quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                    marker_color="markerColor",
                    marker_shape="markerShape",
                    marker_size="markerSize",
                    marker_visibility="markerVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0ed467167c488109aa9bf06c701d587d3346e7a4ccd6729073280a8eb9a2e52d)
                check_type(argname="argument marker_color", value=marker_color, expected_type=type_hints["marker_color"])
                check_type(argname="argument marker_shape", value=marker_shape, expected_type=type_hints["marker_shape"])
                check_type(argname="argument marker_size", value=marker_size, expected_type=type_hints["marker_size"])
                check_type(argname="argument marker_visibility", value=marker_visibility, expected_type=type_hints["marker_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if marker_color is not None:
                self._values["marker_color"] = marker_color
            if marker_shape is not None:
                self._values["marker_shape"] = marker_shape
            if marker_size is not None:
                self._values["marker_size"] = marker_size
            if marker_visibility is not None:
                self._values["marker_visibility"] = marker_visibility

        @builtins.property
        def marker_color(self) -> typing.Optional[builtins.str]:
            '''Color of marker in the series.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html#cfn-quicksight-template-linechartmarkerstylesettings-markercolor
            '''
            result = self._values.get("marker_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_shape(self) -> typing.Optional[builtins.str]:
            '''Shape option for markers in the series.

            - ``CIRCLE`` : Show marker as a circle.
            - ``TRIANGLE`` : Show marker as a triangle.
            - ``SQUARE`` : Show marker as a square.
            - ``DIAMOND`` : Show marker as a diamond.
            - ``ROUNDED_SQUARE`` : Show marker as a rounded square.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html#cfn-quicksight-template-linechartmarkerstylesettings-markershape
            '''
            result = self._values.get("marker_shape")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_size(self) -> typing.Optional[builtins.str]:
            '''Size of marker in the series.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html#cfn-quicksight-template-linechartmarkerstylesettings-markersize
            '''
            result = self._values.get("marker_size")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_visibility(self) -> typing.Optional[builtins.str]:
            '''Configuration option that determines whether to show the markers in the series.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html#cfn-quicksight-template-linechartmarkerstylesettings-markervisibility
            '''
            result = self._values.get("marker_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartMarkerStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.LineChartSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_style_settings": "lineStyleSettings",
            "marker_style_settings": "markerStyleSettings",
        },
    )
    class LineChartSeriesSettingsProperty:
        def __init__(
            self,
            *,
            line_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LineChartLineStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            marker_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LineChartMarkerStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of a line series in the visual.

            :param line_style_settings: Line styles options for a line series in ``LineChartVisual`` .
            :param marker_style_settings: Marker styles options for a line series in ``LineChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                line_chart_series_settings_property = quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                    line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                        line_interpolation="lineInterpolation",
                        line_style="lineStyle",
                        line_visibility="lineVisibility",
                        line_width="lineWidth"
                    ),
                    marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                        marker_color="markerColor",
                        marker_shape="markerShape",
                        marker_size="markerSize",
                        marker_visibility="markerVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8502b89cafafdbf3399b7a94abe4819063ea7034731a35b721557ad60395e2f5)
                check_type(argname="argument line_style_settings", value=line_style_settings, expected_type=type_hints["line_style_settings"])
                check_type(argname="argument marker_style_settings", value=marker_style_settings, expected_type=type_hints["marker_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_style_settings is not None:
                self._values["line_style_settings"] = line_style_settings
            if marker_style_settings is not None:
                self._values["marker_style_settings"] = marker_style_settings

        @builtins.property
        def line_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartLineStyleSettingsProperty"]]:
            '''Line styles options for a line series in ``LineChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartseriessettings.html#cfn-quicksight-template-linechartseriessettings-linestylesettings
            '''
            result = self._values.get("line_style_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartLineStyleSettingsProperty"]], result)

        @builtins.property
        def marker_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartMarkerStyleSettingsProperty"]]:
            '''Marker styles options for a line series in ``LineChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartseriessettings.html#cfn-quicksight-template-linechartseriessettings-markerstylesettings
            '''
            result = self._values.get("marker_style_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartMarkerStyleSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.LineChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit_configuration": "categoryItemsLimitConfiguration",
            "category_sort": "categorySort",
            "color_items_limit_configuration": "colorItemsLimitConfiguration",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class LineChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a line chart.

            :param category_items_limit_configuration: The limit on the number of categories that are displayed in a line chart.
            :param category_sort: The sort configuration of the category fields.
            :param color_items_limit_configuration: The limit on the number of lines that are displayed in a line chart.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                line_chart_sort_configuration_property = quicksight.CfnTemplate.LineChartSortConfigurationProperty(
                    category_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2f7936e46a8b600d8690037a0869afdc0f413c715a5f0f59d4bbb2593d5e4602)
                check_type(argname="argument category_items_limit_configuration", value=category_items_limit_configuration, expected_type=type_hints["category_items_limit_configuration"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit_configuration", value=color_items_limit_configuration, expected_type=type_hints["color_items_limit_configuration"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit_configuration is not None:
                self._values["category_items_limit_configuration"] = category_items_limit_configuration
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit_configuration is not None:
                self._values["color_items_limit_configuration"] = color_items_limit_configuration
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories that are displayed in a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-categoryitemslimitconfiguration
            '''
            result = self._values.get("category_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of lines that are displayed in a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-coloritemslimitconfiguration
            '''
            result = self._values.get("color_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of small multiples panels that are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the small multiples field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.LineChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class LineChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LineChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A line chart.

            For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a line chart.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9e19cca65c746b1f803157557ecfc1e6cd720a70dce62910e5a0d55c63c36102)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartConfigurationProperty"]]:
            '''The configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_options": "axisOptions",
            "missing_data_configurations": "missingDataConfigurations",
        },
    )
    class LineSeriesAxisDisplayOptionsProperty:
        def __init__(
            self,
            *,
            axis_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            missing_data_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MissingDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The series axis configuration of a line chart.

            :param axis_options: The options that determine the presentation of the line series axis.
            :param missing_data_configurations: The configuration options that determine how missing data is treated during the rendering of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-lineseriesaxisdisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                line_series_axis_display_options_property = quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                    axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                        treatment_option="treatmentOption"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__44dc37136cfaae10bb2310298b57d1421b364f7819ec02ff088f1fdf28e40d97)
                check_type(argname="argument axis_options", value=axis_options, expected_type=type_hints["axis_options"])
                check_type(argname="argument missing_data_configurations", value=missing_data_configurations, expected_type=type_hints["missing_data_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_options is not None:
                self._values["axis_options"] = axis_options
            if missing_data_configurations is not None:
                self._values["missing_data_configurations"] = missing_data_configurations

        @builtins.property
        def axis_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the line series axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-lineseriesaxisdisplayoptions.html#cfn-quicksight-template-lineseriesaxisdisplayoptions-axisoptions
            '''
            result = self._values.get("axis_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def missing_data_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MissingDataConfigurationProperty"]]]]:
            '''The configuration options that determine how missing data is treated during the rendering of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-lineseriesaxisdisplayoptions.html#cfn-quicksight-template-lineseriesaxisdisplayoptions-missingdataconfigurations
            '''
            result = self._values.get("missing_data_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MissingDataConfigurationProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineSeriesAxisDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ListControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "info_icon_label_options": "infoIconLabelOptions",
            "search_options": "searchOptions",
            "select_all_options": "selectAllOptions",
            "title_options": "titleOptions",
        },
    )
    class ListControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SheetControlInfoIconLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            search_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ListControlSearchOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            select_all_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ListControlSelectAllOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param info_icon_label_options: The configuration of info icon label options.
            :param search_options: The configuration of the search options in a list control.
            :param select_all_options: The configuration of the ``Select all`` options in a list control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                list_control_display_options_property = quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                    info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                        info_icon_text="infoIconText",
                        visibility="visibility"
                    ),
                    search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                        visibility="visibility"
                    ),
                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ca8cba505438f9cc90d295b2d3da50b8e8c8feb94f873f2ada533b9fe8f8a089)
                check_type(argname="argument info_icon_label_options", value=info_icon_label_options, expected_type=type_hints["info_icon_label_options"])
                check_type(argname="argument search_options", value=search_options, expected_type=type_hints["search_options"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if info_icon_label_options is not None:
                self._values["info_icon_label_options"] = info_icon_label_options
            if search_options is not None:
                self._values["search_options"] = search_options
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def info_icon_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetControlInfoIconLabelOptionsProperty"]]:
            '''The configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html#cfn-quicksight-template-listcontroldisplayoptions-infoiconlabeloptions
            '''
            result = self._values.get("info_icon_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetControlInfoIconLabelOptionsProperty"]], result)

        @builtins.property
        def search_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ListControlSearchOptionsProperty"]]:
            '''The configuration of the search options in a list control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html#cfn-quicksight-template-listcontroldisplayoptions-searchoptions
            '''
            result = self._values.get("search_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ListControlSearchOptionsProperty"]], result)

        @builtins.property
        def select_all_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ListControlSelectAllOptionsProperty"]]:
            '''The configuration of the ``Select all`` options in a list control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html#cfn-quicksight-template-listcontroldisplayoptions-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ListControlSelectAllOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html#cfn-quicksight-template-listcontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ListControlSearchOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ListControlSearchOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the search options in a list control.

            :param visibility: The visibility configuration of the search options in a list control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontrolsearchoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                list_control_search_options_property = quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__619d434836756e0902fe7f71906803e4e2c3977837d91d51178e7f6b47ad63f1)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the search options in a list control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontrolsearchoptions.html#cfn-quicksight-template-listcontrolsearchoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlSearchOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ListControlSelectAllOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ListControlSelectAllOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the ``Select all`` options in a list control.

            :param visibility: The visibility configuration of the ``Select all`` options in a list control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontrolselectalloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                list_control_select_all_options_property = quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__496c17dd9f8144236cddbe3bf135a2c4ea2601c94f841e25b9902b1822a7ee57)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the ``Select all`` options in a list control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontrolselectalloptions.html#cfn-quicksight-template-listcontrolselectalloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlSelectAllOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.LoadingAnimationProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class LoadingAnimationProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of loading animation in free-form layout.

            :param visibility: The visibility configuration of ``LoadingAnimation`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-loadinganimation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                loading_animation_property = quicksight.CfnTemplate.LoadingAnimationProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c786885e8082b3b3457d8ec95c9eb5836ea170a678aac001f47406157e1f344e)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of ``LoadingAnimation`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-loadinganimation.html#cfn-quicksight-template-loadinganimation-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LoadingAnimationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.LocalNavigationConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"target_sheet_id": "targetSheetId"},
    )
    class LocalNavigationConfigurationProperty:
        def __init__(self, *, target_sheet_id: builtins.str) -> None:
            '''The navigation configuration for ``CustomActionNavigationOperation`` .

            :param target_sheet_id: The sheet that is targeted for navigation in the same analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-localnavigationconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                local_navigation_configuration_property = quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                    target_sheet_id="targetSheetId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0e3a6c3c5bf767ba83e8c991e07df42198274e5ded97e47305b195b7d7b92e8d)
                check_type(argname="argument target_sheet_id", value=target_sheet_id, expected_type=type_hints["target_sheet_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "target_sheet_id": target_sheet_id,
            }

        @builtins.property
        def target_sheet_id(self) -> builtins.str:
            '''The sheet that is targeted for navigation in the same analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-localnavigationconfiguration.html#cfn-quicksight-template-localnavigationconfiguration-targetsheetid
            '''
            result = self._values.get("target_sheet_id")
            assert result is not None, "Required property 'target_sheet_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LocalNavigationConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.LongFormatTextProperty",
        jsii_struct_bases=[],
        name_mapping={"plain_text": "plainText", "rich_text": "richText"},
    )
    class LongFormatTextProperty:
        def __init__(
            self,
            *,
            plain_text: typing.Optional[builtins.str] = None,
            rich_text: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The text format for a subtitle.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param plain_text: Plain text format.
            :param rich_text: Rich text. Examples of rich text include bold, underline, and italics.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-longformattext.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                long_format_text_property = quicksight.CfnTemplate.LongFormatTextProperty(
                    plain_text="plainText",
                    rich_text="richText"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__65bdec78f38ce1afe5db408d8940b5fe563893e6e91d7740622358620cc94ee6)
                check_type(argname="argument plain_text", value=plain_text, expected_type=type_hints["plain_text"])
                check_type(argname="argument rich_text", value=rich_text, expected_type=type_hints["rich_text"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if plain_text is not None:
                self._values["plain_text"] = plain_text
            if rich_text is not None:
                self._values["rich_text"] = rich_text

        @builtins.property
        def plain_text(self) -> typing.Optional[builtins.str]:
            '''Plain text format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-longformattext.html#cfn-quicksight-template-longformattext-plaintext
            '''
            result = self._values.get("plain_text")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rich_text(self) -> typing.Optional[builtins.str]:
            '''Rich text.

            Examples of rich text include bold, underline, and italics.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-longformattext.html#cfn-quicksight-template-longformattext-richtext
            '''
            result = self._values.get("rich_text")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LongFormatTextProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.MappedDataSetParameterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "data_set_parameter_name": "dataSetParameterName",
        },
    )
    class MappedDataSetParameterProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            data_set_parameter_name: builtins.str,
        ) -> None:
            '''A dataset parameter that is mapped to an analysis parameter.

            :param data_set_identifier: A unique name that identifies a dataset within the analysis or dashboard.
            :param data_set_parameter_name: The name of the dataset parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-mappeddatasetparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                mapped_data_set_parameter_property = quicksight.CfnTemplate.MappedDataSetParameterProperty(
                    data_set_identifier="dataSetIdentifier",
                    data_set_parameter_name="dataSetParameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8c6ae60e451fe7dff8753ad0d950d26682e2f3ab5be66b26b771d70abb5c5f79)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument data_set_parameter_name", value=data_set_parameter_name, expected_type=type_hints["data_set_parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "data_set_parameter_name": data_set_parameter_name,
            }

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''A unique name that identifies a dataset within the analysis or dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-mappeddatasetparameter.html#cfn-quicksight-template-mappeddatasetparameter-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_parameter_name(self) -> builtins.str:
            '''The name of the dataset parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-mappeddatasetparameter.html#cfn-quicksight-template-mappeddatasetparameter-datasetparametername
            '''
            result = self._values.get("data_set_parameter_name")
            assert result is not None, "Required property 'data_set_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MappedDataSetParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.MaximumLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class MaximumLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The maximum label of a data path label.

            :param visibility: The visibility of the maximum label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                maximum_label_type_property = quicksight.CfnTemplate.MaximumLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ac6cf684662783fe0378195f35ffe1875e4d7baae65cd6777baae1964cdf7bca)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the maximum label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumlabeltype.html#cfn-quicksight-template-maximumlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MaximumLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.MaximumMinimumComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "type": "type",
            "name": "name",
            "time": "time",
            "value": "value",
        },
    )
    class MaximumMinimumComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            type: builtins.str,
            name: typing.Optional[builtins.str] = None,
            time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The maximum and minimum computation configuration.

            :param computation_id: The ID for a computation.
            :param type: The type of computation. Choose one of the following options:. - MAXIMUM: A maximum computation. - MINIMUM: A minimum computation.
            :param name: The name of a computation.
            :param time: The time field that is used in a computation.
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                maximum_minimum_computation_property = quicksight.CfnTemplate.MaximumMinimumComputationProperty(
                    computation_id="computationId",
                    type="type",
                
                    # the properties below are optional
                    name="name",
                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__15dd15ed61f2c2e17a6d1829ac2976b57cf91069b8bb28fab8202b92ceac09d2)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "type": type,
            }
            if name is not None:
                self._values["name"] = name
            if time is not None:
                self._values["time"] = time
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The type of computation. Choose one of the following options:.

            - MAXIMUM: A maximum computation.
            - MINIMUM: A minimum computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]:
            '''The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-time
            '''
            result = self._values.get("time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MaximumMinimumComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.MeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "calculated_measure_field": "calculatedMeasureField",
            "categorical_measure_field": "categoricalMeasureField",
            "date_measure_field": "dateMeasureField",
            "numerical_measure_field": "numericalMeasureField",
        },
    )
    class MeasureFieldProperty:
        def __init__(
            self,
            *,
            calculated_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CalculatedMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            categorical_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CategoricalMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            date_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DateMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numerical_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumericalMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure (metric) type field.

            :param calculated_measure_field: The calculated measure field only used in pivot tables.
            :param categorical_measure_field: The measure type field with categorical type columns.
            :param date_measure_field: The measure type field with date type columns.
            :param numerical_measure_field: The measure type field with numerical type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                measure_field_property = quicksight.CfnTemplate.MeasureFieldProperty(
                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                        expression="expression",
                        field_id="fieldId"
                    ),
                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function="aggregationFunction",
                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function="aggregationFunction",
                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        ),
                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e3bd18060e8ab68dbd312d5880484954da32dfa2e19eb25a7ffa1eb190c8c271)
                check_type(argname="argument calculated_measure_field", value=calculated_measure_field, expected_type=type_hints["calculated_measure_field"])
                check_type(argname="argument categorical_measure_field", value=categorical_measure_field, expected_type=type_hints["categorical_measure_field"])
                check_type(argname="argument date_measure_field", value=date_measure_field, expected_type=type_hints["date_measure_field"])
                check_type(argname="argument numerical_measure_field", value=numerical_measure_field, expected_type=type_hints["numerical_measure_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if calculated_measure_field is not None:
                self._values["calculated_measure_field"] = calculated_measure_field
            if categorical_measure_field is not None:
                self._values["categorical_measure_field"] = categorical_measure_field
            if date_measure_field is not None:
                self._values["date_measure_field"] = date_measure_field
            if numerical_measure_field is not None:
                self._values["numerical_measure_field"] = numerical_measure_field

        @builtins.property
        def calculated_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CalculatedMeasureFieldProperty"]]:
            '''The calculated measure field only used in pivot tables.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html#cfn-quicksight-template-measurefield-calculatedmeasurefield
            '''
            result = self._values.get("calculated_measure_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CalculatedMeasureFieldProperty"]], result)

        @builtins.property
        def categorical_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CategoricalMeasureFieldProperty"]]:
            '''The measure type field with categorical type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html#cfn-quicksight-template-measurefield-categoricalmeasurefield
            '''
            result = self._values.get("categorical_measure_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CategoricalMeasureFieldProperty"]], result)

        @builtins.property
        def date_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateMeasureFieldProperty"]]:
            '''The measure type field with date type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html#cfn-quicksight-template-measurefield-datemeasurefield
            '''
            result = self._values.get("date_measure_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateMeasureFieldProperty"]], result)

        @builtins.property
        def numerical_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericalMeasureFieldProperty"]]:
            '''The measure type field with numerical type columns.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html#cfn-quicksight-template-measurefield-numericalmeasurefield
            '''
            result = self._values.get("numerical_measure_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericalMeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.MetricComparisonComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "from_value": "fromValue",
            "name": "name",
            "target_value": "targetValue",
            "time": "time",
        },
    )
    class MetricComparisonComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            from_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            name: typing.Optional[builtins.str] = None,
            target_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The metric comparison computation configuration.

            :param computation_id: The ID for a computation.
            :param from_value: The field that is used in a metric comparison from value setup.
            :param name: The name of a computation.
            :param target_value: The field that is used in a metric comparison to value setup.
            :param time: The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__51ce5b40674bb03088d888ca46951ae63eb7409301c5120f31de7353649c627c)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument from_value", value=from_value, expected_type=type_hints["from_value"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument target_value", value=target_value, expected_type=type_hints["target_value"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
            }
            if from_value is not None:
                self._values["from_value"] = from_value
            if name is not None:
                self._values["name"] = name
            if target_value is not None:
                self._values["target_value"] = target_value
            if time is not None:
                self._values["time"] = time

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def from_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]:
            '''The field that is used in a metric comparison from value setup.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-fromvalue
            '''
            result = self._values.get("from_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def target_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]:
            '''The field that is used in a metric comparison to value setup.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-targetvalue
            '''
            result = self._values.get("target_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]:
            '''The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-time
            '''
            result = self._values.get("time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MetricComparisonComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.MinimumLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class MinimumLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The minimum label of a data path label.

            :param visibility: The visibility of the minimum label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-minimumlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                minimum_label_type_property = quicksight.CfnTemplate.MinimumLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3379fed9e190f7ceb91e3580e038ddada30db775f39391d082d4c9e949a82715)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the minimum label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-minimumlabeltype.html#cfn-quicksight-template-minimumlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MinimumLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.MissingDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"treatment_option": "treatmentOption"},
    )
    class MissingDataConfigurationProperty:
        def __init__(
            self,
            *,
            treatment_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration options that determine how missing data is treated during the rendering of a line chart.

            :param treatment_option: The treatment option that determines how missing data should be rendered. Choose from the following options:. - ``INTERPOLATE`` : Interpolate missing values between the prior and the next known value. - ``SHOW_AS_ZERO`` : Show missing values as the value ``0`` . - ``SHOW_AS_BLANK`` : Display a blank space when rendering missing data.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-missingdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                missing_data_configuration_property = quicksight.CfnTemplate.MissingDataConfigurationProperty(
                    treatment_option="treatmentOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__660d39b682dcb70af4c7f14448b4f3d65dd00c45cd9613f3a74dbf817ba4e237)
                check_type(argname="argument treatment_option", value=treatment_option, expected_type=type_hints["treatment_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if treatment_option is not None:
                self._values["treatment_option"] = treatment_option

        @builtins.property
        def treatment_option(self) -> typing.Optional[builtins.str]:
            '''The treatment option that determines how missing data should be rendered. Choose from the following options:.

            - ``INTERPOLATE`` : Interpolate missing values between the prior and the next known value.
            - ``SHOW_AS_ZERO`` : Show missing values as the value ``0`` .
            - ``SHOW_AS_BLANK`` : Display a blank space when rendering missing data.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-missingdataconfiguration.html#cfn-quicksight-template-missingdataconfiguration-treatmentoption
            '''
            result = self._values.get("treatment_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MissingDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.NegativeValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"display_mode": "displayMode"},
    )
    class NegativeValueConfigurationProperty:
        def __init__(self, *, display_mode: builtins.str) -> None:
            '''The options that determine the negative value configuration.

            :param display_mode: Determines the display mode of the negative value configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-negativevalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                negative_value_configuration_property = quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                    display_mode="displayMode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__861dacb150b9116530cacc74aeb5fef839aa760953bb470a63908c93a5d65c88)
                check_type(argname="argument display_mode", value=display_mode, expected_type=type_hints["display_mode"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "display_mode": display_mode,
            }

        @builtins.property
        def display_mode(self) -> builtins.str:
            '''Determines the display mode of the negative value configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-negativevalueconfiguration.html#cfn-quicksight-template-negativevalueconfiguration-displaymode
            '''
            result = self._values.get("display_mode")
            assert result is not None, "Required property 'display_mode' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NegativeValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.NullValueFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"null_string": "nullString"},
    )
    class NullValueFormatConfigurationProperty:
        def __init__(self, *, null_string: builtins.str) -> None:
            '''The options that determine the null value format configuration.

            :param null_string: Determines the null string of null values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-nullvalueformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                null_value_format_configuration_property = quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                    null_string="nullString"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7ef2703bb84434a9c18efac4a8fe2867f5900bb19178ac0f4e9a9e81b63125ca)
                check_type(argname="argument null_string", value=null_string, expected_type=type_hints["null_string"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "null_string": null_string,
            }

        @builtins.property
        def null_string(self) -> builtins.str:
            '''Determines the null string of null values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-nullvalueformatconfiguration.html#cfn-quicksight-template-nullvalueformatconfiguration-nullstring
            '''
            result = self._values.get("null_string")
            assert result is not None, "Required property 'null_string' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NullValueFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "number_scale": "numberScale",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
        },
    )
    class NumberDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            negative_value_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_scale: typing.Optional[builtins.str] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            suffix: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the number display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param number_scale: Determines the number scale value of the number format.
            :param prefix: Determines the prefix value of the number format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the number format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                number_display_format_configuration_property = quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    number_scale="numberScale",
                    prefix="prefix",
                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__32d6a92fcbcf2ed74695382053c5d78ad7aee0a3d227f0ad9308f1c9a79fd4b2)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument number_scale", value=number_scale, expected_type=type_hints["number_scale"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if number_scale is not None:
                self._values["number_scale"] = number_scale
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DecimalPlacesConfigurationProperty"]]:
            '''The option that determines the decimal places configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DecimalPlacesConfigurationProperty"]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NegativeValueConfigurationProperty"]]:
            '''The options that determine the negative value configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NegativeValueConfigurationProperty"]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def number_scale(self) -> typing.Optional[builtins.str]:
            '''Determines the number scale value of the number format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-numberscale
            '''
            result = self._values.get("number_scale")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the number format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericSeparatorConfigurationProperty"]]:
            '''The options that determine the numeric separator configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericSeparatorConfigurationProperty"]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the number format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumberDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.NumberFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"format_configuration": "formatConfiguration"},
    )
    class NumberFormatConfigurationProperty:
        def __init__(
            self,
            *,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Formatting configuration for number fields.

            :param format_configuration: The options that determine the numeric format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                number_format_configuration_property = quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c5b337fd34b602376c2d4b2a56c499171ad222d849e3826259e72cbfc560ac95)
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericFormatConfigurationProperty"]]:
            '''The options that determine the numeric format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberformatconfiguration.html#cfn-quicksight-template-numberformatconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumberFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.NumericAxisOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"range": "range", "scale": "scale"},
    )
    class NumericAxisOptionsProperty:
        def __init__(
            self,
            *,
            range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisDisplayRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scale: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options for an axis with a numeric field.

            :param range: The range setup of a numeric axis.
            :param scale: The scale setup of a numeric axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaxisoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                numeric_axis_options_property = quicksight.CfnTemplate.NumericAxisOptionsProperty(
                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                        data_driven=data_driven,
                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                            maximum=123,
                            minimum=123
                        )
                    ),
                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                            step_count=123,
                            step_size=123
                        ),
                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                            base=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8f05adaa975168b09a3c5a5b4ebee87c01d6fa8b72b3c3d742e44124e4419115)
                check_type(argname="argument range", value=range, expected_type=type_hints["range"])
                check_type(argname="argument scale", value=scale, expected_type=type_hints["scale"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if range is not None:
                self._values["range"] = range
            if scale is not None:
                self._values["scale"] = scale

        @builtins.property
        def range(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayRangeProperty"]]:
            '''The range setup of a numeric axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaxisoptions.html#cfn-quicksight-template-numericaxisoptions-range
            '''
            result = self._values.get("range")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayRangeProperty"]], result)

        @builtins.property
        def scale(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisScaleProperty"]]:
            '''The scale setup of a numeric axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaxisoptions.html#cfn-quicksight-template-numericaxisoptions-scale
            '''
            result = self._values.get("scale")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisScaleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericAxisOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "value": "value"},
    )
    class NumericEqualityDrillDownFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            value: jsii.Number,
        ) -> None:
            '''The category drill down filter.

            :param column: The column that the filter is applied to.
            :param value: The value of the double input numeric drill down filter. Default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalitydrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numeric_equality_drill_down_filter_property = quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__da6dafc8fe3785b9a50e89ba100d517e376fd5564f2be7f84e16710256f392b9)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "value": value,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalitydrilldownfilter.html#cfn-quicksight-template-numericequalitydrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The value of the double input numeric drill down filter.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalitydrilldownfilter.html#cfn-quicksight-template-numericequalitydrilldownfilter-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericEqualityDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.NumericEqualityFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "aggregation_function": "aggregationFunction",
            "parameter_name": "parameterName",
            "select_all_options": "selectAllOptions",
            "value": "value",
        },
    )
    class NumericEqualityFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            match_operator: builtins.str,
            null_option: builtins.str,
            aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            select_all_options: typing.Optional[builtins.str] = None,
            value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A ``NumericEqualityFilter`` filters values that are equal to the specified value.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param aggregation_function: The aggregation function of the filter.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``
            :param value: The input value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numeric_equality_filter_property = quicksight.CfnTemplate.NumericEqualityFilterProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                        attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                            simple_attribute_aggregation="simpleAttributeAggregation",
                            value_for_multiple_values="valueForMultipleValues"
                        ),
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    parameter_name="parameterName",
                    select_all_options="selectAllOptions",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__077d3058a3ae75f8e36d381073421b87da859085b5b2d17726a9cb51677e04c1)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AggregationFunctionProperty"]]:
            '''The aggregation function of the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AggregationFunctionProperty"]], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The input value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericEqualityFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.NumericFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "currency_display_format_configuration": "currencyDisplayFormatConfiguration",
            "number_display_format_configuration": "numberDisplayFormatConfiguration",
            "percentage_display_format_configuration": "percentageDisplayFormatConfiguration",
        },
    )
    class NumericFormatConfigurationProperty:
        def __init__(
            self,
            *,
            currency_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CurrencyDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumberDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            percentage_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PercentageDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the numeric format configuration.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param currency_display_format_configuration: The options that determine the currency display format configuration.
            :param number_display_format_configuration: The options that determine the number display format configuration.
            :param percentage_display_format_configuration: The options that determine the percentage display format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numeric_format_configuration_property = quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix",
                        symbol="symbol"
                    ),
                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    ),
                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        prefix="prefix",
                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__255f8d073f54dec93bd2c56bb6a5a7f43a33751ea474002c12e635fb4a27fb42)
                check_type(argname="argument currency_display_format_configuration", value=currency_display_format_configuration, expected_type=type_hints["currency_display_format_configuration"])
                check_type(argname="argument number_display_format_configuration", value=number_display_format_configuration, expected_type=type_hints["number_display_format_configuration"])
                check_type(argname="argument percentage_display_format_configuration", value=percentage_display_format_configuration, expected_type=type_hints["percentage_display_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if currency_display_format_configuration is not None:
                self._values["currency_display_format_configuration"] = currency_display_format_configuration
            if number_display_format_configuration is not None:
                self._values["number_display_format_configuration"] = number_display_format_configuration
            if percentage_display_format_configuration is not None:
                self._values["percentage_display_format_configuration"] = percentage_display_format_configuration

        @builtins.property
        def currency_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CurrencyDisplayFormatConfigurationProperty"]]:
            '''The options that determine the currency display format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericformatconfiguration.html#cfn-quicksight-template-numericformatconfiguration-currencydisplayformatconfiguration
            '''
            result = self._values.get("currency_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CurrencyDisplayFormatConfigurationProperty"]], result)

        @builtins.property
        def number_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumberDisplayFormatConfigurationProperty"]]:
            '''The options that determine the number display format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericformatconfiguration.html#cfn-quicksight-template-numericformatconfiguration-numberdisplayformatconfiguration
            '''
            result = self._values.get("number_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumberDisplayFormatConfigurationProperty"]], result)

        @builtins.property
        def percentage_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PercentageDisplayFormatConfigurationProperty"]]:
            '''The options that determine the percentage display format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericformatconfiguration.html#cfn-quicksight-template-numericformatconfiguration-percentagedisplayformatconfiguration
            '''
            result = self._values.get("percentage_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PercentageDisplayFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.NumericRangeFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "aggregation_function": "aggregationFunction",
            "include_maximum": "includeMaximum",
            "include_minimum": "includeMinimum",
            "range_maximum": "rangeMaximum",
            "range_minimum": "rangeMinimum",
            "select_all_options": "selectAllOptions",
        },
    )
    class NumericRangeFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            null_option: builtins.str,
            aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
            include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
            range_maximum: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumericRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            range_minimum: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumericRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``NumericRangeFilter`` filters values that are within the value range.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param aggregation_function: The aggregation function of the filter.
            :param include_maximum: Determines whether the maximum value in the filter value range should be included in the filtered results.
            :param include_minimum: Determines whether the minimum value in the filter value range should be included in the filtered results.
            :param range_maximum: The maximum value for the filter value range.
            :param range_minimum: The minimum value for the filter value range.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numeric_range_filter_property = quicksight.CfnTemplate.NumericRangeFilterProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                        attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                            simple_attribute_aggregation="simpleAttributeAggregation",
                            value_for_multiple_values="valueForMultipleValues"
                        ),
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    include_maximum=False,
                    include_minimum=False,
                    range_maximum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                        parameter="parameter",
                        static_value=123
                    ),
                    range_minimum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                        parameter="parameter",
                        static_value=123
                    ),
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e7c41df0822b558a329cc70bdd5a20bc6c7ff2cdfa1e87de73209c354f5a86ab)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument include_maximum", value=include_maximum, expected_type=type_hints["include_maximum"])
                check_type(argname="argument include_minimum", value=include_minimum, expected_type=type_hints["include_minimum"])
                check_type(argname="argument range_maximum", value=range_maximum, expected_type=type_hints["range_maximum"])
                check_type(argname="argument range_minimum", value=range_minimum, expected_type=type_hints["range_minimum"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if include_maximum is not None:
                self._values["include_maximum"] = include_maximum
            if include_minimum is not None:
                self._values["include_minimum"] = include_minimum
            if range_maximum is not None:
                self._values["range_maximum"] = range_maximum
            if range_minimum is not None:
                self._values["range_minimum"] = range_minimum
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AggregationFunctionProperty"]]:
            '''The aggregation function of the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AggregationFunctionProperty"]], result)

        @builtins.property
        def include_maximum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''Determines whether the maximum value in the filter value range should be included in the filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-includemaximum
            '''
            result = self._values.get("include_maximum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        @builtins.property
        def include_minimum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''Determines whether the minimum value in the filter value range should be included in the filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-includeminimum
            '''
            result = self._values.get("include_minimum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        @builtins.property
        def range_maximum(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericRangeFilterValueProperty"]]:
            '''The maximum value for the filter value range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-rangemaximum
            '''
            result = self._values.get("range_maximum")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericRangeFilterValueProperty"]], result)

        @builtins.property
        def range_minimum(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericRangeFilterValueProperty"]]:
            '''The minimum value for the filter value range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-rangeminimum
            '''
            result = self._values.get("range_minimum")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericRangeFilterValueProperty"]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericRangeFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.NumericRangeFilterValueProperty",
        jsii_struct_bases=[],
        name_mapping={"parameter": "parameter", "static_value": "staticValue"},
    )
    class NumericRangeFilterValueProperty:
        def __init__(
            self,
            *,
            parameter: typing.Optional[builtins.str] = None,
            static_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The value input pf the numeric range filter.

            :param parameter: The parameter that is used in the numeric range.
            :param static_value: The static value of the numeric range filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefiltervalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numeric_range_filter_value_property = quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                    parameter="parameter",
                    static_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e4eb10de204924c8f371165138bd4aa3765f920645f18a3ec41d52ccb14760af)
                check_type(argname="argument parameter", value=parameter, expected_type=type_hints["parameter"])
                check_type(argname="argument static_value", value=static_value, expected_type=type_hints["static_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if parameter is not None:
                self._values["parameter"] = parameter
            if static_value is not None:
                self._values["static_value"] = static_value

        @builtins.property
        def parameter(self) -> typing.Optional[builtins.str]:
            '''The parameter that is used in the numeric range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefiltervalue.html#cfn-quicksight-template-numericrangefiltervalue-parameter
            '''
            result = self._values.get("parameter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def static_value(self) -> typing.Optional[jsii.Number]:
            '''The static value of the numeric range filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefiltervalue.html#cfn-quicksight-template-numericrangefiltervalue-staticvalue
            '''
            result = self._values.get("static_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericRangeFilterValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.NumericSeparatorConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_separator": "decimalSeparator",
            "thousands_separator": "thousandsSeparator",
        },
    )
    class NumericSeparatorConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_separator: typing.Optional[builtins.str] = None,
            thousands_separator: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ThousandSeparatorOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the numeric separator configuration.

            :param decimal_separator: Determines the decimal separator.
            :param thousands_separator: The options that determine the thousands separator configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericseparatorconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numeric_separator_configuration_property = quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                    decimal_separator="decimalSeparator",
                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                        symbol="symbol",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6388026317ac90b875b9560e9ffaf93e3f7fd7d23c01d8ca1a3db65f342bbe3a)
                check_type(argname="argument decimal_separator", value=decimal_separator, expected_type=type_hints["decimal_separator"])
                check_type(argname="argument thousands_separator", value=thousands_separator, expected_type=type_hints["thousands_separator"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_separator is not None:
                self._values["decimal_separator"] = decimal_separator
            if thousands_separator is not None:
                self._values["thousands_separator"] = thousands_separator

        @builtins.property
        def decimal_separator(self) -> typing.Optional[builtins.str]:
            '''Determines the decimal separator.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericseparatorconfiguration.html#cfn-quicksight-template-numericseparatorconfiguration-decimalseparator
            '''
            result = self._values.get("decimal_separator")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def thousands_separator(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ThousandSeparatorOptionsProperty"]]:
            '''The options that determine the thousands separator configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericseparatorconfiguration.html#cfn-quicksight-template-numericseparatorconfiguration-thousandsseparator
            '''
            result = self._values.get("thousands_separator")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ThousandSeparatorOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericSeparatorConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.NumericalAggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "percentile_aggregation": "percentileAggregation",
            "simple_numerical_aggregation": "simpleNumericalAggregation",
        },
    )
    class NumericalAggregationFunctionProperty:
        def __init__(
            self,
            *,
            percentile_aggregation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PercentileAggregationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            simple_numerical_aggregation: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Aggregation for numerical values.

            :param percentile_aggregation: An aggregation based on the percentile of values in a dimension or measure.
            :param simple_numerical_aggregation: Built-in aggregation functions for numerical values. - ``SUM`` : The sum of a dimension or measure. - ``AVERAGE`` : The average of a dimension or measure. - ``MIN`` : The minimum value of a dimension or measure. - ``MAX`` : The maximum value of a dimension or measure. - ``COUNT`` : The count of a dimension or measure. - ``DISTINCT_COUNT`` : The count of distinct values in a dimension or measure. - ``VAR`` : The variance of a dimension or measure. - ``VARP`` : The partitioned variance of a dimension or measure. - ``STDEV`` : The standard deviation of a dimension or measure. - ``STDEVP`` : The partitioned standard deviation of a dimension or measure. - ``MEDIAN`` : The median value of a dimension or measure.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalaggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numerical_aggregation_function_property = quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                        percentile_value=123
                    ),
                    simple_numerical_aggregation="simpleNumericalAggregation"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__976084e0b8f503e1d4a3cc34315384fd7458cd243b551586f2e765f1b75bc560)
                check_type(argname="argument percentile_aggregation", value=percentile_aggregation, expected_type=type_hints["percentile_aggregation"])
                check_type(argname="argument simple_numerical_aggregation", value=simple_numerical_aggregation, expected_type=type_hints["simple_numerical_aggregation"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percentile_aggregation is not None:
                self._values["percentile_aggregation"] = percentile_aggregation
            if simple_numerical_aggregation is not None:
                self._values["simple_numerical_aggregation"] = simple_numerical_aggregation

        @builtins.property
        def percentile_aggregation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PercentileAggregationProperty"]]:
            '''An aggregation based on the percentile of values in a dimension or measure.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalaggregationfunction.html#cfn-quicksight-template-numericalaggregationfunction-percentileaggregation
            '''
            result = self._values.get("percentile_aggregation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PercentileAggregationProperty"]], result)

        @builtins.property
        def simple_numerical_aggregation(self) -> typing.Optional[builtins.str]:
            '''Built-in aggregation functions for numerical values.

            - ``SUM`` : The sum of a dimension or measure.
            - ``AVERAGE`` : The average of a dimension or measure.
            - ``MIN`` : The minimum value of a dimension or measure.
            - ``MAX`` : The maximum value of a dimension or measure.
            - ``COUNT`` : The count of a dimension or measure.
            - ``DISTINCT_COUNT`` : The count of distinct values in a dimension or measure.
            - ``VAR`` : The variance of a dimension or measure.
            - ``VARP`` : The partitioned variance of a dimension or measure.
            - ``STDEV`` : The standard deviation of a dimension or measure.
            - ``STDEVP`` : The partitioned standard deviation of a dimension or measure.
            - ``MEDIAN`` : The median value of a dimension or measure.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalaggregationfunction.html#cfn-quicksight-template-numericalaggregationfunction-simplenumericalaggregation
            '''
            result = self._values.get("simple_numerical_aggregation")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalAggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.NumericalDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class NumericalDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with numerical type columns.

            :param column: The column that is used in the ``NumericalDimensionField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numerical_dimension_field_property = quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1fc40f6a0439d409cb0f32912334e2b232712f81f4cde7ca9164d72426dfb3c7)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that is used in the ``NumericalDimensionField`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html#cfn-quicksight-template-numericaldimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html#cfn-quicksight-template-numericaldimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumberFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html#cfn-quicksight-template-numericaldimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumberFormatConfigurationProperty"]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html#cfn-quicksight-template-numericaldimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.NumericalMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class NumericalMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure type field with numerical type columns.

            :param column: The column that is used in the ``NumericalMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                numerical_measure_field_property = quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    ),
                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8dbff5970ac76bcbe5f856c919a637aa0e845c724320f1b388dc32ed62b0771d)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that is used in the ``NumericalMeasureField`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html#cfn-quicksight-template-numericalmeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html#cfn-quicksight-template-numericalmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericalAggregationFunctionProperty"]]:
            '''The aggregation function of the measure field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html#cfn-quicksight-template-numericalmeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericalAggregationFunctionProperty"]], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumberFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html#cfn-quicksight-template-numericalmeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumberFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PaginationConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"page_number": "pageNumber", "page_size": "pageSize"},
    )
    class PaginationConfigurationProperty:
        def __init__(self, *, page_number: jsii.Number, page_size: jsii.Number) -> None:
            '''The pagination configuration for a table visual or boxplot.

            :param page_number: Indicates the page number.
            :param page_size: Indicates how many items render in one page.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paginationconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pagination_configuration_property = quicksight.CfnTemplate.PaginationConfigurationProperty(
                    page_number=123,
                    page_size=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__270b59e4b6a2e8a93161529222f4ea2238f653fb098e010d7896eea3a69f216f)
                check_type(argname="argument page_number", value=page_number, expected_type=type_hints["page_number"])
                check_type(argname="argument page_size", value=page_size, expected_type=type_hints["page_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "page_number": page_number,
                "page_size": page_size,
            }

        @builtins.property
        def page_number(self) -> jsii.Number:
            '''Indicates the page number.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paginationconfiguration.html#cfn-quicksight-template-paginationconfiguration-pagenumber
            '''
            result = self._values.get("page_number")
            assert result is not None, "Required property 'page_number' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def page_size(self) -> jsii.Number:
            '''Indicates how many items render in one page.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paginationconfiguration.html#cfn-quicksight-template-paginationconfiguration-pagesize
            '''
            result = self._values.get("page_size")
            assert result is not None, "Required property 'page_size' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PaginationConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PanelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "background_visibility": "backgroundVisibility",
            "border_color": "borderColor",
            "border_style": "borderStyle",
            "border_thickness": "borderThickness",
            "border_visibility": "borderVisibility",
            "gutter_spacing": "gutterSpacing",
            "gutter_visibility": "gutterVisibility",
            "title": "title",
        },
    )
    class PanelConfigurationProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[builtins.str] = None,
            background_visibility: typing.Optional[builtins.str] = None,
            border_color: typing.Optional[builtins.str] = None,
            border_style: typing.Optional[builtins.str] = None,
            border_thickness: typing.Optional[builtins.str] = None,
            border_visibility: typing.Optional[builtins.str] = None,
            gutter_spacing: typing.Optional[builtins.str] = None,
            gutter_visibility: typing.Optional[builtins.str] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PanelTitleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A collection of options that configure how each panel displays in a small multiples chart.

            :param background_color: Sets the background color for each panel.
            :param background_visibility: Determines whether or not a background for each small multiples panel is rendered.
            :param border_color: Sets the line color of panel borders.
            :param border_style: Sets the line style of panel borders.
            :param border_thickness: Sets the line thickness of panel borders.
            :param border_visibility: Determines whether or not each panel displays a border.
            :param gutter_spacing: Sets the total amount of negative space to display between sibling panels.
            :param gutter_visibility: Determines whether or not negative space between sibling panels is rendered.
            :param title: Configures the title display within each small multiples panel.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                panel_configuration_property = quicksight.CfnTemplate.PanelConfigurationProperty(
                    background_color="backgroundColor",
                    background_visibility="backgroundVisibility",
                    border_color="borderColor",
                    border_style="borderStyle",
                    border_thickness="borderThickness",
                    border_visibility="borderVisibility",
                    gutter_spacing="gutterSpacing",
                    gutter_visibility="gutterVisibility",
                    title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        horizontal_text_alignment="horizontalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0fac64ca9f41312eb62a68abd7c113da3c7eebab0c12065d4078969746227026)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument background_visibility", value=background_visibility, expected_type=type_hints["background_visibility"])
                check_type(argname="argument border_color", value=border_color, expected_type=type_hints["border_color"])
                check_type(argname="argument border_style", value=border_style, expected_type=type_hints["border_style"])
                check_type(argname="argument border_thickness", value=border_thickness, expected_type=type_hints["border_thickness"])
                check_type(argname="argument border_visibility", value=border_visibility, expected_type=type_hints["border_visibility"])
                check_type(argname="argument gutter_spacing", value=gutter_spacing, expected_type=type_hints["gutter_spacing"])
                check_type(argname="argument gutter_visibility", value=gutter_visibility, expected_type=type_hints["gutter_visibility"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if background_visibility is not None:
                self._values["background_visibility"] = background_visibility
            if border_color is not None:
                self._values["border_color"] = border_color
            if border_style is not None:
                self._values["border_style"] = border_style
            if border_thickness is not None:
                self._values["border_thickness"] = border_thickness
            if border_visibility is not None:
                self._values["border_visibility"] = border_visibility
            if gutter_spacing is not None:
                self._values["gutter_spacing"] = gutter_spacing
            if gutter_visibility is not None:
                self._values["gutter_visibility"] = gutter_visibility
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def background_color(self) -> typing.Optional[builtins.str]:
            '''Sets the background color for each panel.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def background_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not a background for each small multiples panel is rendered.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-backgroundvisibility
            '''
            result = self._values.get("background_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_color(self) -> typing.Optional[builtins.str]:
            '''Sets the line color of panel borders.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-bordercolor
            '''
            result = self._values.get("border_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_style(self) -> typing.Optional[builtins.str]:
            '''Sets the line style of panel borders.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-borderstyle
            '''
            result = self._values.get("border_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_thickness(self) -> typing.Optional[builtins.str]:
            '''Sets the line thickness of panel borders.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-borderthickness
            '''
            result = self._values.get("border_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not each panel displays a border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-bordervisibility
            '''
            result = self._values.get("border_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def gutter_spacing(self) -> typing.Optional[builtins.str]:
            '''Sets the total amount of negative space to display between sibling panels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-gutterspacing
            '''
            result = self._values.get("gutter_spacing")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def gutter_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not negative space between sibling panels is rendered.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-guttervisibility
            '''
            result = self._values.get("gutter_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PanelTitleOptionsProperty"]]:
            '''Configures the title display within each small multiples panel.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PanelTitleOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PanelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PanelTitleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "font_configuration": "fontConfiguration",
            "horizontal_text_alignment": "horizontalTextAlignment",
            "visibility": "visibility",
        },
    )
    class PanelTitleOptionsProperty:
        def __init__(
            self,
            *,
            font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            horizontal_text_alignment: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the title styles for each small multiples panel.

            :param font_configuration: 
            :param horizontal_text_alignment: Sets the horizontal text alignment of the title within each panel.
            :param visibility: Determines whether or not panel titles are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paneltitleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                panel_title_options_property = quicksight.CfnTemplate.PanelTitleOptionsProperty(
                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    horizontal_text_alignment="horizontalTextAlignment",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__45ab70b3fd95e49ef3268cc1edce400bb46b4a415c8091086a630aa8383a4e05)
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument horizontal_text_alignment", value=horizontal_text_alignment, expected_type=type_hints["horizontal_text_alignment"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if horizontal_text_alignment is not None:
                self._values["horizontal_text_alignment"] = horizontal_text_alignment
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paneltitleoptions.html#cfn-quicksight-template-paneltitleoptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"]], result)

        @builtins.property
        def horizontal_text_alignment(self) -> typing.Optional[builtins.str]:
            '''Sets the horizontal text alignment of the title within each panel.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paneltitleoptions.html#cfn-quicksight-template-paneltitleoptions-horizontaltextalignment
            '''
            result = self._values.get("horizontal_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not panel titles are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paneltitleoptions.html#cfn-quicksight-template-paneltitleoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PanelTitleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ParameterControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_picker": "dateTimePicker",
            "dropdown": "dropdown",
            "list": "list",
            "slider": "slider",
            "text_area": "textArea",
            "text_field": "textField",
        },
    )
    class ParameterControlProperty:
        def __init__(
            self,
            *,
            date_time_picker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ParameterDateTimePickerControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            dropdown: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ParameterDropDownControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            list: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ParameterListControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            slider: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ParameterSliderControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_area: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ParameterTextAreaControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ParameterTextFieldControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The control of a parameter that users can interact with in a dashboard or an analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_picker: A control from a date parameter that specifies date and time.
            :param dropdown: A control to display a dropdown list with buttons that are used to select a single value.
            :param list: A control to display a list with buttons or boxes that are used to select either a single value or multiple values.
            :param slider: A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
            :param text_area: A control to display a text box that is used to enter multiple entries.
            :param text_field: A control to display a text box that is used to enter a single entry.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_control_property = quicksight.CfnTemplate.ParameterControlProperty(
                    date_time_picker=quicksight.CfnTemplate.ParameterDateTimePickerControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    dropdown=quicksight.CfnTemplate.ParameterDropDownControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                            link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            values=["values"]
                        ),
                        type="type"
                    ),
                    list=quicksight.CfnTemplate.ParameterListControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                            link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            values=["values"]
                        ),
                        type="type"
                    ),
                    slider=quicksight.CfnTemplate.ParameterSliderControlProperty(
                        maximum_value=123,
                        minimum_value=123,
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        step_size=123,
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_area=quicksight.CfnTemplate.ParameterTextAreaControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        delimiter="delimiter",
                        display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_field=quicksight.CfnTemplate.ParameterTextFieldControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                            info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                                info_icon_text="infoIconText",
                                visibility="visibility"
                            ),
                            placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__47d5e3a66805c54a34bfe8d0e68d7e8d019846c76d7516bf16ae89cf5b21bdda)
                check_type(argname="argument date_time_picker", value=date_time_picker, expected_type=type_hints["date_time_picker"])
                check_type(argname="argument dropdown", value=dropdown, expected_type=type_hints["dropdown"])
                check_type(argname="argument list", value=list, expected_type=type_hints["list"])
                check_type(argname="argument slider", value=slider, expected_type=type_hints["slider"])
                check_type(argname="argument text_area", value=text_area, expected_type=type_hints["text_area"])
                check_type(argname="argument text_field", value=text_field, expected_type=type_hints["text_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_picker is not None:
                self._values["date_time_picker"] = date_time_picker
            if dropdown is not None:
                self._values["dropdown"] = dropdown
            if list is not None:
                self._values["list"] = list
            if slider is not None:
                self._values["slider"] = slider
            if text_area is not None:
                self._values["text_area"] = text_area
            if text_field is not None:
                self._values["text_field"] = text_field

        @builtins.property
        def date_time_picker(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ParameterDateTimePickerControlProperty"]]:
            '''A control from a date parameter that specifies date and time.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-datetimepicker
            '''
            result = self._values.get("date_time_picker")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ParameterDateTimePickerControlProperty"]], result)

        @builtins.property
        def dropdown(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ParameterDropDownControlProperty"]]:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-dropdown
            '''
            result = self._values.get("dropdown")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ParameterDropDownControlProperty"]], result)

        @builtins.property
        def list(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ParameterListControlProperty"]]:
            '''A control to display a list with buttons or boxes that are used to select either a single value or multiple values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-list
            '''
            result = self._values.get("list")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ParameterListControlProperty"]], result)

        @builtins.property
        def slider(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ParameterSliderControlProperty"]]:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-slider
            '''
            result = self._values.get("slider")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ParameterSliderControlProperty"]], result)

        @builtins.property
        def text_area(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ParameterTextAreaControlProperty"]]:
            '''A control to display a text box that is used to enter multiple entries.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-textarea
            '''
            result = self._values.get("text_area")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ParameterTextAreaControlProperty"]], result)

        @builtins.property
        def text_field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ParameterTextFieldControlProperty"]]:
            '''A control to display a text box that is used to enter a single entry.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-textfield
            '''
            result = self._values.get("text_field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ParameterTextFieldControlProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ParameterDateTimePickerControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterDateTimePickerControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DateTimePickerControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control from a date parameter that specifies date and time.

            :param parameter_control_id: The ID of the ``ParameterDateTimePickerControl`` .
            :param source_parameter_name: The name of the ``ParameterDateTimePickerControl`` .
            :param title: The title of the ``ParameterDateTimePickerControl`` .
            :param display_options: The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_date_time_picker_control_property = quicksight.CfnTemplate.ParameterDateTimePickerControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e9ecad2e18890766f2c4aca0e0f85799fbaf55dc846f14a7f89c858279412498)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterDateTimePickerControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html#cfn-quicksight-template-parameterdatetimepickercontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The name of the ``ParameterDateTimePickerControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html#cfn-quicksight-template-parameterdatetimepickercontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterDateTimePickerControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html#cfn-quicksight-template-parameterdatetimepickercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateTimePickerControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html#cfn-quicksight-template-parameterdatetimepickercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateTimePickerControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDateTimePickerControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_parameter_declaration": "dateTimeParameterDeclaration",
            "decimal_parameter_declaration": "decimalParameterDeclaration",
            "integer_parameter_declaration": "integerParameterDeclaration",
            "string_parameter_declaration": "stringParameterDeclaration",
        },
    )
    class ParameterDeclarationProperty:
        def __init__(
            self,
            *,
            date_time_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DateTimeParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            decimal_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DecimalParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            integer_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.IntegerParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            string_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.StringParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The declaration definition of a parameter.

            For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_parameter_declaration: A parameter declaration for the ``DateTime`` data type.
            :param decimal_parameter_declaration: A parameter declaration for the ``Decimal`` data type.
            :param integer_parameter_declaration: A parameter declaration for the ``Integer`` data type.
            :param string_parameter_declaration: A parameter declaration for the ``String`` data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_declaration_property = quicksight.CfnTemplate.ParameterDeclarationProperty(
                    date_time_parameter_declaration=quicksight.CfnTemplate.DateTimeParameterDeclarationProperty(
                        name="name",
                
                        # the properties below are optional
                        default_values=quicksight.CfnTemplate.DateTimeDefaultValuesProperty(
                            dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        time_granularity="timeGranularity",
                        value_when_unset=quicksight.CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    decimal_parameter_declaration=quicksight.CfnTemplate.DecimalParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnTemplate.DecimalDefaultValuesProperty(
                            dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnTemplate.DecimalValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    integer_parameter_declaration=quicksight.CfnTemplate.IntegerParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnTemplate.IntegerDefaultValuesProperty(
                            dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnTemplate.IntegerValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    string_parameter_declaration=quicksight.CfnTemplate.StringParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnTemplate.StringDefaultValuesProperty(
                            dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnTemplate.StringValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7702a729402847cd3b9f7ff918a131852b209d248928eee0cc7914f2e2c6cd19)
                check_type(argname="argument date_time_parameter_declaration", value=date_time_parameter_declaration, expected_type=type_hints["date_time_parameter_declaration"])
                check_type(argname="argument decimal_parameter_declaration", value=decimal_parameter_declaration, expected_type=type_hints["decimal_parameter_declaration"])
                check_type(argname="argument integer_parameter_declaration", value=integer_parameter_declaration, expected_type=type_hints["integer_parameter_declaration"])
                check_type(argname="argument string_parameter_declaration", value=string_parameter_declaration, expected_type=type_hints["string_parameter_declaration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_parameter_declaration is not None:
                self._values["date_time_parameter_declaration"] = date_time_parameter_declaration
            if decimal_parameter_declaration is not None:
                self._values["decimal_parameter_declaration"] = decimal_parameter_declaration
            if integer_parameter_declaration is not None:
                self._values["integer_parameter_declaration"] = integer_parameter_declaration
            if string_parameter_declaration is not None:
                self._values["string_parameter_declaration"] = string_parameter_declaration

        @builtins.property
        def date_time_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateTimeParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``DateTime`` data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html#cfn-quicksight-template-parameterdeclaration-datetimeparameterdeclaration
            '''
            result = self._values.get("date_time_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DateTimeParameterDeclarationProperty"]], result)

        @builtins.property
        def decimal_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DecimalParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``Decimal`` data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html#cfn-quicksight-template-parameterdeclaration-decimalparameterdeclaration
            '''
            result = self._values.get("decimal_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DecimalParameterDeclarationProperty"]], result)

        @builtins.property
        def integer_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.IntegerParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``Integer`` data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html#cfn-quicksight-template-parameterdeclaration-integerparameterdeclaration
            '''
            result = self._values.get("integer_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.IntegerParameterDeclarationProperty"]], result)

        @builtins.property
        def string_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.StringParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``String`` data type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html#cfn-quicksight-template-parameterdeclaration-stringparameterdeclaration
            '''
            result = self._values.get("string_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.StringParameterDeclarationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ParameterDropDownControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class ParameterDropDownControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DropDownControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ParameterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :param parameter_control_id: The ID of the ``ParameterDropDownControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterDropDownControl`` .
            :param title: The title of the ``ParameterDropDownControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type parameter name of the ``ParameterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_drop_down_control_property = quicksight.CfnTemplate.ParameterDropDownControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                        link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7aa165991c6350bb966a26a09859966bdfeaa334d539dc305d12cfac86b56c19)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DropDownControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DropDownControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ParameterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ParameterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type parameter name of the ``ParameterDropDownControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDropDownControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ParameterListControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class ParameterListControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ListControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ParameterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a list with buttons or boxes that are used to select either a single value or multiple values.

            :param parameter_control_id: The ID of the ``ParameterListControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterListControl`` .
            :param title: The title of the ``ParameterListControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of ``ParameterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_list_control_property = quicksight.CfnTemplate.ParameterListControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                        link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c2b9011b851175e8cabd06e74494d4ba410de5a0604e0bd305959d960be42c4a)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ListControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ListControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ParameterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ParameterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``ParameterListControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterListControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ParameterSelectableValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "link_to_data_set_column": "linkToDataSetColumn",
            "values": "values",
        },
    )
    class ParameterSelectableValuesProperty:
        def __init__(
            self,
            *,
            link_to_data_set_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A list of selectable values that are used in a control.

            :param link_to_data_set_column: The column identifier that fetches values from the data set.
            :param values: The values that are used in ``ParameterSelectableValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterselectablevalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_selectable_values_property = quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                    link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__02febe921a1aae761973af4de966ca120691e228959c6290908875cc28f8200f)
                check_type(argname="argument link_to_data_set_column", value=link_to_data_set_column, expected_type=type_hints["link_to_data_set_column"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if link_to_data_set_column is not None:
                self._values["link_to_data_set_column"] = link_to_data_set_column
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def link_to_data_set_column(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]]:
            '''The column identifier that fetches values from the data set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterselectablevalues.html#cfn-quicksight-template-parameterselectablevalues-linktodatasetcolumn
            '''
            result = self._values.get("link_to_data_set_column")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]], result)

        @builtins.property
        def values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The values that are used in ``ParameterSelectableValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterselectablevalues.html#cfn-quicksight-template-parameterselectablevalues-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterSelectableValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ParameterSliderControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "maximum_value": "maximumValue",
            "minimum_value": "minimumValue",
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "step_size": "stepSize",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterSliderControlProperty:
        def __init__(
            self,
            *,
            maximum_value: jsii.Number,
            minimum_value: jsii.Number,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            step_size: jsii.Number,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SliderControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :param maximum_value: The smaller value that is displayed at the left of the slider. Default: - 0
            :param minimum_value: The larger value that is displayed at the right of the slider. Default: - 0
            :param parameter_control_id: The ID of the ``ParameterSliderControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterSliderControl`` .
            :param step_size: The number of increments that the slider bar is divided into. Default: - 0
            :param title: The title of the ``ParameterSliderControl`` .
            :param display_options: The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_slider_control_property = quicksight.CfnTemplate.ParameterSliderControlProperty(
                    maximum_value=123,
                    minimum_value=123,
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    step_size=123,
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__debaa75b83a5c74194078475b0f788270d3c456ba5c124f6401ed3f4a96210fb)
                check_type(argname="argument maximum_value", value=maximum_value, expected_type=type_hints["maximum_value"])
                check_type(argname="argument minimum_value", value=minimum_value, expected_type=type_hints["minimum_value"])
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "maximum_value": maximum_value,
                "minimum_value": minimum_value,
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "step_size": step_size,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def maximum_value(self) -> jsii.Number:
            '''The smaller value that is displayed at the left of the slider.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-maximumvalue
            '''
            result = self._values.get("maximum_value")
            assert result is not None, "Required property 'maximum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def minimum_value(self) -> jsii.Number:
            '''The larger value that is displayed at the right of the slider.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-minimumvalue
            '''
            result = self._values.get("minimum_value")
            assert result is not None, "Required property 'minimum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterSliderControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterSliderControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def step_size(self) -> jsii.Number:
            '''The number of increments that the slider bar is divided into.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-stepsize
            '''
            result = self._values.get("step_size")
            assert result is not None, "Required property 'step_size' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterSliderControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SliderControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SliderControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterSliderControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ParameterTextAreaControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "delimiter": "delimiter",
            "display_options": "displayOptions",
        },
    )
    class ParameterTextAreaControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            delimiter: typing.Optional[builtins.str] = None,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TextAreaControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter multiple entries.

            :param parameter_control_id: The ID of the ``ParameterTextAreaControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterTextAreaControl`` .
            :param title: The title of the ``ParameterTextAreaControl`` .
            :param delimiter: The delimiter that is used to separate the lines in text.
            :param display_options: The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_text_area_control_property = quicksight.CfnTemplate.ParameterTextAreaControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    delimiter="delimiter",
                    display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8036ec596e30eaf8755087de485ebc547948d90258011a864e4cccac4ca82900)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument delimiter", value=delimiter, expected_type=type_hints["delimiter"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if delimiter is not None:
                self._values["delimiter"] = delimiter
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterTextAreaControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def delimiter(self) -> typing.Optional[builtins.str]:
            '''The delimiter that is used to separate the lines in text.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-delimiter
            '''
            result = self._values.get("delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TextAreaControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TextAreaControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterTextAreaControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ParameterTextFieldControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterTextFieldControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TextFieldControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter a single entry.

            :param parameter_control_id: The ID of the ``ParameterTextFieldControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterTextFieldControl`` .
            :param title: The title of the ``ParameterTextFieldControl`` .
            :param display_options: The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                parameter_text_field_control_property = quicksight.CfnTemplate.ParameterTextFieldControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                        info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                            info_icon_text="infoIconText",
                            visibility="visibility"
                        ),
                        placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2201056e2e7e9e630572eb58fe4a67aa8d3d9e11cfccc33365981d45c4aebb99)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterTextFieldControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html#cfn-quicksight-template-parametertextfieldcontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterTextFieldControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html#cfn-quicksight-template-parametertextfieldcontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterTextFieldControl`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html#cfn-quicksight-template-parametertextfieldcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TextFieldControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html#cfn-quicksight-template-parametertextfieldcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TextFieldControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterTextFieldControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PercentVisibleRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"from_": "from", "to": "to"},
    )
    class PercentVisibleRangeProperty:
        def __init__(
            self,
            *,
            from_: typing.Optional[jsii.Number] = None,
            to: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The percent range in the visible range.

            :param from_: The lower bound of the range.
            :param to: The top bound of the range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentvisiblerange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                percent_visible_range_property = quicksight.CfnTemplate.PercentVisibleRangeProperty(
                    from=123,
                    to=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__93375d06c22852c4caa7f5ef789ecbb1759add926a659101140431d71482e369)
                check_type(argname="argument from_", value=from_, expected_type=type_hints["from_"])
                check_type(argname="argument to", value=to, expected_type=type_hints["to"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if from_ is not None:
                self._values["from_"] = from_
            if to is not None:
                self._values["to"] = to

        @builtins.property
        def from_(self) -> typing.Optional[jsii.Number]:
            '''The lower bound of the range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentvisiblerange.html#cfn-quicksight-template-percentvisiblerange-from
            '''
            result = self._values.get("from_")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def to(self) -> typing.Optional[jsii.Number]:
            '''The top bound of the range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentvisiblerange.html#cfn-quicksight-template-percentvisiblerange-to
            '''
            result = self._values.get("to")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentVisibleRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
        },
    )
    class PercentageDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            negative_value_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            suffix: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the percentage display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param prefix: Determines the prefix value of the percentage format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the percentage format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                percentage_display_format_configuration_property = quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    prefix="prefix",
                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2e28c16030570b3912964aafd4b26f1fa75b4133594c8cb00202f799bf436f9a)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DecimalPlacesConfigurationProperty"]]:
            '''The option that determines the decimal places configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DecimalPlacesConfigurationProperty"]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NegativeValueConfigurationProperty"]]:
            '''The options that determine the negative value configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NegativeValueConfigurationProperty"]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the percentage format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericSeparatorConfigurationProperty"]]:
            '''The options that determine the numeric separator configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericSeparatorConfigurationProperty"]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the percentage format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentageDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PercentileAggregationProperty",
        jsii_struct_bases=[],
        name_mapping={"percentile_value": "percentileValue"},
    )
    class PercentileAggregationProperty:
        def __init__(
            self,
            *,
            percentile_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''An aggregation based on the percentile of values in a dimension or measure.

            :param percentile_value: The percentile value. This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentileaggregation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                percentile_aggregation_property = quicksight.CfnTemplate.PercentileAggregationProperty(
                    percentile_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c2dd05d8b08387ab86292cc30c74083647c706f46201ecc59a494fe1b2912614)
                check_type(argname="argument percentile_value", value=percentile_value, expected_type=type_hints["percentile_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percentile_value is not None:
                self._values["percentile_value"] = percentile_value

        @builtins.property
        def percentile_value(self) -> typing.Optional[jsii.Number]:
            '''The percentile value.

            This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentileaggregation.html#cfn-quicksight-template-percentileaggregation-percentilevalue
            '''
            result = self._values.get("percentile_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentileAggregationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PeriodOverPeriodComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "name": "name",
            "time": "time",
            "value": "value",
        },
    )
    class PeriodOverPeriodComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            name: typing.Optional[builtins.str] = None,
            time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The period over period computation configuration.

            :param computation_id: The ID for a computation.
            :param name: The name of a computation.
            :param time: The time field that is used in a computation.
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                period_over_period_computation_property = quicksight.CfnTemplate.PeriodOverPeriodComputationProperty(
                    computation_id="computationId",
                
                    # the properties below are optional
                    name="name",
                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__53f9997128020d044b3f06eabf7741d00417d19712b9ac21cdd48187ac4885ff)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
            }
            if name is not None:
                self._values["name"] = name
            if time is not None:
                self._values["time"] = time
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html#cfn-quicksight-template-periodoverperiodcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html#cfn-quicksight-template-periodoverperiodcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]:
            '''The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html#cfn-quicksight-template-periodoverperiodcomputation-time
            '''
            result = self._values.get("time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html#cfn-quicksight-template-periodoverperiodcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PeriodOverPeriodComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PeriodToDateComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "name": "name",
            "period_time_granularity": "periodTimeGranularity",
            "time": "time",
            "value": "value",
        },
    )
    class PeriodToDateComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            name: typing.Optional[builtins.str] = None,
            period_time_granularity: typing.Optional[builtins.str] = None,
            time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The period to date computation configuration.

            :param computation_id: The ID for a computation.
            :param name: The name of a computation.
            :param period_time_granularity: The time granularity setup of period to date computation. Choose from the following options:. - YEAR: Year to date. - MONTH: Month to date.
            :param time: The time field that is used in a computation.
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                period_to_date_computation_property = quicksight.CfnTemplate.PeriodToDateComputationProperty(
                    computation_id="computationId",
                
                    # the properties below are optional
                    name="name",
                    period_time_granularity="periodTimeGranularity",
                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__119c047085a74c43e8ed6ef2cd82bd8ba8f88b1a847c008c69588aa6a9bde55c)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument period_time_granularity", value=period_time_granularity, expected_type=type_hints["period_time_granularity"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
            }
            if name is not None:
                self._values["name"] = name
            if period_time_granularity is not None:
                self._values["period_time_granularity"] = period_time_granularity
            if time is not None:
                self._values["time"] = time
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def period_time_granularity(self) -> typing.Optional[builtins.str]:
            '''The time granularity setup of period to date computation. Choose from the following options:.

            - YEAR: Year to date.
            - MONTH: Month to date.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-periodtimegranularity
            '''
            result = self._values.get("period_time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]:
            '''The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-time
            '''
            result = self._values.get("time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PeriodToDateComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PieChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class PieChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a pie chart.

            :param category: The category (group/color) field wells of a pie chart.
            :param small_multiples: The small multiples field well of a pie chart.
            :param values: The value field wells of a pie chart. Values are aggregated based on categories.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__67a594736efda49ae352612e8753174881b3d3a7a5874efabf9803ef2c56350d)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The category (group/color) field wells of a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartaggregatedfieldwells.html#cfn-quicksight-template-piechartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The small multiples field well of a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartaggregatedfieldwells.html#cfn-quicksight-template-piechartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The value field wells of a pie chart.

            Values are aggregated based on categories.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartaggregatedfieldwells.html#cfn-quicksight-template-piechartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PieChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "donut_options": "donutOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class PieChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            donut_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DonutOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PieChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PieChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a pie chart.

            :param category_label_options: The label options of the group/color that is displayed in a pie chart.
            :param contribution_analysis_defaults: The contribution analysis (anomaly configuration) setup of the visual.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param donut_options: The options that determine the shape of the chart. This option determines whether the chart is a pie chart or a donut chart.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a pie chart.
            :param tooltip: The tooltip display setup of the visual.
            :param value_label_options: The label options for the value that is displayed in a pie chart.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__753ed9f6b9b7f0426a2e0c4bce80bc7e939f0a5d150e85d66f2207a29f7fa05b)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument donut_options", value=donut_options, expected_type=type_hints["donut_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if donut_options is not None:
                self._values["donut_options"] = donut_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the group/color that is displayed in a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ContributionAnalysisDefaultProperty"]]]]:
            '''The contribution analysis (anomaly configuration) setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ContributionAnalysisDefaultProperty"]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def donut_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DonutOptionsProperty"]]:
            '''The options that determine the shape of the chart.

            This option determines whether the chart is a pie chart or a donut chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-donutoptions
            '''
            result = self._values.get("donut_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DonutOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PieChartFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PieChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SmallMultiplesOptionsProperty"]]:
            '''The small multiples setup for the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SmallMultiplesOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PieChartSortConfigurationProperty"]]:
            '''The sort configuration of a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PieChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options for the value that is displayed in a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PieChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pie_chart_aggregated_field_wells": "pieChartAggregatedFieldWells",
        },
    )
    class PieChartFieldWellsProperty:
        def __init__(
            self,
            *,
            pie_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PieChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a pie chart.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param pie_chart_aggregated_field_wells: The field well configuration of a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b107ffd40a92c542d866a2f96f95d07c6f8410c207d831f748256eca4f30654a)
                check_type(argname="argument pie_chart_aggregated_field_wells", value=pie_chart_aggregated_field_wells, expected_type=type_hints["pie_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pie_chart_aggregated_field_wells is not None:
                self._values["pie_chart_aggregated_field_wells"] = pie_chart_aggregated_field_wells

        @builtins.property
        def pie_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PieChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartfieldwells.html#cfn-quicksight-template-piechartfieldwells-piechartaggregatedfieldwells
            '''
            result = self._values.get("pie_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PieChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PieChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class PieChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a pie chart.

            :param category_items_limit: The limit on the number of categories that are displayed in a pie chart.
            :param category_sort: The sort configuration of the category fields.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pie_chart_sort_configuration_property = quicksight.CfnTemplate.PieChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c169cd1f70c1bf335049afe1918d08491ff5dc90e37bd3a98c7f9c787cfcf96d)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories that are displayed in a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html#cfn-quicksight-template-piechartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html#cfn-quicksight-template-piechartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of small multiples panels that are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html#cfn-quicksight-template-piechartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the small multiples field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html#cfn-quicksight-template-piechartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PieChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class PieChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PieChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A pie or donut chart.

            The ``PieChartVisual`` structure describes a visual that is a member of the pie chart family.

            The following charts can be described by using this structure:

            - Pie charts
            - Donut charts

            For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .

            For more information, see `Using donut charts <https://docs.aws.amazon.com/quicksight/latest/user/donut-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a pie chart.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d6fcdea99db171d2a0f21d5b13ae314e1dc3d13454f406e8ede6c5d2e39e71b0)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PieChartConfigurationProperty"]]:
            '''The configuration of a pie chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PieChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotFieldSortOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "sort_by": "sortBy"},
    )
    class PivotFieldSortOptionsProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            sort_by: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTableSortByProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The field sort options for a pivot table sort configuration.

            :param field_id: The field ID for the field sort options.
            :param sort_by: The sort by field for the field sort options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivotfieldsortoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_field_sort_options_property = quicksight.CfnTemplate.PivotFieldSortOptionsProperty(
                    field_id="fieldId",
                    sort_by=quicksight.CfnTemplate.PivotTableSortByProperty(
                        column=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        data_path=quicksight.CfnTemplate.DataPathSortProperty(
                            direction="direction",
                            sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                                data_path_type=quicksight.CfnTemplate.DataPathTypeProperty(
                                    pivot_table_data_path_type="pivotTableDataPathType"
                                ),
                                field_id="fieldId",
                                field_value="fieldValue"
                            )]
                        ),
                        field=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aea4fab7f5fea27b9021ac76a6b8b14d11881784a0e1e07e1a4fcab04a8f7ebf)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument sort_by", value=sort_by, expected_type=type_hints["sort_by"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
                "sort_by": sort_by,
            }

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for the field sort options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivotfieldsortoptions.html#cfn-quicksight-template-pivotfieldsortoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_by(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableSortByProperty"]:
            '''The sort by field for the field sort options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivotfieldsortoptions.html#cfn-quicksight-template-pivotfieldsortoptions-sortby
            '''
            result = self._values.get("sort_by")
            assert result is not None, "Required property 'sort_by' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableSortByProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotFieldSortOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotTableAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns", "rows": "rows", "values": "values"},
    )
    class PivotTableAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            columns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            rows: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well for the pivot table.

            :param columns: The columns field well for a pivot table. Values are grouped by columns fields.
            :param rows: The rows field well for a pivot table. Values are grouped by rows fields.
            :param values: The values field well for a pivot table. Values are aggregated based on rows and columns fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1aaf9f615751c99146a946cbb53e523cb25228c3272f1a4ed4475f8aaee6dc48)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument rows", value=rows, expected_type=type_hints["rows"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if columns is not None:
                self._values["columns"] = columns
            if rows is not None:
                self._values["rows"] = rows
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def columns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The columns field well for a pivot table.

            Values are grouped by columns fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableaggregatedfieldwells.html#cfn-quicksight-template-pivottableaggregatedfieldwells-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def rows(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The rows field well for a pivot table.

            Values are grouped by rows fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableaggregatedfieldwells.html#cfn-quicksight-template-pivottableaggregatedfieldwells-rows
            '''
            result = self._values.get("rows")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The values field well for a pivot table.

            Values are aggregated based on rows and columns fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableaggregatedfieldwells.html#cfn-quicksight-template-pivottableaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "scope": "scope",
            "scopes": "scopes",
            "text_format": "textFormat",
        },
    )
    class PivotTableCellConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            scope: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTableConditionalFormattingScopeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scopes: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTableConditionalFormattingScopeProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            text_format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TextConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cell conditional formatting option for a pivot table.

            :param field_id: The field ID of the cell for conditional formatting.
            :param scope: The scope of the cell for conditional formatting.
            :param scopes: A list of cell scopes for conditional formatting.
            :param text_format: The text format of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_cell_conditional_formatting_property = quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    scope=quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                        role="role"
                    ),
                    scopes=[quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                        role="role"
                    )],
                    text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2c0a9dabb25bb51951b8353fa11224adb471304577a761fd86824f26214787ca)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
                check_type(argname="argument scopes", value=scopes, expected_type=type_hints["scopes"])
                check_type(argname="argument text_format", value=text_format, expected_type=type_hints["text_format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if scope is not None:
                self._values["scope"] = scope
            if scopes is not None:
                self._values["scopes"] = scopes
            if text_format is not None:
                self._values["text_format"] = text_format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html#cfn-quicksight-template-pivottablecellconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def scope(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableConditionalFormattingScopeProperty"]]:
            '''The scope of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html#cfn-quicksight-template-pivottablecellconditionalformatting-scope
            '''
            result = self._values.get("scope")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableConditionalFormattingScopeProperty"]], result)

        @builtins.property
        def scopes(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableConditionalFormattingScopeProperty"]]]]:
            '''A list of cell scopes for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html#cfn-quicksight-template-pivottablecellconditionalformatting-scopes
            '''
            result = self._values.get("scopes")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableConditionalFormattingScopeProperty"]]]], result)

        @builtins.property
        def text_format(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TextConditionalFormatProperty"]]:
            '''The text format of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html#cfn-quicksight-template-pivottablecellconditionalformatting-textformat
            '''
            result = self._values.get("text_format")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TextConditionalFormatProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableCellConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotTableConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"cell": "cell"},
    )
    class PivotTableConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            cell: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTableCellConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :param cell: The cell conditional formatting option for a pivot table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_option_property = quicksight.CfnTemplate.PivotTableConditionalFormattingOptionProperty(
                    cell=quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        scope=quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                            role="role"
                        ),
                        scopes=[quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                            role="role"
                        )],
                        text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__60d1ad0a17f98540768122e7a693c51331b270b1c39d4d09e6536b86709a8664)
                check_type(argname="argument cell", value=cell, expected_type=type_hints["cell"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell is not None:
                self._values["cell"] = cell

        @builtins.property
        def cell(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableCellConditionalFormattingProperty"]]:
            '''The cell conditional formatting option for a pivot table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformattingoption.html#cfn-quicksight-template-pivottableconditionalformattingoption-cell
            '''
            result = self._values.get("cell")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableCellConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotTableConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class PivotTableConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTableConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :param conditional_formatting_options: Conditional formatting options for a ``PivotTableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_property = quicksight.CfnTemplate.PivotTableConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnTemplate.PivotTableConditionalFormattingOptionProperty(
                        cell=quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            scope=quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                                role="role"
                            ),
                            scopes=[quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                                role="role"
                            )],
                            text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__66a2cd3955a034899ff5325feab9f88dfc7e9e0dcde2daf65a61963ce934303e)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableConditionalFormattingOptionProperty"]]]]:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformatting.html#cfn-quicksight-template-pivottableconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty",
        jsii_struct_bases=[],
        name_mapping={"role": "role"},
    )
    class PivotTableConditionalFormattingScopeProperty:
        def __init__(self, *, role: typing.Optional[builtins.str] = None) -> None:
            '''The scope of the cell for conditional formatting.

            :param role: The role (field, field total, grand total) of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformattingscope.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_scope_property = quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                    role="role"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__172ad52c74b1ac21a38b984944da4f33e60ed5fdd833f09346cfd57646078383)
                check_type(argname="argument role", value=role, expected_type=type_hints["role"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if role is not None:
                self._values["role"] = role

        @builtins.property
        def role(self) -> typing.Optional[builtins.str]:
            '''The role (field, field total, grand total) of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformattingscope.html#cfn-quicksight-template-pivottableconditionalformattingscope-role
            '''
            result = self._values.get("role")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingScopeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotTableConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_options": "fieldOptions",
            "field_wells": "fieldWells",
            "paginated_report_options": "paginatedReportOptions",
            "sort_configuration": "sortConfiguration",
            "table_options": "tableOptions",
            "total_options": "totalOptions",
        },
    )
    class PivotTableConfigurationProperty:
        def __init__(
            self,
            *,
            field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTableFieldOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTableFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paginated_report_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTablePaginatedReportOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTableSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTableOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTableTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``PivotTableVisual`` .

            :param field_options: The field options for a pivot table visual.
            :param field_wells: The field wells of the visual.
            :param paginated_report_options: The paginated report options for a pivot table visual.
            :param sort_configuration: The sort configuration for a ``PivotTableVisual`` .
            :param table_options: The table options for a pivot table visual.
            :param total_options: The total options for a pivot table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__721a1a2646b528a0f39a6d54c430519c81b71e531c079d47fa37528046e0990c)
                check_type(argname="argument field_options", value=field_options, expected_type=type_hints["field_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument paginated_report_options", value=paginated_report_options, expected_type=type_hints["paginated_report_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument table_options", value=table_options, expected_type=type_hints["table_options"])
                check_type(argname="argument total_options", value=total_options, expected_type=type_hints["total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_options is not None:
                self._values["field_options"] = field_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if paginated_report_options is not None:
                self._values["paginated_report_options"] = paginated_report_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if table_options is not None:
                self._values["table_options"] = table_options
            if total_options is not None:
                self._values["total_options"] = total_options

        @builtins.property
        def field_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableFieldOptionsProperty"]]:
            '''The field options for a pivot table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-fieldoptions
            '''
            result = self._values.get("field_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableFieldOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableFieldWellsProperty"]], result)

        @builtins.property
        def paginated_report_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTablePaginatedReportOptionsProperty"]]:
            '''The paginated report options for a pivot table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-paginatedreportoptions
            '''
            result = self._values.get("paginated_report_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTablePaginatedReportOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableSortConfigurationProperty"]]:
            '''The sort configuration for a ``PivotTableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableSortConfigurationProperty"]], result)

        @builtins.property
        def table_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableOptionsProperty"]]:
            '''The table options for a pivot table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-tableoptions
            '''
            result = self._values.get("table_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableOptionsProperty"]], result)

        @builtins.property
        def total_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableTotalOptionsProperty"]]:
            '''The total options for a pivot table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-totaloptions
            '''
            result = self._values.get("total_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableTotalOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotTableDataPathOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"data_path_list": "dataPathList", "width": "width"},
    )
    class PivotTableDataPathOptionProperty:
        def __init__(
            self,
            *,
            data_path_list: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]]]]],
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The data path options for the pivot table field options.

            :param data_path_list: The list of data path values for the data path options.
            :param width: The width of the data path option.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabledatapathoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_data_path_option_property = quicksight.CfnTemplate.PivotTableDataPathOptionProperty(
                    data_path_list=[quicksight.CfnTemplate.DataPathValueProperty(
                        data_path_type=quicksight.CfnTemplate.DataPathTypeProperty(
                            pivot_table_data_path_type="pivotTableDataPathType"
                        ),
                        field_id="fieldId",
                        field_value="fieldValue"
                    )],
                
                    # the properties below are optional
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__65d2f7cee829af963ae66906b27517f97dbcdc4089a2c84a398496d15146e0bf)
                check_type(argname="argument data_path_list", value=data_path_list, expected_type=type_hints["data_path_list"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_path_list": data_path_list,
            }
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def data_path_list(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataPathValueProperty"]]]:
            '''The list of data path values for the data path options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabledatapathoption.html#cfn-quicksight-template-pivottabledatapathoption-datapathlist
            '''
            result = self._values.get("data_path_list")
            assert result is not None, "Required property 'data_path_list' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataPathValueProperty"]]], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width of the data path option.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabledatapathoption.html#cfn-quicksight-template-pivottabledatapathoption-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableDataPathOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotTableFieldCollapseStateOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"target": "target", "state": "state"},
    )
    class PivotTableFieldCollapseStateOptionProperty:
        def __init__(
            self,
            *,
            target: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTableFieldCollapseStateTargetProperty", typing.Dict[builtins.str, typing.Any]]],
            state: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The collapse state options for the pivot table field options.

            :param target: A tagged-union object that sets the collapse state.
            :param state: The state of the field target of a pivot table. Choose one of the following options:. - ``COLLAPSED`` - ``EXPANDED``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldcollapsestateoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_field_collapse_state_option_property = quicksight.CfnTemplate.PivotTableFieldCollapseStateOptionProperty(
                    target=quicksight.CfnTemplate.PivotTableFieldCollapseStateTargetProperty(
                        field_data_path_values=[quicksight.CfnTemplate.DataPathValueProperty(
                            data_path_type=quicksight.CfnTemplate.DataPathTypeProperty(
                                pivot_table_data_path_type="pivotTableDataPathType"
                            ),
                            field_id="fieldId",
                            field_value="fieldValue"
                        )],
                        field_id="fieldId"
                    ),
                
                    # the properties below are optional
                    state="state"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8c664424ee2ee8340d6471477dd4b4151305f25205b910c022c3ac7a2f783e35)
                check_type(argname="argument target", value=target, expected_type=type_hints["target"])
                check_type(argname="argument state", value=state, expected_type=type_hints["state"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "target": target,
            }
            if state is not None:
                self._values["state"] = state

        @builtins.property
        def target(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableFieldCollapseStateTargetProperty"]:
            '''A tagged-union object that sets the collapse state.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldcollapsestateoption.html#cfn-quicksight-template-pivottablefieldcollapsestateoption-target
            '''
            result = self._values.get("target")
            assert result is not None, "Required property 'target' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableFieldCollapseStateTargetProperty"], result)

        @builtins.property
        def state(self) -> typing.Optional[builtins.str]:
            '''The state of the field target of a pivot table. Choose one of the following options:.

            - ``COLLAPSED``
            - ``EXPANDED``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldcollapsestateoption.html#cfn-quicksight-template-pivottablefieldcollapsestateoption-state
            '''
            result = self._values.get("state")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldCollapseStateOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotTableFieldCollapseStateTargetProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_data_path_values": "fieldDataPathValues",
            "field_id": "fieldId",
        },
    )
    class PivotTableFieldCollapseStateTargetProperty:
        def __init__(
            self,
            *,
            field_data_path_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            field_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The target of a pivot table field collapse state.

            :param field_data_path_values: The data path of the pivot table's header. Used to set the collapse state.
            :param field_id: The field ID of the pivot table that the collapse state needs to be set to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldcollapsestatetarget.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_field_collapse_state_target_property = quicksight.CfnTemplate.PivotTableFieldCollapseStateTargetProperty(
                    field_data_path_values=[quicksight.CfnTemplate.DataPathValueProperty(
                        data_path_type=quicksight.CfnTemplate.DataPathTypeProperty(
                            pivot_table_data_path_type="pivotTableDataPathType"
                        ),
                        field_id="fieldId",
                        field_value="fieldValue"
                    )],
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7834d29ffa6ca6dbc548e8ed48b94f44a1d193103bdce641f1b7f2ba8893ac37)
                check_type(argname="argument field_data_path_values", value=field_data_path_values, expected_type=type_hints["field_data_path_values"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_data_path_values is not None:
                self._values["field_data_path_values"] = field_data_path_values
            if field_id is not None:
                self._values["field_id"] = field_id

        @builtins.property
        def field_data_path_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataPathValueProperty"]]]]:
            '''The data path of the pivot table's header.

            Used to set the collapse state.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldcollapsestatetarget.html#cfn-quicksight-template-pivottablefieldcollapsestatetarget-fielddatapathvalues
            '''
            result = self._values.get("field_data_path_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataPathValueProperty"]]]], result)

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the pivot table that the collapse state needs to be set to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldcollapsestatetarget.html#cfn-quicksight-template-pivottablefieldcollapsestatetarget-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldCollapseStateTargetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotTableFieldOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "custom_label": "customLabel",
            "visibility": "visibility",
        },
    )
    class PivotTableFieldOptionProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            custom_label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The selected field options for the pivot table field options.

            :param field_id: The field ID of the pivot table field.
            :param custom_label: The custom label of the pivot table field.
            :param visibility: The visibility of the pivot table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_field_option_property = quicksight.CfnTemplate.PivotTableFieldOptionProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    custom_label="customLabel",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8eebf08bbbc71497293b914df7065a880198d46c5fa9fc98fb69d7df131f9767)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the pivot table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoption.html#cfn-quicksight-template-pivottablefieldoption-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label of the pivot table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoption.html#cfn-quicksight-template-pivottablefieldoption-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the pivot table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoption.html#cfn-quicksight-template-pivottablefieldoption-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotTableFieldOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "collapse_state_options": "collapseStateOptions",
            "data_path_options": "dataPathOptions",
            "selected_field_options": "selectedFieldOptions",
        },
    )
    class PivotTableFieldOptionsProperty:
        def __init__(
            self,
            *,
            collapse_state_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTableFieldCollapseStateOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_path_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTableDataPathOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            selected_field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTableFieldOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field options for a pivot table visual.

            :param collapse_state_options: The collapse state options for the pivot table field options.
            :param data_path_options: The data path options for the pivot table field options.
            :param selected_field_options: The selected field options for the pivot table field options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_field_options_property = quicksight.CfnTemplate.PivotTableFieldOptionsProperty(
                    collapse_state_options=[quicksight.CfnTemplate.PivotTableFieldCollapseStateOptionProperty(
                        target=quicksight.CfnTemplate.PivotTableFieldCollapseStateTargetProperty(
                            field_data_path_values=[quicksight.CfnTemplate.DataPathValueProperty(
                                data_path_type=quicksight.CfnTemplate.DataPathTypeProperty(
                                    pivot_table_data_path_type="pivotTableDataPathType"
                                ),
                                field_id="fieldId",
                                field_value="fieldValue"
                            )],
                            field_id="fieldId"
                        ),
                
                        # the properties below are optional
                        state="state"
                    )],
                    data_path_options=[quicksight.CfnTemplate.PivotTableDataPathOptionProperty(
                        data_path_list=[quicksight.CfnTemplate.DataPathValueProperty(
                            data_path_type=quicksight.CfnTemplate.DataPathTypeProperty(
                                pivot_table_data_path_type="pivotTableDataPathType"
                            ),
                            field_id="fieldId",
                            field_value="fieldValue"
                        )],
                
                        # the properties below are optional
                        width="width"
                    )],
                    selected_field_options=[quicksight.CfnTemplate.PivotTableFieldOptionProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        custom_label="customLabel",
                        visibility="visibility"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f2f73bf13a652217ea66bad7282ca340406c63df7e24fb9957788dd86087b499)
                check_type(argname="argument collapse_state_options", value=collapse_state_options, expected_type=type_hints["collapse_state_options"])
                check_type(argname="argument data_path_options", value=data_path_options, expected_type=type_hints["data_path_options"])
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if collapse_state_options is not None:
                self._values["collapse_state_options"] = collapse_state_options
            if data_path_options is not None:
                self._values["data_path_options"] = data_path_options
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options

        @builtins.property
        def collapse_state_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableFieldCollapseStateOptionProperty"]]]]:
            '''The collapse state options for the pivot table field options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoptions.html#cfn-quicksight-template-pivottablefieldoptions-collapsestateoptions
            '''
            result = self._values.get("collapse_state_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableFieldCollapseStateOptionProperty"]]]], result)

        @builtins.property
        def data_path_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableDataPathOptionProperty"]]]]:
            '''The data path options for the pivot table field options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoptions.html#cfn-quicksight-template-pivottablefieldoptions-datapathoptions
            '''
            result = self._values.get("data_path_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableDataPathOptionProperty"]]]], result)

        @builtins.property
        def selected_field_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableFieldOptionProperty"]]]]:
            '''The selected field options for the pivot table field options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoptions.html#cfn-quicksight-template-pivottablefieldoptions-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableFieldOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId"},
    )
    class PivotTableFieldSubtotalOptionsProperty:
        def __init__(self, *, field_id: typing.Optional[builtins.str] = None) -> None:
            '''The optional configuration of subtotals cells.

            :param field_id: The field ID of the subtotal options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldsubtotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_field_subtotal_options_property = quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__78f5f1418344785a12a2059eed9d6f7a257807d04da28d814d2f38d8f862850d)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the subtotal options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldsubtotaloptions.html#cfn-quicksight-template-pivottablefieldsubtotaloptions-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldSubtotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotTableFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pivot_table_aggregated_field_wells": "pivotTableAggregatedFieldWells",
        },
    )
    class PivotTableFieldWellsProperty:
        def __init__(
            self,
            *,
            pivot_table_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTableAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells for a pivot table visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param pivot_table_aggregated_field_wells: The aggregated field well for the pivot table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d559863b89a60184d3b7448898dfa331551dda6628e33e60f7c35feb479a01d1)
                check_type(argname="argument pivot_table_aggregated_field_wells", value=pivot_table_aggregated_field_wells, expected_type=type_hints["pivot_table_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pivot_table_aggregated_field_wells is not None:
                self._values["pivot_table_aggregated_field_wells"] = pivot_table_aggregated_field_wells

        @builtins.property
        def pivot_table_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableAggregatedFieldWellsProperty"]]:
            '''The aggregated field well for the pivot table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldwells.html#cfn-quicksight-template-pivottablefieldwells-pivottableaggregatedfieldwells
            '''
            result = self._values.get("pivot_table_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotTableOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cell_style": "cellStyle",
            "collapsed_row_dimensions_visibility": "collapsedRowDimensionsVisibility",
            "column_header_style": "columnHeaderStyle",
            "column_names_visibility": "columnNamesVisibility",
            "default_cell_width": "defaultCellWidth",
            "metric_placement": "metricPlacement",
            "row_alternate_color_options": "rowAlternateColorOptions",
            "row_field_names_style": "rowFieldNamesStyle",
            "row_header_style": "rowHeaderStyle",
            "rows_label_options": "rowsLabelOptions",
            "rows_layout": "rowsLayout",
            "single_metric_visibility": "singleMetricVisibility",
            "toggle_buttons_visibility": "toggleButtonsVisibility",
        },
    )
    class PivotTableOptionsProperty:
        def __init__(
            self,
            *,
            cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            collapsed_row_dimensions_visibility: typing.Optional[builtins.str] = None,
            column_header_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_names_visibility: typing.Optional[builtins.str] = None,
            default_cell_width: typing.Optional[builtins.str] = None,
            metric_placement: typing.Optional[builtins.str] = None,
            row_alternate_color_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.RowAlternateColorOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_field_names_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_header_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rows_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTableRowsLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rows_layout: typing.Optional[builtins.str] = None,
            single_metric_visibility: typing.Optional[builtins.str] = None,
            toggle_buttons_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The table options for a pivot table visual.

            :param cell_style: The table cell style of cells.
            :param collapsed_row_dimensions_visibility: The visibility setting of a pivot table's collapsed row dimension fields. If the value of this structure is ``HIDDEN`` , all collapsed columns in a pivot table are automatically hidden. The default value is ``VISIBLE`` .
            :param column_header_style: The table cell style of the column header.
            :param column_names_visibility: The visibility of the column names.
            :param default_cell_width: The default cell width of the pivot table.
            :param metric_placement: The metric placement (row, column) options.
            :param row_alternate_color_options: The row alternate color options (widget status, row alternate colors).
            :param row_field_names_style: The table cell style of row field names.
            :param row_header_style: The table cell style of the row headers.
            :param rows_label_options: The options for the label that is located above the row headers. This option is only applicable when ``RowsLayout`` is set to ``HIERARCHY`` .
            :param rows_layout: The layout for the row dimension headers of a pivot table. Choose one of the following options. - ``TABULAR`` : (Default) Each row field is displayed in a separate column. - ``HIERARCHY`` : All row fields are displayed in a single column. Indentation is used to differentiate row headers of different fields.
            :param single_metric_visibility: The visibility of the single metric options.
            :param toggle_buttons_visibility: Determines the visibility of the pivot table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_options_property = quicksight.CfnTemplate.PivotTableOptionsProperty(
                    cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    collapsed_row_dimensions_visibility="collapsedRowDimensionsVisibility",
                    column_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    column_names_visibility="columnNamesVisibility",
                    default_cell_width="defaultCellWidth",
                    metric_placement="metricPlacement",
                    row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                        row_alternate_colors=["rowAlternateColors"],
                        status="status",
                        use_primary_background_color="usePrimaryBackgroundColor"
                    ),
                    row_field_names_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    row_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    rows_label_options=quicksight.CfnTemplate.PivotTableRowsLabelOptionsProperty(
                        custom_label="customLabel",
                        visibility="visibility"
                    ),
                    rows_layout="rowsLayout",
                    single_metric_visibility="singleMetricVisibility",
                    toggle_buttons_visibility="toggleButtonsVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c7b18650c965a207638aa8c482bb96d77b098414dd1fed613958eb169969c580)
                check_type(argname="argument cell_style", value=cell_style, expected_type=type_hints["cell_style"])
                check_type(argname="argument collapsed_row_dimensions_visibility", value=collapsed_row_dimensions_visibility, expected_type=type_hints["collapsed_row_dimensions_visibility"])
                check_type(argname="argument column_header_style", value=column_header_style, expected_type=type_hints["column_header_style"])
                check_type(argname="argument column_names_visibility", value=column_names_visibility, expected_type=type_hints["column_names_visibility"])
                check_type(argname="argument default_cell_width", value=default_cell_width, expected_type=type_hints["default_cell_width"])
                check_type(argname="argument metric_placement", value=metric_placement, expected_type=type_hints["metric_placement"])
                check_type(argname="argument row_alternate_color_options", value=row_alternate_color_options, expected_type=type_hints["row_alternate_color_options"])
                check_type(argname="argument row_field_names_style", value=row_field_names_style, expected_type=type_hints["row_field_names_style"])
                check_type(argname="argument row_header_style", value=row_header_style, expected_type=type_hints["row_header_style"])
                check_type(argname="argument rows_label_options", value=rows_label_options, expected_type=type_hints["rows_label_options"])
                check_type(argname="argument rows_layout", value=rows_layout, expected_type=type_hints["rows_layout"])
                check_type(argname="argument single_metric_visibility", value=single_metric_visibility, expected_type=type_hints["single_metric_visibility"])
                check_type(argname="argument toggle_buttons_visibility", value=toggle_buttons_visibility, expected_type=type_hints["toggle_buttons_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell_style is not None:
                self._values["cell_style"] = cell_style
            if collapsed_row_dimensions_visibility is not None:
                self._values["collapsed_row_dimensions_visibility"] = collapsed_row_dimensions_visibility
            if column_header_style is not None:
                self._values["column_header_style"] = column_header_style
            if column_names_visibility is not None:
                self._values["column_names_visibility"] = column_names_visibility
            if default_cell_width is not None:
                self._values["default_cell_width"] = default_cell_width
            if metric_placement is not None:
                self._values["metric_placement"] = metric_placement
            if row_alternate_color_options is not None:
                self._values["row_alternate_color_options"] = row_alternate_color_options
            if row_field_names_style is not None:
                self._values["row_field_names_style"] = row_field_names_style
            if row_header_style is not None:
                self._values["row_header_style"] = row_header_style
            if rows_label_options is not None:
                self._values["rows_label_options"] = rows_label_options
            if rows_layout is not None:
                self._values["rows_layout"] = rows_layout
            if single_metric_visibility is not None:
                self._values["single_metric_visibility"] = single_metric_visibility
            if toggle_buttons_visibility is not None:
                self._values["toggle_buttons_visibility"] = toggle_buttons_visibility

        @builtins.property
        def cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]]:
            '''The table cell style of cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-cellstyle
            '''
            result = self._values.get("cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def collapsed_row_dimensions_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility setting of a pivot table's collapsed row dimension fields.

            If the value of this structure is ``HIDDEN`` , all collapsed columns in a pivot table are automatically hidden. The default value is ``VISIBLE`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-collapsedrowdimensionsvisibility
            '''
            result = self._values.get("collapsed_row_dimensions_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def column_header_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]]:
            '''The table cell style of the column header.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-columnheaderstyle
            '''
            result = self._values.get("column_header_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def column_names_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the column names.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-columnnamesvisibility
            '''
            result = self._values.get("column_names_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def default_cell_width(self) -> typing.Optional[builtins.str]:
            '''The default cell width of the pivot table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-defaultcellwidth
            '''
            result = self._values.get("default_cell_width")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def metric_placement(self) -> typing.Optional[builtins.str]:
            '''The metric placement (row, column) options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-metricplacement
            '''
            result = self._values.get("metric_placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def row_alternate_color_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RowAlternateColorOptionsProperty"]]:
            '''The row alternate color options (widget status, row alternate colors).

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-rowalternatecoloroptions
            '''
            result = self._values.get("row_alternate_color_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RowAlternateColorOptionsProperty"]], result)

        @builtins.property
        def row_field_names_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]]:
            '''The table cell style of row field names.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-rowfieldnamesstyle
            '''
            result = self._values.get("row_field_names_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def row_header_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]]:
            '''The table cell style of the row headers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-rowheaderstyle
            '''
            result = self._values.get("row_header_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def rows_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableRowsLabelOptionsProperty"]]:
            '''The options for the label that is located above the row headers.

            This option is only applicable when ``RowsLayout`` is set to ``HIERARCHY`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-rowslabeloptions
            '''
            result = self._values.get("rows_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableRowsLabelOptionsProperty"]], result)

        @builtins.property
        def rows_layout(self) -> typing.Optional[builtins.str]:
            '''The layout for the row dimension headers of a pivot table. Choose one of the following options.

            - ``TABULAR`` : (Default) Each row field is displayed in a separate column.
            - ``HIERARCHY`` : All row fields are displayed in a single column. Indentation is used to differentiate row headers of different fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-rowslayout
            '''
            result = self._values.get("rows_layout")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def single_metric_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the single metric options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-singlemetricvisibility
            '''
            result = self._values.get("single_metric_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def toggle_buttons_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the pivot table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-togglebuttonsvisibility
            '''
            result = self._values.get("toggle_buttons_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotTablePaginatedReportOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "overflow_column_header_visibility": "overflowColumnHeaderVisibility",
            "vertical_overflow_visibility": "verticalOverflowVisibility",
        },
    )
    class PivotTablePaginatedReportOptionsProperty:
        def __init__(
            self,
            *,
            overflow_column_header_visibility: typing.Optional[builtins.str] = None,
            vertical_overflow_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The paginated report options for a pivot table visual.

            :param overflow_column_header_visibility: The visibility of the repeating header rows on each page.
            :param vertical_overflow_visibility: The visibility of the printing table overflow across pages.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablepaginatedreportoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_paginated_report_options_property = quicksight.CfnTemplate.PivotTablePaginatedReportOptionsProperty(
                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                    vertical_overflow_visibility="verticalOverflowVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f0b3d9b74952ab7869387bd736f5945e3b0867cd27d99ef24ffb44c366ab4d47)
                check_type(argname="argument overflow_column_header_visibility", value=overflow_column_header_visibility, expected_type=type_hints["overflow_column_header_visibility"])
                check_type(argname="argument vertical_overflow_visibility", value=vertical_overflow_visibility, expected_type=type_hints["vertical_overflow_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if overflow_column_header_visibility is not None:
                self._values["overflow_column_header_visibility"] = overflow_column_header_visibility
            if vertical_overflow_visibility is not None:
                self._values["vertical_overflow_visibility"] = vertical_overflow_visibility

        @builtins.property
        def overflow_column_header_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the repeating header rows on each page.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablepaginatedreportoptions.html#cfn-quicksight-template-pivottablepaginatedreportoptions-overflowcolumnheadervisibility
            '''
            result = self._values.get("overflow_column_header_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_overflow_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the printing table overflow across pages.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablepaginatedreportoptions.html#cfn-quicksight-template-pivottablepaginatedreportoptions-verticaloverflowvisibility
            '''
            result = self._values.get("vertical_overflow_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTablePaginatedReportOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotTableRowsLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_label": "customLabel", "visibility": "visibility"},
    )
    class PivotTableRowsLabelOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for the label thta is located above the row headers.

            This option is only applicable when ``RowsLayout`` is set to ``HIERARCHY`` .

            :param custom_label: The custom label string for the rows label.
            :param visibility: The visibility of the rows label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablerowslabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_rows_label_options_property = quicksight.CfnTemplate.PivotTableRowsLabelOptionsProperty(
                    custom_label="customLabel",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__708c2ee8fa6ad42c9119986aa20e9f62968254e5f0c9bb479d9fbbcff8fa1413)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the rows label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablerowslabeloptions.html#cfn-quicksight-template-pivottablerowslabeloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the rows label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablerowslabeloptions.html#cfn-quicksight-template-pivottablerowslabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableRowsLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotTableSortByProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "data_path": "dataPath", "field": "field"},
    )
    class PivotTableSortByProperty:
        def __init__(
            self,
            *,
            column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_path: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataPathSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The sort by field for the field sort options.

            :param column: The column sort (field id, direction) for the pivot table sort by options.
            :param data_path: The data path sort (data path value, direction) for the pivot table sort by options.
            :param field: The field sort (field id, direction) for the pivot table sort by options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortby.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_sort_by_property = quicksight.CfnTemplate.PivotTableSortByProperty(
                    column=quicksight.CfnTemplate.ColumnSortProperty(
                        direction="direction",
                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                            attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                simple_attribute_aggregation="simpleAttributeAggregation",
                                value_for_multiple_values="valueForMultipleValues"
                            ),
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    data_path=quicksight.CfnTemplate.DataPathSortProperty(
                        direction="direction",
                        sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                            data_path_type=quicksight.CfnTemplate.DataPathTypeProperty(
                                pivot_table_data_path_type="pivotTableDataPathType"
                            ),
                            field_id="fieldId",
                            field_value="fieldValue"
                        )]
                    ),
                    field=quicksight.CfnTemplate.FieldSortProperty(
                        direction="direction",
                        field_id="fieldId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9b16f94d643e218a8c2ab38374ef5850297aadb59ef53cc0bcefb632c0ca8b82)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument data_path", value=data_path, expected_type=type_hints["data_path"])
                check_type(argname="argument field", value=field, expected_type=type_hints["field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column is not None:
                self._values["column"] = column
            if data_path is not None:
                self._values["data_path"] = data_path
            if field is not None:
                self._values["field"] = field

        @builtins.property
        def column(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnSortProperty"]]:
            '''The column sort (field id, direction) for the pivot table sort by options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortby.html#cfn-quicksight-template-pivottablesortby-column
            '''
            result = self._values.get("column")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnSortProperty"]], result)

        @builtins.property
        def data_path(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataPathSortProperty"]]:
            '''The data path sort (data path value, direction) for the pivot table sort by options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortby.html#cfn-quicksight-template-pivottablesortby-datapath
            '''
            result = self._values.get("data_path")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataPathSortProperty"]], result)

        @builtins.property
        def field(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortProperty"]]:
            '''The field sort (field id, direction) for the pivot table sort by options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortby.html#cfn-quicksight-template-pivottablesortby-field
            '''
            result = self._values.get("field")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableSortByProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotTableSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"field_sort_options": "fieldSortOptions"},
    )
    class PivotTableSortConfigurationProperty:
        def __init__(
            self,
            *,
            field_sort_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotFieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration for a ``PivotTableVisual`` .

            :param field_sort_options: The field sort options for a pivot table sort configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_table_sort_configuration_property = quicksight.CfnTemplate.PivotTableSortConfigurationProperty(
                    field_sort_options=[quicksight.CfnTemplate.PivotFieldSortOptionsProperty(
                        field_id="fieldId",
                        sort_by=quicksight.CfnTemplate.PivotTableSortByProperty(
                            column=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                        simple_attribute_aggregation="simpleAttributeAggregation",
                                        value_for_multiple_values="valueForMultipleValues"
                                    ),
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            data_path=quicksight.CfnTemplate.DataPathSortProperty(
                                direction="direction",
                                sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                                    data_path_type=quicksight.CfnTemplate.DataPathTypeProperty(
                                        pivot_table_data_path_type="pivotTableDataPathType"
                                    ),
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                )]
                            ),
                            field=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ef85321f15888e8c0f3a5fa0bcc8a12f931c4d5066414db4e5fde06478d3e67e)
                check_type(argname="argument field_sort_options", value=field_sort_options, expected_type=type_hints["field_sort_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_sort_options is not None:
                self._values["field_sort_options"] = field_sort_options

        @builtins.property
        def field_sort_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotFieldSortOptionsProperty"]]]]:
            '''The field sort options for a pivot table sort configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortconfiguration.html#cfn-quicksight-template-pivottablesortconfiguration-fieldsortoptions
            '''
            result = self._values.get("field_sort_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotFieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotTableTotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_subtotal_options": "columnSubtotalOptions",
            "column_total_options": "columnTotalOptions",
            "row_subtotal_options": "rowSubtotalOptions",
            "row_total_options": "rowTotalOptions",
        },
    )
    class PivotTableTotalOptionsProperty:
        def __init__(
            self,
            *,
            column_subtotal_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_subtotal_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The total options for a pivot table visual.

            :param column_subtotal_options: The column subtotal options.
            :param column_total_options: The column total options.
            :param row_subtotal_options: The row subtotal options.
            :param row_total_options: The row total options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__be59d283da376e9d42d7ecb599df249f829dffe04e932db375724da27ee38386)
                check_type(argname="argument column_subtotal_options", value=column_subtotal_options, expected_type=type_hints["column_subtotal_options"])
                check_type(argname="argument column_total_options", value=column_total_options, expected_type=type_hints["column_total_options"])
                check_type(argname="argument row_subtotal_options", value=row_subtotal_options, expected_type=type_hints["row_subtotal_options"])
                check_type(argname="argument row_total_options", value=row_total_options, expected_type=type_hints["row_total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_subtotal_options is not None:
                self._values["column_subtotal_options"] = column_subtotal_options
            if column_total_options is not None:
                self._values["column_total_options"] = column_total_options
            if row_subtotal_options is not None:
                self._values["row_subtotal_options"] = row_subtotal_options
            if row_total_options is not None:
                self._values["row_total_options"] = row_total_options

        @builtins.property
        def column_subtotal_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SubtotalOptionsProperty"]]:
            '''The column subtotal options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html#cfn-quicksight-template-pivottabletotaloptions-columnsubtotaloptions
            '''
            result = self._values.get("column_subtotal_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SubtotalOptionsProperty"]], result)

        @builtins.property
        def column_total_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTotalOptionsProperty"]]:
            '''The column total options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html#cfn-quicksight-template-pivottabletotaloptions-columntotaloptions
            '''
            result = self._values.get("column_total_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTotalOptionsProperty"]], result)

        @builtins.property
        def row_subtotal_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SubtotalOptionsProperty"]]:
            '''The row subtotal options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html#cfn-quicksight-template-pivottabletotaloptions-rowsubtotaloptions
            '''
            result = self._values.get("row_subtotal_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SubtotalOptionsProperty"]], result)

        @builtins.property
        def row_total_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTotalOptionsProperty"]]:
            '''The row total options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html#cfn-quicksight-template-pivottabletotaloptions-rowtotaloptions
            '''
            result = self._values.get("row_total_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTotalOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableTotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotTableVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class PivotTableVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTableConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTableConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A pivot table.

            For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param conditional_formatting: The conditional formatting for a ``PivotTableVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3d39c1ec15f49a6d8169c96a134105a89975ec3248982335d2109a987d67982b)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableConfigurationProperty"]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableConditionalFormattingProperty"]]:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PivotTotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "metric_header_cell_style": "metricHeaderCellStyle",
            "placement": "placement",
            "scroll_status": "scrollStatus",
            "total_aggregation_options": "totalAggregationOptions",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
            "value_cell_style": "valueCellStyle",
        },
    )
    class PivotTotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            metric_header_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            placement: typing.Optional[builtins.str] = None,
            scroll_status: typing.Optional[builtins.str] = None,
            total_aggregation_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TotalAggregationOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            total_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
            value_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The optional configuration of totals cells in a ``PivotTableVisual`` .

            :param custom_label: The custom label string for the total cells.
            :param metric_header_cell_style: The cell styling options for the total of header cells.
            :param placement: The placement (start, end) for the total cells.
            :param scroll_status: The scroll status (pinned, scrolled) for the total cells.
            :param total_aggregation_options: The total aggregation options for each value field.
            :param total_cell_style: The cell styling options for the total cells.
            :param totals_visibility: The visibility configuration for the total cells.
            :param value_cell_style: The cell styling options for the totals of value cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                pivot_total_options_property = quicksight.CfnTemplate.PivotTotalOptionsProperty(
                    custom_label="customLabel",
                    metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    placement="placement",
                    scroll_status="scrollStatus",
                    total_aggregation_options=[quicksight.CfnTemplate.TotalAggregationOptionProperty(
                        field_id="fieldId",
                        total_aggregation_function=quicksight.CfnTemplate.TotalAggregationFunctionProperty(
                            simple_total_aggregation_function="simpleTotalAggregationFunction"
                        )
                    )],
                    total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility",
                    value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c18ce2a83acb5dd2cdd206b9990dc5e18b46c2f9e3769414b4d5c304e6632bcb)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument metric_header_cell_style", value=metric_header_cell_style, expected_type=type_hints["metric_header_cell_style"])
                check_type(argname="argument placement", value=placement, expected_type=type_hints["placement"])
                check_type(argname="argument scroll_status", value=scroll_status, expected_type=type_hints["scroll_status"])
                check_type(argname="argument total_aggregation_options", value=total_aggregation_options, expected_type=type_hints["total_aggregation_options"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
                check_type(argname="argument value_cell_style", value=value_cell_style, expected_type=type_hints["value_cell_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if metric_header_cell_style is not None:
                self._values["metric_header_cell_style"] = metric_header_cell_style
            if placement is not None:
                self._values["placement"] = placement
            if scroll_status is not None:
                self._values["scroll_status"] = scroll_status
            if total_aggregation_options is not None:
                self._values["total_aggregation_options"] = total_aggregation_options
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility
            if value_cell_style is not None:
                self._values["value_cell_style"] = value_cell_style

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def metric_header_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]]:
            '''The cell styling options for the total of header cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-metricheadercellstyle
            '''
            result = self._values.get("metric_header_cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def placement(self) -> typing.Optional[builtins.str]:
            '''The placement (start, end) for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-placement
            '''
            result = self._values.get("placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scroll_status(self) -> typing.Optional[builtins.str]:
            '''The scroll status (pinned, scrolled) for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-scrollstatus
            '''
            result = self._values.get("scroll_status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def total_aggregation_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TotalAggregationOptionProperty"]]]]:
            '''The total aggregation options for each value field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-totalaggregationoptions
            '''
            result = self._values.get("total_aggregation_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TotalAggregationOptionProperty"]]]], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]]:
            '''The cell styling options for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]]:
            '''The cell styling options for the totals of value cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-valuecellstyle
            '''
            result = self._values.get("value_cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.PredefinedHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class PredefinedHierarchyProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]]],
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields that are defined during data preparation.

            These fields are available to use in any analysis that uses the data source.

            :param columns: The list of columns that define the predefined hierarchy.
            :param hierarchy_id: The hierarchy ID of the predefined hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the predefined hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-predefinedhierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                predefined_hierarchy_property = quicksight.CfnTemplate.PredefinedHierarchyProperty(
                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ad591b783fa5fa196df370a4f4402b4128b38a891b2fdc1575856a9a944d1a92)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]]]:
            '''The list of columns that define the predefined hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-predefinedhierarchy.html#cfn-quicksight-template-predefinedhierarchy-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]]], result)

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the predefined hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-predefinedhierarchy.html#cfn-quicksight-template-predefinedhierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DrillDownFilterProperty"]]]]:
            '''The option that determines the drill down filters for the predefined hierarchy.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-predefinedhierarchy.html#cfn-quicksight-template-predefinedhierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DrillDownFilterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PredefinedHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ProgressBarOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ProgressBarOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of the progress bar of a KPI visual.

            :param visibility: The visibility of the progress bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-progressbaroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                progress_bar_options_property = quicksight.CfnTemplate.ProgressBarOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bb41668f45eb37d8d64df1fa71a745e5417dbc9277dd4ca8c0c665d1a2a40ba1)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the progress bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-progressbaroptions.html#cfn-quicksight-template-progressbaroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ProgressBarOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.RadarChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"category": "category", "color": "color", "values": "values"},
    )
    class RadarChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well configuration of a ``RadarChartVisual`` .

            :param category: The aggregated field well categories of a radar chart.
            :param color: The color that are assigned to the aggregated field wells of a radar chart.
            :param values: The values that are assigned to the aggregated field wells of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__46c93b0194d8213c14a61ec775d8aa1349dd19712c87d825c6d2fe73f5e37968)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if color is not None:
                self._values["color"] = color
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The aggregated field well categories of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartaggregatedfieldwells.html#cfn-quicksight-template-radarchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The color that are assigned to the aggregated field wells of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartaggregatedfieldwells.html#cfn-quicksight-template-radarchartaggregatedfieldwells-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The values that are assigned to the aggregated field wells of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartaggregatedfieldwells.html#cfn-quicksight-template-radarchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class RadarChartAreaStyleSettingsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configured style settings of a radar chart.

            :param visibility: The visibility settings of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartareastylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                radar_chart_area_style_settings_property = quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fb539595ab9b08310e48bd065032dfcf316fac36084aff51215bdb8a7e4b7275)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility settings of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartareastylesettings.html#cfn-quicksight-template-radarchartareastylesettings-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartAreaStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.RadarChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "alternate_band_colors_visibility": "alternateBandColorsVisibility",
            "alternate_band_even_color": "alternateBandEvenColor",
            "alternate_band_odd_color": "alternateBandOddColor",
            "axes_range_scale": "axesRangeScale",
            "base_series_settings": "baseSeriesSettings",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_axis": "colorAxis",
            "color_label_options": "colorLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "shape": "shape",
            "sort_configuration": "sortConfiguration",
            "start_angle": "startAngle",
            "visual_palette": "visualPalette",
        },
    )
    class RadarChartConfigurationProperty:
        def __init__(
            self,
            *,
            alternate_band_colors_visibility: typing.Optional[builtins.str] = None,
            alternate_band_even_color: typing.Optional[builtins.str] = None,
            alternate_band_odd_color: typing.Optional[builtins.str] = None,
            axes_range_scale: typing.Optional[builtins.str] = None,
            base_series_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.RadarChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.RadarChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            shape: typing.Optional[builtins.str] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.RadarChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            start_angle: typing.Optional[jsii.Number] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``RadarChartVisual`` .

            :param alternate_band_colors_visibility: Determines the visibility of the colors of alternatign bands in a radar chart.
            :param alternate_band_even_color: The color of the even-numbered alternate bands of a radar chart.
            :param alternate_band_odd_color: The color of the odd-numbered alternate bands of a radar chart.
            :param axes_range_scale: The axis behavior options of a radar chart.
            :param base_series_settings: The base sreies settings of a radar chart.
            :param category_axis: The category axis of a radar chart.
            :param category_label_options: The category label options of a radar chart.
            :param color_axis: The color axis of a radar chart.
            :param color_label_options: The color label options of a radar chart.
            :param field_wells: The field well configuration of a ``RadarChartVisual`` .
            :param legend: The legend display setup of the visual.
            :param shape: The shape of the radar chart.
            :param sort_configuration: The sort configuration of a ``RadarChartVisual`` .
            :param start_angle: The start angle of a radar chart's axis.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__106a5058bf6fa7ca94cf2199e6968a77010c71510f006e0362301aaa16d11628)
                check_type(argname="argument alternate_band_colors_visibility", value=alternate_band_colors_visibility, expected_type=type_hints["alternate_band_colors_visibility"])
                check_type(argname="argument alternate_band_even_color", value=alternate_band_even_color, expected_type=type_hints["alternate_band_even_color"])
                check_type(argname="argument alternate_band_odd_color", value=alternate_band_odd_color, expected_type=type_hints["alternate_band_odd_color"])
                check_type(argname="argument axes_range_scale", value=axes_range_scale, expected_type=type_hints["axes_range_scale"])
                check_type(argname="argument base_series_settings", value=base_series_settings, expected_type=type_hints["base_series_settings"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_axis", value=color_axis, expected_type=type_hints["color_axis"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument shape", value=shape, expected_type=type_hints["shape"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument start_angle", value=start_angle, expected_type=type_hints["start_angle"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if alternate_band_colors_visibility is not None:
                self._values["alternate_band_colors_visibility"] = alternate_band_colors_visibility
            if alternate_band_even_color is not None:
                self._values["alternate_band_even_color"] = alternate_band_even_color
            if alternate_band_odd_color is not None:
                self._values["alternate_band_odd_color"] = alternate_band_odd_color
            if axes_range_scale is not None:
                self._values["axes_range_scale"] = axes_range_scale
            if base_series_settings is not None:
                self._values["base_series_settings"] = base_series_settings
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_axis is not None:
                self._values["color_axis"] = color_axis
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if shape is not None:
                self._values["shape"] = shape
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if start_angle is not None:
                self._values["start_angle"] = start_angle
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def alternate_band_colors_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the colors of alternatign bands in a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-alternatebandcolorsvisibility
            '''
            result = self._values.get("alternate_band_colors_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def alternate_band_even_color(self) -> typing.Optional[builtins.str]:
            '''The color of the even-numbered alternate bands of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-alternatebandevencolor
            '''
            result = self._values.get("alternate_band_even_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def alternate_band_odd_color(self) -> typing.Optional[builtins.str]:
            '''The color of the odd-numbered alternate bands of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-alternatebandoddcolor
            '''
            result = self._values.get("alternate_band_odd_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def axes_range_scale(self) -> typing.Optional[builtins.str]:
            '''The axis behavior options of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-axesrangescale
            '''
            result = self._values.get("axes_range_scale")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def base_series_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RadarChartSeriesSettingsProperty"]]:
            '''The base sreies settings of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-baseseriessettings
            '''
            result = self._values.get("base_series_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RadarChartSeriesSettingsProperty"]], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The category axis of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The category label options of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The color axis of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-coloraxis
            '''
            result = self._values.get("color_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The color label options of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RadarChartFieldWellsProperty"]]:
            '''The field well configuration of a ``RadarChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RadarChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def shape(self) -> typing.Optional[builtins.str]:
            '''The shape of the radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-shape
            '''
            result = self._values.get("shape")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RadarChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``RadarChartVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RadarChartSortConfigurationProperty"]], result)

        @builtins.property
        def start_angle(self) -> typing.Optional[jsii.Number]:
            '''The start angle of a radar chart's axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-startangle
            '''
            result = self._values.get("start_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.RadarChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "radar_chart_aggregated_field_wells": "radarChartAggregatedFieldWells",
        },
    )
    class RadarChartFieldWellsProperty:
        def __init__(
            self,
            *,
            radar_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.RadarChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a radar chart visual.

            :param radar_chart_aggregated_field_wells: The aggregated field wells of a radar chart visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4bae251f32c771911ca8b2be63d86c15669ebbe793125cf3cd5ea5e9a703f1dd)
                check_type(argname="argument radar_chart_aggregated_field_wells", value=radar_chart_aggregated_field_wells, expected_type=type_hints["radar_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if radar_chart_aggregated_field_wells is not None:
                self._values["radar_chart_aggregated_field_wells"] = radar_chart_aggregated_field_wells

        @builtins.property
        def radar_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RadarChartAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a radar chart visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartfieldwells.html#cfn-quicksight-template-radarchartfieldwells-radarchartaggregatedfieldwells
            '''
            result = self._values.get("radar_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RadarChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.RadarChartSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={"area_style_settings": "areaStyleSettings"},
    )
    class RadarChartSeriesSettingsProperty:
        def __init__(
            self,
            *,
            area_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.RadarChartAreaStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The series settings of a radar chart.

            :param area_style_settings: The area style settings of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                radar_chart_series_settings_property = quicksight.CfnTemplate.RadarChartSeriesSettingsProperty(
                    area_style_settings=quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5eab408b399dad4a06a7313fffa42352e787d1bd99de1ba672af562069b2df91)
                check_type(argname="argument area_style_settings", value=area_style_settings, expected_type=type_hints["area_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if area_style_settings is not None:
                self._values["area_style_settings"] = area_style_settings

        @builtins.property
        def area_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RadarChartAreaStyleSettingsProperty"]]:
            '''The area style settings of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartseriessettings.html#cfn-quicksight-template-radarchartseriessettings-areastylesettings
            '''
            result = self._values.get("area_style_settings")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RadarChartAreaStyleSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.RadarChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
        },
    )
    class RadarChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``RadarChartVisual`` .

            :param category_items_limit: The category items limit for a radar chart.
            :param category_sort: The category sort options of a radar chart.
            :param color_items_limit: The color items limit of a radar chart.
            :param color_sort: The color sort configuration of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                radar_chart_sort_configuration_property = quicksight.CfnTemplate.RadarChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7c6675a95eeacf8a9db24b3acfeddb075b954352d556c59fd200f8b055fcda26)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The category items limit for a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html#cfn-quicksight-template-radarchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The category sort options of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html#cfn-quicksight-template-radarchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The color items limit of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html#cfn-quicksight-template-radarchartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The color sort configuration of a radar chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html#cfn-quicksight-template-radarchartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.RadarChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class RadarChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.RadarChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A radar chart visual.

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3cf5b3fffb435c163304fe45aeed443d272acb7ee1fc6313bb1d30b78f4feeb8)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RadarChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RadarChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.RangeEndsLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class RangeEndsLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The range ends label type of a data path label.

            :param visibility: The visibility of the range ends label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rangeendslabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                range_ends_label_type_property = quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__650d8a6baa5221eddd94d67bb0c9303c2b5e4817e5d47fc4c018515e03cbae6b)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the range ends label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rangeendslabeltype.html#cfn-quicksight-template-rangeendslabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RangeEndsLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_label": "customLabel"},
    )
    class ReferenceLineCustomLabelConfigurationProperty:
        def __init__(self, *, custom_label: builtins.str) -> None:
            '''The configuration for a custom label on a ``ReferenceLine`` .

            :param custom_label: The string text of the custom label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinecustomlabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_custom_label_configuration_property = quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                    custom_label="customLabel"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0f71115fae8644cef2d84477c85bad8fd377d7d191469b59e52f89d62ea9a798)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "custom_label": custom_label,
            }

        @builtins.property
        def custom_label(self) -> builtins.str:
            '''The string text of the custom label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinecustomlabelconfiguration.html#cfn-quicksight-template-referencelinecustomlabelconfiguration-customlabel
            '''
            result = self._values.get("custom_label")
            assert result is not None, "Required property 'custom_label' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineCustomLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "dynamic_configuration": "dynamicConfiguration",
            "series_type": "seriesType",
            "static_configuration": "staticConfiguration",
        },
    )
    class ReferenceLineDataConfigurationProperty:
        def __init__(
            self,
            *,
            axis_binding: typing.Optional[builtins.str] = None,
            dynamic_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ReferenceLineDynamicDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            series_type: typing.Optional[builtins.str] = None,
            static_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ReferenceLineStaticDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The data configuration of the reference line.

            :param axis_binding: The axis binding type of the reference line. Choose one of the following options:. - ``PrimaryY`` - ``SecondaryY``
            :param dynamic_configuration: The dynamic configuration of the reference line data configuration.
            :param series_type: The series type of the reference line data configuration. Choose one of the following options:. - ``BAR`` - ``LINE``
            :param static_configuration: The static data configuration of the reference line data configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_data_configuration_property = quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                    axis_binding="axisBinding",
                    dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                        calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        ),
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                            attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                simple_attribute_aggregation="simpleAttributeAggregation",
                                value_for_multiple_values="valueForMultipleValues"
                            ),
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    series_type="seriesType",
                    static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                        value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__da5de79943e1959490d8aa872550015dd5047b5e9a13e47dd41b0cc4192c6bf4)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument dynamic_configuration", value=dynamic_configuration, expected_type=type_hints["dynamic_configuration"])
                check_type(argname="argument series_type", value=series_type, expected_type=type_hints["series_type"])
                check_type(argname="argument static_configuration", value=static_configuration, expected_type=type_hints["static_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_binding is not None:
                self._values["axis_binding"] = axis_binding
            if dynamic_configuration is not None:
                self._values["dynamic_configuration"] = dynamic_configuration
            if series_type is not None:
                self._values["series_type"] = series_type
            if static_configuration is not None:
                self._values["static_configuration"] = static_configuration

        @builtins.property
        def axis_binding(self) -> typing.Optional[builtins.str]:
            '''The axis binding type of the reference line. Choose one of the following options:.

            - ``PrimaryY``
            - ``SecondaryY``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html#cfn-quicksight-template-referencelinedataconfiguration-axisbinding
            '''
            result = self._values.get("axis_binding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def dynamic_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineDynamicDataConfigurationProperty"]]:
            '''The dynamic configuration of the reference line data configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html#cfn-quicksight-template-referencelinedataconfiguration-dynamicconfiguration
            '''
            result = self._values.get("dynamic_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineDynamicDataConfigurationProperty"]], result)

        @builtins.property
        def series_type(self) -> typing.Optional[builtins.str]:
            '''The series type of the reference line data configuration. Choose one of the following options:.

            - ``BAR``
            - ``LINE``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html#cfn-quicksight-template-referencelinedataconfiguration-seriestype
            '''
            result = self._values.get("series_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def static_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineStaticDataConfigurationProperty"]]:
            '''The static data configuration of the reference line data configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html#cfn-quicksight-template-referencelinedataconfiguration-staticconfiguration
            '''
            result = self._values.get("static_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineStaticDataConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "calculation": "calculation",
            "column": "column",
            "measure_aggregation_function": "measureAggregationFunction",
        },
    )
    class ReferenceLineDynamicDataConfigurationProperty:
        def __init__(
            self,
            *,
            calculation: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]],
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            measure_aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The dynamic configuration of the reference line data configuration.

            :param calculation: The calculation that is used in the dynamic data.
            :param column: The column that the dynamic data targets.
            :param measure_aggregation_function: The aggregation function that is used in the dynamic data.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedynamicdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_dynamic_data_configuration_property = quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                    calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    ),
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                        attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                            simple_attribute_aggregation="simpleAttributeAggregation",
                            value_for_multiple_values="valueForMultipleValues"
                        ),
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cb6f388ca1e7726651534509a34615205e188e11705fef02d546d7276c3fe353)
                check_type(argname="argument calculation", value=calculation, expected_type=type_hints["calculation"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument measure_aggregation_function", value=measure_aggregation_function, expected_type=type_hints["measure_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "calculation": calculation,
                "column": column,
            }
            if measure_aggregation_function is not None:
                self._values["measure_aggregation_function"] = measure_aggregation_function

        @builtins.property
        def calculation(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericalAggregationFunctionProperty"]:
            '''The calculation that is used in the dynamic data.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedynamicdataconfiguration.html#cfn-quicksight-template-referencelinedynamicdataconfiguration-calculation
            '''
            result = self._values.get("calculation")
            assert result is not None, "Required property 'calculation' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericalAggregationFunctionProperty"], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the dynamic data targets.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedynamicdataconfiguration.html#cfn-quicksight-template-referencelinedynamicdataconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def measure_aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AggregationFunctionProperty"]]:
            '''The aggregation function that is used in the dynamic data.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedynamicdataconfiguration.html#cfn-quicksight-template-referencelinedynamicdataconfiguration-measureaggregationfunction
            '''
            result = self._values.get("measure_aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AggregationFunctionProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineDynamicDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label_configuration": "customLabelConfiguration",
            "font_color": "fontColor",
            "font_configuration": "fontConfiguration",
            "horizontal_position": "horizontalPosition",
            "value_label_configuration": "valueLabelConfiguration",
            "vertical_position": "verticalPosition",
        },
    )
    class ReferenceLineLabelConfigurationProperty:
        def __init__(
            self,
            *,
            custom_label_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ReferenceLineCustomLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            font_color: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            horizontal_position: typing.Optional[builtins.str] = None,
            value_label_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ReferenceLineValueLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            vertical_position: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label configuration of a reference line.

            :param custom_label_configuration: The custom label configuration of the label in a reference line.
            :param font_color: The font color configuration of the label in a reference line.
            :param font_configuration: The font configuration of the label in a reference line.
            :param horizontal_position: The horizontal position configuration of the label in a reference line. Choose one of the following options:. - ``LEFT`` - ``CENTER`` - ``RIGHT``
            :param value_label_configuration: The value label configuration of the label in a reference line.
            :param vertical_position: The vertical position configuration of the label in a reference line. Choose one of the following options:. - ``ABOVE`` - ``BELOW``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_label_configuration_property = quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                    custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                        custom_label="customLabel"
                    ),
                    font_color="fontColor",
                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    horizontal_position="horizontalPosition",
                    value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        relative_position="relativePosition"
                    ),
                    vertical_position="verticalPosition"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f77bc8bf89c9f0e27a1b8c85487033d2dcada397afb0553a86302a8b3914741b)
                check_type(argname="argument custom_label_configuration", value=custom_label_configuration, expected_type=type_hints["custom_label_configuration"])
                check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument horizontal_position", value=horizontal_position, expected_type=type_hints["horizontal_position"])
                check_type(argname="argument value_label_configuration", value=value_label_configuration, expected_type=type_hints["value_label_configuration"])
                check_type(argname="argument vertical_position", value=vertical_position, expected_type=type_hints["vertical_position"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label_configuration is not None:
                self._values["custom_label_configuration"] = custom_label_configuration
            if font_color is not None:
                self._values["font_color"] = font_color
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if horizontal_position is not None:
                self._values["horizontal_position"] = horizontal_position
            if value_label_configuration is not None:
                self._values["value_label_configuration"] = value_label_configuration
            if vertical_position is not None:
                self._values["vertical_position"] = vertical_position

        @builtins.property
        def custom_label_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineCustomLabelConfigurationProperty"]]:
            '''The custom label configuration of the label in a reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-customlabelconfiguration
            '''
            result = self._values.get("custom_label_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineCustomLabelConfigurationProperty"]], result)

        @builtins.property
        def font_color(self) -> typing.Optional[builtins.str]:
            '''The font color configuration of the label in a reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-fontcolor
            '''
            result = self._values.get("font_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"]]:
            '''The font configuration of the label in a reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"]], result)

        @builtins.property
        def horizontal_position(self) -> typing.Optional[builtins.str]:
            '''The horizontal position configuration of the label in a reference line. Choose one of the following options:.

            - ``LEFT``
            - ``CENTER``
            - ``RIGHT``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-horizontalposition
            '''
            result = self._values.get("horizontal_position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_label_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineValueLabelConfigurationProperty"]]:
            '''The value label configuration of the label in a reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-valuelabelconfiguration
            '''
            result = self._values.get("value_label_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineValueLabelConfigurationProperty"]], result)

        @builtins.property
        def vertical_position(self) -> typing.Optional[builtins.str]:
            '''The vertical position configuration of the label in a reference line. Choose one of the following options:.

            - ``ABOVE``
            - ``BELOW``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-verticalposition
            '''
            result = self._values.get("vertical_position")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ReferenceLineProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_configuration": "dataConfiguration",
            "label_configuration": "labelConfiguration",
            "status": "status",
            "style_configuration": "styleConfiguration",
        },
    )
    class ReferenceLineProperty:
        def __init__(
            self,
            *,
            data_configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ReferenceLineDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            label_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ReferenceLineLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            status: typing.Optional[builtins.str] = None,
            style_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ReferenceLineStyleConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The reference line visual display options.

            :param data_configuration: The data configuration of the reference line.
            :param label_configuration: The label configuration of the reference line.
            :param status: The status of the reference line. Choose one of the following options:. - ``ENABLE`` - ``DISABLE``
            :param style_configuration: The style configuration of the reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_property = quicksight.CfnTemplate.ReferenceLineProperty(
                    data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                        axis_binding="axisBinding",
                        dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                            calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        series_type="seriesType",
                        static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                            value=123
                        )
                    ),
                
                    # the properties below are optional
                    label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                        custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                            custom_label="customLabel"
                        ),
                        font_color="fontColor",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        horizontal_position="horizontalPosition",
                        value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            ),
                            relative_position="relativePosition"
                        ),
                        vertical_position="verticalPosition"
                    ),
                    status="status",
                    style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                        color="color",
                        pattern="pattern"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5cccbf131d76f477371049fef51f604cfb16a84b126f423e4e2b3c70b6c6f75a)
                check_type(argname="argument data_configuration", value=data_configuration, expected_type=type_hints["data_configuration"])
                check_type(argname="argument label_configuration", value=label_configuration, expected_type=type_hints["label_configuration"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument style_configuration", value=style_configuration, expected_type=type_hints["style_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_configuration": data_configuration,
            }
            if label_configuration is not None:
                self._values["label_configuration"] = label_configuration
            if status is not None:
                self._values["status"] = status
            if style_configuration is not None:
                self._values["style_configuration"] = style_configuration

        @builtins.property
        def data_configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineDataConfigurationProperty"]:
            '''The data configuration of the reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html#cfn-quicksight-template-referenceline-dataconfiguration
            '''
            result = self._values.get("data_configuration")
            assert result is not None, "Required property 'data_configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineDataConfigurationProperty"], result)

        @builtins.property
        def label_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineLabelConfigurationProperty"]]:
            '''The label configuration of the reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html#cfn-quicksight-template-referenceline-labelconfiguration
            '''
            result = self._values.get("label_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineLabelConfigurationProperty"]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the reference line. Choose one of the following options:.

            - ``ENABLE``
            - ``DISABLE``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html#cfn-quicksight-template-referenceline-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineStyleConfigurationProperty"]]:
            '''The style configuration of the reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html#cfn-quicksight-template-referenceline-styleconfiguration
            '''
            result = self._values.get("style_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ReferenceLineStyleConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"value": "value"},
    )
    class ReferenceLineStaticDataConfigurationProperty:
        def __init__(self, *, value: jsii.Number) -> None:
            '''The static data configuration of the reference line data configuration.

            :param value: The double input of the static data. Default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestaticdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_static_data_configuration_property = quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__20157a5288f35eb360ed5849d2a6efce6750ddf16135829250ed59447015cd7f)
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "value": value,
            }

        @builtins.property
        def value(self) -> jsii.Number:
            '''The double input of the static data.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestaticdataconfiguration.html#cfn-quicksight-template-referencelinestaticdataconfiguration-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineStaticDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "pattern": "pattern"},
    )
    class ReferenceLineStyleConfigurationProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            pattern: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The style configuration of the reference line.

            :param color: The hex color of the reference line.
            :param pattern: The pattern type of the line style. Choose one of the following options:. - ``SOLID`` - ``DASHED`` - ``DOTTED``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestyleconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_style_configuration_property = quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                    color="color",
                    pattern="pattern"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cbcf012995ca009b92f00c1dac21c0f15c968a37d25d2b356a13b11cc48ce39b)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if pattern is not None:
                self._values["pattern"] = pattern

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The hex color of the reference line.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestyleconfiguration.html#cfn-quicksight-template-referencelinestyleconfiguration-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def pattern(self) -> typing.Optional[builtins.str]:
            '''The pattern type of the line style. Choose one of the following options:.

            - ``SOLID``
            - ``DASHED``
            - ``DOTTED``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestyleconfiguration.html#cfn-quicksight-template-referencelinestyleconfiguration-pattern
            '''
            result = self._values.get("pattern")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineStyleConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "format_configuration": "formatConfiguration",
            "relative_position": "relativePosition",
        },
    )
    class ReferenceLineValueLabelConfigurationProperty:
        def __init__(
            self,
            *,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relative_position: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The value label configuration of the label in a reference line.

            :param format_configuration: The format configuration of the value label.
            :param relative_position: The relative position of the value label. Choose one of the following options:. - ``BEFORE_CUSTOM_LABEL`` - ``AFTER_CUSTOM_LABEL``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinevaluelabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                reference_line_value_label_configuration_property = quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    ),
                    relative_position="relativePosition"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f9a9cf2a5e90fccbbedddb9230bb64c130cf8bedbd44c7ebd715f87319c2058a)
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument relative_position", value=relative_position, expected_type=type_hints["relative_position"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if relative_position is not None:
                self._values["relative_position"] = relative_position

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericFormatConfigurationProperty"]]:
            '''The format configuration of the value label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinevaluelabelconfiguration.html#cfn-quicksight-template-referencelinevaluelabelconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericFormatConfigurationProperty"]], result)

        @builtins.property
        def relative_position(self) -> typing.Optional[builtins.str]:
            '''The relative position of the value label. Choose one of the following options:.

            - ``BEFORE_CUSTOM_LABEL``
            - ``AFTER_CUSTOM_LABEL``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinevaluelabelconfiguration.html#cfn-quicksight-template-referencelinevaluelabelconfiguration-relativeposition
            '''
            result = self._values.get("relative_position")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineValueLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "info_icon_label_options": "infoIconLabelOptions",
            "title_options": "titleOptions",
        },
    )
    class RelativeDateTimeControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SheetControlInfoIconLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param date_time_format: Customize how dates are formatted in controls.
            :param info_icon_label_options: The configuration of info icon label options.
            :param title_options: The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatetimecontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                relative_date_time_control_display_options_property = quicksight.CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty(
                    date_time_format="dateTimeFormat",
                    info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                        info_icon_text="infoIconText",
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__35f8219e8a55bacee9602344d4869eb77b9e343298c47b6959fe9e989c1eecfd)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument info_icon_label_options", value=info_icon_label_options, expected_type=type_hints["info_icon_label_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if info_icon_label_options is not None:
                self._values["info_icon_label_options"] = info_icon_label_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Customize how dates are formatted in controls.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatetimecontroldisplayoptions.html#cfn-quicksight-template-relativedatetimecontroldisplayoptions-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def info_icon_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetControlInfoIconLabelOptionsProperty"]]:
            '''The configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatetimecontroldisplayoptions.html#cfn-quicksight-template-relativedatetimecontroldisplayoptions-infoiconlabeloptions
            '''
            result = self._values.get("info_icon_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetControlInfoIconLabelOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatetimecontroldisplayoptions.html#cfn-quicksight-template-relativedatetimecontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RelativeDateTimeControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.RelativeDatesFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "anchor_date_configuration": "anchorDateConfiguration",
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "relative_date_type": "relativeDateType",
            "time_granularity": "timeGranularity",
            "exclude_period_configuration": "excludePeriodConfiguration",
            "minimum_granularity": "minimumGranularity",
            "parameter_name": "parameterName",
            "relative_date_value": "relativeDateValue",
        },
    )
    class RelativeDatesFilterProperty:
        def __init__(
            self,
            *,
            anchor_date_configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AnchorDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            null_option: builtins.str,
            relative_date_type: builtins.str,
            time_granularity: builtins.str,
            exclude_period_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ExcludePeriodConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            minimum_granularity: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            relative_date_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A ``RelativeDatesFilter`` filters relative dates values.

            :param anchor_date_configuration: The date configuration of the filter.
            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param relative_date_type: The range date type of the filter. Choose one of the options below:. - ``PREVIOUS`` - ``THIS`` - ``LAST`` - ``NOW`` - ``NEXT``
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param exclude_period_configuration: The configuration for the exclude period of the filter.
            :param minimum_granularity: The minimum granularity (period granularity) of the relative dates filter.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param relative_date_value: The date value of the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                relative_dates_filter_property = quicksight.CfnTemplate.RelativeDatesFilterProperty(
                    anchor_date_configuration=quicksight.CfnTemplate.AnchorDateConfigurationProperty(
                        anchor_option="anchorOption",
                        parameter_name="parameterName"
                    ),
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                    relative_date_type="relativeDateType",
                    time_granularity="timeGranularity",
                
                    # the properties below are optional
                    exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                        amount=123,
                        granularity="granularity",
                
                        # the properties below are optional
                        status="status"
                    ),
                    minimum_granularity="minimumGranularity",
                    parameter_name="parameterName",
                    relative_date_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__92fd36912f41fb616fcc2ea44b0301396ac5aeb0d8b751da8a7ca19993715ded)
                check_type(argname="argument anchor_date_configuration", value=anchor_date_configuration, expected_type=type_hints["anchor_date_configuration"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument relative_date_type", value=relative_date_type, expected_type=type_hints["relative_date_type"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument exclude_period_configuration", value=exclude_period_configuration, expected_type=type_hints["exclude_period_configuration"])
                check_type(argname="argument minimum_granularity", value=minimum_granularity, expected_type=type_hints["minimum_granularity"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument relative_date_value", value=relative_date_value, expected_type=type_hints["relative_date_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "anchor_date_configuration": anchor_date_configuration,
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
                "relative_date_type": relative_date_type,
                "time_granularity": time_granularity,
            }
            if exclude_period_configuration is not None:
                self._values["exclude_period_configuration"] = exclude_period_configuration
            if minimum_granularity is not None:
                self._values["minimum_granularity"] = minimum_granularity
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if relative_date_value is not None:
                self._values["relative_date_value"] = relative_date_value

        @builtins.property
        def anchor_date_configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.AnchorDateConfigurationProperty"]:
            '''The date configuration of the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-anchordateconfiguration
            '''
            result = self._values.get("anchor_date_configuration")
            assert result is not None, "Required property 'anchor_date_configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.AnchorDateConfigurationProperty"], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def relative_date_type(self) -> builtins.str:
            '''The range date type of the filter. Choose one of the options below:.

            - ``PREVIOUS``
            - ``THIS``
            - ``LAST``
            - ``NOW``
            - ``NEXT``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-relativedatetype
            '''
            result = self._values.get("relative_date_type")
            assert result is not None, "Required property 'relative_date_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time_granularity(self) -> builtins.str:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            assert result is not None, "Required property 'time_granularity' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def exclude_period_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ExcludePeriodConfigurationProperty"]]:
            '''The configuration for the exclude period of the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-excludeperiodconfiguration
            '''
            result = self._values.get("exclude_period_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ExcludePeriodConfigurationProperty"]], result)

        @builtins.property
        def minimum_granularity(self) -> typing.Optional[builtins.str]:
            '''The minimum granularity (period granularity) of the relative dates filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-minimumgranularity
            '''
            result = self._values.get("minimum_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def relative_date_value(self) -> typing.Optional[jsii.Number]:
            '''The date value of the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-relativedatevalue
            '''
            result = self._values.get("relative_date_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RelativeDatesFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ResourcePermissionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "actions": "actions",
            "principal": "principal",
            "resource": "resource",
        },
    )
    class ResourcePermissionProperty:
        def __init__(
            self,
            *,
            actions: typing.Sequence[builtins.str],
            principal: builtins.str,
            resource: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Permission for the resource.

            :param actions: The IAM action to grant or revoke permissions on.
            :param principal: The Amazon Resource Name (ARN) of the principal. This can be one of the following:. - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.) - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.) - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
            :param resource: 

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-resourcepermission.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                resource_permission_property = quicksight.CfnTemplate.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal",
                
                    # the properties below are optional
                    resource="resource"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__45b749995134d34d827369dbbb9838430a21db65d9f345e3d90ab4119be7f4ce)
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
                check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "actions": actions,
                "principal": principal,
            }
            if resource is not None:
                self._values["resource"] = resource

        @builtins.property
        def actions(self) -> typing.List[builtins.str]:
            '''The IAM action to grant or revoke permissions on.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-resourcepermission.html#cfn-quicksight-template-resourcepermission-actions
            '''
            result = self._values.get("actions")
            assert result is not None, "Required property 'actions' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def principal(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the principal. This can be one of the following:.

            - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
            - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
            - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-resourcepermission.html#cfn-quicksight-template-resourcepermission-principal
            '''
            result = self._values.get("principal")
            assert result is not None, "Required property 'principal' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def resource(self) -> typing.Optional[builtins.str]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-resourcepermission.html#cfn-quicksight-template-resourcepermission-resource
            '''
            result = self._values.get("resource")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ResourcePermissionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.RollingDateConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "expression": "expression",
            "data_set_identifier": "dataSetIdentifier",
        },
    )
    class RollingDateConfigurationProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            data_set_identifier: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The rolling date configuration of a date time filter.

            :param expression: The expression of the rolling date configuration.
            :param data_set_identifier: The data set that is used in the rolling date configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rollingdateconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                rolling_date_configuration_property = quicksight.CfnTemplate.RollingDateConfigurationProperty(
                    expression="expression",
                
                    # the properties below are optional
                    data_set_identifier="dataSetIdentifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__37a50dd839a676dd9dc51bfffd04661b36646f859856fd4fadeacd2fb342ae88)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if data_set_identifier is not None:
                self._values["data_set_identifier"] = data_set_identifier

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the rolling date configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rollingdateconfiguration.html#cfn-quicksight-template-rollingdateconfiguration-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_identifier(self) -> typing.Optional[builtins.str]:
            '''The data set that is used in the rolling date configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rollingdateconfiguration.html#cfn-quicksight-template-rollingdateconfiguration-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RollingDateConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.RowAlternateColorOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "row_alternate_colors": "rowAlternateColors",
            "status": "status",
            "use_primary_background_color": "usePrimaryBackgroundColor",
        },
    )
    class RowAlternateColorOptionsProperty:
        def __init__(
            self,
            *,
            row_alternate_colors: typing.Optional[typing.Sequence[builtins.str]] = None,
            status: typing.Optional[builtins.str] = None,
            use_primary_background_color: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the row alternate color options.

            :param row_alternate_colors: Determines the list of row alternate colors.
            :param status: Determines the widget status.
            :param use_primary_background_color: The primary background color options for alternate rows.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rowalternatecoloroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                row_alternate_color_options_property = quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                    row_alternate_colors=["rowAlternateColors"],
                    status="status",
                    use_primary_background_color="usePrimaryBackgroundColor"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1ef83b8a5b599b6d25d136eb812da4b37ed9e81a2ea99419d4d71d48156cf928)
                check_type(argname="argument row_alternate_colors", value=row_alternate_colors, expected_type=type_hints["row_alternate_colors"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument use_primary_background_color", value=use_primary_background_color, expected_type=type_hints["use_primary_background_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if row_alternate_colors is not None:
                self._values["row_alternate_colors"] = row_alternate_colors
            if status is not None:
                self._values["status"] = status
            if use_primary_background_color is not None:
                self._values["use_primary_background_color"] = use_primary_background_color

        @builtins.property
        def row_alternate_colors(self) -> typing.Optional[typing.List[builtins.str]]:
            '''Determines the list of row alternate colors.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rowalternatecoloroptions.html#cfn-quicksight-template-rowalternatecoloroptions-rowalternatecolors
            '''
            result = self._values.get("row_alternate_colors")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''Determines the widget status.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rowalternatecoloroptions.html#cfn-quicksight-template-rowalternatecoloroptions-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def use_primary_background_color(self) -> typing.Optional[builtins.str]:
            '''The primary background color options for alternate rows.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rowalternatecoloroptions.html#cfn-quicksight-template-rowalternatecoloroptions-useprimarybackgroundcolor
            '''
            result = self._values.get("use_primary_background_color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RowAlternateColorOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "target_visual_options": "targetVisualOptions",
            "target_visuals": "targetVisuals",
        },
    )
    class SameSheetTargetVisualConfigurationProperty:
        def __init__(
            self,
            *,
            target_visual_options: typing.Optional[builtins.str] = None,
            target_visuals: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The configuration of the same-sheet target visuals that you want to be filtered.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param target_visual_options: The options that choose the target visual in the same sheet. Valid values are defined as follows: - ``ALL_VISUALS`` : Applies the filter operation to all visuals in the same sheet.
            :param target_visuals: A list of the target visual IDs that are located in the same sheet of the analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-samesheettargetvisualconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                same_sheet_target_visual_configuration_property = quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                    target_visual_options="targetVisualOptions",
                    target_visuals=["targetVisuals"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2c7e60056e3b5cbe822ab42d550b65a6e94b3023aefc8057a91e122d6e831d0c)
                check_type(argname="argument target_visual_options", value=target_visual_options, expected_type=type_hints["target_visual_options"])
                check_type(argname="argument target_visuals", value=target_visuals, expected_type=type_hints["target_visuals"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_visual_options is not None:
                self._values["target_visual_options"] = target_visual_options
            if target_visuals is not None:
                self._values["target_visuals"] = target_visuals

        @builtins.property
        def target_visual_options(self) -> typing.Optional[builtins.str]:
            '''The options that choose the target visual in the same sheet.

            Valid values are defined as follows:

            - ``ALL_VISUALS`` : Applies the filter operation to all visuals in the same sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-samesheettargetvisualconfiguration.html#cfn-quicksight-template-samesheettargetvisualconfiguration-targetvisualoptions
            '''
            result = self._values.get("target_visual_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def target_visuals(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of the target visual IDs that are located in the same sheet of the analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-samesheettargetvisualconfiguration.html#cfn-quicksight-template-samesheettargetvisualconfiguration-targetvisuals
            '''
            result = self._values.get("target_visuals")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SameSheetTargetVisualConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination": "destination",
            "source": "source",
            "weight": "weight",
        },
    )
    class SankeyDiagramAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            destination: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            source: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            weight: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a sankey diagram.

            :param destination: The destination field wells of a sankey diagram.
            :param source: The source field wells of a sankey diagram.
            :param weight: The weight field wells of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e245ef9b2d48edb0045aeb023cd9de4a0ef751b92c86eaa8c3c2b9803aa56ad2)
                check_type(argname="argument destination", value=destination, expected_type=type_hints["destination"])
                check_type(argname="argument source", value=source, expected_type=type_hints["source"])
                check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if destination is not None:
                self._values["destination"] = destination
            if source is not None:
                self._values["source"] = source
            if weight is not None:
                self._values["weight"] = weight

        @builtins.property
        def destination(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The destination field wells of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-template-sankeydiagramaggregatedfieldwells-destination
            '''
            result = self._values.get("destination")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def source(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The source field wells of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-template-sankeydiagramaggregatedfieldwells-source
            '''
            result = self._values.get("source")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def weight(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The weight field wells of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-template-sankeydiagramaggregatedfieldwells-weight
            '''
            result = self._values.get("weight")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SankeyDiagramChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
        },
    )
    class SankeyDiagramChartConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SankeyDiagramFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SankeyDiagramSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a sankey diagram.

            :param data_labels: The data label configuration of a sankey diagram.
            :param field_wells: The field well configuration of a sankey diagram.
            :param sort_configuration: The sort configuration of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3d09679114b9bf9d034a4a2e73ce075aa2b8913c3fcb664a905099e7ecff45e6)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The data label configuration of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramchartconfiguration.html#cfn-quicksight-template-sankeydiagramchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SankeyDiagramFieldWellsProperty"]]:
            '''The field well configuration of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramchartconfiguration.html#cfn-quicksight-template-sankeydiagramchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SankeyDiagramFieldWellsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SankeyDiagramSortConfigurationProperty"]]:
            '''The sort configuration of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramchartconfiguration.html#cfn-quicksight-template-sankeydiagramchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SankeyDiagramSortConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SankeyDiagramFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sankey_diagram_aggregated_field_wells": "sankeyDiagramAggregatedFieldWells",
        },
    )
    class SankeyDiagramFieldWellsProperty:
        def __init__(
            self,
            *,
            sankey_diagram_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a sankey diagram.

            :param sankey_diagram_aggregated_field_wells: The field well configuration of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8918193e2be2a8d34f73cc2dbc1c1de479bb1b75e545e92f12aeb84e9f7acd95)
                check_type(argname="argument sankey_diagram_aggregated_field_wells", value=sankey_diagram_aggregated_field_wells, expected_type=type_hints["sankey_diagram_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sankey_diagram_aggregated_field_wells is not None:
                self._values["sankey_diagram_aggregated_field_wells"] = sankey_diagram_aggregated_field_wells

        @builtins.property
        def sankey_diagram_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramfieldwells.html#cfn-quicksight-template-sankeydiagramfieldwells-sankeydiagramaggregatedfieldwells
            '''
            result = self._values.get("sankey_diagram_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SankeyDiagramSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination_items_limit": "destinationItemsLimit",
            "source_items_limit": "sourceItemsLimit",
            "weight_sort": "weightSort",
        },
    )
    class SankeyDiagramSortConfigurationProperty:
        def __init__(
            self,
            *,
            destination_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            source_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            weight_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a sankey diagram.

            :param destination_items_limit: The limit on the number of destination nodes that are displayed in a sankey diagram.
            :param source_items_limit: The limit on the number of source nodes that are displayed in a sankey diagram.
            :param weight_sort: The sort configuration of the weight fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sankey_diagram_sort_configuration_property = quicksight.CfnTemplate.SankeyDiagramSortConfigurationProperty(
                    destination_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    source_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    weight_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9694f4b68ce3b50d527e73d5c0c4a9a74ef14f98061a504476145f49e78cbdb4)
                check_type(argname="argument destination_items_limit", value=destination_items_limit, expected_type=type_hints["destination_items_limit"])
                check_type(argname="argument source_items_limit", value=source_items_limit, expected_type=type_hints["source_items_limit"])
                check_type(argname="argument weight_sort", value=weight_sort, expected_type=type_hints["weight_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if destination_items_limit is not None:
                self._values["destination_items_limit"] = destination_items_limit
            if source_items_limit is not None:
                self._values["source_items_limit"] = source_items_limit
            if weight_sort is not None:
                self._values["weight_sort"] = weight_sort

        @builtins.property
        def destination_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of destination nodes that are displayed in a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramsortconfiguration.html#cfn-quicksight-template-sankeydiagramsortconfiguration-destinationitemslimit
            '''
            result = self._values.get("destination_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def source_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of source nodes that are displayed in a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramsortconfiguration.html#cfn-quicksight-template-sankeydiagramsortconfiguration-sourceitemslimit
            '''
            result = self._values.get("source_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def weight_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the weight fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramsortconfiguration.html#cfn-quicksight-template-sankeydiagramsortconfiguration-weightsort
            '''
            result = self._values.get("weight_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SankeyDiagramVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class SankeyDiagramVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SankeyDiagramChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A sankey diagram.

            For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a sankey diagram.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2a885e901778bedce1f2ebda579b9189e8b0c4e41459173af6bc298ca1e0a3b3)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SankeyDiagramChartConfigurationProperty"]]:
            '''The configuration of a sankey diagram.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SankeyDiagramChartConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "label": "label",
            "size": "size",
            "x_axis": "xAxis",
            "y_axis": "yAxis",
        },
    )
    class ScatterPlotCategoricallyAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            label: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            x_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            y_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well of a scatter plot.

            :param category: The category field well of a scatter plot.
            :param label: The label field well of a scatter plot.
            :param size: The size field well of a scatter plot.
            :param x_axis: The x-axis field well of a scatter plot. The x-axis is aggregated by category.
            :param y_axis: The y-axis field well of a scatter plot. The y-axis is aggregated by category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f6746ff4b87ff0a299e29af4269c999a5ef7d4e252e4e2102fa4e82aac925648)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
                check_type(argname="argument x_axis", value=x_axis, expected_type=type_hints["x_axis"])
                check_type(argname="argument y_axis", value=y_axis, expected_type=type_hints["y_axis"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if label is not None:
                self._values["label"] = label
            if size is not None:
                self._values["size"] = size
            if x_axis is not None:
                self._values["x_axis"] = x_axis
            if y_axis is not None:
                self._values["y_axis"] = y_axis

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The category field well of a scatter plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def label(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The label field well of a scatter plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The size field well of a scatter plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        @builtins.property
        def x_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The x-axis field well of a scatter plot.

            The x-axis is aggregated by category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-xaxis
            '''
            result = self._values.get("x_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        @builtins.property
        def y_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The y-axis field well of a scatter plot.

            The y-axis is aggregated by category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-yaxis
            '''
            result = self._values.get("y_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotCategoricallyAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ScatterPlotConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
            "y_axis_display_options": "yAxisDisplayOptions",
            "y_axis_label_options": "yAxisLabelOptions",
        },
    )
    class ScatterPlotConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ScatterPlotFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a scatter plot.

            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param tooltip: The legend display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.
            :param x_axis_display_options: The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.
            :param x_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.
            :param y_axis_display_options: The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.
            :param y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__258bf8090d349be6903de00f58a3ca9d2e589346e08d480950437072326c047d)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
                check_type(argname="argument y_axis_display_options", value=y_axis_display_options, expected_type=type_hints["y_axis_display_options"])
                check_type(argname="argument y_axis_label_options", value=y_axis_label_options, expected_type=type_hints["y_axis_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options
            if y_axis_display_options is not None:
                self._values["y_axis_display_options"] = y_axis_display_options
            if y_axis_label_options is not None:
                self._values["y_axis_label_options"] = y_axis_label_options

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ScatterPlotFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ScatterPlotFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-yaxisdisplayoptions
            '''
            result = self._values.get("y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-yaxislabeloptions
            '''
            result = self._values.get("y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ScatterPlotFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "scatter_plot_categorically_aggregated_field_wells": "scatterPlotCategoricallyAggregatedFieldWells",
            "scatter_plot_unaggregated_field_wells": "scatterPlotUnaggregatedFieldWells",
        },
    )
    class ScatterPlotFieldWellsProperty:
        def __init__(
            self,
            *,
            scatter_plot_categorically_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scatter_plot_unaggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a scatter plot.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param scatter_plot_categorically_aggregated_field_wells: The aggregated field wells of a scatter plot. The x and y-axes of scatter plots with aggregated field wells are aggregated by category, label, or both.
            :param scatter_plot_unaggregated_field_wells: The unaggregated field wells of a scatter plot. The x and y-axes of these scatter plots are unaggregated.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__29da102eef55bc93c228f4ac0e24ff94c2d527af918d2a61f5ed6031a4c61279)
                check_type(argname="argument scatter_plot_categorically_aggregated_field_wells", value=scatter_plot_categorically_aggregated_field_wells, expected_type=type_hints["scatter_plot_categorically_aggregated_field_wells"])
                check_type(argname="argument scatter_plot_unaggregated_field_wells", value=scatter_plot_unaggregated_field_wells, expected_type=type_hints["scatter_plot_unaggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if scatter_plot_categorically_aggregated_field_wells is not None:
                self._values["scatter_plot_categorically_aggregated_field_wells"] = scatter_plot_categorically_aggregated_field_wells
            if scatter_plot_unaggregated_field_wells is not None:
                self._values["scatter_plot_unaggregated_field_wells"] = scatter_plot_unaggregated_field_wells

        @builtins.property
        def scatter_plot_categorically_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a scatter plot.

            The x and y-axes of scatter plots with aggregated field wells are aggregated by category, label, or both.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotfieldwells.html#cfn-quicksight-template-scatterplotfieldwells-scatterplotcategoricallyaggregatedfieldwells
            '''
            result = self._values.get("scatter_plot_categorically_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty"]], result)

        @builtins.property
        def scatter_plot_unaggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty"]]:
            '''The unaggregated field wells of a scatter plot.

            The x and y-axes of these scatter plots are unaggregated.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotfieldwells.html#cfn-quicksight-template-scatterplotfieldwells-scatterplotunaggregatedfieldwells
            '''
            result = self._values.get("scatter_plot_unaggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "label": "label",
            "size": "size",
            "x_axis": "xAxis",
            "y_axis": "yAxis",
        },
    )
    class ScatterPlotUnaggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            label: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            x_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            y_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The unaggregated field wells of a scatter plot.

            :param category: The category field well of a scatter plot.
            :param label: The label field well of a scatter plot.
            :param size: The size field well of a scatter plot.
            :param x_axis: The x-axis field well of a scatter plot. The x-axis is a dimension field and cannot be aggregated.
            :param y_axis: The y-axis field well of a scatter plot. The y-axis is a dimension field and cannot be aggregated.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e207ffaafa8cdfaf404f62a6555d52c0e9e5a07242a8038d2d16f32ec284a1df)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
                check_type(argname="argument x_axis", value=x_axis, expected_type=type_hints["x_axis"])
                check_type(argname="argument y_axis", value=y_axis, expected_type=type_hints["y_axis"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if label is not None:
                self._values["label"] = label
            if size is not None:
                self._values["size"] = size
            if x_axis is not None:
                self._values["x_axis"] = x_axis
            if y_axis is not None:
                self._values["y_axis"] = y_axis

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The category field well of a scatter plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html#cfn-quicksight-template-scatterplotunaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def label(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The label field well of a scatter plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html#cfn-quicksight-template-scatterplotunaggregatedfieldwells-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The size field well of a scatter plot.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html#cfn-quicksight-template-scatterplotunaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        @builtins.property
        def x_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The x-axis field well of a scatter plot.

            The x-axis is a dimension field and cannot be aggregated.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html#cfn-quicksight-template-scatterplotunaggregatedfieldwells-xaxis
            '''
            result = self._values.get("x_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def y_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The y-axis field well of a scatter plot.

            The y-axis is a dimension field and cannot be aggregated.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html#cfn-quicksight-template-scatterplotunaggregatedfieldwells-yaxis
            '''
            result = self._values.get("y_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotUnaggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ScatterPlotVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class ScatterPlotVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ScatterPlotConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A scatter plot.

            For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__879575b049e53b3daa0d983662cc655e11b4d69d4c8f5ca28013cb537ecf487c)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ScatterPlotConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ScatterPlotConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ScrollBarOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility", "visible_range": "visibleRange"},
    )
    class ScrollBarOptionsProperty:
        def __init__(
            self,
            *,
            visibility: typing.Optional[builtins.str] = None,
            visible_range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisibleRangeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The visual display options for a data zoom scroll bar.

            :param visibility: The visibility of the data zoom scroll bar.
            :param visible_range: The visibility range for the data zoom scroll bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scrollbaroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                scroll_bar_options_property = quicksight.CfnTemplate.ScrollBarOptionsProperty(
                    visibility="visibility",
                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                            from=123,
                            to=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4ee368d35744531b8573eff531ffb1d0ad1e891e30d9b365574b131167fca688)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument visible_range", value=visible_range, expected_type=type_hints["visible_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility
            if visible_range is not None:
                self._values["visible_range"] = visible_range

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the data zoom scroll bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scrollbaroptions.html#cfn-quicksight-template-scrollbaroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visible_range(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisibleRangeOptionsProperty"]]:
            '''The visibility range for the data zoom scroll bar.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scrollbaroptions.html#cfn-quicksight-template-scrollbaroptions-visiblerange
            '''
            result = self._values.get("visible_range")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisibleRangeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScrollBarOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SecondaryValueOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class SecondaryValueOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of the secondary value of a KPI visual.

            :param visibility: Determines the visibility of the secondary value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-secondaryvalueoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                secondary_value_options_property = quicksight.CfnTemplate.SecondaryValueOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__97f044f8cc96381e546020326f02d820f630974a369eb22d2213428fa19a12ff)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the secondary value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-secondaryvalueoptions.html#cfn-quicksight-template-secondaryvalueoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SecondaryValueOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SectionAfterPageBreakProperty",
        jsii_struct_bases=[],
        name_mapping={"status": "status"},
    )
    class SectionAfterPageBreakProperty:
        def __init__(self, *, status: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of a page break after a section.

            :param status: The option that enables or disables a page break at the end of a section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionafterpagebreak.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                section_after_page_break_property = quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9a5d86e966b487b229aaa556fa1931deb9adc5b7323cf139727280a9f7fab4dd)
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The option that enables or disables a page break at the end of a section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionafterpagebreak.html#cfn-quicksight-template-sectionafterpagebreak-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionAfterPageBreakProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"paper_canvas_size_options": "paperCanvasSizeOptions"},
    )
    class SectionBasedLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            paper_canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options for the canvas of a section-based layout.

            :param paper_canvas_size_options: The options for a paper canvas of a section-based layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                section_based_layout_canvas_size_options_property = quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                    paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                        paper_margin=quicksight.CfnTemplate.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        ),
                        paper_orientation="paperOrientation",
                        paper_size="paperSize"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__33052b6e45bf47c0da040740720240f654800dca3ca1098ffd1fd52e795be469)
                check_type(argname="argument paper_canvas_size_options", value=paper_canvas_size_options, expected_type=type_hints["paper_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if paper_canvas_size_options is not None:
                self._values["paper_canvas_size_options"] = paper_canvas_size_options

        @builtins.property
        def paper_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty"]]:
            '''The options for a paper canvas of a section-based layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutcanvassizeoptions.html#cfn-quicksight-template-sectionbasedlayoutcanvassizeoptions-papercanvassizeoptions
            '''
            result = self._values.get("paper_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SectionBasedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "body_sections": "bodySections",
            "canvas_size_options": "canvasSizeOptions",
            "footer_sections": "footerSections",
            "header_sections": "headerSections",
        },
    )
    class SectionBasedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            body_sections: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.BodySectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
            footer_sections: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.HeaderFooterSectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            header_sections: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.HeaderFooterSectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The configuration for a section-based layout.

            :param body_sections: A list of body section configurations.
            :param canvas_size_options: The options for the canvas of a section-based layout.
            :param footer_sections: A list of footer section configurations.
            :param header_sections: A list of header section configurations.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                section_based_layout_configuration_property = quicksight.CfnTemplate.SectionBasedLayoutConfigurationProperty(
                    body_sections=[quicksight.CfnTemplate.BodySectionConfigurationProperty(
                        content=quicksight.CfnTemplate.BodySectionContentProperty(
                            layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        page_break_configuration=quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                            after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                                status="status"
                            )
                        ),
                        style=quicksight.CfnTemplate.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnTemplate.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )],
                    canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                        paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                            paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            ),
                            paper_orientation="paperOrientation",
                            paper_size="paperSize"
                        )
                    ),
                    footer_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                        layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        style=quicksight.CfnTemplate.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnTemplate.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )],
                    header_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                        layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        style=quicksight.CfnTemplate.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnTemplate.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b808d8e615270149e5e6d77d1642245ca3d9612e469b8ec5e554d04ad0083824)
                check_type(argname="argument body_sections", value=body_sections, expected_type=type_hints["body_sections"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
                check_type(argname="argument footer_sections", value=footer_sections, expected_type=type_hints["footer_sections"])
                check_type(argname="argument header_sections", value=header_sections, expected_type=type_hints["header_sections"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "body_sections": body_sections,
                "canvas_size_options": canvas_size_options,
                "footer_sections": footer_sections,
                "header_sections": header_sections,
            }

        @builtins.property
        def body_sections(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BodySectionConfigurationProperty"]]]:
            '''A list of body section configurations.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html#cfn-quicksight-template-sectionbasedlayoutconfiguration-bodysections
            '''
            result = self._values.get("body_sections")
            assert result is not None, "Required property 'body_sections' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BodySectionConfigurationProperty"]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty"]:
            '''The options for the canvas of a section-based layout.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html#cfn-quicksight-template-sectionbasedlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty"], result)

        @builtins.property
        def footer_sections(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HeaderFooterSectionConfigurationProperty"]]]:
            '''A list of footer section configurations.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html#cfn-quicksight-template-sectionbasedlayoutconfiguration-footersections
            '''
            result = self._values.get("footer_sections")
            assert result is not None, "Required property 'footer_sections' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HeaderFooterSectionConfigurationProperty"]]], result)

        @builtins.property
        def header_sections(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HeaderFooterSectionConfigurationProperty"]]]:
            '''A list of header section configurations.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html#cfn-quicksight-template-sectionbasedlayoutconfiguration-headersections
            '''
            result = self._values.get("header_sections")
            assert result is not None, "Required property 'header_sections' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HeaderFooterSectionConfigurationProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "paper_margin": "paperMargin",
            "paper_orientation": "paperOrientation",
            "paper_size": "paperSize",
        },
    )
    class SectionBasedLayoutPaperCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            paper_margin: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SpacingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paper_orientation: typing.Optional[builtins.str] = None,
            paper_size: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for a paper canvas of a section-based layout.

            :param paper_margin: Defines the spacing between the canvas content and the top, bottom, left, and right edges.
            :param paper_orientation: The paper orientation that is used to define canvas dimensions. Choose one of the following options:. - PORTRAIT - LANDSCAPE
            :param paper_size: The paper size that is used to define canvas dimensions.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutpapercanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                section_based_layout_paper_canvas_size_options_property = quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                    paper_margin=quicksight.CfnTemplate.SpacingProperty(
                        bottom="bottom",
                        left="left",
                        right="right",
                        top="top"
                    ),
                    paper_orientation="paperOrientation",
                    paper_size="paperSize"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d042ffe0f1c54f771a4e20da8edb49b765bd89dbb4c4a113b6408a39a1437a04)
                check_type(argname="argument paper_margin", value=paper_margin, expected_type=type_hints["paper_margin"])
                check_type(argname="argument paper_orientation", value=paper_orientation, expected_type=type_hints["paper_orientation"])
                check_type(argname="argument paper_size", value=paper_size, expected_type=type_hints["paper_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if paper_margin is not None:
                self._values["paper_margin"] = paper_margin
            if paper_orientation is not None:
                self._values["paper_orientation"] = paper_orientation
            if paper_size is not None:
                self._values["paper_size"] = paper_size

        @builtins.property
        def paper_margin(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SpacingProperty"]]:
            '''Defines the spacing between the canvas content and the top, bottom, left, and right edges.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-template-sectionbasedlayoutpapercanvassizeoptions-papermargin
            '''
            result = self._values.get("paper_margin")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SpacingProperty"]], result)

        @builtins.property
        def paper_orientation(self) -> typing.Optional[builtins.str]:
            '''The paper orientation that is used to define canvas dimensions. Choose one of the following options:.

            - PORTRAIT
            - LANDSCAPE

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-template-sectionbasedlayoutpapercanvassizeoptions-paperorientation
            '''
            result = self._values.get("paper_orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def paper_size(self) -> typing.Optional[builtins.str]:
            '''The paper size that is used to define canvas dimensions.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-template-sectionbasedlayoutpapercanvassizeoptions-papersize
            '''
            result = self._values.get("paper_size")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutPaperCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SectionLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"free_form_layout": "freeFormLayout"},
    )
    class SectionLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form_layout: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FreeFormSectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The layout configuration of a section.

            :param free_form_layout: The free-form layout configuration of a section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                section_layout_configuration_property = quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                    free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                        elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                            element_id="elementId",
                            element_type="elementType",
                            height="height",
                            width="width",
                            x_axis_location="xAxisLocation",
                            y_axis_location="yAxisLocation",
                
                            # the properties below are optional
                            background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                visibility="visibility"
                            ),
                            rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                    visibility="visibility"
                                ),
                                expression="expression"
                            )],
                            selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            visibility="visibility"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2da0fb63ea8d987243457aaf1d3ca394c90fb7e0c6ee28ac40f811b99100305f)
                check_type(argname="argument free_form_layout", value=free_form_layout, expected_type=type_hints["free_form_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "free_form_layout": free_form_layout,
            }

        @builtins.property
        def free_form_layout(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.FreeFormSectionLayoutConfigurationProperty"]:
            '''The free-form layout configuration of a section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionlayoutconfiguration.html#cfn-quicksight-template-sectionlayoutconfiguration-freeformlayout
            '''
            result = self._values.get("free_form_layout")
            assert result is not None, "Required property 'free_form_layout' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.FreeFormSectionLayoutConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SectionPageBreakConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"after": "after"},
    )
    class SectionPageBreakConfigurationProperty:
        def __init__(
            self,
            *,
            after: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SectionAfterPageBreakProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a page break for a section.

            :param after: The configuration of a page break after a section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionpagebreakconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                section_page_break_configuration_property = quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                    after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                        status="status"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__db30e6b419845c46570e29203ae83399f8721ffa1a91e707ca14f0bb9235817e)
                check_type(argname="argument after", value=after, expected_type=type_hints["after"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if after is not None:
                self._values["after"] = after

        @builtins.property
        def after(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SectionAfterPageBreakProperty"]]:
            '''The configuration of a page break after a section.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionpagebreakconfiguration.html#cfn-quicksight-template-sectionpagebreakconfiguration-after
            '''
            result = self._values.get("after")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SectionAfterPageBreakProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionPageBreakConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SectionStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"height": "height", "padding": "padding"},
    )
    class SectionStyleProperty:
        def __init__(
            self,
            *,
            height: typing.Optional[builtins.str] = None,
            padding: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SpacingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that style a section.

            :param height: The height of a section. Heights can only be defined for header and footer sections. The default height margin is 0.5 inches.
            :param padding: The spacing between section content and its top, bottom, left, and right edges. There is no padding by default.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                section_style_property = quicksight.CfnTemplate.SectionStyleProperty(
                    height="height",
                    padding=quicksight.CfnTemplate.SpacingProperty(
                        bottom="bottom",
                        left="left",
                        right="right",
                        top="top"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dcbe0aaba90a7cc6014902ad99b3dd94c4aaa3f24e57d836a5b672fe0348bd05)
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument padding", value=padding, expected_type=type_hints["padding"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if height is not None:
                self._values["height"] = height
            if padding is not None:
                self._values["padding"] = padding

        @builtins.property
        def height(self) -> typing.Optional[builtins.str]:
            '''The height of a section.

            Heights can only be defined for header and footer sections. The default height margin is 0.5 inches.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionstyle.html#cfn-quicksight-template-sectionstyle-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def padding(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SpacingProperty"]]:
            '''The spacing between section content and its top, bottom, left, and right edges.

            There is no padding by default.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionstyle.html#cfn-quicksight-template-sectionstyle-padding
            '''
            result = self._values.get("padding")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SpacingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sheet_visual_scoping_configurations": "sheetVisualScopingConfigurations",
        },
    )
    class SelectedSheetsFilterScopeConfigurationProperty:
        def __init__(
            self,
            *,
            sheet_visual_scoping_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SheetVisualScopingConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The configuration for applying a filter to specific sheets or visuals.

            You can apply this filter to multiple visuals that are on one sheet or to all visuals on a sheet.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param sheet_visual_scoping_configurations: The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-selectedsheetsfilterscopeconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                selected_sheets_filter_scope_configuration_property = quicksight.CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty(
                    sheet_visual_scoping_configurations=[quicksight.CfnTemplate.SheetVisualScopingConfigurationProperty(
                        scope="scope",
                        sheet_id="sheetId",
                
                        # the properties below are optional
                        visual_ids=["visualIds"]
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__03f2659c419f0277a65415d4deb56ae640b6d784c92fc471ad8fd48b4816abbd)
                check_type(argname="argument sheet_visual_scoping_configurations", value=sheet_visual_scoping_configurations, expected_type=type_hints["sheet_visual_scoping_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sheet_visual_scoping_configurations is not None:
                self._values["sheet_visual_scoping_configurations"] = sheet_visual_scoping_configurations

        @builtins.property
        def sheet_visual_scoping_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetVisualScopingConfigurationProperty"]]]]:
            '''The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-selectedsheetsfilterscopeconfiguration.html#cfn-quicksight-template-selectedsheetsfilterscopeconfiguration-sheetvisualscopingconfigurations
            '''
            result = self._values.get("sheet_visual_scoping_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetVisualScopingConfigurationProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SelectedSheetsFilterScopeConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_field_series_item": "dataFieldSeriesItem",
            "field_series_item": "fieldSeriesItem",
        },
    )
    class SeriesItemProperty:
        def __init__(
            self,
            *,
            data_field_series_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataFieldSeriesItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_series_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSeriesItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The series item configuration of a line chart.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_field_series_item: The data field series item configuration of a line chart.
            :param field_series_item: The field series item configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-seriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                series_item_property = quicksight.CfnTemplate.SeriesItemProperty(
                    data_field_series_item=quicksight.CfnTemplate.DataFieldSeriesItemProperty(
                        axis_binding="axisBinding",
                        field_id="fieldId",
                
                        # the properties below are optional
                        field_value="fieldValue",
                        settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                            line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        )
                    ),
                    field_series_item=quicksight.CfnTemplate.FieldSeriesItemProperty(
                        axis_binding="axisBinding",
                        field_id="fieldId",
                
                        # the properties below are optional
                        settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                            line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3338eb15b7d38ba0122fc3b24cc043290799e60c6db15e789f6cf17872fa9515)
                check_type(argname="argument data_field_series_item", value=data_field_series_item, expected_type=type_hints["data_field_series_item"])
                check_type(argname="argument field_series_item", value=field_series_item, expected_type=type_hints["field_series_item"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_field_series_item is not None:
                self._values["data_field_series_item"] = data_field_series_item
            if field_series_item is not None:
                self._values["field_series_item"] = field_series_item

        @builtins.property
        def data_field_series_item(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataFieldSeriesItemProperty"]]:
            '''The data field series item configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-seriesitem.html#cfn-quicksight-template-seriesitem-datafieldseriesitem
            '''
            result = self._values.get("data_field_series_item")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataFieldSeriesItemProperty"]], result)

        @builtins.property
        def field_series_item(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSeriesItemProperty"]]:
            '''The field series item configuration of a line chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-seriesitem.html#cfn-quicksight-template-seriesitem-fieldseriesitem
            '''
            result = self._values.get("field_series_item")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSeriesItemProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SetParameterValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination_parameter_name": "destinationParameterName",
            "value": "value",
        },
    )
    class SetParameterValueConfigurationProperty:
        def __init__(
            self,
            *,
            destination_parameter_name: builtins.str,
            value: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DestinationParameterValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The configuration of adding parameters in action.

            :param destination_parameter_name: The destination parameter name of the ``SetParameterValueConfiguration`` .
            :param value: 

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-setparametervalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                set_parameter_value_configuration_property = quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                    destination_parameter_name="destinationParameterName",
                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                date_time_values=["dateTimeValues"],
                                decimal_values=[123],
                                integer_values=[123],
                                string_values=["stringValues"]
                            ),
                
                            # the properties below are optional
                            include_null_value=False
                        ),
                        select_all_value_options="selectAllValueOptions",
                        source_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        source_field="sourceField",
                        source_parameter_name="sourceParameterName"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__034463d50982832ccf6825757352509454b017d2493f262ce5689009916f43e8)
                check_type(argname="argument destination_parameter_name", value=destination_parameter_name, expected_type=type_hints["destination_parameter_name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "destination_parameter_name": destination_parameter_name,
                "value": value,
            }

        @builtins.property
        def destination_parameter_name(self) -> builtins.str:
            '''The destination parameter name of the ``SetParameterValueConfiguration`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-setparametervalueconfiguration.html#cfn-quicksight-template-setparametervalueconfiguration-destinationparametername
            '''
            result = self._values.get("destination_parameter_name")
            assert result is not None, "Required property 'destination_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.DestinationParameterValueConfigurationProperty"]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-setparametervalueconfiguration.html#cfn-quicksight-template-setparametervalueconfiguration-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.DestinationParameterValueConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SetParameterValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ShapeConditionalFormatProperty",
        jsii_struct_bases=[],
        name_mapping={"background_color": "backgroundColor"},
    )
    class ShapeConditionalFormatProperty:
        def __init__(
            self,
            *,
            background_color: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The shape conditional formatting of a filled map visual.

            :param background_color: The conditional formatting for the shape background color of a filled map visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shapeconditionalformat.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                shape_conditional_format_property = quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                    background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__34c6c10c5e3e0a20e7e9f04dd2ddcc33ce9bcce5ddddaf4435788da1ec64efb9)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "background_color": background_color,
            }

        @builtins.property
        def background_color(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"]:
            '''The conditional formatting for the shape background color of a filled map visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shapeconditionalformat.html#cfn-quicksight-template-shapeconditionalformat-backgroundcolor
            '''
            result = self._values.get("background_color")
            assert result is not None, "Required property 'background_color' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ShapeConditionalFormatProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"info_icon_text": "infoIconText", "visibility": "visibility"},
    )
    class SheetControlInfoIconLabelOptionsProperty:
        def __init__(
            self,
            *,
            info_icon_text: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display info icons for filters and parameters.

            :param info_icon_text: The text content of info icon.
            :param visibility: The visibility configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrolinfoiconlabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_control_info_icon_label_options_property = quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                    info_icon_text="infoIconText",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2ae88d5fea8298f0a719902b0f6021e6dad59cc5b8411d69e95be72c9ad5c726)
                check_type(argname="argument info_icon_text", value=info_icon_text, expected_type=type_hints["info_icon_text"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if info_icon_text is not None:
                self._values["info_icon_text"] = info_icon_text
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def info_icon_text(self) -> typing.Optional[builtins.str]:
            '''The text content of info icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrolinfoiconlabeloptions.html#cfn-quicksight-template-sheetcontrolinfoiconlabeloptions-infoicontext
            '''
            result = self._values.get("info_icon_text")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrolinfoiconlabeloptions.html#cfn-quicksight-template-sheetcontrolinfoiconlabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlInfoIconLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SheetControlLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"grid_layout": "gridLayout"},
    )
    class SheetControlLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            grid_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :param grid_layout: The configuration that determines the elements and canvas size options of sheet control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrollayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_control_layout_configuration_property = quicksight.CfnTemplate.SheetControlLayoutConfigurationProperty(
                    grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                        elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                            column_span=123,
                            element_id="elementId",
                            element_type="elementType",
                            row_span=123,
                
                            # the properties below are optional
                            column_index=123,
                            row_index=123
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c9ec99a58e33bd9b37220b93a7ed75aa3d5e4ad1d68f36cd2a575a89974d900d)
                check_type(argname="argument grid_layout", value=grid_layout, expected_type=type_hints["grid_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if grid_layout is not None:
                self._values["grid_layout"] = grid_layout

        @builtins.property
        def grid_layout(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GridLayoutConfigurationProperty"]]:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrollayoutconfiguration.html#cfn-quicksight-template-sheetcontrollayoutconfiguration-gridlayout
            '''
            result = self._values.get("grid_layout")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GridLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SheetControlLayoutProperty",
        jsii_struct_bases=[],
        name_mapping={"configuration": "configuration"},
    )
    class SheetControlLayoutProperty:
        def __init__(
            self,
            *,
            configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SheetControlLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''A grid layout to define the placement of sheet control.

            :param configuration: The configuration that determines the elements and canvas size options of sheet control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrollayout.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_control_layout_property = quicksight.CfnTemplate.SheetControlLayoutProperty(
                    configuration=quicksight.CfnTemplate.SheetControlLayoutConfigurationProperty(
                        grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                            elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                column_span=123,
                                element_id="elementId",
                                element_type="elementType",
                                row_span=123,
                
                                # the properties below are optional
                                column_index=123,
                                row_index=123
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aaaac5ff5ebdc4bf0b37374bb4f4c95c0de18091f8c90146a8d801a536f0c870)
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration": configuration,
            }

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetControlLayoutConfigurationProperty"]:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrollayout.html#cfn-quicksight-template-sheetcontrollayout-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetControlLayoutConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlLayoutProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SheetDefinitionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sheet_id": "sheetId",
            "content_type": "contentType",
            "description": "description",
            "filter_controls": "filterControls",
            "layouts": "layouts",
            "name": "name",
            "parameter_controls": "parameterControls",
            "sheet_control_layouts": "sheetControlLayouts",
            "text_boxes": "textBoxes",
            "title": "title",
            "visuals": "visuals",
        },
    )
    class SheetDefinitionProperty:
        def __init__(
            self,
            *,
            sheet_id: builtins.str,
            content_type: typing.Optional[builtins.str] = None,
            description: typing.Optional[builtins.str] = None,
            filter_controls: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilterControlProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            layouts: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LayoutProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            name: typing.Optional[builtins.str] = None,
            parameter_controls: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ParameterControlProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sheet_control_layouts: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SheetControlLayoutProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            text_boxes: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SheetTextBoxProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            title: typing.Optional[builtins.str] = None,
            visuals: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''A sheet is an object that contains a set of visuals that are viewed together on one page in a paginated report.

            Every analysis and dashboard must contain at least one sheet.

            :param sheet_id: The unique identifier of a sheet.
            :param content_type: The layout content type of the sheet. Choose one of the following options:. - ``PAGINATED`` : Creates a sheet for a paginated report. - ``INTERACTIVE`` : Creates a sheet for an interactive dashboard.
            :param description: A description of the sheet.
            :param filter_controls: The list of filter controls that are on a sheet. For more information, see `Adding filter controls to analysis sheets <https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html>`_ in the *Amazon QuickSight User Guide* .
            :param layouts: Layouts define how the components of a sheet are arranged. For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .
            :param name: The name of the sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
            :param parameter_controls: The list of parameter controls that are on a sheet. For more information, see `Using a Control with a Parameter in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html>`_ in the *Amazon QuickSight User Guide* .
            :param sheet_control_layouts: The control layouts of the sheet.
            :param text_boxes: The text boxes that are on a sheet.
            :param title: The title of the sheet.
            :param visuals: A list of the visuals that are on a sheet. Visual placement is determined by the layout of the sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c3313b0e171ff99a25b9ac017fb854e9c54356e9a7a0634c13fbdd9a3cdf4102)
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
                check_type(argname="argument content_type", value=content_type, expected_type=type_hints["content_type"])
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
                check_type(argname="argument filter_controls", value=filter_controls, expected_type=type_hints["filter_controls"])
                check_type(argname="argument layouts", value=layouts, expected_type=type_hints["layouts"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_controls", value=parameter_controls, expected_type=type_hints["parameter_controls"])
                check_type(argname="argument sheet_control_layouts", value=sheet_control_layouts, expected_type=type_hints["sheet_control_layouts"])
                check_type(argname="argument text_boxes", value=text_boxes, expected_type=type_hints["text_boxes"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument visuals", value=visuals, expected_type=type_hints["visuals"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "sheet_id": sheet_id,
            }
            if content_type is not None:
                self._values["content_type"] = content_type
            if description is not None:
                self._values["description"] = description
            if filter_controls is not None:
                self._values["filter_controls"] = filter_controls
            if layouts is not None:
                self._values["layouts"] = layouts
            if name is not None:
                self._values["name"] = name
            if parameter_controls is not None:
                self._values["parameter_controls"] = parameter_controls
            if sheet_control_layouts is not None:
                self._values["sheet_control_layouts"] = sheet_control_layouts
            if text_boxes is not None:
                self._values["text_boxes"] = text_boxes
            if title is not None:
                self._values["title"] = title
            if visuals is not None:
                self._values["visuals"] = visuals

        @builtins.property
        def sheet_id(self) -> builtins.str:
            '''The unique identifier of a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-sheetid
            '''
            result = self._values.get("sheet_id")
            assert result is not None, "Required property 'sheet_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def content_type(self) -> typing.Optional[builtins.str]:
            '''The layout content type of the sheet. Choose one of the following options:.

            - ``PAGINATED`` : Creates a sheet for a paginated report.
            - ``INTERACTIVE`` : Creates a sheet for an interactive dashboard.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-contenttype
            '''
            result = self._values.get("content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''A description of the sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def filter_controls(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterControlProperty"]]]]:
            '''The list of filter controls that are on a sheet.

            For more information, see `Adding filter controls to analysis sheets <https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-filtercontrols
            '''
            result = self._values.get("filter_controls")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterControlProperty"]]]], result)

        @builtins.property
        def layouts(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LayoutProperty"]]]]:
            '''Layouts define how the components of a sheet are arranged.

            For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-layouts
            '''
            result = self._values.get("layouts")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LayoutProperty"]]]], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of the sheet.

            This name is displayed on the sheet's tab in the Amazon QuickSight console.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_controls(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ParameterControlProperty"]]]]:
            '''The list of parameter controls that are on a sheet.

            For more information, see `Using a Control with a Parameter in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-parametercontrols
            '''
            result = self._values.get("parameter_controls")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ParameterControlProperty"]]]], result)

        @builtins.property
        def sheet_control_layouts(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetControlLayoutProperty"]]]]:
            '''The control layouts of the sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-sheetcontrollayouts
            '''
            result = self._values.get("sheet_control_layouts")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetControlLayoutProperty"]]]], result)

        @builtins.property
        def text_boxes(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetTextBoxProperty"]]]]:
            '''The text boxes that are on a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-textboxes
            '''
            result = self._values.get("text_boxes")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetTextBoxProperty"]]]], result)

        @builtins.property
        def title(self) -> typing.Optional[builtins.str]:
            '''The title of the sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visuals(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualProperty"]]]]:
            '''A list of the visuals that are on a sheet.

            Visual placement is determined by the layout of the sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-visuals
            '''
            result = self._values.get("visuals")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetDefinitionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class SheetElementConfigurationOverridesProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The override configuration of the rendering rules of a sheet.

            :param visibility: Determines whether or not the overrides are visible. Choose one of the following options:. - ``VISIBLE`` - ``HIDDEN``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementconfigurationoverrides.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_element_configuration_overrides_property = quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6ed1f65dff6275ad4cb009a9fd7432d542c83e61fb75e3c9c4ec1e00b1ba2a81)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the overrides are visible. Choose one of the following options:.

            - ``VISIBLE``
            - ``HIDDEN``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementconfigurationoverrides.html#cfn-quicksight-template-sheetelementconfigurationoverrides-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetElementConfigurationOverridesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SheetElementRenderingRuleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "configuration_overrides": "configurationOverrides",
            "expression": "expression",
        },
    )
    class SheetElementRenderingRuleProperty:
        def __init__(
            self,
            *,
            configuration_overrides: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SheetElementConfigurationOverridesProperty", typing.Dict[builtins.str, typing.Any]]],
            expression: builtins.str,
        ) -> None:
            '''The rendering rules of a sheet that uses a free-form layout.

            :param configuration_overrides: The override configuration of the rendering rules of a sheet.
            :param expression: The expression of the rendering rules of a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementrenderingrule.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_element_rendering_rule_property = quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                        visibility="visibility"
                    ),
                    expression="expression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__edfd223307d1b10f72a1e801ddedce4a7b4b235b74b97c41d72e52fbc6309c62)
                check_type(argname="argument configuration_overrides", value=configuration_overrides, expected_type=type_hints["configuration_overrides"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration_overrides": configuration_overrides,
                "expression": expression,
            }

        @builtins.property
        def configuration_overrides(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetElementConfigurationOverridesProperty"]:
            '''The override configuration of the rendering rules of a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementrenderingrule.html#cfn-quicksight-template-sheetelementrenderingrule-configurationoverrides
            '''
            result = self._values.get("configuration_overrides")
            assert result is not None, "Required property 'configuration_overrides' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetElementConfigurationOverridesProperty"], result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the rendering rules of a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementrenderingrule.html#cfn-quicksight-template-sheetelementrenderingrule-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetElementRenderingRuleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SheetProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "sheet_id": "sheetId"},
    )
    class SheetProperty:
        def __init__(
            self,
            *,
            name: typing.Optional[builtins.str] = None,
            sheet_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A *sheet* , which is an object that contains a set of visuals that are viewed together on one page in Amazon QuickSight.

            Every analysis and dashboard contains at least one sheet. Each sheet contains at least one visualization widget, for example a chart, pivot table, or narrative insight. Sheets can be associated with other components, such as controls, filters, and so on.

            :param name: The name of a sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
            :param sheet_id: The unique identifier associated with a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheet.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_property = quicksight.CfnTemplate.SheetProperty(
                    name="name",
                    sheet_id="sheetId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6df9b86d781b54d6d5a62373d1345c592393c94d85fdb7b8cbfaf9bad004e072)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if name is not None:
                self._values["name"] = name
            if sheet_id is not None:
                self._values["sheet_id"] = sheet_id

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a sheet.

            This name is displayed on the sheet's tab in the Amazon QuickSight console.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheet.html#cfn-quicksight-template-sheet-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sheet_id(self) -> typing.Optional[builtins.str]:
            '''The unique identifier associated with a sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheet.html#cfn-quicksight-template-sheet-sheetid
            '''
            result = self._values.get("sheet_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SheetTextBoxProperty",
        jsii_struct_bases=[],
        name_mapping={"sheet_text_box_id": "sheetTextBoxId", "content": "content"},
    )
    class SheetTextBoxProperty:
        def __init__(
            self,
            *,
            sheet_text_box_id: builtins.str,
            content: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A text box.

            :param sheet_text_box_id: The unique identifier for a text box. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.
            :param content: The content that is displayed in the text box.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheettextbox.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_text_box_property = quicksight.CfnTemplate.SheetTextBoxProperty(
                    sheet_text_box_id="sheetTextBoxId",
                
                    # the properties below are optional
                    content="content"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c9b83b0fa0f3bbeb8b8bb8cb25987a9de88b749ef27c4f94c0eeed905842d767)
                check_type(argname="argument sheet_text_box_id", value=sheet_text_box_id, expected_type=type_hints["sheet_text_box_id"])
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "sheet_text_box_id": sheet_text_box_id,
            }
            if content is not None:
                self._values["content"] = content

        @builtins.property
        def sheet_text_box_id(self) -> builtins.str:
            '''The unique identifier for a text box.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheettextbox.html#cfn-quicksight-template-sheettextbox-sheettextboxid
            '''
            result = self._values.get("sheet_text_box_id")
            assert result is not None, "Required property 'sheet_text_box_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def content(self) -> typing.Optional[builtins.str]:
            '''The content that is displayed in the text box.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheettextbox.html#cfn-quicksight-template-sheettextbox-content
            '''
            result = self._values.get("content")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetTextBoxProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SheetVisualScopingConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "scope": "scope",
            "sheet_id": "sheetId",
            "visual_ids": "visualIds",
        },
    )
    class SheetVisualScopingConfigurationProperty:
        def __init__(
            self,
            *,
            scope: builtins.str,
            sheet_id: builtins.str,
            visual_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The filter that is applied to the options.

            :param scope: The scope of the applied entities. Choose one of the following options:. - ``ALL_VISUALS`` - ``SELECTED_VISUALS``
            :param sheet_id: The selected sheet that the filter is applied to.
            :param visual_ids: The selected visuals that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetvisualscopingconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_visual_scoping_configuration_property = quicksight.CfnTemplate.SheetVisualScopingConfigurationProperty(
                    scope="scope",
                    sheet_id="sheetId",
                
                    # the properties below are optional
                    visual_ids=["visualIds"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__296ed0698acc06e604e3df4f98123b4a27cf35e5a1da56a14e80d1aa42094f8e)
                check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
                check_type(argname="argument visual_ids", value=visual_ids, expected_type=type_hints["visual_ids"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "scope": scope,
                "sheet_id": sheet_id,
            }
            if visual_ids is not None:
                self._values["visual_ids"] = visual_ids

        @builtins.property
        def scope(self) -> builtins.str:
            '''The scope of the applied entities. Choose one of the following options:.

            - ``ALL_VISUALS``
            - ``SELECTED_VISUALS``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetvisualscopingconfiguration.html#cfn-quicksight-template-sheetvisualscopingconfiguration-scope
            '''
            result = self._values.get("scope")
            assert result is not None, "Required property 'scope' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sheet_id(self) -> builtins.str:
            '''The selected sheet that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetvisualscopingconfiguration.html#cfn-quicksight-template-sheetvisualscopingconfiguration-sheetid
            '''
            result = self._values.get("sheet_id")
            assert result is not None, "Required property 'sheet_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_ids(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The selected visuals that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetvisualscopingconfiguration.html#cfn-quicksight-template-sheetvisualscopingconfiguration-visualids
            '''
            result = self._values.get("visual_ids")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetVisualScopingConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ShortFormatTextProperty",
        jsii_struct_bases=[],
        name_mapping={"plain_text": "plainText", "rich_text": "richText"},
    )
    class ShortFormatTextProperty:
        def __init__(
            self,
            *,
            plain_text: typing.Optional[builtins.str] = None,
            rich_text: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The text format for the title.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param plain_text: Plain text format.
            :param rich_text: Rich text. Examples of rich text include bold, underline, and italics.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shortformattext.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                short_format_text_property = quicksight.CfnTemplate.ShortFormatTextProperty(
                    plain_text="plainText",
                    rich_text="richText"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5bb36f4dc8887a2f1b11dbd613818886546e0a9a0e0ac28df0a483c056326983)
                check_type(argname="argument plain_text", value=plain_text, expected_type=type_hints["plain_text"])
                check_type(argname="argument rich_text", value=rich_text, expected_type=type_hints["rich_text"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if plain_text is not None:
                self._values["plain_text"] = plain_text
            if rich_text is not None:
                self._values["rich_text"] = rich_text

        @builtins.property
        def plain_text(self) -> typing.Optional[builtins.str]:
            '''Plain text format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shortformattext.html#cfn-quicksight-template-shortformattext-plaintext
            '''
            result = self._values.get("plain_text")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rich_text(self) -> typing.Optional[builtins.str]:
            '''Rich text.

            Examples of rich text include bold, underline, and italics.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shortformattext.html#cfn-quicksight-template-shortformattext-richtext
            '''
            result = self._values.get("rich_text")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ShortFormatTextProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SimpleClusterMarkerProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color"},
    )
    class SimpleClusterMarkerProperty:
        def __init__(self, *, color: typing.Optional[builtins.str] = None) -> None:
            '''The simple cluster marker of the cluster marker.

            :param color: The color of the simple cluster marker.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-simpleclustermarker.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                simple_cluster_marker_property = quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                    color="color"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f980a5ef17fbfcec69f5d6a4e065d2bf7bd9d99c1982054307ca27101bd0d4dc)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color of the simple cluster marker.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-simpleclustermarker.html#cfn-quicksight-template-simpleclustermarker-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SimpleClusterMarkerProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SliderControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "info_icon_label_options": "infoIconLabelOptions",
            "title_options": "titleOptions",
        },
    )
    class SliderControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SheetControlInfoIconLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param info_icon_label_options: The configuration of info icon label options.
            :param title_options: The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-slidercontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                slider_control_display_options_property = quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                    info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                        info_icon_text="infoIconText",
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0a7c7b522b4a45f40e638d2984c0d7a3e0bb412595353b539c1ca5b0ca4ee15f)
                check_type(argname="argument info_icon_label_options", value=info_icon_label_options, expected_type=type_hints["info_icon_label_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if info_icon_label_options is not None:
                self._values["info_icon_label_options"] = info_icon_label_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def info_icon_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetControlInfoIconLabelOptionsProperty"]]:
            '''The configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-slidercontroldisplayoptions.html#cfn-quicksight-template-slidercontroldisplayoptions-infoiconlabeloptions
            '''
            result = self._values.get("info_icon_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetControlInfoIconLabelOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-slidercontroldisplayoptions.html#cfn-quicksight-template-slidercontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SliderControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SmallMultiplesAxisPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={"placement": "placement", "scale": "scale"},
    )
    class SmallMultiplesAxisPropertiesProperty:
        def __init__(
            self,
            *,
            placement: typing.Optional[builtins.str] = None,
            scale: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Configures the properties of a chart's axes that are used by small multiples panels.

            :param placement: Defines the placement of the axis. By default, axes are rendered ``OUTSIDE`` of the panels. Axes with ``INDEPENDENT`` scale are rendered ``INSIDE`` the panels.
            :param scale: Determines whether scale of the axes are shared or independent. The default value is ``SHARED`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesaxisproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                small_multiples_axis_properties_property = quicksight.CfnTemplate.SmallMultiplesAxisPropertiesProperty(
                    placement="placement",
                    scale="scale"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d7374f243a60a5ee5bac2c475f2e77ad74a7148487962df0214189de2d3a0ccf)
                check_type(argname="argument placement", value=placement, expected_type=type_hints["placement"])
                check_type(argname="argument scale", value=scale, expected_type=type_hints["scale"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if placement is not None:
                self._values["placement"] = placement
            if scale is not None:
                self._values["scale"] = scale

        @builtins.property
        def placement(self) -> typing.Optional[builtins.str]:
            '''Defines the placement of the axis.

            By default, axes are rendered ``OUTSIDE`` of the panels. Axes with ``INDEPENDENT`` scale are rendered ``INSIDE`` the panels.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesaxisproperties.html#cfn-quicksight-template-smallmultiplesaxisproperties-placement
            '''
            result = self._values.get("placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scale(self) -> typing.Optional[builtins.str]:
            '''Determines whether scale of the axes are shared or independent.

            The default value is ``SHARED`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesaxisproperties.html#cfn-quicksight-template-smallmultiplesaxisproperties-scale
            '''
            result = self._values.get("scale")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SmallMultiplesAxisPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SmallMultiplesOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "max_visible_columns": "maxVisibleColumns",
            "max_visible_rows": "maxVisibleRows",
            "panel_configuration": "panelConfiguration",
            "x_axis": "xAxis",
            "y_axis": "yAxis",
        },
    )
    class SmallMultiplesOptionsProperty:
        def __init__(
            self,
            *,
            max_visible_columns: typing.Optional[jsii.Number] = None,
            max_visible_rows: typing.Optional[jsii.Number] = None,
            panel_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PanelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SmallMultiplesAxisPropertiesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            y_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SmallMultiplesAxisPropertiesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Options that determine the layout and display options of a chart's small multiples.

            :param max_visible_columns: Sets the maximum number of visible columns to display in the grid of small multiples panels. The default is ``Auto`` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.
            :param max_visible_rows: Sets the maximum number of visible rows to display in the grid of small multiples panels. The default value is ``Auto`` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.
            :param panel_configuration: Configures the display options for each small multiples panel.
            :param x_axis: The properties of a small multiples X axis.
            :param y_axis: The properties of a small multiples Y axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                small_multiples_options_property = quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                    max_visible_columns=123,
                    max_visible_rows=123,
                    panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                        background_color="backgroundColor",
                        background_visibility="backgroundVisibility",
                        border_color="borderColor",
                        border_style="borderStyle",
                        border_thickness="borderThickness",
                        border_visibility="borderVisibility",
                        gutter_spacing="gutterSpacing",
                        gutter_visibility="gutterVisibility",
                        title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_text_alignment="horizontalTextAlignment",
                            visibility="visibility"
                        )
                    ),
                    x_axis=quicksight.CfnTemplate.SmallMultiplesAxisPropertiesProperty(
                        placement="placement",
                        scale="scale"
                    ),
                    y_axis=quicksight.CfnTemplate.SmallMultiplesAxisPropertiesProperty(
                        placement="placement",
                        scale="scale"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d922fb4c3c198cbe3fd5d6044cdd8fbd7f8a975e5055d9c32a66ea8c4c242ffa)
                check_type(argname="argument max_visible_columns", value=max_visible_columns, expected_type=type_hints["max_visible_columns"])
                check_type(argname="argument max_visible_rows", value=max_visible_rows, expected_type=type_hints["max_visible_rows"])
                check_type(argname="argument panel_configuration", value=panel_configuration, expected_type=type_hints["panel_configuration"])
                check_type(argname="argument x_axis", value=x_axis, expected_type=type_hints["x_axis"])
                check_type(argname="argument y_axis", value=y_axis, expected_type=type_hints["y_axis"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if max_visible_columns is not None:
                self._values["max_visible_columns"] = max_visible_columns
            if max_visible_rows is not None:
                self._values["max_visible_rows"] = max_visible_rows
            if panel_configuration is not None:
                self._values["panel_configuration"] = panel_configuration
            if x_axis is not None:
                self._values["x_axis"] = x_axis
            if y_axis is not None:
                self._values["y_axis"] = y_axis

        @builtins.property
        def max_visible_columns(self) -> typing.Optional[jsii.Number]:
            '''Sets the maximum number of visible columns to display in the grid of small multiples panels.

            The default is ``Auto`` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html#cfn-quicksight-template-smallmultiplesoptions-maxvisiblecolumns
            '''
            result = self._values.get("max_visible_columns")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def max_visible_rows(self) -> typing.Optional[jsii.Number]:
            '''Sets the maximum number of visible rows to display in the grid of small multiples panels.

            The default value is ``Auto`` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html#cfn-quicksight-template-smallmultiplesoptions-maxvisiblerows
            '''
            result = self._values.get("max_visible_rows")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def panel_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PanelConfigurationProperty"]]:
            '''Configures the display options for each small multiples panel.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html#cfn-quicksight-template-smallmultiplesoptions-panelconfiguration
            '''
            result = self._values.get("panel_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PanelConfigurationProperty"]], result)

        @builtins.property
        def x_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SmallMultiplesAxisPropertiesProperty"]]:
            '''The properties of a small multiples X axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html#cfn-quicksight-template-smallmultiplesoptions-xaxis
            '''
            result = self._values.get("x_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SmallMultiplesAxisPropertiesProperty"]], result)

        @builtins.property
        def y_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SmallMultiplesAxisPropertiesProperty"]]:
            '''The properties of a small multiples Y axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html#cfn-quicksight-template-smallmultiplesoptions-yaxis
            '''
            result = self._values.get("y_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SmallMultiplesAxisPropertiesProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SmallMultiplesOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SpacingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bottom": "bottom",
            "left": "left",
            "right": "right",
            "top": "top",
        },
    )
    class SpacingProperty:
        def __init__(
            self,
            *,
            bottom: typing.Optional[builtins.str] = None,
            left: typing.Optional[builtins.str] = None,
            right: typing.Optional[builtins.str] = None,
            top: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of spacing (often a margin or padding).

            :param bottom: Define the bottom spacing.
            :param left: Define the left spacing.
            :param right: Define the right spacing.
            :param top: Define the top spacing.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                spacing_property = quicksight.CfnTemplate.SpacingProperty(
                    bottom="bottom",
                    left="left",
                    right="right",
                    top="top"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fb46ceb73d3a6b2d9198e936558664a2b60d7e30b7aba7e01b77f71e23cc96af)
                check_type(argname="argument bottom", value=bottom, expected_type=type_hints["bottom"])
                check_type(argname="argument left", value=left, expected_type=type_hints["left"])
                check_type(argname="argument right", value=right, expected_type=type_hints["right"])
                check_type(argname="argument top", value=top, expected_type=type_hints["top"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bottom is not None:
                self._values["bottom"] = bottom
            if left is not None:
                self._values["left"] = left
            if right is not None:
                self._values["right"] = right
            if top is not None:
                self._values["top"] = top

        @builtins.property
        def bottom(self) -> typing.Optional[builtins.str]:
            '''Define the bottom spacing.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html#cfn-quicksight-template-spacing-bottom
            '''
            result = self._values.get("bottom")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def left(self) -> typing.Optional[builtins.str]:
            '''Define the left spacing.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html#cfn-quicksight-template-spacing-left
            '''
            result = self._values.get("left")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def right(self) -> typing.Optional[builtins.str]:
            '''Define the right spacing.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html#cfn-quicksight-template-spacing-right
            '''
            result = self._values.get("right")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def top(self) -> typing.Optional[builtins.str]:
            '''Define the top spacing.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html#cfn-quicksight-template-spacing-top
            '''
            result = self._values.get("top")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SpacingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.StringDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class StringDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The default values of the ``StringParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``StringDefaultValues`` . Different defaults displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``DecimalDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                string_default_values_property = quicksight.CfnTemplate.StringDefaultValuesProperty(
                    dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=["staticValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cabefb15919c8ee02103755c5a017477d19667a351a29b3b267d047452ec8102)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``StringDefaultValues`` .

            Different defaults displayed according to users, groups, and values mapping.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringdefaultvalues.html#cfn-quicksight-template-stringdefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The static values of the ``DecimalDefaultValues`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringdefaultvalues.html#cfn-quicksight-template-stringdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.StringFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "numeric_format_configuration": "numericFormatConfiguration",
        },
    )
    class StringFormatConfigurationProperty:
        def __init__(
            self,
            *,
            null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Formatting configuration for string fields.

            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param numeric_format_configuration: The formatting configuration for numeric strings.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                string_format_configuration_property = quicksight.CfnTemplate.StringFormatConfigurationProperty(
                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__49861957d453963c2eca90276acc8ba15f9b268877dc2a273da6d00d996395d2)
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument numeric_format_configuration", value=numeric_format_configuration, expected_type=type_hints["numeric_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if numeric_format_configuration is not None:
                self._values["numeric_format_configuration"] = numeric_format_configuration

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringformatconfiguration.html#cfn-quicksight-template-stringformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def numeric_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericFormatConfigurationProperty"]]:
            '''The formatting configuration for numeric strings.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringformatconfiguration.html#cfn-quicksight-template-stringformatconfiguration-numericformatconfiguration
            '''
            result = self._values.get("numeric_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.NumericFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.StringParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class StringParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.StringDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.StringValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``String`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: 
            :param value_when_unset: The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                string_parameter_declaration_property = quicksight.CfnTemplate.StringParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnTemplate.StringDefaultValuesProperty(
                        dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=["staticValues"]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnTemplate.StringValueWhenUnsetConfigurationProperty(
                        custom_value="customValue",
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fe8646d53ea6c4deb3b1e7d298342695f471d38be987914d361e12b4e39d86d3)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.StringDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.StringDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MappedDataSetParameterProperty"]]]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.StringValueWhenUnsetConfigurationProperty"]]:
            '''The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.StringValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.StringValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class StringValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[builtins.str] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringvaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                string_value_when_unset_configuration_property = quicksight.CfnTemplate.StringValueWhenUnsetConfigurationProperty(
                    custom_value="customValue",
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__22b81d54727c77a339eb4d008d5c483ae06b25abdcb20befff536eba1ee3735b)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[builtins.str]:
            '''A custom value that's used when the value of a parameter isn't set.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringvaluewhenunsetconfiguration.html#cfn-quicksight-template-stringvaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringvaluewhenunsetconfiguration.html#cfn-quicksight-template-stringvaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.SubtotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "field_level": "fieldLevel",
            "field_level_options": "fieldLevelOptions",
            "metric_header_cell_style": "metricHeaderCellStyle",
            "style_targets": "styleTargets",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
            "value_cell_style": "valueCellStyle",
        },
    )
    class SubtotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            field_level: typing.Optional[builtins.str] = None,
            field_level_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTableFieldSubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            metric_header_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            style_targets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableStyleTargetProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            total_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
            value_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The subtotal options.

            :param custom_label: The custom label string for the subtotal cells.
            :param field_level: The field level (all, custom, last) for the subtotal cells.
            :param field_level_options: The optional configuration of subtotal cells.
            :param metric_header_cell_style: The cell styling options for the subtotals of header cells.
            :param style_targets: The style targets options for subtotals.
            :param total_cell_style: The cell styling options for the subtotal cells.
            :param totals_visibility: The visibility configuration for the subtotal cells.
            :param value_cell_style: The cell styling options for the subtotals of value cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                subtotal_options_property = quicksight.CfnTemplate.SubtotalOptionsProperty(
                    custom_label="customLabel",
                    field_level="fieldLevel",
                    field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                        field_id="fieldId"
                    )],
                    metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    style_targets=[quicksight.CfnTemplate.TableStyleTargetProperty(
                        cell_type="cellType"
                    )],
                    total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility",
                    value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__835884f6f4c1d755581fd9bdc65529e47e3d99fd69106dc8e604086a4b07daa6)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument field_level", value=field_level, expected_type=type_hints["field_level"])
                check_type(argname="argument field_level_options", value=field_level_options, expected_type=type_hints["field_level_options"])
                check_type(argname="argument metric_header_cell_style", value=metric_header_cell_style, expected_type=type_hints["metric_header_cell_style"])
                check_type(argname="argument style_targets", value=style_targets, expected_type=type_hints["style_targets"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
                check_type(argname="argument value_cell_style", value=value_cell_style, expected_type=type_hints["value_cell_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if field_level is not None:
                self._values["field_level"] = field_level
            if field_level_options is not None:
                self._values["field_level_options"] = field_level_options
            if metric_header_cell_style is not None:
                self._values["metric_header_cell_style"] = metric_header_cell_style
            if style_targets is not None:
                self._values["style_targets"] = style_targets
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility
            if value_cell_style is not None:
                self._values["value_cell_style"] = value_cell_style

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the subtotal cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_level(self) -> typing.Optional[builtins.str]:
            '''The field level (all, custom, last) for the subtotal cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-fieldlevel
            '''
            result = self._values.get("field_level")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_level_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableFieldSubtotalOptionsProperty"]]]]:
            '''The optional configuration of subtotal cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-fieldleveloptions
            '''
            result = self._values.get("field_level_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableFieldSubtotalOptionsProperty"]]]], result)

        @builtins.property
        def metric_header_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]]:
            '''The cell styling options for the subtotals of header cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-metricheadercellstyle
            '''
            result = self._values.get("metric_header_cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def style_targets(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableStyleTargetProperty"]]]]:
            '''The style targets options for subtotals.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-styletargets
            '''
            result = self._values.get("style_targets")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableStyleTargetProperty"]]]], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]]:
            '''The cell styling options for the subtotal cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the subtotal cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]]:
            '''The cell styling options for the subtotals of value cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-valuecellstyle
            '''
            result = self._values.get("value_cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SubtotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "values": "values"},
    )
    class TableAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well for the table.

            :param group_by: The group by field well for a pivot table. Values are grouped by group by fields.
            :param values: The values field well for a pivot table. Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_aggregated_field_wells_property = quicksight.CfnTemplate.TableAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2caf71a40f9c72ee8a7c06fd6e2c10a5f9ef4571000fe3c2ae6b37afca04c803)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The group by field well for a pivot table.

            Values are grouped by group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableaggregatedfieldwells.html#cfn-quicksight-template-tableaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The values field well for a pivot table.

            Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableaggregatedfieldwells.html#cfn-quicksight-template-tableaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "style": "style", "thickness": "thickness"},
    )
    class TableBorderOptionsProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            style: typing.Optional[builtins.str] = None,
            thickness: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The border options for a table border.

            :param color: The color of a table border.
            :param style: The style (none, solid) of a table border.
            :param thickness: The thickness of a table border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_border_options_property = quicksight.CfnTemplate.TableBorderOptionsProperty(
                    color="color",
                    style="style",
                    thickness=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__48fec0f69acb2e5339f552b662a39b4d5bd8b376097bab6d917a82e94ce1d8b0)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
                check_type(argname="argument thickness", value=thickness, expected_type=type_hints["thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if style is not None:
                self._values["style"] = style
            if thickness is not None:
                self._values["thickness"] = thickness

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color of a table border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableborderoptions.html#cfn-quicksight-template-tableborderoptions-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style(self) -> typing.Optional[builtins.str]:
            '''The style (none, solid) of a table border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableborderoptions.html#cfn-quicksight-template-tableborderoptions-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def thickness(self) -> typing.Optional[jsii.Number]:
            '''The thickness of a table border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableborderoptions.html#cfn-quicksight-template-tableborderoptions-thickness
            '''
            result = self._values.get("thickness")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableCellConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "text_format": "textFormat"},
    )
    class TableCellConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            text_format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TextConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cell conditional formatting option for a table.

            :param field_id: The field ID of the cell for conditional formatting.
            :param text_format: The text format of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_cell_conditional_formatting_property = quicksight.CfnTemplate.TableCellConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e6533f9a293da2b7b7fe3b874be774bdaca01b7cf111f0027e20294b13f92765)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument text_format", value=text_format, expected_type=type_hints["text_format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if text_format is not None:
                self._values["text_format"] = text_format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellconditionalformatting.html#cfn-quicksight-template-tablecellconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def text_format(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TextConditionalFormatProperty"]]:
            '''The text format of the cell for conditional formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellconditionalformatting.html#cfn-quicksight-template-tablecellconditionalformatting-textformat
            '''
            result = self._values.get("text_format")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TextConditionalFormatProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "table_cell_image_scaling_configuration": "tableCellImageScalingConfiguration",
        },
    )
    class TableCellImageSizingConfigurationProperty:
        def __init__(
            self,
            *,
            table_cell_image_scaling_configuration: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The sizing options for the table image configuration.

            :param table_cell_image_scaling_configuration: The cell scaling configuration of the sizing options for the table image configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellimagesizingconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_cell_image_sizing_configuration_property = quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e7d0b13a76f1aaf645209ca42a07ff53cb21f72c71d29f55fff8519ce7134e9e)
                check_type(argname="argument table_cell_image_scaling_configuration", value=table_cell_image_scaling_configuration, expected_type=type_hints["table_cell_image_scaling_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if table_cell_image_scaling_configuration is not None:
                self._values["table_cell_image_scaling_configuration"] = table_cell_image_scaling_configuration

        @builtins.property
        def table_cell_image_scaling_configuration(
            self,
        ) -> typing.Optional[builtins.str]:
            '''The cell scaling configuration of the sizing options for the table image configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellimagesizingconfiguration.html#cfn-quicksight-template-tablecellimagesizingconfiguration-tablecellimagescalingconfiguration
            '''
            result = self._values.get("table_cell_image_scaling_configuration")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellImageSizingConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableCellStyleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "border": "border",
            "font_configuration": "fontConfiguration",
            "height": "height",
            "horizontal_text_alignment": "horizontalTextAlignment",
            "text_wrap": "textWrap",
            "vertical_text_alignment": "verticalTextAlignment",
            "visibility": "visibility",
        },
    )
    class TableCellStyleProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[builtins.str] = None,
            border: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GlobalTableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            height: typing.Optional[jsii.Number] = None,
            horizontal_text_alignment: typing.Optional[builtins.str] = None,
            text_wrap: typing.Optional[builtins.str] = None,
            vertical_text_alignment: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The table cell style for a cell in pivot table or table visual.

            :param background_color: The background color for the table cells.
            :param border: The borders for the table cells.
            :param font_configuration: The font configuration of the table cells.
            :param height: The height color for the table cells.
            :param horizontal_text_alignment: The horizontal text alignment (left, center, right, auto) for the table cells.
            :param text_wrap: The text wrap (none, wrap) for the table cells.
            :param vertical_text_alignment: The vertical text alignment (top, middle, bottom) for the table cells.
            :param visibility: The visibility of the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_cell_style_property = quicksight.CfnTemplate.TableCellStyleProperty(
                    background_color="backgroundColor",
                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        )
                    ),
                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    height=123,
                    horizontal_text_alignment="horizontalTextAlignment",
                    text_wrap="textWrap",
                    vertical_text_alignment="verticalTextAlignment",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4efb4aa43b4a101c11102e25898dd6ad18500f86e682b74456292880d731a853)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument border", value=border, expected_type=type_hints["border"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument horizontal_text_alignment", value=horizontal_text_alignment, expected_type=type_hints["horizontal_text_alignment"])
                check_type(argname="argument text_wrap", value=text_wrap, expected_type=type_hints["text_wrap"])
                check_type(argname="argument vertical_text_alignment", value=vertical_text_alignment, expected_type=type_hints["vertical_text_alignment"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if border is not None:
                self._values["border"] = border
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if height is not None:
                self._values["height"] = height
            if horizontal_text_alignment is not None:
                self._values["horizontal_text_alignment"] = horizontal_text_alignment
            if text_wrap is not None:
                self._values["text_wrap"] = text_wrap
            if vertical_text_alignment is not None:
                self._values["vertical_text_alignment"] = vertical_text_alignment
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def background_color(self) -> typing.Optional[builtins.str]:
            '''The background color for the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GlobalTableBorderOptionsProperty"]]:
            '''The borders for the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-border
            '''
            result = self._values.get("border")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GlobalTableBorderOptionsProperty"]], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"]]:
            '''The font configuration of the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"]], result)

        @builtins.property
        def height(self) -> typing.Optional[jsii.Number]:
            '''The height color for the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def horizontal_text_alignment(self) -> typing.Optional[builtins.str]:
            '''The horizontal text alignment (left, center, right, auto) for the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-horizontaltextalignment
            '''
            result = self._values.get("horizontal_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def text_wrap(self) -> typing.Optional[builtins.str]:
            '''The text wrap (none, wrap) for the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-textwrap
            '''
            result = self._values.get("text_wrap")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_text_alignment(self) -> typing.Optional[builtins.str]:
            '''The vertical text alignment (top, middle, bottom) for the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-verticaltextalignment
            '''
            result = self._values.get("vertical_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"cell": "cell", "row": "row"},
    )
    class TableConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            cell: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableCellConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableRowConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :param cell: The cell conditional formatting option for a table.
            :param row: The row conditional formatting option for a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_conditional_formatting_option_property = quicksight.CfnTemplate.TableConditionalFormattingOptionProperty(
                    cell=quicksight.CfnTemplate.TableCellConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    ),
                    row=quicksight.CfnTemplate.TableRowConditionalFormattingProperty(
                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__06365328764f7ef94fe9f0f304f6cf93d96ea0bffa6303928547d170bc09f445)
                check_type(argname="argument cell", value=cell, expected_type=type_hints["cell"])
                check_type(argname="argument row", value=row, expected_type=type_hints["row"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell is not None:
                self._values["cell"] = cell
            if row is not None:
                self._values["row"] = row

        @builtins.property
        def cell(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellConditionalFormattingProperty"]]:
            '''The cell conditional formatting option for a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformattingoption.html#cfn-quicksight-template-tableconditionalformattingoption-cell
            '''
            result = self._values.get("cell")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellConditionalFormattingProperty"]], result)

        @builtins.property
        def row(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableRowConditionalFormattingProperty"]]:
            '''The row conditional formatting option for a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformattingoption.html#cfn-quicksight-template-tableconditionalformattingoption-row
            '''
            result = self._values.get("row")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableRowConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class TableConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :param conditional_formatting_options: Conditional formatting options for a ``PivotTableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_conditional_formatting_property = quicksight.CfnTemplate.TableConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnTemplate.TableConditionalFormattingOptionProperty(
                        cell=quicksight.CfnTemplate.TableCellConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        ),
                        row=quicksight.CfnTemplate.TableRowConditionalFormattingProperty(
                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e7636513daad776039befdfc20d7d5d664e1e53c61dca3af43bbffdd81b0a46e)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableConditionalFormattingOptionProperty"]]]]:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformatting.html#cfn-quicksight-template-tableconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_options": "fieldOptions",
            "field_wells": "fieldWells",
            "paginated_report_options": "paginatedReportOptions",
            "sort_configuration": "sortConfiguration",
            "table_inline_visualizations": "tableInlineVisualizations",
            "table_options": "tableOptions",
            "total_options": "totalOptions",
        },
    )
    class TableConfigurationProperty:
        def __init__(
            self,
            *,
            field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableFieldOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paginated_report_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TablePaginatedReportOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_inline_visualizations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableInlineVisualizationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            table_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``TableVisual`` .

            :param field_options: The field options for a table visual.
            :param field_wells: The field wells of the visual.
            :param paginated_report_options: The paginated report options for a table visual.
            :param sort_configuration: The sort configuration for a ``TableVisual`` .
            :param table_inline_visualizations: A collection of inline visualizations to display within a chart.
            :param table_options: The table options for a table visual.
            :param total_options: The total options for a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__78e6e21c76adbe4208f10f052675a816389a108f79b0f9e3970324b3daadda06)
                check_type(argname="argument field_options", value=field_options, expected_type=type_hints["field_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument paginated_report_options", value=paginated_report_options, expected_type=type_hints["paginated_report_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument table_inline_visualizations", value=table_inline_visualizations, expected_type=type_hints["table_inline_visualizations"])
                check_type(argname="argument table_options", value=table_options, expected_type=type_hints["table_options"])
                check_type(argname="argument total_options", value=total_options, expected_type=type_hints["total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_options is not None:
                self._values["field_options"] = field_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if paginated_report_options is not None:
                self._values["paginated_report_options"] = paginated_report_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if table_inline_visualizations is not None:
                self._values["table_inline_visualizations"] = table_inline_visualizations
            if table_options is not None:
                self._values["table_options"] = table_options
            if total_options is not None:
                self._values["total_options"] = total_options

        @builtins.property
        def field_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableFieldOptionsProperty"]]:
            '''The field options for a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-fieldoptions
            '''
            result = self._values.get("field_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableFieldOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableFieldWellsProperty"]], result)

        @builtins.property
        def paginated_report_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TablePaginatedReportOptionsProperty"]]:
            '''The paginated report options for a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-paginatedreportoptions
            '''
            result = self._values.get("paginated_report_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TablePaginatedReportOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableSortConfigurationProperty"]]:
            '''The sort configuration for a ``TableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableSortConfigurationProperty"]], result)

        @builtins.property
        def table_inline_visualizations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableInlineVisualizationProperty"]]]]:
            '''A collection of inline visualizations to display within a chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-tableinlinevisualizations
            '''
            result = self._values.get("table_inline_visualizations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableInlineVisualizationProperty"]]]], result)

        @builtins.property
        def table_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableOptionsProperty"]]:
            '''The table options for a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-tableoptions
            '''
            result = self._values.get("table_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableOptionsProperty"]], result)

        @builtins.property
        def total_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TotalOptionsProperty"]]:
            '''The total options for a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-totaloptions
            '''
            result = self._values.get("total_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TotalOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableFieldCustomIconContentProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon"},
    )
    class TableFieldCustomIconContentProperty:
        def __init__(self, *, icon: typing.Optional[builtins.str] = None) -> None:
            '''The custom icon content for the table link content configuration.

            :param icon: The icon set type (link) of the custom icon content for table URL link content.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomiconcontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_custom_icon_content_property = quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                    icon="icon"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b92f803cfb445a663dd5996de264bb637b182c6eb6c3efa7e1fb945da29b848a)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon

        @builtins.property
        def icon(self) -> typing.Optional[builtins.str]:
            '''The icon set type (link) of the custom icon content for table URL link content.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomiconcontent.html#cfn-quicksight-template-tablefieldcustomiconcontent-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldCustomIconContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableFieldCustomTextContentProperty",
        jsii_struct_bases=[],
        name_mapping={"font_configuration": "fontConfiguration", "value": "value"},
    )
    class TableFieldCustomTextContentProperty:
        def __init__(
            self,
            *,
            font_configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The custom text content (value, font configuration) for the table link content configuration.

            :param font_configuration: The font configuration of the custom text content for the table URL link content.
            :param value: The string value of the custom text content for the table URL link content.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomtextcontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_custom_text_content_property = quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                
                    # the properties below are optional
                    value="value"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__86d64eebc27a31236e17d644270b05e6bb9993e683f24bf7ea4ceda3e5e1d26b)
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "font_configuration": font_configuration,
            }
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"]:
            '''The font configuration of the custom text content for the table URL link content.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomtextcontent.html#cfn-quicksight-template-tablefieldcustomtextcontent-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            assert result is not None, "Required property 'font_configuration' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.FontConfigurationProperty"], result)

        @builtins.property
        def value(self) -> typing.Optional[builtins.str]:
            '''The string value of the custom text content for the table URL link content.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomtextcontent.html#cfn-quicksight-template-tablefieldcustomtextcontent-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldCustomTextContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableFieldImageConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"sizing_options": "sizingOptions"},
    )
    class TableFieldImageConfigurationProperty:
        def __init__(
            self,
            *,
            sizing_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableCellImageSizingConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The image configuration of a table field URL.

            :param sizing_options: The sizing options for the table image configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldimageconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_image_configuration_property = quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                    sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3b24f39dc5525a2bbd0e65127a3ecf08cf567859527e3c53d13adbaf1c4472bc)
                check_type(argname="argument sizing_options", value=sizing_options, expected_type=type_hints["sizing_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sizing_options is not None:
                self._values["sizing_options"] = sizing_options

        @builtins.property
        def sizing_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellImageSizingConfigurationProperty"]]:
            '''The sizing options for the table image configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldimageconfiguration.html#cfn-quicksight-template-tablefieldimageconfiguration-sizingoptions
            '''
            result = self._values.get("sizing_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellImageSizingConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldImageConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableFieldLinkConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"content": "content", "target": "target"},
    )
    class TableFieldLinkConfigurationProperty:
        def __init__(
            self,
            *,
            content: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableFieldLinkContentConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            target: builtins.str,
        ) -> None:
            '''The link configuration of a table field URL.

            :param content: The URL content (text, icon) for the table link configuration.
            :param target: The URL target (new tab, new window, same tab) for the table link configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_link_configuration_property = quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                    content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                        custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                            icon="icon"
                        ),
                        custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                
                            # the properties below are optional
                            value="value"
                        )
                    ),
                    target="target"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b4623085f8dfac9e24d556bd10d59a883f44dfb076fe1d955b9c51f3e8bfc86a)
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
                check_type(argname="argument target", value=target, expected_type=type_hints["target"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "content": content,
                "target": target,
            }

        @builtins.property
        def content(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableFieldLinkContentConfigurationProperty"]:
            '''The URL content (text, icon) for the table link configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkconfiguration.html#cfn-quicksight-template-tablefieldlinkconfiguration-content
            '''
            result = self._values.get("content")
            assert result is not None, "Required property 'content' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableFieldLinkContentConfigurationProperty"], result)

        @builtins.property
        def target(self) -> builtins.str:
            '''The URL target (new tab, new window, same tab) for the table link configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkconfiguration.html#cfn-quicksight-template-tablefieldlinkconfiguration-target
            '''
            result = self._values.get("target")
            assert result is not None, "Required property 'target' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldLinkConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_icon_content": "customIconContent",
            "custom_text_content": "customTextContent",
        },
    )
    class TableFieldLinkContentConfigurationProperty:
        def __init__(
            self,
            *,
            custom_icon_content: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableFieldCustomIconContentProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_text_content: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableFieldCustomTextContentProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The URL content (text, icon) for the table link configuration.

            :param custom_icon_content: The custom icon content for the table link content configuration.
            :param custom_text_content: The custom text content (value, font configuration) for the table link content configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkcontentconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_link_content_configuration_property = quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                    custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                        icon="icon"
                    ),
                    custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                
                        # the properties below are optional
                        value="value"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bbc0e4260a6c448007ce1648f53594e5fe639da096f4466f29d660bc7e28950f)
                check_type(argname="argument custom_icon_content", value=custom_icon_content, expected_type=type_hints["custom_icon_content"])
                check_type(argname="argument custom_text_content", value=custom_text_content, expected_type=type_hints["custom_text_content"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_icon_content is not None:
                self._values["custom_icon_content"] = custom_icon_content
            if custom_text_content is not None:
                self._values["custom_text_content"] = custom_text_content

        @builtins.property
        def custom_icon_content(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableFieldCustomIconContentProperty"]]:
            '''The custom icon content for the table link content configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkcontentconfiguration.html#cfn-quicksight-template-tablefieldlinkcontentconfiguration-customiconcontent
            '''
            result = self._values.get("custom_icon_content")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableFieldCustomIconContentProperty"]], result)

        @builtins.property
        def custom_text_content(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableFieldCustomTextContentProperty"]]:
            '''The custom text content (value, font configuration) for the table link content configuration.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkcontentconfiguration.html#cfn-quicksight-template-tablefieldlinkcontentconfiguration-customtextcontent
            '''
            result = self._values.get("custom_text_content")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableFieldCustomTextContentProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldLinkContentConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableFieldOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "custom_label": "customLabel",
            "url_styling": "urlStyling",
            "visibility": "visibility",
            "width": "width",
        },
    )
    class TableFieldOptionProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            custom_label: typing.Optional[builtins.str] = None,
            url_styling: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableFieldURLConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for a table field.

            :param field_id: The field ID for a table field.
            :param custom_label: The custom label for a table field.
            :param url_styling: The URL configuration for a table field.
            :param visibility: The visibility of a table field.
            :param width: The width for a table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_option_property = quicksight.CfnTemplate.TableFieldOptionProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    custom_label="customLabel",
                    url_styling=quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                        image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                            sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                                table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                            )
                        ),
                        link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                            content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                                custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                    icon="icon"
                                ),
                                custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    value="value"
                                )
                            ),
                            target="target"
                        )
                    ),
                    visibility="visibility",
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__779e6a5f975a683bc59b05bce4b3c638ac2dd48df1efff42a514cf6d6fd25461)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument url_styling", value=url_styling, expected_type=type_hints["url_styling"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if url_styling is not None:
                self._values["url_styling"] = url_styling
            if visibility is not None:
                self._values["visibility"] = visibility
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for a table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label for a table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def url_styling(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableFieldURLConfigurationProperty"]]:
            '''The URL configuration for a table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-urlstyling
            '''
            result = self._values.get("url_styling")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableFieldURLConfigurationProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of a table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width for a table field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableFieldOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "order": "order",
            "pinned_field_options": "pinnedFieldOptions",
            "selected_field_options": "selectedFieldOptions",
        },
    )
    class TableFieldOptionsProperty:
        def __init__(
            self,
            *,
            order: typing.Optional[typing.Sequence[builtins.str]] = None,
            pinned_field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TablePinnedFieldOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selected_field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableFieldOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field options of a table visual.

            :param order: The order of the field IDs that are configured as field options for a table visual.
            :param pinned_field_options: The settings for the pinned columns of a table visual.
            :param selected_field_options: The field options to be configured to a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_options_property = quicksight.CfnTemplate.TableFieldOptionsProperty(
                    order=["order"],
                    pinned_field_options=quicksight.CfnTemplate.TablePinnedFieldOptionsProperty(
                        pinned_left_fields=["pinnedLeftFields"]
                    ),
                    selected_field_options=[quicksight.CfnTemplate.TableFieldOptionProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        custom_label="customLabel",
                        url_styling=quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                            image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                                sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                )
                            ),
                            link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                                content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                                    custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                        icon="icon"
                                    ),
                                    custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        value="value"
                                    )
                                ),
                                target="target"
                            )
                        ),
                        visibility="visibility",
                        width="width"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2796b1737ad870376487761ac141740bbac607a367593f554b3fd534c5f32a36)
                check_type(argname="argument order", value=order, expected_type=type_hints["order"])
                check_type(argname="argument pinned_field_options", value=pinned_field_options, expected_type=type_hints["pinned_field_options"])
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if order is not None:
                self._values["order"] = order
            if pinned_field_options is not None:
                self._values["pinned_field_options"] = pinned_field_options
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options

        @builtins.property
        def order(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The order of the field IDs that are configured as field options for a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoptions.html#cfn-quicksight-template-tablefieldoptions-order
            '''
            result = self._values.get("order")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def pinned_field_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TablePinnedFieldOptionsProperty"]]:
            '''The settings for the pinned columns of a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoptions.html#cfn-quicksight-template-tablefieldoptions-pinnedfieldoptions
            '''
            result = self._values.get("pinned_field_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TablePinnedFieldOptionsProperty"]], result)

        @builtins.property
        def selected_field_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableFieldOptionProperty"]]]]:
            '''The field options to be configured to a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoptions.html#cfn-quicksight-template-tablefieldoptions-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableFieldOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableFieldURLConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "image_configuration": "imageConfiguration",
            "link_configuration": "linkConfiguration",
        },
    )
    class TableFieldURLConfigurationProperty:
        def __init__(
            self,
            *,
            image_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableFieldImageConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            link_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableFieldLinkConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The URL configuration for a table field.

            :param image_configuration: The image configuration of a table field URL.
            :param link_configuration: The link configuration of a table field URL.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldurlconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_field_uRLConfiguration_property = quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                    image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                        sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                            table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                        )
                    ),
                    link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                        content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                            custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                icon="icon"
                            ),
                            custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                
                                # the properties below are optional
                                value="value"
                            )
                        ),
                        target="target"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__04c4cefd3fa19c90120d27e9ddd55e2ce8bcd220fba3f34242468d6152e1abfa)
                check_type(argname="argument image_configuration", value=image_configuration, expected_type=type_hints["image_configuration"])
                check_type(argname="argument link_configuration", value=link_configuration, expected_type=type_hints["link_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if image_configuration is not None:
                self._values["image_configuration"] = image_configuration
            if link_configuration is not None:
                self._values["link_configuration"] = link_configuration

        @builtins.property
        def image_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableFieldImageConfigurationProperty"]]:
            '''The image configuration of a table field URL.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldurlconfiguration.html#cfn-quicksight-template-tablefieldurlconfiguration-imageconfiguration
            '''
            result = self._values.get("image_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableFieldImageConfigurationProperty"]], result)

        @builtins.property
        def link_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableFieldLinkConfigurationProperty"]]:
            '''The link configuration of a table field URL.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldurlconfiguration.html#cfn-quicksight-template-tablefieldurlconfiguration-linkconfiguration
            '''
            result = self._values.get("link_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableFieldLinkConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldURLConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "table_aggregated_field_wells": "tableAggregatedFieldWells",
            "table_unaggregated_field_wells": "tableUnaggregatedFieldWells",
        },
    )
    class TableFieldWellsProperty:
        def __init__(
            self,
            *,
            table_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_unaggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableUnaggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells for a table visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param table_aggregated_field_wells: The aggregated field well for the table.
            :param table_unaggregated_field_wells: The unaggregated field well for the table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a02e236036f7bcd69e7ce7530c8eb0d601444a38ffa8ac1e5f30f2714f07c873)
                check_type(argname="argument table_aggregated_field_wells", value=table_aggregated_field_wells, expected_type=type_hints["table_aggregated_field_wells"])
                check_type(argname="argument table_unaggregated_field_wells", value=table_unaggregated_field_wells, expected_type=type_hints["table_unaggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if table_aggregated_field_wells is not None:
                self._values["table_aggregated_field_wells"] = table_aggregated_field_wells
            if table_unaggregated_field_wells is not None:
                self._values["table_unaggregated_field_wells"] = table_unaggregated_field_wells

        @builtins.property
        def table_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableAggregatedFieldWellsProperty"]]:
            '''The aggregated field well for the table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldwells.html#cfn-quicksight-template-tablefieldwells-tableaggregatedfieldwells
            '''
            result = self._values.get("table_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableAggregatedFieldWellsProperty"]], result)

        @builtins.property
        def table_unaggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableUnaggregatedFieldWellsProperty"]]:
            '''The unaggregated field well for the table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldwells.html#cfn-quicksight-template-tablefieldwells-tableunaggregatedfieldwells
            '''
            result = self._values.get("table_unaggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableUnaggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableInlineVisualizationProperty",
        jsii_struct_bases=[],
        name_mapping={"data_bars": "dataBars"},
    )
    class TableInlineVisualizationProperty:
        def __init__(
            self,
            *,
            data_bars: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataBarsOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The inline visualization of a specific type to display within a chart.

            :param data_bars: The configuration of the inline visualization of the data bars within a chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableinlinevisualization.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_inline_visualization_property = quicksight.CfnTemplate.TableInlineVisualizationProperty(
                    data_bars=quicksight.CfnTemplate.DataBarsOptionsProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        negative_color="negativeColor",
                        positive_color="positiveColor"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ceb0d418c99510db7c0c0d9697bc4a52e447eb65699b23c1ca5c0ffe36580475)
                check_type(argname="argument data_bars", value=data_bars, expected_type=type_hints["data_bars"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_bars is not None:
                self._values["data_bars"] = data_bars

        @builtins.property
        def data_bars(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataBarsOptionsProperty"]]:
            '''The configuration of the inline visualization of the data bars within a chart.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableinlinevisualization.html#cfn-quicksight-template-tableinlinevisualization-databars
            '''
            result = self._values.get("data_bars")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataBarsOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableInlineVisualizationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cell_style": "cellStyle",
            "header_style": "headerStyle",
            "orientation": "orientation",
            "row_alternate_color_options": "rowAlternateColorOptions",
        },
    )
    class TableOptionsProperty:
        def __init__(
            self,
            *,
            cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            header_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            orientation: typing.Optional[builtins.str] = None,
            row_alternate_color_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.RowAlternateColorOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The table options for a table visual.

            :param cell_style: The table cell style of table cells.
            :param header_style: The table cell style of a table header.
            :param orientation: The orientation (vertical, horizontal) for a table.
            :param row_alternate_color_options: The row alternate color options (widget status, row alternate colors) for a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_options_property = quicksight.CfnTemplate.TableOptionsProperty(
                    cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    orientation="orientation",
                    row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                        row_alternate_colors=["rowAlternateColors"],
                        status="status",
                        use_primary_background_color="usePrimaryBackgroundColor"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__72989fbf4fb65e8ef177defebf306d8d8586aff29022aa898fc0e7b021461953)
                check_type(argname="argument cell_style", value=cell_style, expected_type=type_hints["cell_style"])
                check_type(argname="argument header_style", value=header_style, expected_type=type_hints["header_style"])
                check_type(argname="argument orientation", value=orientation, expected_type=type_hints["orientation"])
                check_type(argname="argument row_alternate_color_options", value=row_alternate_color_options, expected_type=type_hints["row_alternate_color_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell_style is not None:
                self._values["cell_style"] = cell_style
            if header_style is not None:
                self._values["header_style"] = header_style
            if orientation is not None:
                self._values["orientation"] = orientation
            if row_alternate_color_options is not None:
                self._values["row_alternate_color_options"] = row_alternate_color_options

        @builtins.property
        def cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]]:
            '''The table cell style of table cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html#cfn-quicksight-template-tableoptions-cellstyle
            '''
            result = self._values.get("cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def header_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]]:
            '''The table cell style of a table header.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html#cfn-quicksight-template-tableoptions-headerstyle
            '''
            result = self._values.get("header_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def orientation(self) -> typing.Optional[builtins.str]:
            '''The orientation (vertical, horizontal) for a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html#cfn-quicksight-template-tableoptions-orientation
            '''
            result = self._values.get("orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def row_alternate_color_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RowAlternateColorOptionsProperty"]]:
            '''The row alternate color options (widget status, row alternate colors) for a table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html#cfn-quicksight-template-tableoptions-rowalternatecoloroptions
            '''
            result = self._values.get("row_alternate_color_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RowAlternateColorOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TablePaginatedReportOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "overflow_column_header_visibility": "overflowColumnHeaderVisibility",
            "vertical_overflow_visibility": "verticalOverflowVisibility",
        },
    )
    class TablePaginatedReportOptionsProperty:
        def __init__(
            self,
            *,
            overflow_column_header_visibility: typing.Optional[builtins.str] = None,
            vertical_overflow_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The paginated report options for a table visual.

            :param overflow_column_header_visibility: The visibility of repeating header rows on each page.
            :param vertical_overflow_visibility: The visibility of printing table overflow across pages.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablepaginatedreportoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_paginated_report_options_property = quicksight.CfnTemplate.TablePaginatedReportOptionsProperty(
                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                    vertical_overflow_visibility="verticalOverflowVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__314e5e5ec10f290574f10eaea635bbed4ba331282f6e96fbb8e6bde77b05863c)
                check_type(argname="argument overflow_column_header_visibility", value=overflow_column_header_visibility, expected_type=type_hints["overflow_column_header_visibility"])
                check_type(argname="argument vertical_overflow_visibility", value=vertical_overflow_visibility, expected_type=type_hints["vertical_overflow_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if overflow_column_header_visibility is not None:
                self._values["overflow_column_header_visibility"] = overflow_column_header_visibility
            if vertical_overflow_visibility is not None:
                self._values["vertical_overflow_visibility"] = vertical_overflow_visibility

        @builtins.property
        def overflow_column_header_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of repeating header rows on each page.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablepaginatedreportoptions.html#cfn-quicksight-template-tablepaginatedreportoptions-overflowcolumnheadervisibility
            '''
            result = self._values.get("overflow_column_header_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_overflow_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of printing table overflow across pages.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablepaginatedreportoptions.html#cfn-quicksight-template-tablepaginatedreportoptions-verticaloverflowvisibility
            '''
            result = self._values.get("vertical_overflow_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TablePaginatedReportOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TablePinnedFieldOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"pinned_left_fields": "pinnedLeftFields"},
    )
    class TablePinnedFieldOptionsProperty:
        def __init__(
            self,
            *,
            pinned_left_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The settings for the pinned columns of a table visual.

            :param pinned_left_fields: A list of columns to be pinned to the left of a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablepinnedfieldoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_pinned_field_options_property = quicksight.CfnTemplate.TablePinnedFieldOptionsProperty(
                    pinned_left_fields=["pinnedLeftFields"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b45b9f9c4a8e69871af3d427ee971e1adea8a6f8e95067f90063fb60e3665b0e)
                check_type(argname="argument pinned_left_fields", value=pinned_left_fields, expected_type=type_hints["pinned_left_fields"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pinned_left_fields is not None:
                self._values["pinned_left_fields"] = pinned_left_fields

        @builtins.property
        def pinned_left_fields(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of columns to be pinned to the left of a table visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablepinnedfieldoptions.html#cfn-quicksight-template-tablepinnedfieldoptions-pinnedleftfields
            '''
            result = self._values.get("pinned_left_fields")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TablePinnedFieldOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableRowConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "text_color": "textColor",
        },
    )
    class TableRowConditionalFormattingProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting of a table row.

            :param background_color: The conditional formatting color (solid, gradient) of the background for a table row.
            :param text_color: The conditional formatting color (solid, gradient) of the text for a table row.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablerowconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_row_conditional_formatting_property = quicksight.CfnTemplate.TableRowConditionalFormattingProperty(
                    background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    ),
                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__178cc4da695f91cc458c7388d9d495874b607f05c4a8d391049bccdc3abe00f8)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def background_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting color (solid, gradient) of the background for a table row.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablerowconditionalformatting.html#cfn-quicksight-template-tablerowconditionalformatting-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting color (solid, gradient) of the text for a table row.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablerowconditionalformatting.html#cfn-quicksight-template-tablerowconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableRowConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableSideBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bottom": "bottom",
            "inner_horizontal": "innerHorizontal",
            "inner_vertical": "innerVertical",
            "left": "left",
            "right": "right",
            "top": "top",
        },
    )
    class TableSideBorderOptionsProperty:
        def __init__(
            self,
            *,
            bottom: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            inner_horizontal: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            inner_vertical: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            left: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            right: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The side border options for a table.

            :param bottom: The table border options of the bottom border.
            :param inner_horizontal: The table border options of the inner horizontal border.
            :param inner_vertical: The table border options of the inner vertical border.
            :param left: The table border options of the left border.
            :param right: The table border options of the right border.
            :param top: The table border options of the top border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_side_border_options_property = quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__75ad05777fe46c30662f9ad6fe87b26918feac5967802af413b29b7ec3409eb2)
                check_type(argname="argument bottom", value=bottom, expected_type=type_hints["bottom"])
                check_type(argname="argument inner_horizontal", value=inner_horizontal, expected_type=type_hints["inner_horizontal"])
                check_type(argname="argument inner_vertical", value=inner_vertical, expected_type=type_hints["inner_vertical"])
                check_type(argname="argument left", value=left, expected_type=type_hints["left"])
                check_type(argname="argument right", value=right, expected_type=type_hints["right"])
                check_type(argname="argument top", value=top, expected_type=type_hints["top"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bottom is not None:
                self._values["bottom"] = bottom
            if inner_horizontal is not None:
                self._values["inner_horizontal"] = inner_horizontal
            if inner_vertical is not None:
                self._values["inner_vertical"] = inner_vertical
            if left is not None:
                self._values["left"] = left
            if right is not None:
                self._values["right"] = right
            if top is not None:
                self._values["top"] = top

        @builtins.property
        def bottom(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableBorderOptionsProperty"]]:
            '''The table border options of the bottom border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-bottom
            '''
            result = self._values.get("bottom")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableBorderOptionsProperty"]], result)

        @builtins.property
        def inner_horizontal(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableBorderOptionsProperty"]]:
            '''The table border options of the inner horizontal border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-innerhorizontal
            '''
            result = self._values.get("inner_horizontal")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableBorderOptionsProperty"]], result)

        @builtins.property
        def inner_vertical(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableBorderOptionsProperty"]]:
            '''The table border options of the inner vertical border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-innervertical
            '''
            result = self._values.get("inner_vertical")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableBorderOptionsProperty"]], result)

        @builtins.property
        def left(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableBorderOptionsProperty"]]:
            '''The table border options of the left border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-left
            '''
            result = self._values.get("left")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableBorderOptionsProperty"]], result)

        @builtins.property
        def right(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableBorderOptionsProperty"]]:
            '''The table border options of the right border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-right
            '''
            result = self._values.get("right")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableBorderOptionsProperty"]], result)

        @builtins.property
        def top(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableBorderOptionsProperty"]]:
            '''The table border options of the top border.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-top
            '''
            result = self._values.get("top")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableBorderOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableSideBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pagination_configuration": "paginationConfiguration",
            "row_sort": "rowSort",
        },
    )
    class TableSortConfigurationProperty:
        def __init__(
            self,
            *,
            pagination_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PaginationConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration for a ``TableVisual`` .

            :param pagination_configuration: The pagination configuration (page size, page number) for the table.
            :param row_sort: The field sort options for rows in the table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_sort_configuration_property = quicksight.CfnTemplate.TableSortConfigurationProperty(
                    pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                        page_number=123,
                        page_size=123
                    ),
                    row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__903046e28c98a6ec8103ae79dcbc439d13256653096eae7e28c723aca09f5b79)
                check_type(argname="argument pagination_configuration", value=pagination_configuration, expected_type=type_hints["pagination_configuration"])
                check_type(argname="argument row_sort", value=row_sort, expected_type=type_hints["row_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pagination_configuration is not None:
                self._values["pagination_configuration"] = pagination_configuration
            if row_sort is not None:
                self._values["row_sort"] = row_sort

        @builtins.property
        def pagination_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PaginationConfigurationProperty"]]:
            '''The pagination configuration (page size, page number) for the table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesortconfiguration.html#cfn-quicksight-template-tablesortconfiguration-paginationconfiguration
            '''
            result = self._values.get("pagination_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PaginationConfigurationProperty"]], result)

        @builtins.property
        def row_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The field sort options for rows in the table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesortconfiguration.html#cfn-quicksight-template-tablesortconfiguration-rowsort
            '''
            result = self._values.get("row_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableStyleTargetProperty",
        jsii_struct_bases=[],
        name_mapping={"cell_type": "cellType"},
    )
    class TableStyleTargetProperty:
        def __init__(self, *, cell_type: builtins.str) -> None:
            '''The table style target.

            :param cell_type: The cell type of the table style target.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablestyletarget.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_style_target_property = quicksight.CfnTemplate.TableStyleTargetProperty(
                    cell_type="cellType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__eb65d9330b2c4bb046bded2bf8120b89581164d4583157da562916af1833ede2)
                check_type(argname="argument cell_type", value=cell_type, expected_type=type_hints["cell_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "cell_type": cell_type,
            }

        @builtins.property
        def cell_type(self) -> builtins.str:
            '''The cell type of the table style target.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablestyletarget.html#cfn-quicksight-template-tablestyletarget-celltype
            '''
            result = self._values.get("cell_type")
            assert result is not None, "Required property 'cell_type' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableStyleTargetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class TableUnaggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.UnaggregatedFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The unaggregated field well for the table.

            :param values: The values field well for a pivot table. Values are unaggregated for an unaggregated table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableunaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                table_unaggregated_field_wells_property = quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty(
                    values=[quicksight.CfnTemplate.UnaggregatedFieldProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                            date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e82e4b250bc24e2b79ecb297f9e7fd6cd917bb5458dd230d700971964e97a7c8)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.UnaggregatedFieldProperty"]]]]:
            '''The values field well for a pivot table.

            Values are unaggregated for an unaggregated table.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableunaggregatedfieldwells.html#cfn-quicksight-template-tableunaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.UnaggregatedFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableUnaggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TableVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class TableVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A table visual.

            For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param conditional_formatting: The conditional formatting for a ``PivotTableVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1c31b2114cdc370dfdb415437cd997a1b122d96ab50bfd66c8858e768988542e)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableConfigurationProperty"]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableConditionalFormattingProperty"]]:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TemplateErrorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "message": "message",
            "type": "type",
            "violated_entities": "violatedEntities",
        },
    )
    class TemplateErrorProperty:
        def __init__(
            self,
            *,
            message: typing.Optional[builtins.str] = None,
            type: typing.Optional[builtins.str] = None,
            violated_entities: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.EntityProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''List of errors that occurred when the template version creation failed.

            :param message: Description of the error type.
            :param type: Type of error.
            :param violated_entities: An error path that shows which entities caused the template error.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateerror.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                template_error_property = quicksight.CfnTemplate.TemplateErrorProperty(
                    message="message",
                    type="type",
                    violated_entities=[quicksight.CfnTemplate.EntityProperty(
                        path="path"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fb1493e0de2aa92be7a3455753aed11235085d8489c8a548fd1fd5385201a46a)
                check_type(argname="argument message", value=message, expected_type=type_hints["message"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument violated_entities", value=violated_entities, expected_type=type_hints["violated_entities"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if message is not None:
                self._values["message"] = message
            if type is not None:
                self._values["type"] = type
            if violated_entities is not None:
                self._values["violated_entities"] = violated_entities

        @builtins.property
        def message(self) -> typing.Optional[builtins.str]:
            '''Description of the error type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateerror.html#cfn-quicksight-template-templateerror-message
            '''
            result = self._values.get("message")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''Type of error.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateerror.html#cfn-quicksight-template-templateerror-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def violated_entities(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.EntityProperty"]]]]:
            '''An error path that shows which entities caused the template error.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateerror.html#cfn-quicksight-template-templateerror-violatedentities
            '''
            result = self._values.get("violated_entities")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.EntityProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TemplateErrorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TemplateSourceAnalysisProperty",
        jsii_struct_bases=[],
        name_mapping={"arn": "arn", "data_set_references": "dataSetReferences"},
    )
    class TemplateSourceAnalysisProperty:
        def __init__(
            self,
            *,
            arn: builtins.str,
            data_set_references: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataSetReferenceProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The source analysis of the template.

            :param arn: The Amazon Resource Name (ARN) of the resource.
            :param data_set_references: A structure containing information about the dataset references used as placeholders in the template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceanalysis.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                template_source_analysis_property = quicksight.CfnTemplate.TemplateSourceAnalysisProperty(
                    arn="arn",
                    data_set_references=[quicksight.CfnTemplate.DataSetReferenceProperty(
                        data_set_arn="dataSetArn",
                        data_set_placeholder="dataSetPlaceholder"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2eb54d447b487456995a6fe75d674789538c60109d204f87757468168fcfbc16)
                check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
                check_type(argname="argument data_set_references", value=data_set_references, expected_type=type_hints["data_set_references"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "arn": arn,
                "data_set_references": data_set_references,
            }

        @builtins.property
        def arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the resource.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceanalysis.html#cfn-quicksight-template-templatesourceanalysis-arn
            '''
            result = self._values.get("arn")
            assert result is not None, "Required property 'arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_references(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataSetReferenceProperty"]]]:
            '''A structure containing information about the dataset references used as placeholders in the template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceanalysis.html#cfn-quicksight-template-templatesourceanalysis-datasetreferences
            '''
            result = self._values.get("data_set_references")
            assert result is not None, "Required property 'data_set_references' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataSetReferenceProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TemplateSourceAnalysisProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TemplateSourceEntityProperty",
        jsii_struct_bases=[],
        name_mapping={
            "source_analysis": "sourceAnalysis",
            "source_template": "sourceTemplate",
        },
    )
    class TemplateSourceEntityProperty:
        def __init__(
            self,
            *,
            source_analysis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TemplateSourceAnalysisProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            source_template: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TemplateSourceTemplateProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The source entity of the template.

            :param source_analysis: The source analysis, if it is based on an analysis.
            :param source_template: The source template, if it is based on an template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceentity.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                template_source_entity_property = quicksight.CfnTemplate.TemplateSourceEntityProperty(
                    source_analysis=quicksight.CfnTemplate.TemplateSourceAnalysisProperty(
                        arn="arn",
                        data_set_references=[quicksight.CfnTemplate.DataSetReferenceProperty(
                            data_set_arn="dataSetArn",
                            data_set_placeholder="dataSetPlaceholder"
                        )]
                    ),
                    source_template=quicksight.CfnTemplate.TemplateSourceTemplateProperty(
                        arn="arn"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fb1d67137993dd808f77c6146d2a0e7d0883f456f3cb561e95ee4027432a223f)
                check_type(argname="argument source_analysis", value=source_analysis, expected_type=type_hints["source_analysis"])
                check_type(argname="argument source_template", value=source_template, expected_type=type_hints["source_template"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if source_analysis is not None:
                self._values["source_analysis"] = source_analysis
            if source_template is not None:
                self._values["source_template"] = source_template

        @builtins.property
        def source_analysis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TemplateSourceAnalysisProperty"]]:
            '''The source analysis, if it is based on an analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceentity.html#cfn-quicksight-template-templatesourceentity-sourceanalysis
            '''
            result = self._values.get("source_analysis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TemplateSourceAnalysisProperty"]], result)

        @builtins.property
        def source_template(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TemplateSourceTemplateProperty"]]:
            '''The source template, if it is based on an template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceentity.html#cfn-quicksight-template-templatesourceentity-sourcetemplate
            '''
            result = self._values.get("source_template")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TemplateSourceTemplateProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TemplateSourceEntityProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TemplateSourceTemplateProperty",
        jsii_struct_bases=[],
        name_mapping={"arn": "arn"},
    )
    class TemplateSourceTemplateProperty:
        def __init__(self, *, arn: builtins.str) -> None:
            '''The source template of the template.

            :param arn: The Amazon Resource Name (ARN) of the resource.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourcetemplate.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                template_source_template_property = quicksight.CfnTemplate.TemplateSourceTemplateProperty(
                    arn="arn"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__55a02d9ca40b6ae3ebb345b5e4f20f1611c0d21074e73a8409fc8e561f3f2a74)
                check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "arn": arn,
            }

        @builtins.property
        def arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the resource.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourcetemplate.html#cfn-quicksight-template-templatesourcetemplate-arn
            '''
            result = self._values.get("arn")
            assert result is not None, "Required property 'arn' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TemplateSourceTemplateProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TemplateVersionDefinitionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_configurations": "dataSetConfigurations",
            "analysis_defaults": "analysisDefaults",
            "calculated_fields": "calculatedFields",
            "column_configurations": "columnConfigurations",
            "filter_groups": "filterGroups",
            "options": "options",
            "parameter_declarations": "parameterDeclarations",
            "sheets": "sheets",
        },
    )
    class TemplateVersionDefinitionProperty:
        def __init__(
            self,
            *,
            data_set_configurations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataSetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AnalysisDefaultsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            calculated_fields: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CalculatedFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            column_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            filter_groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilterGroupProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AssetOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            parameter_declarations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sheets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SheetDefinitionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The detailed definition of a template.

            :param data_set_configurations: An array of dataset configurations. These configurations define the required columns for each dataset used within a template.
            :param analysis_defaults: 
            :param calculated_fields: An array of calculated field definitions for the template.
            :param column_configurations: An array of template-level column configurations. Column configurations are used to set default formatting for a column that's used throughout a template.
            :param filter_groups: Filter definitions for a template. For more information, see `Filtering Data <https://docs.aws.amazon.com/quicksight/latest/user/filtering-visual-data.html>`_ in the *Amazon QuickSight User Guide* .
            :param options: An array of option definitions for a template.
            :param parameter_declarations: An array of parameter declarations for a template. *Parameters* are named variables that can transfer a value for use by an action or an object. For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .
            :param sheets: An array of sheet definitions for a template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0d4d306e9cd0974c594353d10bf810e1540586afcd9054498c6bcf94e7c77c23)
                check_type(argname="argument data_set_configurations", value=data_set_configurations, expected_type=type_hints["data_set_configurations"])
                check_type(argname="argument analysis_defaults", value=analysis_defaults, expected_type=type_hints["analysis_defaults"])
                check_type(argname="argument calculated_fields", value=calculated_fields, expected_type=type_hints["calculated_fields"])
                check_type(argname="argument column_configurations", value=column_configurations, expected_type=type_hints["column_configurations"])
                check_type(argname="argument filter_groups", value=filter_groups, expected_type=type_hints["filter_groups"])
                check_type(argname="argument options", value=options, expected_type=type_hints["options"])
                check_type(argname="argument parameter_declarations", value=parameter_declarations, expected_type=type_hints["parameter_declarations"])
                check_type(argname="argument sheets", value=sheets, expected_type=type_hints["sheets"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_configurations": data_set_configurations,
            }
            if analysis_defaults is not None:
                self._values["analysis_defaults"] = analysis_defaults
            if calculated_fields is not None:
                self._values["calculated_fields"] = calculated_fields
            if column_configurations is not None:
                self._values["column_configurations"] = column_configurations
            if filter_groups is not None:
                self._values["filter_groups"] = filter_groups
            if options is not None:
                self._values["options"] = options
            if parameter_declarations is not None:
                self._values["parameter_declarations"] = parameter_declarations
            if sheets is not None:
                self._values["sheets"] = sheets

        @builtins.property
        def data_set_configurations(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataSetConfigurationProperty"]]]:
            '''An array of dataset configurations.

            These configurations define the required columns for each dataset used within a template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-datasetconfigurations
            '''
            result = self._values.get("data_set_configurations")
            assert result is not None, "Required property 'data_set_configurations' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataSetConfigurationProperty"]]], result)

        @builtins.property
        def analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AnalysisDefaultsProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-analysisdefaults
            '''
            result = self._values.get("analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AnalysisDefaultsProperty"]], result)

        @builtins.property
        def calculated_fields(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CalculatedFieldProperty"]]]]:
            '''An array of calculated field definitions for the template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-calculatedfields
            '''
            result = self._values.get("calculated_fields")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CalculatedFieldProperty"]]]], result)

        @builtins.property
        def column_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnConfigurationProperty"]]]]:
            '''An array of template-level column configurations.

            Column configurations are used to set default formatting for a column that's used throughout a template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-columnconfigurations
            '''
            result = self._values.get("column_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnConfigurationProperty"]]]], result)

        @builtins.property
        def filter_groups(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterGroupProperty"]]]]:
            '''Filter definitions for a template.

            For more information, see `Filtering Data <https://docs.aws.amazon.com/quicksight/latest/user/filtering-visual-data.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-filtergroups
            '''
            result = self._values.get("filter_groups")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilterGroupProperty"]]]], result)

        @builtins.property
        def options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AssetOptionsProperty"]]:
            '''An array of option definitions for a template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-options
            '''
            result = self._values.get("options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AssetOptionsProperty"]], result)

        @builtins.property
        def parameter_declarations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ParameterDeclarationProperty"]]]]:
            '''An array of parameter declarations for a template.

            *Parameters* are named variables that can transfer a value for use by an action or an object.

            For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-parameterdeclarations
            '''
            result = self._values.get("parameter_declarations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ParameterDeclarationProperty"]]]], result)

        @builtins.property
        def sheets(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetDefinitionProperty"]]]]:
            '''An array of sheet definitions for a template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-sheets
            '''
            result = self._values.get("sheets")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetDefinitionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TemplateVersionDefinitionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TemplateVersionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "created_time": "createdTime",
            "data_set_configurations": "dataSetConfigurations",
            "description": "description",
            "errors": "errors",
            "sheets": "sheets",
            "source_entity_arn": "sourceEntityArn",
            "status": "status",
            "theme_arn": "themeArn",
            "version_number": "versionNumber",
        },
    )
    class TemplateVersionProperty:
        def __init__(
            self,
            *,
            created_time: typing.Optional[builtins.str] = None,
            data_set_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataSetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            description: typing.Optional[builtins.str] = None,
            errors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TemplateErrorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sheets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SheetProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            source_entity_arn: typing.Optional[builtins.str] = None,
            status: typing.Optional[builtins.str] = None,
            theme_arn: typing.Optional[builtins.str] = None,
            version_number: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A version of a template.

            :param created_time: The time that this template version was created.
            :param data_set_configurations: Schema of the dataset identified by the placeholder. Any dashboard created from this template should be bound to new datasets matching the same schema described through this API operation.
            :param description: The description of the template.
            :param errors: Errors associated with this template version.
            :param sheets: A list of the associated sheets with the unique identifier and name of each sheet.
            :param source_entity_arn: The Amazon Resource Name (ARN) of an analysis or template that was used to create this template.
            :param status: The status that is associated with the template. - ``CREATION_IN_PROGRESS`` - ``CREATION_SUCCESSFUL`` - ``CREATION_FAILED`` - ``UPDATE_IN_PROGRESS`` - ``UPDATE_SUCCESSFUL`` - ``UPDATE_FAILED`` - ``DELETED``
            :param theme_arn: The ARN of the theme associated with this version of the template.
            :param version_number: The version number of the template version.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                template_version_property = quicksight.CfnTemplate.TemplateVersionProperty(
                    created_time="createdTime",
                    data_set_configurations=[quicksight.CfnTemplate.DataSetConfigurationProperty(
                        column_group_schema_list=[quicksight.CfnTemplate.ColumnGroupSchemaProperty(
                            column_group_column_schema_list=[quicksight.CfnTemplate.ColumnGroupColumnSchemaProperty(
                                name="name"
                            )],
                            name="name"
                        )],
                        data_set_schema=quicksight.CfnTemplate.DataSetSchemaProperty(
                            column_schema_list=[quicksight.CfnTemplate.ColumnSchemaProperty(
                                data_type="dataType",
                                geographic_role="geographicRole",
                                name="name"
                            )]
                        ),
                        placeholder="placeholder"
                    )],
                    description="description",
                    errors=[quicksight.CfnTemplate.TemplateErrorProperty(
                        message="message",
                        type="type",
                        violated_entities=[quicksight.CfnTemplate.EntityProperty(
                            path="path"
                        )]
                    )],
                    sheets=[quicksight.CfnTemplate.SheetProperty(
                        name="name",
                        sheet_id="sheetId"
                    )],
                    source_entity_arn="sourceEntityArn",
                    status="status",
                    theme_arn="themeArn",
                    version_number=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c759b390e0d16c21bc3df51154c4360b603f025efdaadfe88ca2354d9636209a)
                check_type(argname="argument created_time", value=created_time, expected_type=type_hints["created_time"])
                check_type(argname="argument data_set_configurations", value=data_set_configurations, expected_type=type_hints["data_set_configurations"])
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
                check_type(argname="argument errors", value=errors, expected_type=type_hints["errors"])
                check_type(argname="argument sheets", value=sheets, expected_type=type_hints["sheets"])
                check_type(argname="argument source_entity_arn", value=source_entity_arn, expected_type=type_hints["source_entity_arn"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument theme_arn", value=theme_arn, expected_type=type_hints["theme_arn"])
                check_type(argname="argument version_number", value=version_number, expected_type=type_hints["version_number"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if created_time is not None:
                self._values["created_time"] = created_time
            if data_set_configurations is not None:
                self._values["data_set_configurations"] = data_set_configurations
            if description is not None:
                self._values["description"] = description
            if errors is not None:
                self._values["errors"] = errors
            if sheets is not None:
                self._values["sheets"] = sheets
            if source_entity_arn is not None:
                self._values["source_entity_arn"] = source_entity_arn
            if status is not None:
                self._values["status"] = status
            if theme_arn is not None:
                self._values["theme_arn"] = theme_arn
            if version_number is not None:
                self._values["version_number"] = version_number

        @builtins.property
        def created_time(self) -> typing.Optional[builtins.str]:
            '''The time that this template version was created.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-createdtime
            '''
            result = self._values.get("created_time")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_set_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataSetConfigurationProperty"]]]]:
            '''Schema of the dataset identified by the placeholder.

            Any dashboard created from this template should be bound to new datasets matching the same schema described through this API operation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-datasetconfigurations
            '''
            result = self._values.get("data_set_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataSetConfigurationProperty"]]]], result)

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''The description of the template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def errors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TemplateErrorProperty"]]]]:
            '''Errors associated with this template version.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-errors
            '''
            result = self._values.get("errors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TemplateErrorProperty"]]]], result)

        @builtins.property
        def sheets(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetProperty"]]]]:
            '''A list of the associated sheets with the unique identifier and name of each sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-sheets
            '''
            result = self._values.get("sheets")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetProperty"]]]], result)

        @builtins.property
        def source_entity_arn(self) -> typing.Optional[builtins.str]:
            '''The Amazon Resource Name (ARN) of an analysis or template that was used to create this template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-sourceentityarn
            '''
            result = self._values.get("source_entity_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status that is associated with the template.

            - ``CREATION_IN_PROGRESS``
            - ``CREATION_SUCCESSFUL``
            - ``CREATION_FAILED``
            - ``UPDATE_IN_PROGRESS``
            - ``UPDATE_SUCCESSFUL``
            - ``UPDATE_FAILED``
            - ``DELETED``

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def theme_arn(self) -> typing.Optional[builtins.str]:
            '''The ARN of the theme associated with this version of the template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-themearn
            '''
            result = self._values.get("theme_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def version_number(self) -> typing.Optional[jsii.Number]:
            '''The version number of the template version.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-versionnumber
            '''
            result = self._values.get("version_number")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TemplateVersionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "info_icon_label_options": "infoIconLabelOptions",
            "placeholder_options": "placeholderOptions",
            "title_options": "titleOptions",
        },
    )
    class TextAreaControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SheetControlInfoIconLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            placeholder_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TextControlPlaceholderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param info_icon_label_options: The configuration of info icon label options.
            :param placeholder_options: The configuration of the placeholder options in a text area control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textareacontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                text_area_control_display_options_property = quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                    info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                        info_icon_text="infoIconText",
                        visibility="visibility"
                    ),
                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__04e1b06dd8d8aeb96baf17821f8818292b8efdd6c06dd06193c5819e54d5ad4d)
                check_type(argname="argument info_icon_label_options", value=info_icon_label_options, expected_type=type_hints["info_icon_label_options"])
                check_type(argname="argument placeholder_options", value=placeholder_options, expected_type=type_hints["placeholder_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if info_icon_label_options is not None:
                self._values["info_icon_label_options"] = info_icon_label_options
            if placeholder_options is not None:
                self._values["placeholder_options"] = placeholder_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def info_icon_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetControlInfoIconLabelOptionsProperty"]]:
            '''The configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textareacontroldisplayoptions.html#cfn-quicksight-template-textareacontroldisplayoptions-infoiconlabeloptions
            '''
            result = self._values.get("info_icon_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetControlInfoIconLabelOptionsProperty"]], result)

        @builtins.property
        def placeholder_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TextControlPlaceholderOptionsProperty"]]:
            '''The configuration of the placeholder options in a text area control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textareacontroldisplayoptions.html#cfn-quicksight-template-textareacontroldisplayoptions-placeholderoptions
            '''
            result = self._values.get("placeholder_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TextControlPlaceholderOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textareacontroldisplayoptions.html#cfn-quicksight-template-textareacontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextAreaControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TextConditionalFormatProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "icon": "icon",
            "text_color": "textColor",
        },
    )
    class TextConditionalFormatProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the text.

            :param background_color: The conditional formatting for the text background color.
            :param icon: The conditional formatting for the icon.
            :param text_color: The conditional formatting for the text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textconditionalformat.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                text_conditional_format_property = quicksight.CfnTemplate.TextConditionalFormatProperty(
                    background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    ),
                    icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0cfb74106da673cde065347bf00164a682139cd3391baf58da9c690beb2eaf32)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def background_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting for the text background color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textconditionalformat.html#cfn-quicksight-template-textconditionalformat-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"]], result)

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting for the icon.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textconditionalformat.html#cfn-quicksight-template-textconditionalformat-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting for the text color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textconditionalformat.html#cfn-quicksight-template-textconditionalformat-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextConditionalFormatProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class TextControlPlaceholderOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the placeholder options in a text control.

            :param visibility: The visibility configuration of the placeholder options in a text control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textcontrolplaceholderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                text_control_placeholder_options_property = quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__705a4841c70945143c7c371c4652bcb6b5c6a9722fb8e4fc3af64ab07671a2d8)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the placeholder options in a text control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textcontrolplaceholderoptions.html#cfn-quicksight-template-textcontrolplaceholderoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextControlPlaceholderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "info_icon_label_options": "infoIconLabelOptions",
            "placeholder_options": "placeholderOptions",
            "title_options": "titleOptions",
        },
    )
    class TextFieldControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SheetControlInfoIconLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            placeholder_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TextControlPlaceholderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param info_icon_label_options: The configuration of info icon label options.
            :param placeholder_options: The configuration of the placeholder options in a text field control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textfieldcontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                text_field_control_display_options_property = quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                    info_icon_label_options=quicksight.CfnTemplate.SheetControlInfoIconLabelOptionsProperty(
                        info_icon_text="infoIconText",
                        visibility="visibility"
                    ),
                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9189931dd3dea3d3adfef97b11c024be8f5817050e174439da9430a8401f1b02)
                check_type(argname="argument info_icon_label_options", value=info_icon_label_options, expected_type=type_hints["info_icon_label_options"])
                check_type(argname="argument placeholder_options", value=placeholder_options, expected_type=type_hints["placeholder_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if info_icon_label_options is not None:
                self._values["info_icon_label_options"] = info_icon_label_options
            if placeholder_options is not None:
                self._values["placeholder_options"] = placeholder_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def info_icon_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetControlInfoIconLabelOptionsProperty"]]:
            '''The configuration of info icon label options.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textfieldcontroldisplayoptions.html#cfn-quicksight-template-textfieldcontroldisplayoptions-infoiconlabeloptions
            '''
            result = self._values.get("info_icon_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SheetControlInfoIconLabelOptionsProperty"]], result)

        @builtins.property
        def placeholder_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TextControlPlaceholderOptionsProperty"]]:
            '''The configuration of the placeholder options in a text field control.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textfieldcontroldisplayoptions.html#cfn-quicksight-template-textfieldcontroldisplayoptions-placeholderoptions
            '''
            result = self._values.get("placeholder_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TextControlPlaceholderOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textfieldcontroldisplayoptions.html#cfn-quicksight-template-textfieldcontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextFieldControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ThousandSeparatorOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"symbol": "symbol", "visibility": "visibility"},
    )
    class ThousandSeparatorOptionsProperty:
        def __init__(
            self,
            *,
            symbol: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the thousands separator configuration.

            :param symbol: Determines the thousands separator symbol.
            :param visibility: Determines the visibility of the thousands separator.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-thousandseparatoroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                thousand_separator_options_property = quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                    symbol="symbol",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2d397da7da8f8895e7843dea41197da2adbdc9b496633b24de5e2d22287e28a4)
                check_type(argname="argument symbol", value=symbol, expected_type=type_hints["symbol"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if symbol is not None:
                self._values["symbol"] = symbol
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def symbol(self) -> typing.Optional[builtins.str]:
            '''Determines the thousands separator symbol.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-thousandseparatoroptions.html#cfn-quicksight-template-thousandseparatoroptions-symbol
            '''
            result = self._values.get("symbol")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the thousands separator.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-thousandseparatoroptions.html#cfn-quicksight-template-thousandseparatoroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ThousandSeparatorOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "lower_boundary": "lowerBoundary",
            "periods_backward": "periodsBackward",
            "periods_forward": "periodsForward",
            "prediction_interval": "predictionInterval",
            "seasonality": "seasonality",
            "upper_boundary": "upperBoundary",
        },
    )
    class TimeBasedForecastPropertiesProperty:
        def __init__(
            self,
            *,
            lower_boundary: typing.Optional[jsii.Number] = None,
            periods_backward: typing.Optional[jsii.Number] = None,
            periods_forward: typing.Optional[jsii.Number] = None,
            prediction_interval: typing.Optional[jsii.Number] = None,
            seasonality: typing.Optional[jsii.Number] = None,
            upper_boundary: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The forecast properties setup of a forecast in the line chart.

            :param lower_boundary: The lower boundary setup of a forecast computation.
            :param periods_backward: The periods backward setup of a forecast computation.
            :param periods_forward: The periods forward setup of a forecast computation.
            :param prediction_interval: The prediction interval setup of a forecast computation.
            :param seasonality: The seasonality setup of a forecast computation. Choose one of the following options:. - ``NULL`` : The input is set to ``NULL`` . - ``NON_NULL`` : The input is set to a custom value.
            :param upper_boundary: The upper boundary setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                time_based_forecast_properties_property = quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty(
                    lower_boundary=123,
                    periods_backward=123,
                    periods_forward=123,
                    prediction_interval=123,
                    seasonality=123,
                    upper_boundary=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dffa84bb07637bef19d754175e4eda7df87f5f7097f441bea214447c5d4025e7)
                check_type(argname="argument lower_boundary", value=lower_boundary, expected_type=type_hints["lower_boundary"])
                check_type(argname="argument periods_backward", value=periods_backward, expected_type=type_hints["periods_backward"])
                check_type(argname="argument periods_forward", value=periods_forward, expected_type=type_hints["periods_forward"])
                check_type(argname="argument prediction_interval", value=prediction_interval, expected_type=type_hints["prediction_interval"])
                check_type(argname="argument seasonality", value=seasonality, expected_type=type_hints["seasonality"])
                check_type(argname="argument upper_boundary", value=upper_boundary, expected_type=type_hints["upper_boundary"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if lower_boundary is not None:
                self._values["lower_boundary"] = lower_boundary
            if periods_backward is not None:
                self._values["periods_backward"] = periods_backward
            if periods_forward is not None:
                self._values["periods_forward"] = periods_forward
            if prediction_interval is not None:
                self._values["prediction_interval"] = prediction_interval
            if seasonality is not None:
                self._values["seasonality"] = seasonality
            if upper_boundary is not None:
                self._values["upper_boundary"] = upper_boundary

        @builtins.property
        def lower_boundary(self) -> typing.Optional[jsii.Number]:
            '''The lower boundary setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-lowerboundary
            '''
            result = self._values.get("lower_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_backward(self) -> typing.Optional[jsii.Number]:
            '''The periods backward setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-periodsbackward
            '''
            result = self._values.get("periods_backward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_forward(self) -> typing.Optional[jsii.Number]:
            '''The periods forward setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-periodsforward
            '''
            result = self._values.get("periods_forward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def prediction_interval(self) -> typing.Optional[jsii.Number]:
            '''The prediction interval setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-predictioninterval
            '''
            result = self._values.get("prediction_interval")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def seasonality(self) -> typing.Optional[jsii.Number]:
            '''The seasonality setup of a forecast computation. Choose one of the following options:.

            - ``NULL`` : The input is set to ``NULL`` .
            - ``NON_NULL`` : The input is set to a custom value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-seasonality
            '''
            result = self._values.get("seasonality")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def upper_boundary(self) -> typing.Optional[jsii.Number]:
            '''The upper boundary setup of a forecast computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-upperboundary
            '''
            result = self._values.get("upper_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeBasedForecastPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TimeEqualityFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "parameter_name": "parameterName",
            "rolling_date": "rollingDate",
            "time_granularity": "timeGranularity",
            "value": "value",
        },
    )
    class TimeEqualityFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            parameter_name: typing.Optional[builtins.str] = None,
            rolling_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.RollingDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
            value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TimeEqualityFilter`` filters values that are equal to a given value.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param parameter_name: The parameter whose value should be used for the filter value. This field is mutually exclusive to ``Value`` and ``RollingDate`` .
            :param rolling_date: The rolling date input for the ``TimeEquality`` filter. This field is mutually exclusive to ``Value`` and ``ParameterName`` .
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param value: The value of a ``TimeEquality`` filter. This field is mutually exclusive to ``RollingDate`` and ``ParameterName`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                time_equality_filter_property = quicksight.CfnTemplate.TimeEqualityFilterProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                
                    # the properties below are optional
                    parameter_name="parameterName",
                    rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                        expression="expression",
                
                        # the properties below are optional
                        data_set_identifier="dataSetIdentifier"
                    ),
                    time_granularity="timeGranularity",
                    value="value"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__82db54c77dc59198ed92925f9b6bc9b69debc632b93c4881c3529a02b9edca8c)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument rolling_date", value=rolling_date, expected_type=type_hints["rolling_date"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
            }
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if rolling_date is not None:
                self._values["rolling_date"] = rolling_date
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            This field is mutually exclusive to ``Value`` and ``RollingDate`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rolling_date(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RollingDateConfigurationProperty"]]:
            '''The rolling date input for the ``TimeEquality`` filter.

            This field is mutually exclusive to ``Value`` and ``ParameterName`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-rollingdate
            '''
            result = self._values.get("rolling_date")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RollingDateConfigurationProperty"]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(self) -> typing.Optional[builtins.str]:
            '''The value of a ``TimeEquality`` filter.

            This field is mutually exclusive to ``RollingDate`` and ``ParameterName`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeEqualityFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "range_maximum": "rangeMaximum",
            "range_minimum": "rangeMinimum",
            "time_granularity": "timeGranularity",
        },
    )
    class TimeRangeDrillDownFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            range_maximum: builtins.str,
            range_minimum: builtins.str,
            time_granularity: builtins.str,
        ) -> None:
            '''The time range drill down filter.

            :param column: The column that the filter is applied to.
            :param range_maximum: The maximum value for the filter value range.
            :param range_minimum: The minimum value for the filter value range.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                time_range_drill_down_filter_property = quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    range_maximum="rangeMaximum",
                    range_minimum="rangeMinimum",
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1c503912fc54359682621ec49956c2f237650db649a7d27c61ad26698186d635)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument range_maximum", value=range_maximum, expected_type=type_hints["range_maximum"])
                check_type(argname="argument range_minimum", value=range_minimum, expected_type=type_hints["range_minimum"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "range_maximum": range_maximum,
                "range_minimum": range_minimum,
                "time_granularity": time_granularity,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html#cfn-quicksight-template-timerangedrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def range_maximum(self) -> builtins.str:
            '''The maximum value for the filter value range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html#cfn-quicksight-template-timerangedrilldownfilter-rangemaximum
            '''
            result = self._values.get("range_maximum")
            assert result is not None, "Required property 'range_maximum' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def range_minimum(self) -> builtins.str:
            '''The minimum value for the filter value range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html#cfn-quicksight-template-timerangedrilldownfilter-rangeminimum
            '''
            result = self._values.get("range_minimum")
            assert result is not None, "Required property 'range_minimum' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time_granularity(self) -> builtins.str:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html#cfn-quicksight-template-timerangedrilldownfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            assert result is not None, "Required property 'time_granularity' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TimeRangeFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "exclude_period_configuration": "excludePeriodConfiguration",
            "include_maximum": "includeMaximum",
            "include_minimum": "includeMinimum",
            "range_maximum_value": "rangeMaximumValue",
            "range_minimum_value": "rangeMinimumValue",
            "time_granularity": "timeGranularity",
        },
    )
    class TimeRangeFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            null_option: builtins.str,
            exclude_period_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ExcludePeriodConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
            include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
            range_maximum_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TimeRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            range_minimum_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TimeRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TimeRangeFilter`` filters values that are between two specified values.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param exclude_period_configuration: The exclude period of the time range filter.
            :param include_maximum: Determines whether the maximum value in the filter value range should be included in the filtered results.
            :param include_minimum: Determines whether the minimum value in the filter value range should be included in the filtered results.
            :param range_maximum_value: The maximum value for the filter value range.
            :param range_minimum_value: The minimum value for the filter value range.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                time_range_filter_property = quicksight.CfnTemplate.TimeRangeFilterProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                
                    # the properties below are optional
                    exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                        amount=123,
                        granularity="granularity",
                
                        # the properties below are optional
                        status="status"
                    ),
                    include_maximum=False,
                    include_minimum=False,
                    range_maximum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                        parameter="parameter",
                        rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_value="staticValue"
                    ),
                    range_minimum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                        parameter="parameter",
                        rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_value="staticValue"
                    ),
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__eb817873f5ab1f408bed6b52d8d4d3817058206f1fb7c09f1a9797b874c435ef)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument exclude_period_configuration", value=exclude_period_configuration, expected_type=type_hints["exclude_period_configuration"])
                check_type(argname="argument include_maximum", value=include_maximum, expected_type=type_hints["include_maximum"])
                check_type(argname="argument include_minimum", value=include_minimum, expected_type=type_hints["include_minimum"])
                check_type(argname="argument range_maximum_value", value=range_maximum_value, expected_type=type_hints["range_maximum_value"])
                check_type(argname="argument range_minimum_value", value=range_minimum_value, expected_type=type_hints["range_minimum_value"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
            }
            if exclude_period_configuration is not None:
                self._values["exclude_period_configuration"] = exclude_period_configuration
            if include_maximum is not None:
                self._values["include_maximum"] = include_maximum
            if include_minimum is not None:
                self._values["include_minimum"] = include_minimum
            if range_maximum_value is not None:
                self._values["range_maximum_value"] = range_maximum_value
            if range_minimum_value is not None:
                self._values["range_minimum_value"] = range_minimum_value
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def exclude_period_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ExcludePeriodConfigurationProperty"]]:
            '''The exclude period of the time range filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-excludeperiodconfiguration
            '''
            result = self._values.get("exclude_period_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ExcludePeriodConfigurationProperty"]], result)

        @builtins.property
        def include_maximum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''Determines whether the maximum value in the filter value range should be included in the filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-includemaximum
            '''
            result = self._values.get("include_maximum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        @builtins.property
        def include_minimum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''Determines whether the minimum value in the filter value range should be included in the filtered results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-includeminimum
            '''
            result = self._values.get("include_minimum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        @builtins.property
        def range_maximum_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TimeRangeFilterValueProperty"]]:
            '''The maximum value for the filter value range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-rangemaximumvalue
            '''
            result = self._values.get("range_maximum_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TimeRangeFilterValueProperty"]], result)

        @builtins.property
        def range_minimum_value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TimeRangeFilterValueProperty"]]:
            '''The minimum value for the filter value range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-rangeminimumvalue
            '''
            result = self._values.get("range_minimum_value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TimeRangeFilterValueProperty"]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TimeRangeFilterValueProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter": "parameter",
            "rolling_date": "rollingDate",
            "static_value": "staticValue",
        },
    )
    class TimeRangeFilterValueProperty:
        def __init__(
            self,
            *,
            parameter: typing.Optional[builtins.str] = None,
            rolling_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.RollingDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The value of a time range filter.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param parameter: The parameter type input value.
            :param rolling_date: The rolling date input value.
            :param static_value: The static input value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefiltervalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                time_range_filter_value_property = quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                    parameter="parameter",
                    rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                        expression="expression",
                
                        # the properties below are optional
                        data_set_identifier="dataSetIdentifier"
                    ),
                    static_value="staticValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__37d1329b88307470ba01e1e0bdfb1b76dc8193e46c14138f78fa539b25cae9d1)
                check_type(argname="argument parameter", value=parameter, expected_type=type_hints["parameter"])
                check_type(argname="argument rolling_date", value=rolling_date, expected_type=type_hints["rolling_date"])
                check_type(argname="argument static_value", value=static_value, expected_type=type_hints["static_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if parameter is not None:
                self._values["parameter"] = parameter
            if rolling_date is not None:
                self._values["rolling_date"] = rolling_date
            if static_value is not None:
                self._values["static_value"] = static_value

        @builtins.property
        def parameter(self) -> typing.Optional[builtins.str]:
            '''The parameter type input value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefiltervalue.html#cfn-quicksight-template-timerangefiltervalue-parameter
            '''
            result = self._values.get("parameter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rolling_date(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RollingDateConfigurationProperty"]]:
            '''The rolling date input value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefiltervalue.html#cfn-quicksight-template-timerangefiltervalue-rollingdate
            '''
            result = self._values.get("rolling_date")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RollingDateConfigurationProperty"]], result)

        @builtins.property
        def static_value(self) -> typing.Optional[builtins.str]:
            '''The static input value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefiltervalue.html#cfn-quicksight-template-timerangefiltervalue-staticvalue
            '''
            result = self._values.get("static_value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeFilterValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_tooltip_item": "columnTooltipItem",
            "field_tooltip_item": "fieldTooltipItem",
        },
    )
    class TooltipItemProperty:
        def __init__(
            self,
            *,
            column_tooltip_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnTooltipItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_tooltip_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldTooltipItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The tooltip.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param column_tooltip_item: The tooltip item for the columns that are not part of a field well.
            :param field_tooltip_item: The tooltip item for the fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                tooltip_item_property = quicksight.CfnTemplate.TooltipItemProperty(
                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                            attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                simple_attribute_aggregation="simpleAttributeAggregation",
                                value_for_multiple_values="valueForMultipleValues"
                            ),
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        label="label",
                        visibility="visibility"
                    ),
                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        label="label",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b9be9027b1eafcc625e1d8b7fffbdba8895eff81af1a15884d0f05a079acc904)
                check_type(argname="argument column_tooltip_item", value=column_tooltip_item, expected_type=type_hints["column_tooltip_item"])
                check_type(argname="argument field_tooltip_item", value=field_tooltip_item, expected_type=type_hints["field_tooltip_item"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_tooltip_item is not None:
                self._values["column_tooltip_item"] = column_tooltip_item
            if field_tooltip_item is not None:
                self._values["field_tooltip_item"] = field_tooltip_item

        @builtins.property
        def column_tooltip_item(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnTooltipItemProperty"]]:
            '''The tooltip item for the columns that are not part of a field well.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipitem.html#cfn-quicksight-template-tooltipitem-columntooltipitem
            '''
            result = self._values.get("column_tooltip_item")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnTooltipItemProperty"]], result)

        @builtins.property
        def field_tooltip_item(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldTooltipItemProperty"]]:
            '''The tooltip item for the fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipitem.html#cfn-quicksight-template-tooltipitem-fieldtooltipitem
            '''
            result = self._values.get("field_tooltip_item")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldTooltipItemProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TooltipOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_based_tooltip": "fieldBasedTooltip",
            "selected_tooltip_type": "selectedTooltipType",
            "tooltip_visibility": "tooltipVisibility",
        },
    )
    class TooltipOptionsProperty:
        def __init__(
            self,
            *,
            field_based_tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldBasedTooltipProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selected_tooltip_type: typing.Optional[builtins.str] = None,
            tooltip_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The display options for the visual tooltip.

            :param field_based_tooltip: The setup for the detailed tooltip. The tooltip setup is always saved. The display type is decided based on the tooltip type.
            :param selected_tooltip_type: The selected type for the tooltip. Choose one of the following options:. - ``BASIC`` : A basic tooltip. - ``DETAILED`` : A detailed tooltip.
            :param tooltip_visibility: Determines whether or not the tooltip is visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                tooltip_options_property = quicksight.CfnTemplate.TooltipOptionsProperty(
                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                        aggregation_visibility="aggregationVisibility",
                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                        simple_attribute_aggregation="simpleAttributeAggregation",
                                        value_for_multiple_values="valueForMultipleValues"
                                    ),
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                label="label",
                                visibility="visibility"
                            ),
                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                label="label",
                                visibility="visibility"
                            )
                        )],
                        tooltip_title_type="tooltipTitleType"
                    ),
                    selected_tooltip_type="selectedTooltipType",
                    tooltip_visibility="tooltipVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7d3ad67242a50351d99986e8e684ea5c64b14ae1d1c1ec30709396ec79d71789)
                check_type(argname="argument field_based_tooltip", value=field_based_tooltip, expected_type=type_hints["field_based_tooltip"])
                check_type(argname="argument selected_tooltip_type", value=selected_tooltip_type, expected_type=type_hints["selected_tooltip_type"])
                check_type(argname="argument tooltip_visibility", value=tooltip_visibility, expected_type=type_hints["tooltip_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_based_tooltip is not None:
                self._values["field_based_tooltip"] = field_based_tooltip
            if selected_tooltip_type is not None:
                self._values["selected_tooltip_type"] = selected_tooltip_type
            if tooltip_visibility is not None:
                self._values["tooltip_visibility"] = tooltip_visibility

        @builtins.property
        def field_based_tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldBasedTooltipProperty"]]:
            '''The setup for the detailed tooltip.

            The tooltip setup is always saved. The display type is decided based on the tooltip type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipoptions.html#cfn-quicksight-template-tooltipoptions-fieldbasedtooltip
            '''
            result = self._values.get("field_based_tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldBasedTooltipProperty"]], result)

        @builtins.property
        def selected_tooltip_type(self) -> typing.Optional[builtins.str]:
            '''The selected type for the tooltip. Choose one of the following options:.

            - ``BASIC`` : A basic tooltip.
            - ``DETAILED`` : A detailed tooltip.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipoptions.html#cfn-quicksight-template-tooltipoptions-selectedtooltiptype
            '''
            result = self._values.get("selected_tooltip_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tooltip_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the tooltip is visible.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipoptions.html#cfn-quicksight-template-tooltipoptions-tooltipvisibility
            '''
            result = self._values.get("tooltip_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TooltipOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TopBottomFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_sort_configurations": "aggregationSortConfigurations",
            "column": "column",
            "filter_id": "filterId",
            "limit": "limit",
            "parameter_name": "parameterName",
            "time_granularity": "timeGranularity",
        },
    )
    class TopBottomFilterProperty:
        def __init__(
            self,
            *,
            aggregation_sort_configurations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AggregationSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            limit: typing.Optional[jsii.Number] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TopBottomFilter`` filters values that are at the top or the bottom.

            :param aggregation_sort_configurations: The aggregation and sort configuration of the top bottom filter.
            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param limit: The number of items to include in the top bottom filter results.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                top_bottom_filter_property = quicksight.CfnTemplate.TopBottomFilterProperty(
                    aggregation_sort_configurations=[quicksight.CfnTemplate.AggregationSortConfigurationProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        sort_direction="sortDirection",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                            attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                simple_attribute_aggregation="simpleAttributeAggregation",
                                value_for_multiple_values="valueForMultipleValues"
                            ),
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    )],
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                
                    # the properties below are optional
                    limit=123,
                    parameter_name="parameterName",
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__41846fec1e1aa2e86614deee24ef480c9bac3d7f16c2108ff36087831ed73155)
                check_type(argname="argument aggregation_sort_configurations", value=aggregation_sort_configurations, expected_type=type_hints["aggregation_sort_configurations"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "aggregation_sort_configurations": aggregation_sort_configurations,
                "column": column,
                "filter_id": filter_id,
            }
            if limit is not None:
                self._values["limit"] = limit
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def aggregation_sort_configurations(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AggregationSortConfigurationProperty"]]]:
            '''The aggregation and sort configuration of the top bottom filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-aggregationsortconfigurations
            '''
            result = self._values.get("aggregation_sort_configurations")
            assert result is not None, "Required property 'aggregation_sort_configurations' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AggregationSortConfigurationProperty"]]], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def limit(self) -> typing.Optional[jsii.Number]:
            '''The number of items to include in the top bottom filter results.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-limit
            '''
            result = self._values.get("limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TopBottomMoversComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "type": "type",
            "category": "category",
            "mover_size": "moverSize",
            "name": "name",
            "sort_order": "sortOrder",
            "time": "time",
            "value": "value",
        },
    )
    class TopBottomMoversComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            type: builtins.str,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mover_size: typing.Optional[jsii.Number] = None,
            name: typing.Optional[builtins.str] = None,
            sort_order: typing.Optional[builtins.str] = None,
            time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The top movers and bottom movers computation setup.

            :param computation_id: The ID for a computation.
            :param type: The computation type. Choose from the following options:. - TOP: Top movers computation. - BOTTOM: Bottom movers computation.
            :param category: The category field that is used in a computation.
            :param mover_size: The mover size setup of the top and bottom movers computation. Default: - 0
            :param name: The name of a computation.
            :param sort_order: The sort order setup of the top and bottom movers computation.
            :param time: The time field that is used in a computation.
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f37be253a5e5d32ec97edc66b99be2af738b88ef98625f19eb8dadef6cbfe392)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument mover_size", value=mover_size, expected_type=type_hints["mover_size"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sort_order", value=sort_order, expected_type=type_hints["sort_order"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "type": type,
            }
            if category is not None:
                self._values["category"] = category
            if mover_size is not None:
                self._values["mover_size"] = mover_size
            if name is not None:
                self._values["name"] = name
            if sort_order is not None:
                self._values["sort_order"] = sort_order
            if time is not None:
                self._values["time"] = time
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The computation type. Choose from the following options:.

            - TOP: Top movers computation.
            - BOTTOM: Bottom movers computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]:
            '''The category field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]], result)

        @builtins.property
        def mover_size(self) -> typing.Optional[jsii.Number]:
            '''The mover size setup of the top and bottom movers computation.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-moversize
            '''
            result = self._values.get("mover_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sort_order(self) -> typing.Optional[builtins.str]:
            '''The sort order setup of the top and bottom movers computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-sortorder
            '''
            result = self._values.get("sort_order")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]:
            '''The time field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-time
            '''
            result = self._values.get("time")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomMoversComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TopBottomRankedComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "type": "type",
            "category": "category",
            "name": "name",
            "result_size": "resultSize",
            "value": "value",
        },
    )
    class TopBottomRankedComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            type: builtins.str,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            name: typing.Optional[builtins.str] = None,
            result_size: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The top ranked and bottom ranked computation configuration.

            :param computation_id: The ID for a computation.
            :param type: The computation type. Choose one of the following options:. - TOP: A top ranked computation. - BOTTOM: A bottom ranked computation.
            :param category: The category field that is used in a computation.
            :param name: The name of a computation.
            :param result_size: The result size of a top and bottom ranked computation. Default: - 0
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3e72ca65aab34d2a096e9fdfec9e7be28828777768797ebe577480319b4c1de0)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument result_size", value=result_size, expected_type=type_hints["result_size"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "type": type,
            }
            if category is not None:
                self._values["category"] = category
            if name is not None:
                self._values["name"] = name
            if result_size is not None:
                self._values["result_size"] = result_size
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The computation type. Choose one of the following options:.

            - TOP: A top ranked computation.
            - BOTTOM: A bottom ranked computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]:
            '''The category field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def result_size(self) -> typing.Optional[jsii.Number]:
            '''The result size of a top and bottom ranked computation.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-resultsize
            '''
            result = self._values.get("result_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomRankedComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TotalAggregationComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "name": "name",
            "value": "value",
        },
    )
    class TotalAggregationComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            name: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The total aggregation computation configuration.

            :param computation_id: The ID for a computation.
            :param name: The name of a computation.
            :param value: The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                total_aggregation_computation_property = quicksight.CfnTemplate.TotalAggregationComputationProperty(
                    computation_id="computationId",
                
                    # the properties below are optional
                    name="name",
                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7147e0c586db8a2c6e5a828daf02618345defd5d932f01e6255b2284a7240ec3)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
            }
            if name is not None:
                self._values["name"] = name
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationcomputation.html#cfn-quicksight-template-totalaggregationcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationcomputation.html#cfn-quicksight-template-totalaggregationcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationcomputation.html#cfn-quicksight-template-totalaggregationcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalAggregationComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TotalAggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "simple_total_aggregation_function": "simpleTotalAggregationFunction",
        },
    )
    class TotalAggregationFunctionProperty:
        def __init__(
            self,
            *,
            simple_total_aggregation_function: typing.Optional[builtins.str] = None,
        ) -> None:
            '''An aggregation function that aggregates the total values of a measure.

            :param simple_total_aggregation_function: A built in aggregation function for total values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                total_aggregation_function_property = quicksight.CfnTemplate.TotalAggregationFunctionProperty(
                    simple_total_aggregation_function="simpleTotalAggregationFunction"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f85fb3c95e3ca79dd60b64c25ed1804935d18e91465877fa56574694d5206233)
                check_type(argname="argument simple_total_aggregation_function", value=simple_total_aggregation_function, expected_type=type_hints["simple_total_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if simple_total_aggregation_function is not None:
                self._values["simple_total_aggregation_function"] = simple_total_aggregation_function

        @builtins.property
        def simple_total_aggregation_function(self) -> typing.Optional[builtins.str]:
            '''A built in aggregation function for total values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationfunction.html#cfn-quicksight-template-totalaggregationfunction-simpletotalaggregationfunction
            '''
            result = self._values.get("simple_total_aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalAggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TotalAggregationOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "total_aggregation_function": "totalAggregationFunction",
        },
    )
    class TotalAggregationOptionProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            total_aggregation_function: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TotalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The total aggregation settings map of a field id.

            :param field_id: The field id that's associated with the total aggregation option.
            :param total_aggregation_function: The total aggregation function that you want to set for a specified field id.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                total_aggregation_option_property = quicksight.CfnTemplate.TotalAggregationOptionProperty(
                    field_id="fieldId",
                    total_aggregation_function=quicksight.CfnTemplate.TotalAggregationFunctionProperty(
                        simple_total_aggregation_function="simpleTotalAggregationFunction"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__84172644037d22fa48e11f8e13bcb01c3ea8c0255c9d3cf400ea9cc5811bcdf9)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument total_aggregation_function", value=total_aggregation_function, expected_type=type_hints["total_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
                "total_aggregation_function": total_aggregation_function,
            }

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field id that's associated with the total aggregation option.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationoption.html#cfn-quicksight-template-totalaggregationoption-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def total_aggregation_function(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.TotalAggregationFunctionProperty"]:
            '''The total aggregation function that you want to set for a specified field id.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationoption.html#cfn-quicksight-template-totalaggregationoption-totalaggregationfunction
            '''
            result = self._values.get("total_aggregation_function")
            assert result is not None, "Required property 'total_aggregation_function' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.TotalAggregationFunctionProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalAggregationOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "placement": "placement",
            "scroll_status": "scrollStatus",
            "total_aggregation_options": "totalAggregationOptions",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
        },
    )
    class TotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            placement: typing.Optional[builtins.str] = None,
            scroll_status: typing.Optional[builtins.str] = None,
            total_aggregation_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TotalAggregationOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            total_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The total options for a table visual.

            :param custom_label: The custom label string for the total cells.
            :param placement: The placement (start, end) for the total cells.
            :param scroll_status: The scroll status (pinned, scrolled) for the total cells.
            :param total_aggregation_options: The total aggregation settings for each value field.
            :param total_cell_style: Cell styling options for the total cells.
            :param totals_visibility: The visibility configuration for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                total_options_property = quicksight.CfnTemplate.TotalOptionsProperty(
                    custom_label="customLabel",
                    placement="placement",
                    scroll_status="scrollStatus",
                    total_aggregation_options=[quicksight.CfnTemplate.TotalAggregationOptionProperty(
                        field_id="fieldId",
                        total_aggregation_function=quicksight.CfnTemplate.TotalAggregationFunctionProperty(
                            simple_total_aggregation_function="simpleTotalAggregationFunction"
                        )
                    )],
                    total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a496edcf300ce3343e7814a6546bd962adb9fc4f21bb9108e16a344e13767696)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument placement", value=placement, expected_type=type_hints["placement"])
                check_type(argname="argument scroll_status", value=scroll_status, expected_type=type_hints["scroll_status"])
                check_type(argname="argument total_aggregation_options", value=total_aggregation_options, expected_type=type_hints["total_aggregation_options"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if placement is not None:
                self._values["placement"] = placement
            if scroll_status is not None:
                self._values["scroll_status"] = scroll_status
            if total_aggregation_options is not None:
                self._values["total_aggregation_options"] = total_aggregation_options
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def placement(self) -> typing.Optional[builtins.str]:
            '''The placement (start, end) for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-placement
            '''
            result = self._values.get("placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scroll_status(self) -> typing.Optional[builtins.str]:
            '''The scroll status (pinned, scrolled) for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-scrollstatus
            '''
            result = self._values.get("scroll_status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def total_aggregation_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TotalAggregationOptionProperty"]]]]:
            '''The total aggregation settings for each value field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-totalaggregationoptions
            '''
            result = self._values.get("total_aggregation_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TotalAggregationOptionProperty"]]]], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]]:
            '''Cell styling options for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the total cells.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TreeMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"colors": "colors", "groups": "groups", "sizes": "sizes"},
    )
    class TreeMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sizes: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''Aggregated field wells of a tree map.

            :param colors: The color field well of a tree map. Values are grouped by aggregations based on group by fields.
            :param groups: The group by field well of a tree map. Values are grouped based on group by fields.
            :param sizes: The size field well of a tree map. Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__58d9f611360a00b5cbb0082e1a3b44fc0cba018dcac0afe98725ca272b084516)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument groups", value=groups, expected_type=type_hints["groups"])
                check_type(argname="argument sizes", value=sizes, expected_type=type_hints["sizes"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors
            if groups is not None:
                self._values["groups"] = groups
            if sizes is not None:
                self._values["sizes"] = sizes

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The color field well of a tree map.

            Values are grouped by aggregations based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapaggregatedfieldwells.html#cfn-quicksight-template-treemapaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        @builtins.property
        def groups(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The group by field well of a tree map.

            Values are grouped based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapaggregatedfieldwells.html#cfn-quicksight-template-treemapaggregatedfieldwells-groups
            '''
            result = self._values.get("groups")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def sizes(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The size field well of a tree map.

            Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapaggregatedfieldwells.html#cfn-quicksight-template-treemapaggregatedfieldwells-sizes
            '''
            result = self._values.get("sizes")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TreeMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_label_options": "colorLabelOptions",
            "color_scale": "colorScale",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "group_label_options": "groupLabelOptions",
            "legend": "legend",
            "size_label_options": "sizeLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
        },
    )
    class TreeMapConfigurationProperty:
        def __init__(
            self,
            *,
            color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_scale: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColorScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TreeMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            group_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            size_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TreeMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a tree map.

            :param color_label_options: The label options (label text, label visibility) for the colors displayed in a tree map.
            :param color_scale: The color options (gradient color, point of divergence) of a tree map.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param group_label_options: The label options (label text, label visibility) of the groups that are displayed in a tree map.
            :param legend: The legend display setup of the visual.
            :param size_label_options: The label options (label text, label visibility) of the sizes that are displayed in a tree map.
            :param sort_configuration: The sort configuration of a tree map.
            :param tooltip: The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__277052b6ad49367c36f4513a47753b3482edefbd6fbfe6ca4c3328b3cf0715e9)
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument color_scale", value=color_scale, expected_type=type_hints["color_scale"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument group_label_options", value=group_label_options, expected_type=type_hints["group_label_options"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument size_label_options", value=size_label_options, expected_type=type_hints["size_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if color_scale is not None:
                self._values["color_scale"] = color_scale
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if group_label_options is not None:
                self._values["group_label_options"] = group_label_options
            if legend is not None:
                self._values["legend"] = legend
            if size_label_options is not None:
                self._values["size_label_options"] = size_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility) for the colors displayed in a tree map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_scale(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColorScaleProperty"]]:
            '''The color options (gradient color, point of divergence) of a tree map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-colorscale
            '''
            result = self._values.get("color_scale")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColorScaleProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TreeMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TreeMapFieldWellsProperty"]], result)

        @builtins.property
        def group_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility) of the groups that are displayed in a tree map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-grouplabeloptions
            '''
            result = self._values.get("group_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def size_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility) of the sizes that are displayed in a tree map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-sizelabeloptions
            '''
            result = self._values.get("size_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TreeMapSortConfigurationProperty"]]:
            '''The sort configuration of a tree map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TreeMapSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TooltipOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TreeMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "tree_map_aggregated_field_wells": "treeMapAggregatedFieldWells",
        },
    )
    class TreeMapFieldWellsProperty:
        def __init__(
            self,
            *,
            tree_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TreeMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a tree map.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param tree_map_aggregated_field_wells: The aggregated field wells of a tree map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a2f25f599e767f8263a820c3fab79c28f80a2012bd07d4892a3e11360691c87c)
                check_type(argname="argument tree_map_aggregated_field_wells", value=tree_map_aggregated_field_wells, expected_type=type_hints["tree_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if tree_map_aggregated_field_wells is not None:
                self._values["tree_map_aggregated_field_wells"] = tree_map_aggregated_field_wells

        @builtins.property
        def tree_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TreeMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a tree map.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapfieldwells.html#cfn-quicksight-template-treemapfieldwells-treemapaggregatedfieldwells
            '''
            result = self._values.get("tree_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TreeMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TreeMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "tree_map_group_items_limit_configuration": "treeMapGroupItemsLimitConfiguration",
            "tree_map_sort": "treeMapSort",
        },
    )
    class TreeMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            tree_map_group_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tree_map_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a tree map.

            :param tree_map_group_items_limit_configuration: The limit on the number of groups that are displayed.
            :param tree_map_sort: The sort configuration of group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                tree_map_sort_configuration_property = quicksight.CfnTemplate.TreeMapSortConfigurationProperty(
                    tree_map_group_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    tree_map_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5acae2a51dd77d02772040e7588a09566143b3f2f3305d214225a8d72bb7813c)
                check_type(argname="argument tree_map_group_items_limit_configuration", value=tree_map_group_items_limit_configuration, expected_type=type_hints["tree_map_group_items_limit_configuration"])
                check_type(argname="argument tree_map_sort", value=tree_map_sort, expected_type=type_hints["tree_map_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if tree_map_group_items_limit_configuration is not None:
                self._values["tree_map_group_items_limit_configuration"] = tree_map_group_items_limit_configuration
            if tree_map_sort is not None:
                self._values["tree_map_sort"] = tree_map_sort

        @builtins.property
        def tree_map_group_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of groups that are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapsortconfiguration.html#cfn-quicksight-template-treemapsortconfiguration-treemapgroupitemslimitconfiguration
            '''
            result = self._values.get("tree_map_group_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def tree_map_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapsortconfiguration.html#cfn-quicksight-template-treemapsortconfiguration-treemapsort
            '''
            result = self._values.get("tree_map_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TreeMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class TreeMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TreeMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A tree map.

            For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1c62c9ffa127290e2244bd59d4483c71075aed723f631b2404be11bfdb044c0a)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TreeMapConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TreeMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.TrendArrowOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class TrendArrowOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of trend arrows in a KPI visual.

            :param visibility: The visibility of the trend arrows.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-trendarrowoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                trend_arrow_options_property = quicksight.CfnTemplate.TrendArrowOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2839b234a31139976acf12941e6957dbd01494e54f63fe8824575853b04b1429)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the trend arrows.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-trendarrowoptions.html#cfn-quicksight-template-trendarrowoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TrendArrowOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.UnaggregatedFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
        },
    )
    class UnaggregatedFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The unaggregated field for a table.

            :param column: The column that is used in the ``UnaggregatedField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-unaggregatedfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                unaggregated_field_property = quicksight.CfnTemplate.UnaggregatedFieldProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6503062ec15a4691568519426046f7b1fbb537e033f2db33f6547d6394260812)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that is used in the ``UnaggregatedField`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-unaggregatedfield.html#cfn-quicksight-template-unaggregatedfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-unaggregatedfield.html#cfn-quicksight-template-unaggregatedfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-unaggregatedfield.html#cfn-quicksight-template-unaggregatedfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UnaggregatedFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.UniqueValuesComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "category": "category",
            "name": "name",
        },
    )
    class UniqueValuesComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The unique values computation configuration.

            :param computation_id: The ID for a computation.
            :param category: The category field that is used in a computation.
            :param name: The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-uniquevaluescomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                unique_values_computation_property = quicksight.CfnTemplate.UniqueValuesComputationProperty(
                    computation_id="computationId",
                
                    # the properties below are optional
                    category=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__354e3ff926eebcfb6d7f61649d46d0ae27d05164eff8e46e79271a6862cda687)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
            }
            if category is not None:
                self._values["category"] = category
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-uniquevaluescomputation.html#cfn-quicksight-template-uniquevaluescomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]:
            '''The category field that is used in a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-uniquevaluescomputation.html#cfn-quicksight-template-uniquevaluescomputation-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-uniquevaluescomputation.html#cfn-quicksight-template-uniquevaluescomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UniqueValuesComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.ValidationStrategyProperty",
        jsii_struct_bases=[],
        name_mapping={"mode": "mode"},
    )
    class ValidationStrategyProperty:
        def __init__(self, *, mode: builtins.str) -> None:
            '''The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects.

            When you set this value to ``LENIENT`` , validation is skipped for specific errors.

            :param mode: The mode of validation for the asset to be created or updated. When you set this value to ``STRICT`` , strict validation for every error is enforced. When you set this value to ``LENIENT`` , validation is skipped for specific UI errors.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-validationstrategy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                validation_strategy_property = quicksight.CfnTemplate.ValidationStrategyProperty(
                    mode="mode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4031b4f0222cb7dbd9d665663f64e810d1a958d165896f18e01058d8e035b5d7)
                check_type(argname="argument mode", value=mode, expected_type=type_hints["mode"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "mode": mode,
            }

        @builtins.property
        def mode(self) -> builtins.str:
            '''The mode of validation for the asset to be created or updated.

            When you set this value to ``STRICT`` , strict validation for every error is enforced. When you set this value to ``LENIENT`` , validation is skipped for specific UI errors.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-validationstrategy.html#cfn-quicksight-template-validationstrategy-mode
            '''
            result = self._values.get("mode")
            assert result is not None, "Required property 'mode' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ValidationStrategyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.VisibleRangeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"percent_range": "percentRange"},
    )
    class VisibleRangeOptionsProperty:
        def __init__(
            self,
            *,
            percent_range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PercentVisibleRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The range options for the data zoom scroll bar.

            :param percent_range: The percent range in the visible range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visiblerangeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                visible_range_options_property = quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                        from=123,
                        to=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0f86673dd492374c4a12f9c7568b336f404aba0ab679a3d7dd6cdcd2186ed954)
                check_type(argname="argument percent_range", value=percent_range, expected_type=type_hints["percent_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percent_range is not None:
                self._values["percent_range"] = percent_range

        @builtins.property
        def percent_range(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PercentVisibleRangeProperty"]]:
            '''The percent range in the visible range.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visiblerangeoptions.html#cfn-quicksight-template-visiblerangeoptions-percentrange
            '''
            result = self._values.get("percent_range")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PercentVisibleRangeProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisibleRangeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.VisualCustomActionOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_operation": "filterOperation",
            "navigation_operation": "navigationOperation",
            "set_parameters_operation": "setParametersOperation",
            "url_operation": "urlOperation",
        },
    )
    class VisualCustomActionOperationProperty:
        def __init__(
            self,
            *,
            filter_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CustomActionFilterOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            navigation_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CustomActionNavigationOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            set_parameters_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CustomActionSetParametersOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            url_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CustomActionURLOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The operation that is defined by the custom action.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param filter_operation: The filter operation that filters data included in a visual or in an entire sheet.
            :param navigation_operation: The navigation operation that navigates between different sheets in the same analysis.
            :param set_parameters_operation: The set parameter operation that sets parameters in custom action.
            :param url_operation: The URL operation that opens a link to another webpage.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                visual_custom_action_operation_property = quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                            selected_columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            selected_field_options="selectedFieldOptions",
                            selected_fields=["selectedFields"]
                        ),
                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                target_visual_options="targetVisualOptions",
                                target_visuals=["targetVisuals"]
                            )
                        )
                    ),
                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                            target_sheet_id="targetSheetId"
                        )
                    ),
                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                            destination_parameter_name="destinationParameterName",
                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                        date_time_values=["dateTimeValues"],
                                        decimal_values=[123],
                                        integer_values=[123],
                                        string_values=["stringValues"]
                                    ),
                
                                    # the properties below are optional
                                    include_null_value=False
                                ),
                                select_all_value_options="selectAllValueOptions",
                                source_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_field="sourceField",
                                source_parameter_name="sourceParameterName"
                            )
                        )]
                    ),
                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                        url_target="urlTarget",
                        url_template="urlTemplate"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d8f60b8a1ca99ae307f7c54ffa4387b522534f9ccb2bb011dee92f65ff8c1902)
                check_type(argname="argument filter_operation", value=filter_operation, expected_type=type_hints["filter_operation"])
                check_type(argname="argument navigation_operation", value=navigation_operation, expected_type=type_hints["navigation_operation"])
                check_type(argname="argument set_parameters_operation", value=set_parameters_operation, expected_type=type_hints["set_parameters_operation"])
                check_type(argname="argument url_operation", value=url_operation, expected_type=type_hints["url_operation"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if filter_operation is not None:
                self._values["filter_operation"] = filter_operation
            if navigation_operation is not None:
                self._values["navigation_operation"] = navigation_operation
            if set_parameters_operation is not None:
                self._values["set_parameters_operation"] = set_parameters_operation
            if url_operation is not None:
                self._values["url_operation"] = url_operation

        @builtins.property
        def filter_operation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomActionFilterOperationProperty"]]:
            '''The filter operation that filters data included in a visual or in an entire sheet.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html#cfn-quicksight-template-visualcustomactionoperation-filteroperation
            '''
            result = self._values.get("filter_operation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomActionFilterOperationProperty"]], result)

        @builtins.property
        def navigation_operation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomActionNavigationOperationProperty"]]:
            '''The navigation operation that navigates between different sheets in the same analysis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html#cfn-quicksight-template-visualcustomactionoperation-navigationoperation
            '''
            result = self._values.get("navigation_operation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomActionNavigationOperationProperty"]], result)

        @builtins.property
        def set_parameters_operation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomActionSetParametersOperationProperty"]]:
            '''The set parameter operation that sets parameters in custom action.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html#cfn-quicksight-template-visualcustomactionoperation-setparametersoperation
            '''
            result = self._values.get("set_parameters_operation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomActionSetParametersOperationProperty"]], result)

        @builtins.property
        def url_operation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomActionURLOperationProperty"]]:
            '''The URL operation that opens a link to another webpage.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html#cfn-quicksight-template-visualcustomactionoperation-urloperation
            '''
            result = self._values.get("url_operation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomActionURLOperationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualCustomActionOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.VisualCustomActionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "action_operations": "actionOperations",
            "custom_action_id": "customActionId",
            "name": "name",
            "trigger": "trigger",
            "status": "status",
        },
    )
    class VisualCustomActionProperty:
        def __init__(
            self,
            *,
            action_operations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionOperationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            custom_action_id: builtins.str,
            name: builtins.str,
            trigger: builtins.str,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A custom action defined on a visual.

            :param action_operations: A list of ``VisualCustomActionOperations`` . This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
            :param custom_action_id: The ID of the ``VisualCustomAction`` .
            :param name: The name of the ``VisualCustomAction`` .
            :param trigger: The trigger of the ``VisualCustomAction`` . Valid values are defined as follows: - ``DATA_POINT_CLICK`` : Initiates a custom action by a left pointer click on a data point. - ``DATA_POINT_MENU`` : Initiates a custom action by right pointer click from the menu.
            :param status: The status of the ``VisualCustomAction`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                visual_custom_action_property = quicksight.CfnTemplate.VisualCustomActionProperty(
                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                selected_columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                selected_field_options="selectedFieldOptions",
                                selected_fields=["selectedFields"]
                            ),
                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                    target_visual_options="targetVisualOptions",
                                    target_visuals=["targetVisuals"]
                                )
                            )
                        ),
                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                target_sheet_id="targetSheetId"
                            )
                        ),
                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                destination_parameter_name="destinationParameterName",
                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                            date_time_values=["dateTimeValues"],
                                            decimal_values=[123],
                                            integer_values=[123],
                                            string_values=["stringValues"]
                                        ),
                
                                        # the properties below are optional
                                        include_null_value=False
                                    ),
                                    select_all_value_options="selectAllValueOptions",
                                    source_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_field="sourceField",
                                    source_parameter_name="sourceParameterName"
                                )
                            )]
                        ),
                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                            url_target="urlTarget",
                            url_template="urlTemplate"
                        )
                    )],
                    custom_action_id="customActionId",
                    name="name",
                    trigger="trigger",
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8ce5758fd282e2d9cb311d8afd2daf9144e12ab11e45a2064dae74e24dcdcb88)
                check_type(argname="argument action_operations", value=action_operations, expected_type=type_hints["action_operations"])
                check_type(argname="argument custom_action_id", value=custom_action_id, expected_type=type_hints["custom_action_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument trigger", value=trigger, expected_type=type_hints["trigger"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "action_operations": action_operations,
                "custom_action_id": custom_action_id,
                "name": name,
                "trigger": trigger,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def action_operations(
            self,
        ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionOperationProperty"]]]:
            '''A list of ``VisualCustomActionOperations`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-actionoperations
            '''
            result = self._values.get("action_operations")
            assert result is not None, "Required property 'action_operations' is missing"
            return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionOperationProperty"]]], result)

        @builtins.property
        def custom_action_id(self) -> builtins.str:
            '''The ID of the ``VisualCustomAction`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-customactionid
            '''
            result = self._values.get("custom_action_id")
            assert result is not None, "Required property 'custom_action_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the ``VisualCustomAction`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def trigger(self) -> builtins.str:
            '''The trigger of the ``VisualCustomAction`` .

            Valid values are defined as follows:

            - ``DATA_POINT_CLICK`` : Initiates a custom action by a left pointer click on a data point.
            - ``DATA_POINT_MENU`` : Initiates a custom action by right pointer click from the menu.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-trigger
            '''
            result = self._values.get("trigger")
            assert result is not None, "Required property 'trigger' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the ``VisualCustomAction`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualCustomActionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.VisualPaletteProperty",
        jsii_struct_bases=[],
        name_mapping={"chart_color": "chartColor", "color_map": "colorMap"},
    )
    class VisualPaletteProperty:
        def __init__(
            self,
            *,
            chart_color: typing.Optional[builtins.str] = None,
            color_map: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataPathColorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The visual display options for the visual palette.

            :param chart_color: The chart color options for the visual palette.
            :param color_map: The color map options for the visual palette.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualpalette.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                visual_palette_property = quicksight.CfnTemplate.VisualPaletteProperty(
                    chart_color="chartColor",
                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                        color="color",
                        element=quicksight.CfnTemplate.DataPathValueProperty(
                            data_path_type=quicksight.CfnTemplate.DataPathTypeProperty(
                                pivot_table_data_path_type="pivotTableDataPathType"
                            ),
                            field_id="fieldId",
                            field_value="fieldValue"
                        ),
                
                        # the properties below are optional
                        time_granularity="timeGranularity"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2eb5e88c498a04f3ec75fcac7df165e17071f53c0213813bd77bbf1cdde2e0b6)
                check_type(argname="argument chart_color", value=chart_color, expected_type=type_hints["chart_color"])
                check_type(argname="argument color_map", value=color_map, expected_type=type_hints["color_map"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if chart_color is not None:
                self._values["chart_color"] = chart_color
            if color_map is not None:
                self._values["color_map"] = color_map

        @builtins.property
        def chart_color(self) -> typing.Optional[builtins.str]:
            '''The chart color options for the visual palette.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualpalette.html#cfn-quicksight-template-visualpalette-chartcolor
            '''
            result = self._values.get("chart_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def color_map(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataPathColorProperty"]]]]:
            '''The color map options for the visual palette.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualpalette.html#cfn-quicksight-template-visualpalette-colormap
            '''
            result = self._values.get("color_map")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataPathColorProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualPaletteProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.VisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_chart_visual": "barChartVisual",
            "box_plot_visual": "boxPlotVisual",
            "combo_chart_visual": "comboChartVisual",
            "custom_content_visual": "customContentVisual",
            "empty_visual": "emptyVisual",
            "filled_map_visual": "filledMapVisual",
            "funnel_chart_visual": "funnelChartVisual",
            "gauge_chart_visual": "gaugeChartVisual",
            "geospatial_map_visual": "geospatialMapVisual",
            "heat_map_visual": "heatMapVisual",
            "histogram_visual": "histogramVisual",
            "insight_visual": "insightVisual",
            "kpi_visual": "kpiVisual",
            "line_chart_visual": "lineChartVisual",
            "pie_chart_visual": "pieChartVisual",
            "pivot_table_visual": "pivotTableVisual",
            "radar_chart_visual": "radarChartVisual",
            "sankey_diagram_visual": "sankeyDiagramVisual",
            "scatter_plot_visual": "scatterPlotVisual",
            "table_visual": "tableVisual",
            "tree_map_visual": "treeMapVisual",
            "waterfall_visual": "waterfallVisual",
            "word_cloud_visual": "wordCloudVisual",
        },
    )
    class VisualProperty:
        def __init__(
            self,
            *,
            bar_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.BarChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            box_plot_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.BoxPlotVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            combo_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ComboChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_content_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.CustomContentVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            empty_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.EmptyVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            filled_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FilledMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            funnel_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FunnelChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            gauge_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GaugeChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            geospatial_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.GeospatialMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            heat_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.HeatMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            histogram_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.HistogramVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            insight_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.InsightVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            kpi_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.KPIVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            line_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LineChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            pie_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PieChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            pivot_table_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.PivotTableVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            radar_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.RadarChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sankey_diagram_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.SankeyDiagramVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scatter_plot_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ScatterPlotVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TableVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tree_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.TreeMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            waterfall_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.WaterfallVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            word_cloud_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.WordCloudVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A visual displayed on a sheet in an analysis, dashboard, or template.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param bar_chart_visual: A bar chart. For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param box_plot_visual: A box plot. For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .
            :param combo_chart_visual: A combo chart. For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param custom_content_visual: A visual that contains custom content. For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .
            :param empty_visual: An empty visual.
            :param filled_map_visual: A filled map. For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .
            :param funnel_chart_visual: A funnel chart. For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .
            :param gauge_chart_visual: A gauge chart. For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param geospatial_map_visual: A geospatial map or a points on map visual. For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .
            :param heat_map_visual: A heat map. For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .
            :param histogram_visual: A histogram. For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param insight_visual: An insight visual. For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .
            :param kpi_visual: A key performance indicator (KPI). For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .
            :param line_chart_visual: A line chart. For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param pie_chart_visual: A pie or donut chart. For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param pivot_table_visual: A pivot table. For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .
            :param radar_chart_visual: A radar chart visual. For more information, see `Using radar charts <https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param sankey_diagram_visual: A sankey diagram. For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .
            :param scatter_plot_visual: A scatter plot. For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .
            :param table_visual: A table visual. For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .
            :param tree_map_visual: A tree map. For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .
            :param waterfall_visual: A waterfall chart. For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param word_cloud_visual: A word cloud. For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e016b1dfd9b52a4c51b4649fe1d589d5b5decc781c92161cd3e4357408f9e1aa)
                check_type(argname="argument bar_chart_visual", value=bar_chart_visual, expected_type=type_hints["bar_chart_visual"])
                check_type(argname="argument box_plot_visual", value=box_plot_visual, expected_type=type_hints["box_plot_visual"])
                check_type(argname="argument combo_chart_visual", value=combo_chart_visual, expected_type=type_hints["combo_chart_visual"])
                check_type(argname="argument custom_content_visual", value=custom_content_visual, expected_type=type_hints["custom_content_visual"])
                check_type(argname="argument empty_visual", value=empty_visual, expected_type=type_hints["empty_visual"])
                check_type(argname="argument filled_map_visual", value=filled_map_visual, expected_type=type_hints["filled_map_visual"])
                check_type(argname="argument funnel_chart_visual", value=funnel_chart_visual, expected_type=type_hints["funnel_chart_visual"])
                check_type(argname="argument gauge_chart_visual", value=gauge_chart_visual, expected_type=type_hints["gauge_chart_visual"])
                check_type(argname="argument geospatial_map_visual", value=geospatial_map_visual, expected_type=type_hints["geospatial_map_visual"])
                check_type(argname="argument heat_map_visual", value=heat_map_visual, expected_type=type_hints["heat_map_visual"])
                check_type(argname="argument histogram_visual", value=histogram_visual, expected_type=type_hints["histogram_visual"])
                check_type(argname="argument insight_visual", value=insight_visual, expected_type=type_hints["insight_visual"])
                check_type(argname="argument kpi_visual", value=kpi_visual, expected_type=type_hints["kpi_visual"])
                check_type(argname="argument line_chart_visual", value=line_chart_visual, expected_type=type_hints["line_chart_visual"])
                check_type(argname="argument pie_chart_visual", value=pie_chart_visual, expected_type=type_hints["pie_chart_visual"])
                check_type(argname="argument pivot_table_visual", value=pivot_table_visual, expected_type=type_hints["pivot_table_visual"])
                check_type(argname="argument radar_chart_visual", value=radar_chart_visual, expected_type=type_hints["radar_chart_visual"])
                check_type(argname="argument sankey_diagram_visual", value=sankey_diagram_visual, expected_type=type_hints["sankey_diagram_visual"])
                check_type(argname="argument scatter_plot_visual", value=scatter_plot_visual, expected_type=type_hints["scatter_plot_visual"])
                check_type(argname="argument table_visual", value=table_visual, expected_type=type_hints["table_visual"])
                check_type(argname="argument tree_map_visual", value=tree_map_visual, expected_type=type_hints["tree_map_visual"])
                check_type(argname="argument waterfall_visual", value=waterfall_visual, expected_type=type_hints["waterfall_visual"])
                check_type(argname="argument word_cloud_visual", value=word_cloud_visual, expected_type=type_hints["word_cloud_visual"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_chart_visual is not None:
                self._values["bar_chart_visual"] = bar_chart_visual
            if box_plot_visual is not None:
                self._values["box_plot_visual"] = box_plot_visual
            if combo_chart_visual is not None:
                self._values["combo_chart_visual"] = combo_chart_visual
            if custom_content_visual is not None:
                self._values["custom_content_visual"] = custom_content_visual
            if empty_visual is not None:
                self._values["empty_visual"] = empty_visual
            if filled_map_visual is not None:
                self._values["filled_map_visual"] = filled_map_visual
            if funnel_chart_visual is not None:
                self._values["funnel_chart_visual"] = funnel_chart_visual
            if gauge_chart_visual is not None:
                self._values["gauge_chart_visual"] = gauge_chart_visual
            if geospatial_map_visual is not None:
                self._values["geospatial_map_visual"] = geospatial_map_visual
            if heat_map_visual is not None:
                self._values["heat_map_visual"] = heat_map_visual
            if histogram_visual is not None:
                self._values["histogram_visual"] = histogram_visual
            if insight_visual is not None:
                self._values["insight_visual"] = insight_visual
            if kpi_visual is not None:
                self._values["kpi_visual"] = kpi_visual
            if line_chart_visual is not None:
                self._values["line_chart_visual"] = line_chart_visual
            if pie_chart_visual is not None:
                self._values["pie_chart_visual"] = pie_chart_visual
            if pivot_table_visual is not None:
                self._values["pivot_table_visual"] = pivot_table_visual
            if radar_chart_visual is not None:
                self._values["radar_chart_visual"] = radar_chart_visual
            if sankey_diagram_visual is not None:
                self._values["sankey_diagram_visual"] = sankey_diagram_visual
            if scatter_plot_visual is not None:
                self._values["scatter_plot_visual"] = scatter_plot_visual
            if table_visual is not None:
                self._values["table_visual"] = table_visual
            if tree_map_visual is not None:
                self._values["tree_map_visual"] = tree_map_visual
            if waterfall_visual is not None:
                self._values["waterfall_visual"] = waterfall_visual
            if word_cloud_visual is not None:
                self._values["word_cloud_visual"] = word_cloud_visual

        @builtins.property
        def bar_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BarChartVisualProperty"]]:
            '''A bar chart.

            For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-barchartvisual
            '''
            result = self._values.get("bar_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BarChartVisualProperty"]], result)

        @builtins.property
        def box_plot_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BoxPlotVisualProperty"]]:
            '''A box plot.

            For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-boxplotvisual
            '''
            result = self._values.get("box_plot_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.BoxPlotVisualProperty"]], result)

        @builtins.property
        def combo_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ComboChartVisualProperty"]]:
            '''A combo chart.

            For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-combochartvisual
            '''
            result = self._values.get("combo_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ComboChartVisualProperty"]], result)

        @builtins.property
        def custom_content_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomContentVisualProperty"]]:
            '''A visual that contains custom content.

            For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-customcontentvisual
            '''
            result = self._values.get("custom_content_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.CustomContentVisualProperty"]], result)

        @builtins.property
        def empty_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.EmptyVisualProperty"]]:
            '''An empty visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-emptyvisual
            '''
            result = self._values.get("empty_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.EmptyVisualProperty"]], result)

        @builtins.property
        def filled_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilledMapVisualProperty"]]:
            '''A filled map.

            For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-filledmapvisual
            '''
            result = self._values.get("filled_map_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FilledMapVisualProperty"]], result)

        @builtins.property
        def funnel_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FunnelChartVisualProperty"]]:
            '''A funnel chart.

            For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-funnelchartvisual
            '''
            result = self._values.get("funnel_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FunnelChartVisualProperty"]], result)

        @builtins.property
        def gauge_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GaugeChartVisualProperty"]]:
            '''A gauge chart.

            For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-gaugechartvisual
            '''
            result = self._values.get("gauge_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GaugeChartVisualProperty"]], result)

        @builtins.property
        def geospatial_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialMapVisualProperty"]]:
            '''A geospatial map or a points on map visual.

            For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-geospatialmapvisual
            '''
            result = self._values.get("geospatial_map_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.GeospatialMapVisualProperty"]], result)

        @builtins.property
        def heat_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HeatMapVisualProperty"]]:
            '''A heat map.

            For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-heatmapvisual
            '''
            result = self._values.get("heat_map_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HeatMapVisualProperty"]], result)

        @builtins.property
        def histogram_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HistogramVisualProperty"]]:
            '''A histogram.

            For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-histogramvisual
            '''
            result = self._values.get("histogram_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.HistogramVisualProperty"]], result)

        @builtins.property
        def insight_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.InsightVisualProperty"]]:
            '''An insight visual.

            For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-insightvisual
            '''
            result = self._values.get("insight_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.InsightVisualProperty"]], result)

        @builtins.property
        def kpi_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIVisualProperty"]]:
            '''A key performance indicator (KPI).

            For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-kpivisual
            '''
            result = self._values.get("kpi_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.KPIVisualProperty"]], result)

        @builtins.property
        def line_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartVisualProperty"]]:
            '''A line chart.

            For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-linechartvisual
            '''
            result = self._values.get("line_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LineChartVisualProperty"]], result)

        @builtins.property
        def pie_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PieChartVisualProperty"]]:
            '''A pie or donut chart.

            For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-piechartvisual
            '''
            result = self._values.get("pie_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PieChartVisualProperty"]], result)

        @builtins.property
        def pivot_table_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableVisualProperty"]]:
            '''A pivot table.

            For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-pivottablevisual
            '''
            result = self._values.get("pivot_table_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.PivotTableVisualProperty"]], result)

        @builtins.property
        def radar_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RadarChartVisualProperty"]]:
            '''A radar chart visual.

            For more information, see `Using radar charts <https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-radarchartvisual
            '''
            result = self._values.get("radar_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.RadarChartVisualProperty"]], result)

        @builtins.property
        def sankey_diagram_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SankeyDiagramVisualProperty"]]:
            '''A sankey diagram.

            For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-sankeydiagramvisual
            '''
            result = self._values.get("sankey_diagram_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.SankeyDiagramVisualProperty"]], result)

        @builtins.property
        def scatter_plot_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ScatterPlotVisualProperty"]]:
            '''A scatter plot.

            For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-scatterplotvisual
            '''
            result = self._values.get("scatter_plot_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ScatterPlotVisualProperty"]], result)

        @builtins.property
        def table_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableVisualProperty"]]:
            '''A table visual.

            For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-tablevisual
            '''
            result = self._values.get("table_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TableVisualProperty"]], result)

        @builtins.property
        def tree_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TreeMapVisualProperty"]]:
            '''A tree map.

            For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-treemapvisual
            '''
            result = self._values.get("tree_map_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.TreeMapVisualProperty"]], result)

        @builtins.property
        def waterfall_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WaterfallVisualProperty"]]:
            '''A waterfall chart.

            For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-waterfallvisual
            '''
            result = self._values.get("waterfall_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WaterfallVisualProperty"]], result)

        @builtins.property
        def word_cloud_visual(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WordCloudVisualProperty"]]:
            '''A word cloud.

            For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-wordcloudvisual
            '''
            result = self._values.get("word_cloud_visual")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WordCloudVisualProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"format_text": "formatText", "visibility": "visibility"},
    )
    class VisualSubtitleLabelOptionsProperty:
        def __init__(
            self,
            *,
            format_text: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LongFormatTextProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The subtitle label options for a visual.

            :param format_text: The long text format of the subtitle label, such as plain text or rich text.
            :param visibility: The visibility of the subtitle label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualsubtitlelabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                visual_subtitle_label_options_property = quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                        plain_text="plainText",
                        rich_text="richText"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__77f056b91edf67b9eb6d2edf30db13be84e63331a18191b0be77fda65b9e1645)
                check_type(argname="argument format_text", value=format_text, expected_type=type_hints["format_text"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_text is not None:
                self._values["format_text"] = format_text
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def format_text(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LongFormatTextProperty"]]:
            '''The long text format of the subtitle label, such as plain text or rich text.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualsubtitlelabeloptions.html#cfn-quicksight-template-visualsubtitlelabeloptions-formattext
            '''
            result = self._values.get("format_text")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LongFormatTextProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the subtitle label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualsubtitlelabeloptions.html#cfn-quicksight-template-visualsubtitlelabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualSubtitleLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.VisualTitleLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"format_text": "formatText", "visibility": "visibility"},
    )
    class VisualTitleLabelOptionsProperty:
        def __init__(
            self,
            *,
            format_text: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ShortFormatTextProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The title label options for a visual.

            :param format_text: The short text format of the title label, such as plain text or rich text.
            :param visibility: The visibility of the title label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualtitlelabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                visual_title_label_options_property = quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                        plain_text="plainText",
                        rich_text="richText"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c4081fd93b26340a2623abcc387e340e4e86c84b5fe06a999e9624a073a5ae7c)
                check_type(argname="argument format_text", value=format_text, expected_type=type_hints["format_text"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_text is not None:
                self._values["format_text"] = format_text
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def format_text(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ShortFormatTextProperty"]]:
            '''The short text format of the title label, such as plain text or rich text.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualtitlelabeloptions.html#cfn-quicksight-template-visualtitlelabeloptions-formattext
            '''
            result = self._values.get("format_text")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ShortFormatTextProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the title label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualtitlelabeloptions.html#cfn-quicksight-template-visualtitlelabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualTitleLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.WaterfallChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "breakdowns": "breakdowns",
            "categories": "categories",
            "values": "values",
        },
    )
    class WaterfallChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            breakdowns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            categories: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a waterfall visual.

            :param breakdowns: The breakdown field wells of a waterfall visual.
            :param categories: The category field wells of a waterfall visual.
            :param values: The value field wells of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f76a10e007767a1bd8eb5fb8f4c89350bf25a61bdb5b90a2ce86691c3eb18232)
                check_type(argname="argument breakdowns", value=breakdowns, expected_type=type_hints["breakdowns"])
                check_type(argname="argument categories", value=categories, expected_type=type_hints["categories"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if breakdowns is not None:
                self._values["breakdowns"] = breakdowns
            if categories is not None:
                self._values["categories"] = categories
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def breakdowns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The breakdown field wells of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartaggregatedfieldwells.html#cfn-quicksight-template-waterfallchartaggregatedfieldwells-breakdowns
            '''
            result = self._values.get("breakdowns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def categories(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The category field wells of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartaggregatedfieldwells.html#cfn-quicksight-template-waterfallchartaggregatedfieldwells-categories
            '''
            result = self._values.get("categories")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The value field wells of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartaggregatedfieldwells.html#cfn-quicksight-template-waterfallchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.WaterfallChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_axis_display_options": "categoryAxisDisplayOptions",
            "category_axis_label_options": "categoryAxisLabelOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "sort_configuration": "sortConfiguration",
            "visual_palette": "visualPalette",
            "waterfall_chart_options": "waterfallChartOptions",
        },
    )
    class WaterfallChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.WaterfallChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.WaterfallChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            waterfall_chart_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.WaterfallChartOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a waterfall visual.

            :param category_axis_display_options: The options that determine the presentation of the category axis.
            :param category_axis_label_options: The options that determine the presentation of the category axis label.
            :param data_labels: The data label configuration of a waterfall visual.
            :param field_wells: The field well configuration of a waterfall visual.
            :param legend: The legend configuration of a waterfall visual.
            :param primary_y_axis_display_options: The options that determine the presentation of the y-axis.
            :param primary_y_axis_label_options: The options that determine the presentation of the y-axis label.
            :param sort_configuration: The sort configuration of a waterfall visual.
            :param visual_palette: The visual palette configuration of a waterfall visual.
            :param waterfall_chart_options: The options that determine the presentation of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__54bbc24a1dd04bcd0aad8a335f4a58fa4babda621916af65ddb36b0f40eef74c)
                check_type(argname="argument category_axis_display_options", value=category_axis_display_options, expected_type=type_hints["category_axis_display_options"])
                check_type(argname="argument category_axis_label_options", value=category_axis_label_options, expected_type=type_hints["category_axis_label_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument waterfall_chart_options", value=waterfall_chart_options, expected_type=type_hints["waterfall_chart_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_axis_display_options is not None:
                self._values["category_axis_display_options"] = category_axis_display_options
            if category_axis_label_options is not None:
                self._values["category_axis_label_options"] = category_axis_label_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if waterfall_chart_options is not None:
                self._values["waterfall_chart_options"] = waterfall_chart_options

        @builtins.property
        def category_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the category axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-categoryaxisdisplayoptions
            '''
            result = self._values.get("category_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the category axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-categoryaxislabeloptions
            '''
            result = self._values.get("category_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The data label configuration of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WaterfallChartFieldWellsProperty"]]:
            '''The field well configuration of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WaterfallChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend configuration of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis label.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WaterfallChartSortConfigurationProperty"]]:
            '''The sort configuration of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WaterfallChartSortConfigurationProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]]:
            '''The visual palette configuration of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualPaletteProperty"]], result)

        @builtins.property
        def waterfall_chart_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WaterfallChartOptionsProperty"]]:
            '''The options that determine the presentation of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-waterfallchartoptions
            '''
            result = self._values.get("waterfall_chart_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WaterfallChartOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.WaterfallChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "waterfall_chart_aggregated_field_wells": "waterfallChartAggregatedFieldWells",
        },
    )
    class WaterfallChartFieldWellsProperty:
        def __init__(
            self,
            *,
            waterfall_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.WaterfallChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a waterfall visual.

            :param waterfall_chart_aggregated_field_wells: The field well configuration of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__57a9a9f048061ae2b7250714c2ac7324600fad13206aec0183b583e44a8b198a)
                check_type(argname="argument waterfall_chart_aggregated_field_wells", value=waterfall_chart_aggregated_field_wells, expected_type=type_hints["waterfall_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if waterfall_chart_aggregated_field_wells is not None:
                self._values["waterfall_chart_aggregated_field_wells"] = waterfall_chart_aggregated_field_wells

        @builtins.property
        def waterfall_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WaterfallChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartfieldwells.html#cfn-quicksight-template-waterfallchartfieldwells-waterfallchartaggregatedfieldwells
            '''
            result = self._values.get("waterfall_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WaterfallChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.WaterfallChartOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"total_bar_label": "totalBarLabel"},
    )
    class WaterfallChartOptionsProperty:
        def __init__(
            self,
            *,
            total_bar_label: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of a waterfall visual.

            :param total_bar_label: This option determines the total bar label of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                waterfall_chart_options_property = quicksight.CfnTemplate.WaterfallChartOptionsProperty(
                    total_bar_label="totalBarLabel"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5d123204084888211a2e5a8a1d205b983db8a2f34e90a9658c1c8c534e8c10fa)
                check_type(argname="argument total_bar_label", value=total_bar_label, expected_type=type_hints["total_bar_label"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if total_bar_label is not None:
                self._values["total_bar_label"] = total_bar_label

        @builtins.property
        def total_bar_label(self) -> typing.Optional[builtins.str]:
            '''This option determines the total bar label of a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartoptions.html#cfn-quicksight-template-waterfallchartoptions-totalbarlabel
            '''
            result = self._values.get("total_bar_label")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.WaterfallChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "breakdown_items_limit": "breakdownItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class WaterfallChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            breakdown_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a waterfall visual.

            :param breakdown_items_limit: The limit on the number of bar groups that are displayed.
            :param category_sort: The sort configuration of the category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                waterfall_chart_sort_configuration_property = quicksight.CfnTemplate.WaterfallChartSortConfigurationProperty(
                    breakdown_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__23ecd8c91f5df966f8913e29661ef9cce50438c11d1523bfcf7bee7f58dd4105)
                check_type(argname="argument breakdown_items_limit", value=breakdown_items_limit, expected_type=type_hints["breakdown_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if breakdown_items_limit is not None:
                self._values["breakdown_items_limit"] = breakdown_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def breakdown_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of bar groups that are displayed.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartsortconfiguration.html#cfn-quicksight-template-waterfallchartsortconfiguration-breakdownitemslimit
            '''
            result = self._values.get("breakdown_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartsortconfiguration.html#cfn-quicksight-template-waterfallchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.WaterfallVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class WaterfallVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.WaterfallChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A waterfall chart.

            For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration for a waterfall visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__993bd48ff03f371b23b46d677f72614348b973d834986e7d6f6ebb85a1f480ed)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WaterfallChartConfigurationProperty"]]:
            '''The configuration for a waterfall visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WaterfallChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.WhatIfPointScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={"date": "date", "value": "value"},
    )
    class WhatIfPointScenarioProperty:
        def __init__(self, *, date: builtins.str, value: jsii.Number) -> None:
            '''Provides the forecast to meet the target for a particular date.

            :param date: The date that you need the forecast results for.
            :param value: The target value that you want to meet for the provided date. Default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifpointscenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                what_if_point_scenario_property = quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                    date="date",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bd8bcd47cf9adcab51a68cc6d74f4924df11d6f9c921ed0cfa36db3bcdb72b44)
                check_type(argname="argument date", value=date, expected_type=type_hints["date"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "date": date,
                "value": value,
            }

        @builtins.property
        def date(self) -> builtins.str:
            '''The date that you need the forecast results for.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifpointscenario.html#cfn-quicksight-template-whatifpointscenario-date
            '''
            result = self._values.get("date")
            assert result is not None, "Required property 'date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The target value that you want to meet for the provided date.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifpointscenario.html#cfn-quicksight-template-whatifpointscenario-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WhatIfPointScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.WhatIfRangeScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={
            "end_date": "endDate",
            "start_date": "startDate",
            "value": "value",
        },
    )
    class WhatIfRangeScenarioProperty:
        def __init__(
            self,
            *,
            end_date: builtins.str,
            start_date: builtins.str,
            value: jsii.Number,
        ) -> None:
            '''Provides the forecast to meet the target for a particular date range.

            :param end_date: The end date in the date range that you need the forecast results for.
            :param start_date: The start date in the date range that you need the forecast results for.
            :param value: The target value that you want to meet for the provided date range. Default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifrangescenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                what_if_range_scenario_property = quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                    end_date="endDate",
                    start_date="startDate",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6d39af50e14c0edaacd4dbd28782b722f217bfdcdd74e5200090464f9dfc5c20)
                check_type(argname="argument end_date", value=end_date, expected_type=type_hints["end_date"])
                check_type(argname="argument start_date", value=start_date, expected_type=type_hints["start_date"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "end_date": end_date,
                "start_date": start_date,
                "value": value,
            }

        @builtins.property
        def end_date(self) -> builtins.str:
            '''The end date in the date range that you need the forecast results for.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifrangescenario.html#cfn-quicksight-template-whatifrangescenario-enddate
            '''
            result = self._values.get("end_date")
            assert result is not None, "Required property 'end_date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def start_date(self) -> builtins.str:
            '''The start date in the date range that you need the forecast results for.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifrangescenario.html#cfn-quicksight-template-whatifrangescenario-startdate
            '''
            result = self._values.get("start_date")
            assert result is not None, "Required property 'start_date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The target value that you want to meet for the provided date range.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifrangescenario.html#cfn-quicksight-template-whatifrangescenario-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WhatIfRangeScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "size": "size"},
    )
    class WordCloudAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a word cloud.

            :param group_by: The group by field well of a word cloud. Values are grouped by group by fields.
            :param size: The size field well of a word cloud. Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                word_cloud_aggregated_field_wells_property = quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    size=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c863ec6153fd0fac1389fb1373a5428303e58d1ea2588e9bbd851d04625322d0)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if size is not None:
                self._values["size"] = size

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The group by field well of a word cloud.

            Values are grouped by group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudaggregatedfieldwells.html#cfn-quicksight-template-wordcloudaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The size field well of a word cloud.

            Values are aggregated based on group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudaggregatedfieldwells.html#cfn-quicksight-template-wordcloudaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.WordCloudChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
            "word_cloud_options": "wordCloudOptions",
        },
    )
    class WordCloudChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.WordCloudFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.WordCloudSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            word_cloud_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.WordCloudOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a word cloud visual.

            :param category_label_options: The label options (label text, label visibility, and sort icon visibility) for the word cloud category.
            :param field_wells: The field wells of the visual.
            :param sort_configuration: The sort configuration of a word cloud visual.
            :param word_cloud_options: The options for a word cloud visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__22ddb296c5840988b4af8d2eb9932adec9a6e97a6e2409a17e2251dc5aba565c)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument word_cloud_options", value=word_cloud_options, expected_type=type_hints["word_cloud_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if word_cloud_options is not None:
                self._values["word_cloud_options"] = word_cloud_options

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) for the word cloud category.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html#cfn-quicksight-template-wordcloudchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WordCloudFieldWellsProperty"]]:
            '''The field wells of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html#cfn-quicksight-template-wordcloudchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WordCloudFieldWellsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WordCloudSortConfigurationProperty"]]:
            '''The sort configuration of a word cloud visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html#cfn-quicksight-template-wordcloudchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WordCloudSortConfigurationProperty"]], result)

        @builtins.property
        def word_cloud_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WordCloudOptionsProperty"]]:
            '''The options for a word cloud visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html#cfn-quicksight-template-wordcloudchartconfiguration-wordcloudoptions
            '''
            result = self._values.get("word_cloud_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WordCloudOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.WordCloudFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "word_cloud_aggregated_field_wells": "wordCloudAggregatedFieldWells",
        },
    )
    class WordCloudFieldWellsProperty:
        def __init__(
            self,
            *,
            word_cloud_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.WordCloudAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a word cloud visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param word_cloud_aggregated_field_wells: The aggregated field wells of a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                word_cloud_field_wells_property = quicksight.CfnTemplate.WordCloudFieldWellsProperty(
                    word_cloud_aggregated_field_wells=quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        size=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__25ac92e12dc71a0c6280682ffc55baa9600576146c16c9dcdc6b10cfe3250091)
                check_type(argname="argument word_cloud_aggregated_field_wells", value=word_cloud_aggregated_field_wells, expected_type=type_hints["word_cloud_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if word_cloud_aggregated_field_wells is not None:
                self._values["word_cloud_aggregated_field_wells"] = word_cloud_aggregated_field_wells

        @builtins.property
        def word_cloud_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WordCloudAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudfieldwells.html#cfn-quicksight-template-wordcloudfieldwells-wordcloudaggregatedfieldwells
            '''
            result = self._values.get("word_cloud_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WordCloudAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.WordCloudOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cloud_layout": "cloudLayout",
            "maximum_string_length": "maximumStringLength",
            "word_casing": "wordCasing",
            "word_orientation": "wordOrientation",
            "word_padding": "wordPadding",
            "word_scaling": "wordScaling",
        },
    )
    class WordCloudOptionsProperty:
        def __init__(
            self,
            *,
            cloud_layout: typing.Optional[builtins.str] = None,
            maximum_string_length: typing.Optional[jsii.Number] = None,
            word_casing: typing.Optional[builtins.str] = None,
            word_orientation: typing.Optional[builtins.str] = None,
            word_padding: typing.Optional[builtins.str] = None,
            word_scaling: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The word cloud options for a word cloud visual.

            :param cloud_layout: The cloud layout options (fluid, normal) of a word cloud.
            :param maximum_string_length: The length limit of each word from 1-100.
            :param word_casing: The word casing options (lower_case, existing_case) for the words in a word cloud.
            :param word_orientation: The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.
            :param word_padding: The word padding options (none, small, medium, large) for the words in a word cloud.
            :param word_scaling: The word scaling options (emphasize, normal) for the words in a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                word_cloud_options_property = quicksight.CfnTemplate.WordCloudOptionsProperty(
                    cloud_layout="cloudLayout",
                    maximum_string_length=123,
                    word_casing="wordCasing",
                    word_orientation="wordOrientation",
                    word_padding="wordPadding",
                    word_scaling="wordScaling"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c3780da32cf5efc14579531e18e4aea181730bd8570295951a9c435f4a020980)
                check_type(argname="argument cloud_layout", value=cloud_layout, expected_type=type_hints["cloud_layout"])
                check_type(argname="argument maximum_string_length", value=maximum_string_length, expected_type=type_hints["maximum_string_length"])
                check_type(argname="argument word_casing", value=word_casing, expected_type=type_hints["word_casing"])
                check_type(argname="argument word_orientation", value=word_orientation, expected_type=type_hints["word_orientation"])
                check_type(argname="argument word_padding", value=word_padding, expected_type=type_hints["word_padding"])
                check_type(argname="argument word_scaling", value=word_scaling, expected_type=type_hints["word_scaling"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cloud_layout is not None:
                self._values["cloud_layout"] = cloud_layout
            if maximum_string_length is not None:
                self._values["maximum_string_length"] = maximum_string_length
            if word_casing is not None:
                self._values["word_casing"] = word_casing
            if word_orientation is not None:
                self._values["word_orientation"] = word_orientation
            if word_padding is not None:
                self._values["word_padding"] = word_padding
            if word_scaling is not None:
                self._values["word_scaling"] = word_scaling

        @builtins.property
        def cloud_layout(self) -> typing.Optional[builtins.str]:
            '''The cloud layout options (fluid, normal) of a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-cloudlayout
            '''
            result = self._values.get("cloud_layout")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def maximum_string_length(self) -> typing.Optional[jsii.Number]:
            '''The length limit of each word from 1-100.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-maximumstringlength
            '''
            result = self._values.get("maximum_string_length")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def word_casing(self) -> typing.Optional[builtins.str]:
            '''The word casing options (lower_case, existing_case) for the words in a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-wordcasing
            '''
            result = self._values.get("word_casing")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_orientation(self) -> typing.Optional[builtins.str]:
            '''The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-wordorientation
            '''
            result = self._values.get("word_orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_padding(self) -> typing.Optional[builtins.str]:
            '''The word padding options (none, small, medium, large) for the words in a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-wordpadding
            '''
            result = self._values.get("word_padding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_scaling(self) -> typing.Optional[builtins.str]:
            '''The word scaling options (emphasize, normal) for the words in a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-wordscaling
            '''
            result = self._values.get("word_scaling")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.WordCloudSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class WordCloudSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a word cloud visual.

            :param category_items_limit: The limit on the number of groups that are displayed in a word cloud.
            :param category_sort: The sort configuration of group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                word_cloud_sort_configuration_property = quicksight.CfnTemplate.WordCloudSortConfigurationProperty(
                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                attribute_aggregation_function=quicksight.CfnTemplate.AttributeAggregationFunctionProperty(
                                    simple_attribute_aggregation="simpleAttributeAggregation",
                                    value_for_multiple_values="valueForMultipleValues"
                                ),
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cd5fb0239e8addc760e1695522bdbe004b3acf6afa69a76bf9814487a89d06b8)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of groups that are displayed in a word cloud.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudsortconfiguration.html#cfn-quicksight-template-wordcloudsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of group by fields.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudsortconfiguration.html#cfn-quicksight-template-wordcloudsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplate.WordCloudVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class WordCloudVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.WordCloudChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A word cloud.

            For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b09284c311f9b3aaed0ac05c126480ae5985daf6d0e0bc27b670595ca9e654de)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WordCloudChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.WordCloudChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="aws-cdk-lib.aws_quicksight.CfnTemplateProps",
    jsii_struct_bases=[],
    name_mapping={
        "aws_account_id": "awsAccountId",
        "template_id": "templateId",
        "definition": "definition",
        "name": "name",
        "permissions": "permissions",
        "source_entity": "sourceEntity",
        "tags": "tags",
        "validation_strategy": "validationStrategy",
        "version_description": "versionDescription",
    },
)
class CfnTemplateProps:
    def __init__(
        self,
        *,
        aws_account_id: builtins.str,
        template_id: builtins.str,
        definition: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TemplateVersionDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        source_entity: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TemplateSourceEntityProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
        validation_strategy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ValidationStrategyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        version_description: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Properties for defining a ``CfnTemplate``.

        :param aws_account_id: The ID for the AWS account that the group is in. You use the ID for the AWS account that contains your Amazon QuickSight account.
        :param template_id: An ID for the template that you want to create. This template is unique per AWS Region ; in each AWS account.
        :param definition: 
        :param name: A display name for the template.
        :param permissions: A list of resource permissions to be set on the template.
        :param source_entity: The entity that you are using as a source when you create the template. In ``SourceEntity`` , you specify the type of object you're using as source: ``SourceTemplate`` for a template or ``SourceAnalysis`` for an analysis. Both of these require an Amazon Resource Name (ARN). For ``SourceTemplate`` , specify the ARN of the source template. For ``SourceAnalysis`` , specify the ARN of the source analysis. The ``SourceTemplate`` ARN can contain any AWS account and any Amazon QuickSight-supported AWS Region . Use the ``DataSetReferences`` entity within ``SourceTemplate`` or ``SourceAnalysis`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder. Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the resource.
        :param validation_strategy: The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects. When you set this value to ``LENIENT`` , validation is skipped for specific errors.
        :param version_description: A description of the current template version being created. This API operation creates the first version of the template. Every time ``UpdateTemplate`` is called, a new version is created. Each version of the template maintains a description of the version in the ``VersionDescription`` field.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html
        :exampleMetadata: fixture=_generated

        Example::

            
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__194696706c08c6a7def262580c9972a430e44c1c526329b77b525a87c76a44ed)
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument template_id", value=template_id, expected_type=type_hints["template_id"])
            check_type(argname="argument definition", value=definition, expected_type=type_hints["definition"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument permissions", value=permissions, expected_type=type_hints["permissions"])
            check_type(argname="argument source_entity", value=source_entity, expected_type=type_hints["source_entity"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument validation_strategy", value=validation_strategy, expected_type=type_hints["validation_strategy"])
            check_type(argname="argument version_description", value=version_description, expected_type=type_hints["version_description"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aws_account_id": aws_account_id,
            "template_id": template_id,
        }
        if definition is not None:
            self._values["definition"] = definition
        if name is not None:
            self._values["name"] = name
        if permissions is not None:
            self._values["permissions"] = permissions
        if source_entity is not None:
            self._values["source_entity"] = source_entity
        if tags is not None:
            self._values["tags"] = tags
        if validation_strategy is not None:
            self._values["validation_strategy"] = validation_strategy
        if version_description is not None:
            self._values["version_description"] = version_description

    @builtins.property
    def aws_account_id(self) -> builtins.str:
        '''The ID for the AWS account that the group is in.

        You use the ID for the AWS account that contains your Amazon QuickSight account.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        assert result is not None, "Required property 'aws_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def template_id(self) -> builtins.str:
        '''An ID for the template that you want to create.

        This template is unique per AWS Region ; in each AWS account.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-templateid
        '''
        result = self._values.get("template_id")
        assert result is not None, "Required property 'template_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def definition(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnTemplate.TemplateVersionDefinitionProperty]]:
        '''
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-definition
        '''
        result = self._values.get("definition")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnTemplate.TemplateVersionDefinitionProperty]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''A display name for the template.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-name
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnTemplate.ResourcePermissionProperty]]]]:
        '''A list of resource permissions to be set on the template.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-permissions
        '''
        result = self._values.get("permissions")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnTemplate.ResourcePermissionProperty]]]], result)

    @builtins.property
    def source_entity(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnTemplate.TemplateSourceEntityProperty]]:
        '''The entity that you are using as a source when you create the template.

        In ``SourceEntity`` , you specify the type of object you're using as source: ``SourceTemplate`` for a template or ``SourceAnalysis`` for an analysis. Both of these require an Amazon Resource Name (ARN). For ``SourceTemplate`` , specify the ARN of the source template. For ``SourceAnalysis`` , specify the ARN of the source analysis. The ``SourceTemplate`` ARN can contain any AWS account and any Amazon QuickSight-supported AWS Region .

        Use the ``DataSetReferences`` entity within ``SourceTemplate`` or ``SourceAnalysis`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.

        Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-sourceentity
        '''
        result = self._values.get("source_entity")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnTemplate.TemplateSourceEntityProperty]], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[_CfnTag_f6864754]]:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the resource.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-tags
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[_CfnTag_f6864754]], result)

    @builtins.property
    def validation_strategy(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, CfnTemplate.ValidationStrategyProperty]]:
        '''The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects.

        When you set this value to ``LENIENT`` , validation is skipped for specific errors.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-validationstrategy
        '''
        result = self._values.get("validation_strategy")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, CfnTemplate.ValidationStrategyProperty]], result)

    @builtins.property
    def version_description(self) -> typing.Optional[builtins.str]:
        '''A description of the current template version being created.

        This API operation creates the first version of the template. Every time ``UpdateTemplate`` is called, a new version is created. Each version of the template maintains a description of the version in the ``VersionDescription`` field.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-versiondescription
        '''
        result = self._values.get("version_description")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnTemplateProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_IInspectable_c2943556, _ITaggable_36806126)
class CfnTheme(
    _CfnResource_9df397a6,
    metaclass=jsii.JSIIMeta,
    jsii_type="aws-cdk-lib.aws_quicksight.CfnTheme",
):
    '''Creates a theme.

    A *theme* is set of configuration options for color and layout. Themes apply to analyses and dashboards. For more information, see `Using Themes in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/themes-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .

    :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html
    :cloudformationResource: AWS::QuickSight::Theme
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        from aws_cdk import aws_quicksight as quicksight
        
        cfn_theme = quicksight.CfnTheme(self, "MyCfnTheme",
            aws_account_id="awsAccountId",
            base_theme_id="baseThemeId",
            configuration=quicksight.CfnTheme.ThemeConfigurationProperty(
                data_color_palette=quicksight.CfnTheme.DataColorPaletteProperty(
                    colors=["colors"],
                    empty_fill_color="emptyFillColor",
                    min_max_gradient=["minMaxGradient"]
                ),
                sheet=quicksight.CfnTheme.SheetStyleProperty(
                    tile=quicksight.CfnTheme.TileStyleProperty(
                        border=quicksight.CfnTheme.BorderStyleProperty(
                            show=False
                        )
                    ),
                    tile_layout=quicksight.CfnTheme.TileLayoutStyleProperty(
                        gutter=quicksight.CfnTheme.GutterStyleProperty(
                            show=False
                        ),
                        margin=quicksight.CfnTheme.MarginStyleProperty(
                            show=False
                        )
                    )
                ),
                typography=quicksight.CfnTheme.TypographyProperty(
                    font_families=[quicksight.CfnTheme.FontProperty(
                        font_family="fontFamily"
                    )]
                ),
                ui_color_palette=quicksight.CfnTheme.UIColorPaletteProperty(
                    accent="accent",
                    accent_foreground="accentForeground",
                    danger="danger",
                    danger_foreground="dangerForeground",
                    dimension="dimension",
                    dimension_foreground="dimensionForeground",
                    measure="measure",
                    measure_foreground="measureForeground",
                    primary_background="primaryBackground",
                    primary_foreground="primaryForeground",
                    secondary_background="secondaryBackground",
                    secondary_foreground="secondaryForeground",
                    success="success",
                    success_foreground="successForeground",
                    warning="warning",
                    warning_foreground="warningForeground"
                )
            ),
            name="name",
            theme_id="themeId",
        
            # the properties below are optional
            permissions=[quicksight.CfnTheme.ResourcePermissionProperty(
                actions=["actions"],
                principal="principal",
        
                # the properties below are optional
                resource="resource"
            )],
            tags=[CfnTag(
                key="key",
                value="value"
            )],
            version_description="versionDescription"
        )
    '''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.Construct,
        id: builtins.str,
        *,
        aws_account_id: builtins.str,
        base_theme_id: builtins.str,
        configuration: typing.Union[_IResolvable_da3f097b, typing.Union["CfnTheme.ThemeConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        name: builtins.str,
        theme_id: builtins.str,
        permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTheme.ResourcePermissionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
        version_description: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param scope: Scope in which this resource is defined.
        :param id: Construct identifier for this resource (unique in its scope).
        :param aws_account_id: The ID of the AWS account where you want to store the new theme.
        :param base_theme_id: The ID of the theme that a custom theme will inherit from. All themes inherit from one of the starting themes defined by Amazon QuickSight. For a list of the starting themes, use ``ListThemes`` or choose *Themes* from within an analysis.
        :param configuration: The theme configuration, which contains the theme display properties.
        :param name: A display name for the theme.
        :param theme_id: An ID for the theme that you want to create. The theme ID is unique per AWS Region in each AWS account.
        :param permissions: A valid grouping of resource permissions to apply to the new theme.
        :param tags: A map of the key-value pairs for the resource tag or tags that you want to add to the resource.
        :param version_description: A description of the first version of the theme that you're creating. Every time ``UpdateTheme`` is called, a new version is created. Each version of the theme has a description of the version in the ``VersionDescription`` field.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1cc4ce58f4cafc226ffd62ae865dc8406c4667128fad8afacb6b92f2394c675c)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnThemeProps(
            aws_account_id=aws_account_id,
            base_theme_id=base_theme_id,
            configuration=configuration,
            name=name,
            theme_id=theme_id,
            permissions=permissions,
            tags=tags,
            version_description=version_description,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _TreeInspector_488e0dd5) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d05239799ae44473a946ab0823e3e4e4e4311b9c61047c7910aa1e2d5bd5b49)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4db77359b9c4eb831da1e2c00f88a50e63d806b08d83109a29ee9f92f00db46d)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) of the theme.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="attrCreatedTime")
    def attr_created_time(self) -> builtins.str:
        '''The time the theme was created.

        :cloudformationAttribute: CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrLastUpdatedTime")
    def attr_last_updated_time(self) -> builtins.str:
        '''The time the theme was last updated.

        :cloudformationAttribute: LastUpdatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastUpdatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrType")
    def attr_type(self) -> builtins.str:
        '''Theme type.

        :cloudformationAttribute: Type
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrType"))

    @builtins.property
    @jsii.member(jsii_name="attrVersion")
    def attr_version(self) -> _IResolvable_da3f097b:
        '''The version of the theme.

        :cloudformationAttribute: Version
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrVersion"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionArn")
    def attr_version_arn(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionArn"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionBaseThemeId")
    def attr_version_base_theme_id(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.BaseThemeId
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionBaseThemeId"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionConfiguration")
    def attr_version_configuration(self) -> _IResolvable_da3f097b:
        '''
        :cloudformationAttribute: Version.Configuration
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrVersionConfiguration"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionConfigurationDataColorPalette")
    def attr_version_configuration_data_color_palette(self) -> _IResolvable_da3f097b:
        '''
        :cloudformationAttribute: Version.Configuration.DataColorPalette
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrVersionConfigurationDataColorPalette"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionConfigurationSheet")
    def attr_version_configuration_sheet(self) -> _IResolvable_da3f097b:
        '''
        :cloudformationAttribute: Version.Configuration.Sheet
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrVersionConfigurationSheet"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionConfigurationTypography")
    def attr_version_configuration_typography(self) -> _IResolvable_da3f097b:
        '''
        :cloudformationAttribute: Version.Configuration.Typography
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrVersionConfigurationTypography"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionConfigurationUiColorPalette")
    def attr_version_configuration_ui_color_palette(self) -> _IResolvable_da3f097b:
        '''
        :cloudformationAttribute: Version.Configuration.UIColorPalette
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrVersionConfigurationUiColorPalette"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionCreatedTime")
    def attr_version_created_time(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionDescription")
    def attr_version_description(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Description
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionDescription"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionErrors")
    def attr_version_errors(self) -> _IResolvable_da3f097b:
        '''
        :cloudformationAttribute: Version.Errors
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrVersionErrors"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionStatus")
    def attr_version_status(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Status
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionStatus"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionVersionNumber")
    def attr_version_version_number(self) -> _IResolvable_da3f097b:
        '''
        :cloudformationAttribute: Version.VersionNumber
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrVersionVersionNumber"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> _TagManager_0a598cb3:
        '''Tag Manager which manages the tags for this resource.'''
        return typing.cast(_TagManager_0a598cb3, jsii.get(self, "tags"))

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> builtins.str:
        '''The ID of the AWS account where you want to store the new theme.'''
        return typing.cast(builtins.str, jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52d1ea4febf327cf12813b6e6f9a8cf790ade3963322dc2ec0e8e0931b6b3749)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="baseThemeId")
    def base_theme_id(self) -> builtins.str:
        '''The ID of the theme that a custom theme will inherit from.'''
        return typing.cast(builtins.str, jsii.get(self, "baseThemeId"))

    @base_theme_id.setter
    def base_theme_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b98a6e7f9e431e35bab2bc3e8f863259ef1af8f35a63a3a1ec866d7149956e5a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "baseThemeId", value)

    @builtins.property
    @jsii.member(jsii_name="configuration")
    def configuration(
        self,
    ) -> typing.Union[_IResolvable_da3f097b, "CfnTheme.ThemeConfigurationProperty"]:
        '''The theme configuration, which contains the theme display properties.'''
        return typing.cast(typing.Union[_IResolvable_da3f097b, "CfnTheme.ThemeConfigurationProperty"], jsii.get(self, "configuration"))

    @configuration.setter
    def configuration(
        self,
        value: typing.Union[_IResolvable_da3f097b, "CfnTheme.ThemeConfigurationProperty"],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5729182f5b6dd5994d8da27ef75b86f3ace3522d968d98c6c40b510fc5a6eca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "configuration", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        '''A display name for the theme.'''
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a3b50896d86767abb9692a9b97ea93cac0da3aaf22b214452e5a151968af366)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="themeId")
    def theme_id(self) -> builtins.str:
        '''An ID for the theme that you want to create.'''
        return typing.cast(builtins.str, jsii.get(self, "themeId"))

    @theme_id.setter
    def theme_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cbaf20f7789ed4589d1496cdccefb1181caf1a1b6fd5db8c7d72b0d19e32a8cb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "themeId", value)

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTheme.ResourcePermissionProperty"]]]]:
        '''A valid grouping of resource permissions to apply to the new theme.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTheme.ResourcePermissionProperty"]]]], jsii.get(self, "permissions"))

    @permissions.setter
    def permissions(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTheme.ResourcePermissionProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0714a79adc0c72da405d829e73cb024a318b95c4d924b46c810ad16a58bfab3d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "permissions", value)

    @builtins.property
    @jsii.member(jsii_name="tagsRaw")
    def tags_raw(self) -> typing.Optional[typing.List[_CfnTag_f6864754]]:
        '''A map of the key-value pairs for the resource tag or tags that you want to add to the resource.'''
        return typing.cast(typing.Optional[typing.List[_CfnTag_f6864754]], jsii.get(self, "tagsRaw"))

    @tags_raw.setter
    def tags_raw(self, value: typing.Optional[typing.List[_CfnTag_f6864754]]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c24ccf1ba4e30cab8c766f3ceb57c32cd0562ea3ebbd6d69a4b2b13e38b2e38)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tagsRaw", value)

    @builtins.property
    @jsii.member(jsii_name="versionDescription")
    def version_description(self) -> typing.Optional[builtins.str]:
        '''A description of the first version of the theme that you're creating.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionDescription"))

    @version_description.setter
    def version_description(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__287b27dd94f3e78eee24b00309f7d9dc35d3c632cf3b8eb1c9a76516643152f9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "versionDescription", value)

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTheme.BorderStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"show": "show"},
    )
    class BorderStyleProperty:
        def __init__(
            self,
            *,
            show: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
        ) -> None:
            '''The display options for tile borders for visuals.

            :param show: The option to enable display of borders for visuals.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-borderstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                border_style_property = quicksight.CfnTheme.BorderStyleProperty(
                    show=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b7d3c0eae400f4993f620440cd59405cc03cb757913132b40b92519a3498cf2a)
                check_type(argname="argument show", value=show, expected_type=type_hints["show"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if show is not None:
                self._values["show"] = show

        @builtins.property
        def show(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''The option to enable display of borders for visuals.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-borderstyle.html#cfn-quicksight-theme-borderstyle-show
            '''
            result = self._values.get("show")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BorderStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTheme.DataColorPaletteProperty",
        jsii_struct_bases=[],
        name_mapping={
            "colors": "colors",
            "empty_fill_color": "emptyFillColor",
            "min_max_gradient": "minMaxGradient",
        },
    )
    class DataColorPaletteProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Sequence[builtins.str]] = None,
            empty_fill_color: typing.Optional[builtins.str] = None,
            min_max_gradient: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The theme colors that are used for data colors in charts.

            The colors description is a hexadecimal color code that consists of six alphanumerical characters, prefixed with ``#`` , for example #37BFF5.

            :param colors: The hexadecimal codes for the colors.
            :param empty_fill_color: The hexadecimal code of a color that applies to charts where a lack of data is highlighted.
            :param min_max_gradient: The minimum and maximum hexadecimal codes that describe a color gradient.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-datacolorpalette.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_color_palette_property = quicksight.CfnTheme.DataColorPaletteProperty(
                    colors=["colors"],
                    empty_fill_color="emptyFillColor",
                    min_max_gradient=["minMaxGradient"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__05cf0293625cfaba717f34068740d0ebf0c3421b3eb8337b644a8803283af183)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument empty_fill_color", value=empty_fill_color, expected_type=type_hints["empty_fill_color"])
                check_type(argname="argument min_max_gradient", value=min_max_gradient, expected_type=type_hints["min_max_gradient"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors
            if empty_fill_color is not None:
                self._values["empty_fill_color"] = empty_fill_color
            if min_max_gradient is not None:
                self._values["min_max_gradient"] = min_max_gradient

        @builtins.property
        def colors(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The hexadecimal codes for the colors.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-datacolorpalette.html#cfn-quicksight-theme-datacolorpalette-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def empty_fill_color(self) -> typing.Optional[builtins.str]:
            '''The hexadecimal code of a color that applies to charts where a lack of data is highlighted.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-datacolorpalette.html#cfn-quicksight-theme-datacolorpalette-emptyfillcolor
            '''
            result = self._values.get("empty_fill_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def min_max_gradient(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The minimum and maximum hexadecimal codes that describe a color gradient.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-datacolorpalette.html#cfn-quicksight-theme-datacolorpalette-minmaxgradient
            '''
            result = self._values.get("min_max_gradient")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataColorPaletteProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTheme.FontProperty",
        jsii_struct_bases=[],
        name_mapping={"font_family": "fontFamily"},
    )
    class FontProperty:
        def __init__(
            self,
            *,
            font_family: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the font settings.

            :param font_family: Determines the font family settings.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-font.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                font_property = quicksight.CfnTheme.FontProperty(
                    font_family="fontFamily"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3e01c1ff77a66f6c27599010aee795944a5c515a4ba2eff61abeaaa341a0d101)
                check_type(argname="argument font_family", value=font_family, expected_type=type_hints["font_family"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_family is not None:
                self._values["font_family"] = font_family

        @builtins.property
        def font_family(self) -> typing.Optional[builtins.str]:
            '''Determines the font family settings.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-font.html#cfn-quicksight-theme-font-fontfamily
            '''
            result = self._values.get("font_family")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTheme.GutterStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"show": "show"},
    )
    class GutterStyleProperty:
        def __init__(
            self,
            *,
            show: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
        ) -> None:
            '''The display options for gutter spacing between tiles on a sheet.

            :param show: This Boolean value controls whether to display a gutter space between sheet tiles.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-gutterstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                gutter_style_property = quicksight.CfnTheme.GutterStyleProperty(
                    show=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__23cf2f426f832b1905d0fec59fb1ea5c55f5712ce8c2b1255f4a161d799e52e9)
                check_type(argname="argument show", value=show, expected_type=type_hints["show"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if show is not None:
                self._values["show"] = show

        @builtins.property
        def show(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''This Boolean value controls whether to display a gutter space between sheet tiles.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-gutterstyle.html#cfn-quicksight-theme-gutterstyle-show
            '''
            result = self._values.get("show")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GutterStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTheme.MarginStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"show": "show"},
    )
    class MarginStyleProperty:
        def __init__(
            self,
            *,
            show: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
        ) -> None:
            '''The display options for margins around the outside edge of sheets.

            :param show: This Boolean value controls whether to display sheet margins.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-marginstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                margin_style_property = quicksight.CfnTheme.MarginStyleProperty(
                    show=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c43b9b8222d79d953fd816a99d04dfaa74c0bc05da0298e96c2e8f1113884140)
                check_type(argname="argument show", value=show, expected_type=type_hints["show"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if show is not None:
                self._values["show"] = show

        @builtins.property
        def show(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''This Boolean value controls whether to display sheet margins.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-marginstyle.html#cfn-quicksight-theme-marginstyle-show
            '''
            result = self._values.get("show")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MarginStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTheme.ResourcePermissionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "actions": "actions",
            "principal": "principal",
            "resource": "resource",
        },
    )
    class ResourcePermissionProperty:
        def __init__(
            self,
            *,
            actions: typing.Sequence[builtins.str],
            principal: builtins.str,
            resource: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Permission for the resource.

            :param actions: The IAM action to grant or revoke permissions on.
            :param principal: The Amazon Resource Name (ARN) of the principal. This can be one of the following:. - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.) - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.) - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
            :param resource: 

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-resourcepermission.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                resource_permission_property = quicksight.CfnTheme.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal",
                
                    # the properties below are optional
                    resource="resource"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__08ece21d06f10f1edfb7bf2ffa1e6c7fbf7ea8804de4b99a07380d0ef2ece8a4)
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
                check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "actions": actions,
                "principal": principal,
            }
            if resource is not None:
                self._values["resource"] = resource

        @builtins.property
        def actions(self) -> typing.List[builtins.str]:
            '''The IAM action to grant or revoke permissions on.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-resourcepermission.html#cfn-quicksight-theme-resourcepermission-actions
            '''
            result = self._values.get("actions")
            assert result is not None, "Required property 'actions' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def principal(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the principal. This can be one of the following:.

            - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
            - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
            - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-resourcepermission.html#cfn-quicksight-theme-resourcepermission-principal
            '''
            result = self._values.get("principal")
            assert result is not None, "Required property 'principal' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def resource(self) -> typing.Optional[builtins.str]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-resourcepermission.html#cfn-quicksight-theme-resourcepermission-resource
            '''
            result = self._values.get("resource")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ResourcePermissionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTheme.SheetStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"tile": "tile", "tile_layout": "tileLayout"},
    )
    class SheetStyleProperty:
        def __init__(
            self,
            *,
            tile: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTheme.TileStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tile_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTheme.TileLayoutStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The theme display options for sheets.

            :param tile: The display options for tiles.
            :param tile_layout: The layout options for tiles.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-sheetstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                sheet_style_property = quicksight.CfnTheme.SheetStyleProperty(
                    tile=quicksight.CfnTheme.TileStyleProperty(
                        border=quicksight.CfnTheme.BorderStyleProperty(
                            show=False
                        )
                    ),
                    tile_layout=quicksight.CfnTheme.TileLayoutStyleProperty(
                        gutter=quicksight.CfnTheme.GutterStyleProperty(
                            show=False
                        ),
                        margin=quicksight.CfnTheme.MarginStyleProperty(
                            show=False
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0e786d1c3847105bb2a9d28ff988128838e5c15158f5295b2100991be17292f0)
                check_type(argname="argument tile", value=tile, expected_type=type_hints["tile"])
                check_type(argname="argument tile_layout", value=tile_layout, expected_type=type_hints["tile_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if tile is not None:
                self._values["tile"] = tile
            if tile_layout is not None:
                self._values["tile_layout"] = tile_layout

        @builtins.property
        def tile(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTheme.TileStyleProperty"]]:
            '''The display options for tiles.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-sheetstyle.html#cfn-quicksight-theme-sheetstyle-tile
            '''
            result = self._values.get("tile")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTheme.TileStyleProperty"]], result)

        @builtins.property
        def tile_layout(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTheme.TileLayoutStyleProperty"]]:
            '''The layout options for tiles.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-sheetstyle.html#cfn-quicksight-theme-sheetstyle-tilelayout
            '''
            result = self._values.get("tile_layout")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTheme.TileLayoutStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTheme.ThemeConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_color_palette": "dataColorPalette",
            "sheet": "sheet",
            "typography": "typography",
            "ui_color_palette": "uiColorPalette",
        },
    )
    class ThemeConfigurationProperty:
        def __init__(
            self,
            *,
            data_color_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTheme.DataColorPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sheet: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTheme.SheetStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            typography: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTheme.TypographyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            ui_color_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTheme.UIColorPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The theme configuration.

            This configuration contains all of the display properties for a theme.

            :param data_color_palette: Color properties that apply to chart data colors.
            :param sheet: Display options related to sheets.
            :param typography: 
            :param ui_color_palette: Color properties that apply to the UI and to charts, excluding the colors that apply to data.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                theme_configuration_property = quicksight.CfnTheme.ThemeConfigurationProperty(
                    data_color_palette=quicksight.CfnTheme.DataColorPaletteProperty(
                        colors=["colors"],
                        empty_fill_color="emptyFillColor",
                        min_max_gradient=["minMaxGradient"]
                    ),
                    sheet=quicksight.CfnTheme.SheetStyleProperty(
                        tile=quicksight.CfnTheme.TileStyleProperty(
                            border=quicksight.CfnTheme.BorderStyleProperty(
                                show=False
                            )
                        ),
                        tile_layout=quicksight.CfnTheme.TileLayoutStyleProperty(
                            gutter=quicksight.CfnTheme.GutterStyleProperty(
                                show=False
                            ),
                            margin=quicksight.CfnTheme.MarginStyleProperty(
                                show=False
                            )
                        )
                    ),
                    typography=quicksight.CfnTheme.TypographyProperty(
                        font_families=[quicksight.CfnTheme.FontProperty(
                            font_family="fontFamily"
                        )]
                    ),
                    ui_color_palette=quicksight.CfnTheme.UIColorPaletteProperty(
                        accent="accent",
                        accent_foreground="accentForeground",
                        danger="danger",
                        danger_foreground="dangerForeground",
                        dimension="dimension",
                        dimension_foreground="dimensionForeground",
                        measure="measure",
                        measure_foreground="measureForeground",
                        primary_background="primaryBackground",
                        primary_foreground="primaryForeground",
                        secondary_background="secondaryBackground",
                        secondary_foreground="secondaryForeground",
                        success="success",
                        success_foreground="successForeground",
                        warning="warning",
                        warning_foreground="warningForeground"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ec4921443ed79b199f5fe67018c89abbaa53ea473997191ff6067f7a58a57554)
                check_type(argname="argument data_color_palette", value=data_color_palette, expected_type=type_hints["data_color_palette"])
                check_type(argname="argument sheet", value=sheet, expected_type=type_hints["sheet"])
                check_type(argname="argument typography", value=typography, expected_type=type_hints["typography"])
                check_type(argname="argument ui_color_palette", value=ui_color_palette, expected_type=type_hints["ui_color_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_color_palette is not None:
                self._values["data_color_palette"] = data_color_palette
            if sheet is not None:
                self._values["sheet"] = sheet
            if typography is not None:
                self._values["typography"] = typography
            if ui_color_palette is not None:
                self._values["ui_color_palette"] = ui_color_palette

        @builtins.property
        def data_color_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTheme.DataColorPaletteProperty"]]:
            '''Color properties that apply to chart data colors.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html#cfn-quicksight-theme-themeconfiguration-datacolorpalette
            '''
            result = self._values.get("data_color_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTheme.DataColorPaletteProperty"]], result)

        @builtins.property
        def sheet(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTheme.SheetStyleProperty"]]:
            '''Display options related to sheets.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html#cfn-quicksight-theme-themeconfiguration-sheet
            '''
            result = self._values.get("sheet")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTheme.SheetStyleProperty"]], result)

        @builtins.property
        def typography(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTheme.TypographyProperty"]]:
            '''
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html#cfn-quicksight-theme-themeconfiguration-typography
            '''
            result = self._values.get("typography")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTheme.TypographyProperty"]], result)

        @builtins.property
        def ui_color_palette(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTheme.UIColorPaletteProperty"]]:
            '''Color properties that apply to the UI and to charts, excluding the colors that apply to data.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html#cfn-quicksight-theme-themeconfiguration-uicolorpalette
            '''
            result = self._values.get("ui_color_palette")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTheme.UIColorPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ThemeConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTheme.ThemeErrorProperty",
        jsii_struct_bases=[],
        name_mapping={"message": "message", "type": "type"},
    )
    class ThemeErrorProperty:
        def __init__(
            self,
            *,
            message: typing.Optional[builtins.str] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Theme error.

            :param message: The error message.
            :param type: The type of error.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeerror.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                theme_error_property = quicksight.CfnTheme.ThemeErrorProperty(
                    message="message",
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e678b04d098b0907b9508fe683105cca935519833c5c0f7ead79c924cf3c7943)
                check_type(argname="argument message", value=message, expected_type=type_hints["message"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if message is not None:
                self._values["message"] = message
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def message(self) -> typing.Optional[builtins.str]:
            '''The error message.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeerror.html#cfn-quicksight-theme-themeerror-message
            '''
            result = self._values.get("message")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of error.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeerror.html#cfn-quicksight-theme-themeerror-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ThemeErrorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTheme.ThemeVersionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arn": "arn",
            "base_theme_id": "baseThemeId",
            "configuration": "configuration",
            "created_time": "createdTime",
            "description": "description",
            "errors": "errors",
            "status": "status",
            "version_number": "versionNumber",
        },
    )
    class ThemeVersionProperty:
        def __init__(
            self,
            *,
            arn: typing.Optional[builtins.str] = None,
            base_theme_id: typing.Optional[builtins.str] = None,
            configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTheme.ThemeConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            created_time: typing.Optional[builtins.str] = None,
            description: typing.Optional[builtins.str] = None,
            errors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTheme.ThemeErrorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            status: typing.Optional[builtins.str] = None,
            version_number: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A version of a theme.

            :param arn: The Amazon Resource Name (ARN) of the resource.
            :param base_theme_id: The Amazon QuickSight-defined ID of the theme that a custom theme inherits from. All themes initially inherit from a default Amazon QuickSight theme.
            :param configuration: The theme configuration, which contains all the theme display properties.
            :param created_time: The date and time that this theme version was created.
            :param description: The description of the theme.
            :param errors: Errors associated with the theme.
            :param status: The status of the theme version.
            :param version_number: The version number of the theme.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                theme_version_property = quicksight.CfnTheme.ThemeVersionProperty(
                    arn="arn",
                    base_theme_id="baseThemeId",
                    configuration=quicksight.CfnTheme.ThemeConfigurationProperty(
                        data_color_palette=quicksight.CfnTheme.DataColorPaletteProperty(
                            colors=["colors"],
                            empty_fill_color="emptyFillColor",
                            min_max_gradient=["minMaxGradient"]
                        ),
                        sheet=quicksight.CfnTheme.SheetStyleProperty(
                            tile=quicksight.CfnTheme.TileStyleProperty(
                                border=quicksight.CfnTheme.BorderStyleProperty(
                                    show=False
                                )
                            ),
                            tile_layout=quicksight.CfnTheme.TileLayoutStyleProperty(
                                gutter=quicksight.CfnTheme.GutterStyleProperty(
                                    show=False
                                ),
                                margin=quicksight.CfnTheme.MarginStyleProperty(
                                    show=False
                                )
                            )
                        ),
                        typography=quicksight.CfnTheme.TypographyProperty(
                            font_families=[quicksight.CfnTheme.FontProperty(
                                font_family="fontFamily"
                            )]
                        ),
                        ui_color_palette=quicksight.CfnTheme.UIColorPaletteProperty(
                            accent="accent",
                            accent_foreground="accentForeground",
                            danger="danger",
                            danger_foreground="dangerForeground",
                            dimension="dimension",
                            dimension_foreground="dimensionForeground",
                            measure="measure",
                            measure_foreground="measureForeground",
                            primary_background="primaryBackground",
                            primary_foreground="primaryForeground",
                            secondary_background="secondaryBackground",
                            secondary_foreground="secondaryForeground",
                            success="success",
                            success_foreground="successForeground",
                            warning="warning",
                            warning_foreground="warningForeground"
                        )
                    ),
                    created_time="createdTime",
                    description="description",
                    errors=[quicksight.CfnTheme.ThemeErrorProperty(
                        message="message",
                        type="type"
                    )],
                    status="status",
                    version_number=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f0b677e6443b11f79312872fa23db827dfe2cd6aa78ef29af2775e4160492e05)
                check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
                check_type(argname="argument base_theme_id", value=base_theme_id, expected_type=type_hints["base_theme_id"])
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
                check_type(argname="argument created_time", value=created_time, expected_type=type_hints["created_time"])
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
                check_type(argname="argument errors", value=errors, expected_type=type_hints["errors"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument version_number", value=version_number, expected_type=type_hints["version_number"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arn is not None:
                self._values["arn"] = arn
            if base_theme_id is not None:
                self._values["base_theme_id"] = base_theme_id
            if configuration is not None:
                self._values["configuration"] = configuration
            if created_time is not None:
                self._values["created_time"] = created_time
            if description is not None:
                self._values["description"] = description
            if errors is not None:
                self._values["errors"] = errors
            if status is not None:
                self._values["status"] = status
            if version_number is not None:
                self._values["version_number"] = version_number

        @builtins.property
        def arn(self) -> typing.Optional[builtins.str]:
            '''The Amazon Resource Name (ARN) of the resource.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-arn
            '''
            result = self._values.get("arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def base_theme_id(self) -> typing.Optional[builtins.str]:
            '''The Amazon QuickSight-defined ID of the theme that a custom theme inherits from.

            All themes initially inherit from a default Amazon QuickSight theme.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-basethemeid
            '''
            result = self._values.get("base_theme_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def configuration(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTheme.ThemeConfigurationProperty"]]:
            '''The theme configuration, which contains all the theme display properties.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-configuration
            '''
            result = self._values.get("configuration")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTheme.ThemeConfigurationProperty"]], result)

        @builtins.property
        def created_time(self) -> typing.Optional[builtins.str]:
            '''The date and time that this theme version was created.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-createdtime
            '''
            result = self._values.get("created_time")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''The description of the theme.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def errors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTheme.ThemeErrorProperty"]]]]:
            '''Errors associated with the theme.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-errors
            '''
            result = self._values.get("errors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTheme.ThemeErrorProperty"]]]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the theme version.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def version_number(self) -> typing.Optional[jsii.Number]:
            '''The version number of the theme.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-versionnumber
            '''
            result = self._values.get("version_number")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ThemeVersionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTheme.TileLayoutStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"gutter": "gutter", "margin": "margin"},
    )
    class TileLayoutStyleProperty:
        def __init__(
            self,
            *,
            gutter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTheme.GutterStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            margin: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTheme.MarginStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options for the layout of tiles on a sheet.

            :param gutter: The gutter settings that apply between tiles.
            :param margin: The margin settings that apply around the outside edge of sheets.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilelayoutstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                tile_layout_style_property = quicksight.CfnTheme.TileLayoutStyleProperty(
                    gutter=quicksight.CfnTheme.GutterStyleProperty(
                        show=False
                    ),
                    margin=quicksight.CfnTheme.MarginStyleProperty(
                        show=False
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b3fad0a18f5c86222517f2b5416776d8f96dda5a85036b513e65be064d8ef747)
                check_type(argname="argument gutter", value=gutter, expected_type=type_hints["gutter"])
                check_type(argname="argument margin", value=margin, expected_type=type_hints["margin"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if gutter is not None:
                self._values["gutter"] = gutter
            if margin is not None:
                self._values["margin"] = margin

        @builtins.property
        def gutter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTheme.GutterStyleProperty"]]:
            '''The gutter settings that apply between tiles.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilelayoutstyle.html#cfn-quicksight-theme-tilelayoutstyle-gutter
            '''
            result = self._values.get("gutter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTheme.GutterStyleProperty"]], result)

        @builtins.property
        def margin(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTheme.MarginStyleProperty"]]:
            '''The margin settings that apply around the outside edge of sheets.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilelayoutstyle.html#cfn-quicksight-theme-tilelayoutstyle-margin
            '''
            result = self._values.get("margin")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTheme.MarginStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TileLayoutStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTheme.TileStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"border": "border"},
    )
    class TileStyleProperty:
        def __init__(
            self,
            *,
            border: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTheme.BorderStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Display options related to tiles on a sheet.

            :param border: The border around a tile.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilestyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                tile_style_property = quicksight.CfnTheme.TileStyleProperty(
                    border=quicksight.CfnTheme.BorderStyleProperty(
                        show=False
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e86af7264a0f9499019c7010f1dcfbaa4c6eff11f846eeb2d217062958ceb6ac)
                check_type(argname="argument border", value=border, expected_type=type_hints["border"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if border is not None:
                self._values["border"] = border

        @builtins.property
        def border(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTheme.BorderStyleProperty"]]:
            '''The border around a tile.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilestyle.html#cfn-quicksight-theme-tilestyle-border
            '''
            result = self._values.get("border")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTheme.BorderStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TileStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTheme.TypographyProperty",
        jsii_struct_bases=[],
        name_mapping={"font_families": "fontFamilies"},
    )
    class TypographyProperty:
        def __init__(
            self,
            *,
            font_families: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTheme.FontProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''Determines the typography options.

            :param font_families: Determines the list of font families.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-typography.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                typography_property = quicksight.CfnTheme.TypographyProperty(
                    font_families=[quicksight.CfnTheme.FontProperty(
                        font_family="fontFamily"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b39e5f4e5fcc8ac9b1a509f53d146e359532865400c4d724e83fc36465088efc)
                check_type(argname="argument font_families", value=font_families, expected_type=type_hints["font_families"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_families is not None:
                self._values["font_families"] = font_families

        @builtins.property
        def font_families(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTheme.FontProperty"]]]]:
            '''Determines the list of font families.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-typography.html#cfn-quicksight-theme-typography-fontfamilies
            '''
            result = self._values.get("font_families")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTheme.FontProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TypographyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTheme.UIColorPaletteProperty",
        jsii_struct_bases=[],
        name_mapping={
            "accent": "accent",
            "accent_foreground": "accentForeground",
            "danger": "danger",
            "danger_foreground": "dangerForeground",
            "dimension": "dimension",
            "dimension_foreground": "dimensionForeground",
            "measure": "measure",
            "measure_foreground": "measureForeground",
            "primary_background": "primaryBackground",
            "primary_foreground": "primaryForeground",
            "secondary_background": "secondaryBackground",
            "secondary_foreground": "secondaryForeground",
            "success": "success",
            "success_foreground": "successForeground",
            "warning": "warning",
            "warning_foreground": "warningForeground",
        },
    )
    class UIColorPaletteProperty:
        def __init__(
            self,
            *,
            accent: typing.Optional[builtins.str] = None,
            accent_foreground: typing.Optional[builtins.str] = None,
            danger: typing.Optional[builtins.str] = None,
            danger_foreground: typing.Optional[builtins.str] = None,
            dimension: typing.Optional[builtins.str] = None,
            dimension_foreground: typing.Optional[builtins.str] = None,
            measure: typing.Optional[builtins.str] = None,
            measure_foreground: typing.Optional[builtins.str] = None,
            primary_background: typing.Optional[builtins.str] = None,
            primary_foreground: typing.Optional[builtins.str] = None,
            secondary_background: typing.Optional[builtins.str] = None,
            secondary_foreground: typing.Optional[builtins.str] = None,
            success: typing.Optional[builtins.str] = None,
            success_foreground: typing.Optional[builtins.str] = None,
            warning: typing.Optional[builtins.str] = None,
            warning_foreground: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The theme colors that apply to UI and to charts, excluding data colors.

            The colors description is a hexadecimal color code that consists of six alphanumerical characters, prefixed with ``#`` , for example #37BFF5. For more information, see `Using Themes in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/themes-in-quicksight.html>`_ in the *Amazon QuickSight User Guide.*

            :param accent: This color is that applies to selected states and buttons.
            :param accent_foreground: The foreground color that applies to any text or other elements that appear over the accent color.
            :param danger: The color that applies to error messages.
            :param danger_foreground: The foreground color that applies to any text or other elements that appear over the error color.
            :param dimension: The color that applies to the names of fields that are identified as dimensions.
            :param dimension_foreground: The foreground color that applies to any text or other elements that appear over the dimension color.
            :param measure: The color that applies to the names of fields that are identified as measures.
            :param measure_foreground: The foreground color that applies to any text or other elements that appear over the measure color.
            :param primary_background: The background color that applies to visuals and other high emphasis UI.
            :param primary_foreground: The color of text and other foreground elements that appear over the primary background regions, such as grid lines, borders, table banding, icons, and so on.
            :param secondary_background: The background color that applies to the sheet background and sheet controls.
            :param secondary_foreground: The foreground color that applies to any sheet title, sheet control text, or UI that appears over the secondary background.
            :param success: The color that applies to success messages, for example the check mark for a successful download.
            :param success_foreground: The foreground color that applies to any text or other elements that appear over the success color.
            :param warning: This color that applies to warning and informational messages.
            :param warning_foreground: The foreground color that applies to any text or other elements that appear over the warning color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                u_iColor_palette_property = quicksight.CfnTheme.UIColorPaletteProperty(
                    accent="accent",
                    accent_foreground="accentForeground",
                    danger="danger",
                    danger_foreground="dangerForeground",
                    dimension="dimension",
                    dimension_foreground="dimensionForeground",
                    measure="measure",
                    measure_foreground="measureForeground",
                    primary_background="primaryBackground",
                    primary_foreground="primaryForeground",
                    secondary_background="secondaryBackground",
                    secondary_foreground="secondaryForeground",
                    success="success",
                    success_foreground="successForeground",
                    warning="warning",
                    warning_foreground="warningForeground"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fc061ac7da133cd67e49f491d5008a1ee1aedff1d084050be39461ea733b369e)
                check_type(argname="argument accent", value=accent, expected_type=type_hints["accent"])
                check_type(argname="argument accent_foreground", value=accent_foreground, expected_type=type_hints["accent_foreground"])
                check_type(argname="argument danger", value=danger, expected_type=type_hints["danger"])
                check_type(argname="argument danger_foreground", value=danger_foreground, expected_type=type_hints["danger_foreground"])
                check_type(argname="argument dimension", value=dimension, expected_type=type_hints["dimension"])
                check_type(argname="argument dimension_foreground", value=dimension_foreground, expected_type=type_hints["dimension_foreground"])
                check_type(argname="argument measure", value=measure, expected_type=type_hints["measure"])
                check_type(argname="argument measure_foreground", value=measure_foreground, expected_type=type_hints["measure_foreground"])
                check_type(argname="argument primary_background", value=primary_background, expected_type=type_hints["primary_background"])
                check_type(argname="argument primary_foreground", value=primary_foreground, expected_type=type_hints["primary_foreground"])
                check_type(argname="argument secondary_background", value=secondary_background, expected_type=type_hints["secondary_background"])
                check_type(argname="argument secondary_foreground", value=secondary_foreground, expected_type=type_hints["secondary_foreground"])
                check_type(argname="argument success", value=success, expected_type=type_hints["success"])
                check_type(argname="argument success_foreground", value=success_foreground, expected_type=type_hints["success_foreground"])
                check_type(argname="argument warning", value=warning, expected_type=type_hints["warning"])
                check_type(argname="argument warning_foreground", value=warning_foreground, expected_type=type_hints["warning_foreground"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if accent is not None:
                self._values["accent"] = accent
            if accent_foreground is not None:
                self._values["accent_foreground"] = accent_foreground
            if danger is not None:
                self._values["danger"] = danger
            if danger_foreground is not None:
                self._values["danger_foreground"] = danger_foreground
            if dimension is not None:
                self._values["dimension"] = dimension
            if dimension_foreground is not None:
                self._values["dimension_foreground"] = dimension_foreground
            if measure is not None:
                self._values["measure"] = measure
            if measure_foreground is not None:
                self._values["measure_foreground"] = measure_foreground
            if primary_background is not None:
                self._values["primary_background"] = primary_background
            if primary_foreground is not None:
                self._values["primary_foreground"] = primary_foreground
            if secondary_background is not None:
                self._values["secondary_background"] = secondary_background
            if secondary_foreground is not None:
                self._values["secondary_foreground"] = secondary_foreground
            if success is not None:
                self._values["success"] = success
            if success_foreground is not None:
                self._values["success_foreground"] = success_foreground
            if warning is not None:
                self._values["warning"] = warning
            if warning_foreground is not None:
                self._values["warning_foreground"] = warning_foreground

        @builtins.property
        def accent(self) -> typing.Optional[builtins.str]:
            '''This color is that applies to selected states and buttons.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-accent
            '''
            result = self._values.get("accent")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def accent_foreground(self) -> typing.Optional[builtins.str]:
            '''The foreground color that applies to any text or other elements that appear over the accent color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-accentforeground
            '''
            result = self._values.get("accent_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def danger(self) -> typing.Optional[builtins.str]:
            '''The color that applies to error messages.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-danger
            '''
            result = self._values.get("danger")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def danger_foreground(self) -> typing.Optional[builtins.str]:
            '''The foreground color that applies to any text or other elements that appear over the error color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-dangerforeground
            '''
            result = self._values.get("danger_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def dimension(self) -> typing.Optional[builtins.str]:
            '''The color that applies to the names of fields that are identified as dimensions.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-dimension
            '''
            result = self._values.get("dimension")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def dimension_foreground(self) -> typing.Optional[builtins.str]:
            '''The foreground color that applies to any text or other elements that appear over the dimension color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-dimensionforeground
            '''
            result = self._values.get("dimension_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def measure(self) -> typing.Optional[builtins.str]:
            '''The color that applies to the names of fields that are identified as measures.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-measure
            '''
            result = self._values.get("measure")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def measure_foreground(self) -> typing.Optional[builtins.str]:
            '''The foreground color that applies to any text or other elements that appear over the measure color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-measureforeground
            '''
            result = self._values.get("measure_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_background(self) -> typing.Optional[builtins.str]:
            '''The background color that applies to visuals and other high emphasis UI.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-primarybackground
            '''
            result = self._values.get("primary_background")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_foreground(self) -> typing.Optional[builtins.str]:
            '''The color of text and other foreground elements that appear over the primary background regions, such as grid lines, borders, table banding, icons, and so on.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-primaryforeground
            '''
            result = self._values.get("primary_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def secondary_background(self) -> typing.Optional[builtins.str]:
            '''The background color that applies to the sheet background and sheet controls.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-secondarybackground
            '''
            result = self._values.get("secondary_background")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def secondary_foreground(self) -> typing.Optional[builtins.str]:
            '''The foreground color that applies to any sheet title, sheet control text, or UI that appears over the secondary background.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-secondaryforeground
            '''
            result = self._values.get("secondary_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def success(self) -> typing.Optional[builtins.str]:
            '''The color that applies to success messages, for example the check mark for a successful download.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-success
            '''
            result = self._values.get("success")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def success_foreground(self) -> typing.Optional[builtins.str]:
            '''The foreground color that applies to any text or other elements that appear over the success color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-successforeground
            '''
            result = self._values.get("success_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def warning(self) -> typing.Optional[builtins.str]:
            '''This color that applies to warning and informational messages.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-warning
            '''
            result = self._values.get("warning")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def warning_foreground(self) -> typing.Optional[builtins.str]:
            '''The foreground color that applies to any text or other elements that appear over the warning color.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-warningforeground
            '''
            result = self._values.get("warning_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UIColorPaletteProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="aws-cdk-lib.aws_quicksight.CfnThemeProps",
    jsii_struct_bases=[],
    name_mapping={
        "aws_account_id": "awsAccountId",
        "base_theme_id": "baseThemeId",
        "configuration": "configuration",
        "name": "name",
        "theme_id": "themeId",
        "permissions": "permissions",
        "tags": "tags",
        "version_description": "versionDescription",
    },
)
class CfnThemeProps:
    def __init__(
        self,
        *,
        aws_account_id: builtins.str,
        base_theme_id: builtins.str,
        configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTheme.ThemeConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
        name: builtins.str,
        theme_id: builtins.str,
        permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTheme.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
        version_description: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Properties for defining a ``CfnTheme``.

        :param aws_account_id: The ID of the AWS account where you want to store the new theme.
        :param base_theme_id: The ID of the theme that a custom theme will inherit from. All themes inherit from one of the starting themes defined by Amazon QuickSight. For a list of the starting themes, use ``ListThemes`` or choose *Themes* from within an analysis.
        :param configuration: The theme configuration, which contains the theme display properties.
        :param name: A display name for the theme.
        :param theme_id: An ID for the theme that you want to create. The theme ID is unique per AWS Region in each AWS account.
        :param permissions: A valid grouping of resource permissions to apply to the new theme.
        :param tags: A map of the key-value pairs for the resource tag or tags that you want to add to the resource.
        :param version_description: A description of the first version of the theme that you're creating. Every time ``UpdateTheme`` is called, a new version is created. Each version of the theme has a description of the version in the ``VersionDescription`` field.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            from aws_cdk import aws_quicksight as quicksight
            
            cfn_theme_props = quicksight.CfnThemeProps(
                aws_account_id="awsAccountId",
                base_theme_id="baseThemeId",
                configuration=quicksight.CfnTheme.ThemeConfigurationProperty(
                    data_color_palette=quicksight.CfnTheme.DataColorPaletteProperty(
                        colors=["colors"],
                        empty_fill_color="emptyFillColor",
                        min_max_gradient=["minMaxGradient"]
                    ),
                    sheet=quicksight.CfnTheme.SheetStyleProperty(
                        tile=quicksight.CfnTheme.TileStyleProperty(
                            border=quicksight.CfnTheme.BorderStyleProperty(
                                show=False
                            )
                        ),
                        tile_layout=quicksight.CfnTheme.TileLayoutStyleProperty(
                            gutter=quicksight.CfnTheme.GutterStyleProperty(
                                show=False
                            ),
                            margin=quicksight.CfnTheme.MarginStyleProperty(
                                show=False
                            )
                        )
                    ),
                    typography=quicksight.CfnTheme.TypographyProperty(
                        font_families=[quicksight.CfnTheme.FontProperty(
                            font_family="fontFamily"
                        )]
                    ),
                    ui_color_palette=quicksight.CfnTheme.UIColorPaletteProperty(
                        accent="accent",
                        accent_foreground="accentForeground",
                        danger="danger",
                        danger_foreground="dangerForeground",
                        dimension="dimension",
                        dimension_foreground="dimensionForeground",
                        measure="measure",
                        measure_foreground="measureForeground",
                        primary_background="primaryBackground",
                        primary_foreground="primaryForeground",
                        secondary_background="secondaryBackground",
                        secondary_foreground="secondaryForeground",
                        success="success",
                        success_foreground="successForeground",
                        warning="warning",
                        warning_foreground="warningForeground"
                    )
                ),
                name="name",
                theme_id="themeId",
            
                # the properties below are optional
                permissions=[quicksight.CfnTheme.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal",
            
                    # the properties below are optional
                    resource="resource"
                )],
                tags=[CfnTag(
                    key="key",
                    value="value"
                )],
                version_description="versionDescription"
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b7a0f2dda23b22dcd29969c69e7910c3a23a6bab01e03b8b01a7c9628229f03)
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument base_theme_id", value=base_theme_id, expected_type=type_hints["base_theme_id"])
            check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument theme_id", value=theme_id, expected_type=type_hints["theme_id"])
            check_type(argname="argument permissions", value=permissions, expected_type=type_hints["permissions"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument version_description", value=version_description, expected_type=type_hints["version_description"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aws_account_id": aws_account_id,
            "base_theme_id": base_theme_id,
            "configuration": configuration,
            "name": name,
            "theme_id": theme_id,
        }
        if permissions is not None:
            self._values["permissions"] = permissions
        if tags is not None:
            self._values["tags"] = tags
        if version_description is not None:
            self._values["version_description"] = version_description

    @builtins.property
    def aws_account_id(self) -> builtins.str:
        '''The ID of the AWS account where you want to store the new theme.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        assert result is not None, "Required property 'aws_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def base_theme_id(self) -> builtins.str:
        '''The ID of the theme that a custom theme will inherit from.

        All themes inherit from one of the starting themes defined by Amazon QuickSight. For a list of the starting themes, use ``ListThemes`` or choose *Themes* from within an analysis.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-basethemeid
        '''
        result = self._values.get("base_theme_id")
        assert result is not None, "Required property 'base_theme_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def configuration(
        self,
    ) -> typing.Union[_IResolvable_da3f097b, CfnTheme.ThemeConfigurationProperty]:
        '''The theme configuration, which contains the theme display properties.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-configuration
        '''
        result = self._values.get("configuration")
        assert result is not None, "Required property 'configuration' is missing"
        return typing.cast(typing.Union[_IResolvable_da3f097b, CfnTheme.ThemeConfigurationProperty], result)

    @builtins.property
    def name(self) -> builtins.str:
        '''A display name for the theme.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-name
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def theme_id(self) -> builtins.str:
        '''An ID for the theme that you want to create.

        The theme ID is unique per AWS Region in each AWS account.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-themeid
        '''
        result = self._values.get("theme_id")
        assert result is not None, "Required property 'theme_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnTheme.ResourcePermissionProperty]]]]:
        '''A valid grouping of resource permissions to apply to the new theme.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-permissions
        '''
        result = self._values.get("permissions")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnTheme.ResourcePermissionProperty]]]], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[_CfnTag_f6864754]]:
        '''A map of the key-value pairs for the resource tag or tags that you want to add to the resource.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-tags
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[_CfnTag_f6864754]], result)

    @builtins.property
    def version_description(self) -> typing.Optional[builtins.str]:
        '''A description of the first version of the theme that you're creating.

        Every time ``UpdateTheme`` is called, a new version is created. Each version of the theme has a description of the version in the ``VersionDescription`` field.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-versiondescription
        '''
        result = self._values.get("version_description")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnThemeProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_IInspectable_c2943556)
class CfnTopic(
    _CfnResource_9df397a6,
    metaclass=jsii.JSIIMeta,
    jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic",
):
    '''Creates a new Q topic.

    :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-topic.html
    :cloudformationResource: AWS::QuickSight::Topic
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        from aws_cdk import aws_quicksight as quicksight
        
        cfn_topic = quicksight.CfnTopic(self, "MyCfnTopic",
            aws_account_id="awsAccountId",
            data_sets=[quicksight.CfnTopic.DatasetMetadataProperty(
                dataset_arn="datasetArn",
        
                # the properties below are optional
                calculated_fields=[quicksight.CfnTopic.TopicCalculatedFieldProperty(
                    calculated_field_name="calculatedFieldName",
                    expression="expression",
        
                    # the properties below are optional
                    aggregation="aggregation",
                    allowed_aggregations=["allowedAggregations"],
                    calculated_field_description="calculatedFieldDescription",
                    calculated_field_synonyms=["calculatedFieldSynonyms"],
                    cell_value_synonyms=[quicksight.CfnTopic.CellValueSynonymProperty(
                        cell_value="cellValue",
                        synonyms=["synonyms"]
                    )],
                    column_data_role="columnDataRole",
                    comparative_order=quicksight.CfnTopic.ComparativeOrderProperty(
                        specifed_order=["specifedOrder"],
                        treat_undefined_specified_values="treatUndefinedSpecifiedValues",
                        use_ordering="useOrdering"
                    ),
                    default_formatting=quicksight.CfnTopic.DefaultFormattingProperty(
                        display_format="displayFormat",
                        display_format_options=quicksight.CfnTopic.DisplayFormatOptionsProperty(
                            blank_cell_format="blankCellFormat",
                            currency_symbol="currencySymbol",
                            date_format="dateFormat",
                            decimal_separator="decimalSeparator",
                            fraction_digits=123,
                            grouping_separator="groupingSeparator",
                            negative_format=quicksight.CfnTopic.NegativeFormatProperty(
                                prefix="prefix",
                                suffix="suffix"
                            ),
                            prefix="prefix",
                            suffix="suffix",
                            unit_scaler="unitScaler",
                            use_blank_cell_format=False,
                            use_grouping=False
                        )
                    ),
                    is_included_in_topic=False,
                    never_aggregate_in_filter=False,
                    non_additive=False,
                    not_allowed_aggregations=["notAllowedAggregations"],
                    semantic_type=quicksight.CfnTopic.SemanticTypeProperty(
                        falsey_cell_value="falseyCellValue",
                        falsey_cell_value_synonyms=["falseyCellValueSynonyms"],
                        sub_type_name="subTypeName",
                        truthy_cell_value="truthyCellValue",
                        truthy_cell_value_synonyms=["truthyCellValueSynonyms"],
                        type_name="typeName",
                        type_parameters={
                            "type_parameters_key": "typeParameters"
                        }
                    ),
                    time_granularity="timeGranularity"
                )],
                columns=[quicksight.CfnTopic.TopicColumnProperty(
                    column_name="columnName",
        
                    # the properties below are optional
                    aggregation="aggregation",
                    allowed_aggregations=["allowedAggregations"],
                    cell_value_synonyms=[quicksight.CfnTopic.CellValueSynonymProperty(
                        cell_value="cellValue",
                        synonyms=["synonyms"]
                    )],
                    column_data_role="columnDataRole",
                    column_description="columnDescription",
                    column_friendly_name="columnFriendlyName",
                    column_synonyms=["columnSynonyms"],
                    comparative_order=quicksight.CfnTopic.ComparativeOrderProperty(
                        specifed_order=["specifedOrder"],
                        treat_undefined_specified_values="treatUndefinedSpecifiedValues",
                        use_ordering="useOrdering"
                    ),
                    default_formatting=quicksight.CfnTopic.DefaultFormattingProperty(
                        display_format="displayFormat",
                        display_format_options=quicksight.CfnTopic.DisplayFormatOptionsProperty(
                            blank_cell_format="blankCellFormat",
                            currency_symbol="currencySymbol",
                            date_format="dateFormat",
                            decimal_separator="decimalSeparator",
                            fraction_digits=123,
                            grouping_separator="groupingSeparator",
                            negative_format=quicksight.CfnTopic.NegativeFormatProperty(
                                prefix="prefix",
                                suffix="suffix"
                            ),
                            prefix="prefix",
                            suffix="suffix",
                            unit_scaler="unitScaler",
                            use_blank_cell_format=False,
                            use_grouping=False
                        )
                    ),
                    is_included_in_topic=False,
                    never_aggregate_in_filter=False,
                    non_additive=False,
                    not_allowed_aggregations=["notAllowedAggregations"],
                    semantic_type=quicksight.CfnTopic.SemanticTypeProperty(
                        falsey_cell_value="falseyCellValue",
                        falsey_cell_value_synonyms=["falseyCellValueSynonyms"],
                        sub_type_name="subTypeName",
                        truthy_cell_value="truthyCellValue",
                        truthy_cell_value_synonyms=["truthyCellValueSynonyms"],
                        type_name="typeName",
                        type_parameters={
                            "type_parameters_key": "typeParameters"
                        }
                    ),
                    time_granularity="timeGranularity"
                )],
                data_aggregation=quicksight.CfnTopic.DataAggregationProperty(
                    dataset_row_date_granularity="datasetRowDateGranularity",
                    default_date_column_name="defaultDateColumnName"
                ),
                dataset_description="datasetDescription",
                dataset_name="datasetName",
                filters=[quicksight.CfnTopic.TopicFilterProperty(
                    filter_name="filterName",
                    operand_field_name="operandFieldName",
        
                    # the properties below are optional
                    category_filter=quicksight.CfnTopic.TopicCategoryFilterProperty(
                        category_filter_function="categoryFilterFunction",
                        category_filter_type="categoryFilterType",
                        constant=quicksight.CfnTopic.TopicCategoryFilterConstantProperty(
                            collective_constant=quicksight.CfnTopic.CollectiveConstantProperty(
                                value_list=["valueList"]
                            ),
                            constant_type="constantType",
                            singular_constant="singularConstant"
                        ),
                        inverse=False
                    ),
                    date_range_filter=quicksight.CfnTopic.TopicDateRangeFilterProperty(
                        constant=quicksight.CfnTopic.TopicRangeFilterConstantProperty(
                            constant_type="constantType",
                            range_constant=quicksight.CfnTopic.RangeConstantProperty(
                                maximum="maximum",
                                minimum="minimum"
                            )
                        ),
                        inclusive=False
                    ),
                    filter_class="filterClass",
                    filter_description="filterDescription",
                    filter_synonyms=["filterSynonyms"],
                    filter_type="filterType",
                    numeric_equality_filter=quicksight.CfnTopic.TopicNumericEqualityFilterProperty(
                        aggregation="aggregation",
                        constant=quicksight.CfnTopic.TopicSingularFilterConstantProperty(
                            constant_type="constantType",
                            singular_constant="singularConstant"
                        )
                    ),
                    numeric_range_filter=quicksight.CfnTopic.TopicNumericRangeFilterProperty(
                        aggregation="aggregation",
                        constant=quicksight.CfnTopic.TopicRangeFilterConstantProperty(
                            constant_type="constantType",
                            range_constant=quicksight.CfnTopic.RangeConstantProperty(
                                maximum="maximum",
                                minimum="minimum"
                            )
                        ),
                        inclusive=False
                    ),
                    relative_date_filter=quicksight.CfnTopic.TopicRelativeDateFilterProperty(
                        constant=quicksight.CfnTopic.TopicSingularFilterConstantProperty(
                            constant_type="constantType",
                            singular_constant="singularConstant"
                        ),
                        relative_date_filter_function="relativeDateFilterFunction",
                        time_granularity="timeGranularity"
                    )
                )],
                named_entities=[quicksight.CfnTopic.TopicNamedEntityProperty(
                    entity_name="entityName",
        
                    # the properties below are optional
                    definition=[quicksight.CfnTopic.NamedEntityDefinitionProperty(
                        field_name="fieldName",
                        metric=quicksight.CfnTopic.NamedEntityDefinitionMetricProperty(
                            aggregation="aggregation",
                            aggregation_function_parameters={
                                "aggregation_function_parameters_key": "aggregationFunctionParameters"
                            }
                        ),
                        property_name="propertyName",
                        property_role="propertyRole",
                        property_usage="propertyUsage"
                    )],
                    entity_description="entityDescription",
                    entity_synonyms=["entitySynonyms"],
                    semantic_entity_type=quicksight.CfnTopic.SemanticEntityTypeProperty(
                        sub_type_name="subTypeName",
                        type_name="typeName",
                        type_parameters={
                            "type_parameters_key": "typeParameters"
                        }
                    )
                )]
            )],
            description="description",
            name="name",
            topic_id="topicId",
            user_experience_version="userExperienceVersion"
        )
    '''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.Construct,
        id: builtins.str,
        *,
        aws_account_id: typing.Optional[builtins.str] = None,
        data_sets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.DatasetMetadataProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        description: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        topic_id: typing.Optional[builtins.str] = None,
        user_experience_version: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param scope: Scope in which this resource is defined.
        :param id: Construct identifier for this resource (unique in its scope).
        :param aws_account_id: The ID of the AWS account that you want to create a topic in.
        :param data_sets: The data sets that the topic is associated with.
        :param description: The description of the topic.
        :param name: The name of the topic.
        :param topic_id: The ID for the topic. This ID is unique per AWS Region for each AWS account.
        :param user_experience_version: The user experience version of a topic.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e98a54c810cd62780e1f968a0f83f854bc8baac07e43fc099f3f81b062d8e088)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnTopicProps(
            aws_account_id=aws_account_id,
            data_sets=data_sets,
            description=description,
            name=name,
            topic_id=topic_id,
            user_experience_version=user_experience_version,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _TreeInspector_488e0dd5) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba1a40b47a4dd39d8e7c64883710d38ff5623b8e62637a255de8fd05bdba8b49)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__76423f09362a227c521d6507f7de1870912e335513ea94129d35b3e421a26224)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) of the topic.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The ID of the AWS account that you want to create a topic in.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1f057f56a73762b4877e8579df45fb30889b477dbb063f820ff9ca71e4eb10e1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="dataSets")
    def data_sets(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTopic.DatasetMetadataProperty"]]]]:
        '''The data sets that the topic is associated with.'''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTopic.DatasetMetadataProperty"]]]], jsii.get(self, "dataSets"))

    @data_sets.setter
    def data_sets(
        self,
        value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTopic.DatasetMetadataProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__865dd17cdf0180752414a809eb15588349da7941dd91964b989f41ca7cd29ab4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSets", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[builtins.str]:
        '''The description of the topic.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "description"))

    @description.setter
    def description(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__481ab478962ac0f8201bad9978ce36e28b5065c639475f66dc91f4efd41fe68b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        '''The name of the topic.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "name"))

    @name.setter
    def name(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__50731ae547f0d2238bc12670138bf03f65427325a5cb389667f3552b0ddd15fb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="topicId")
    def topic_id(self) -> typing.Optional[builtins.str]:
        '''The ID for the topic.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "topicId"))

    @topic_id.setter
    def topic_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e7ec12bb62b1d230bdac157875cb0b5b7a386f94a0af70696f88bc8f6e69d49)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "topicId", value)

    @builtins.property
    @jsii.member(jsii_name="userExperienceVersion")
    def user_experience_version(self) -> typing.Optional[builtins.str]:
        '''The user experience version of a topic.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "userExperienceVersion"))

    @user_experience_version.setter
    def user_experience_version(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__28aca8d896b27e7d885e956910a7d20f0e3ff34c9aeb0e70ca664673d5f3fb6f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "userExperienceVersion", value)

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.CellValueSynonymProperty",
        jsii_struct_bases=[],
        name_mapping={"cell_value": "cellValue", "synonyms": "synonyms"},
    )
    class CellValueSynonymProperty:
        def __init__(
            self,
            *,
            cell_value: typing.Optional[builtins.str] = None,
            synonyms: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A structure that represents the cell value synonym.

            :param cell_value: The cell value.
            :param synonyms: Other names or aliases for the cell value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-cellvaluesynonym.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                cell_value_synonym_property = quicksight.CfnTopic.CellValueSynonymProperty(
                    cell_value="cellValue",
                    synonyms=["synonyms"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7e1d2f30468c0518adcf31a483375d454f1b9ff53fc490ffa0914de61161db5a)
                check_type(argname="argument cell_value", value=cell_value, expected_type=type_hints["cell_value"])
                check_type(argname="argument synonyms", value=synonyms, expected_type=type_hints["synonyms"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell_value is not None:
                self._values["cell_value"] = cell_value
            if synonyms is not None:
                self._values["synonyms"] = synonyms

        @builtins.property
        def cell_value(self) -> typing.Optional[builtins.str]:
            '''The cell value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-cellvaluesynonym.html#cfn-quicksight-topic-cellvaluesynonym-cellvalue
            '''
            result = self._values.get("cell_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def synonyms(self) -> typing.Optional[typing.List[builtins.str]]:
            '''Other names or aliases for the cell value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-cellvaluesynonym.html#cfn-quicksight-topic-cellvaluesynonym-synonyms
            '''
            result = self._values.get("synonyms")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CellValueSynonymProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.CollectiveConstantProperty",
        jsii_struct_bases=[],
        name_mapping={"value_list": "valueList"},
    )
    class CollectiveConstantProperty:
        def __init__(
            self,
            *,
            value_list: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A structure that represents a collective constant.

            :param value_list: A list of values for the collective constant.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-collectiveconstant.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                collective_constant_property = quicksight.CfnTopic.CollectiveConstantProperty(
                    value_list=["valueList"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__99077acddad317cc5c85c778458a3e87554410900cfe93fea410bc7903c1737e)
                check_type(argname="argument value_list", value=value_list, expected_type=type_hints["value_list"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if value_list is not None:
                self._values["value_list"] = value_list

        @builtins.property
        def value_list(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of values for the collective constant.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-collectiveconstant.html#cfn-quicksight-topic-collectiveconstant-valuelist
            '''
            result = self._values.get("value_list")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CollectiveConstantProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.ComparativeOrderProperty",
        jsii_struct_bases=[],
        name_mapping={
            "specifed_order": "specifedOrder",
            "treat_undefined_specified_values": "treatUndefinedSpecifiedValues",
            "use_ordering": "useOrdering",
        },
    )
    class ComparativeOrderProperty:
        def __init__(
            self,
            *,
            specifed_order: typing.Optional[typing.Sequence[builtins.str]] = None,
            treat_undefined_specified_values: typing.Optional[builtins.str] = None,
            use_ordering: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The order in which data is displayed for the column when it's used in a comparative context.

            :param specifed_order: The list of columns to be used in the ordering.
            :param treat_undefined_specified_values: The treat of undefined specified values. Valid values for this structure are ``LEAST`` and ``MOST`` .
            :param use_ordering: The ordering type for a column. Valid values for this structure are ``GREATER_IS_BETTER`` , ``LESSER_IS_BETTER`` and ``SPECIFIED`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-comparativeorder.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                comparative_order_property = quicksight.CfnTopic.ComparativeOrderProperty(
                    specifed_order=["specifedOrder"],
                    treat_undefined_specified_values="treatUndefinedSpecifiedValues",
                    use_ordering="useOrdering"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__471648aa1c53b0767a1f96087fccfd258d8d0cb568d1b3ae8ddbb3d37596dc80)
                check_type(argname="argument specifed_order", value=specifed_order, expected_type=type_hints["specifed_order"])
                check_type(argname="argument treat_undefined_specified_values", value=treat_undefined_specified_values, expected_type=type_hints["treat_undefined_specified_values"])
                check_type(argname="argument use_ordering", value=use_ordering, expected_type=type_hints["use_ordering"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if specifed_order is not None:
                self._values["specifed_order"] = specifed_order
            if treat_undefined_specified_values is not None:
                self._values["treat_undefined_specified_values"] = treat_undefined_specified_values
            if use_ordering is not None:
                self._values["use_ordering"] = use_ordering

        @builtins.property
        def specifed_order(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of columns to be used in the ordering.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-comparativeorder.html#cfn-quicksight-topic-comparativeorder-specifedorder
            '''
            result = self._values.get("specifed_order")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def treat_undefined_specified_values(self) -> typing.Optional[builtins.str]:
            '''The treat of undefined specified values.

            Valid values for this structure are ``LEAST`` and ``MOST`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-comparativeorder.html#cfn-quicksight-topic-comparativeorder-treatundefinedspecifiedvalues
            '''
            result = self._values.get("treat_undefined_specified_values")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def use_ordering(self) -> typing.Optional[builtins.str]:
            '''The ordering type for a column.

            Valid values for this structure are ``GREATER_IS_BETTER`` , ``LESSER_IS_BETTER`` and ``SPECIFIED`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-comparativeorder.html#cfn-quicksight-topic-comparativeorder-useordering
            '''
            result = self._values.get("use_ordering")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComparativeOrderProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.DataAggregationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dataset_row_date_granularity": "datasetRowDateGranularity",
            "default_date_column_name": "defaultDateColumnName",
        },
    )
    class DataAggregationProperty:
        def __init__(
            self,
            *,
            dataset_row_date_granularity: typing.Optional[builtins.str] = None,
            default_date_column_name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The definition of a data aggregation.

            :param dataset_row_date_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param default_date_column_name: The column name for the default date.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-dataaggregation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                data_aggregation_property = quicksight.CfnTopic.DataAggregationProperty(
                    dataset_row_date_granularity="datasetRowDateGranularity",
                    default_date_column_name="defaultDateColumnName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6cf5ac3c01c8be3f1bd3d8b91d6b6fa59b49f363c86b67e4f688e399ae84c9d1)
                check_type(argname="argument dataset_row_date_granularity", value=dataset_row_date_granularity, expected_type=type_hints["dataset_row_date_granularity"])
                check_type(argname="argument default_date_column_name", value=default_date_column_name, expected_type=type_hints["default_date_column_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dataset_row_date_granularity is not None:
                self._values["dataset_row_date_granularity"] = dataset_row_date_granularity
            if default_date_column_name is not None:
                self._values["default_date_column_name"] = default_date_column_name

        @builtins.property
        def dataset_row_date_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-dataaggregation.html#cfn-quicksight-topic-dataaggregation-datasetrowdategranularity
            '''
            result = self._values.get("dataset_row_date_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def default_date_column_name(self) -> typing.Optional[builtins.str]:
            '''The column name for the default date.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-dataaggregation.html#cfn-quicksight-topic-dataaggregation-defaultdatecolumnname
            '''
            result = self._values.get("default_date_column_name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataAggregationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.DatasetMetadataProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dataset_arn": "datasetArn",
            "calculated_fields": "calculatedFields",
            "columns": "columns",
            "data_aggregation": "dataAggregation",
            "dataset_description": "datasetDescription",
            "dataset_name": "datasetName",
            "filters": "filters",
            "named_entities": "namedEntities",
        },
    )
    class DatasetMetadataProperty:
        def __init__(
            self,
            *,
            dataset_arn: builtins.str,
            calculated_fields: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.TopicCalculatedFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            columns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.TopicColumnProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_aggregation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.DataAggregationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            dataset_description: typing.Optional[builtins.str] = None,
            dataset_name: typing.Optional[builtins.str] = None,
            filters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.TopicFilterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            named_entities: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.TopicNamedEntityProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''A structure that represents a dataset.

            :param dataset_arn: The Amazon Resource Name (ARN) of the dataset.
            :param calculated_fields: The list of calculated field definitions.
            :param columns: The list of column definitions.
            :param data_aggregation: The definition of a data aggregation.
            :param dataset_description: The description of the dataset.
            :param dataset_name: The name of the dataset.
            :param filters: The list of filter definitions.
            :param named_entities: The list of named entities definitions.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-datasetmetadata.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                dataset_metadata_property = quicksight.CfnTopic.DatasetMetadataProperty(
                    dataset_arn="datasetArn",
                
                    # the properties below are optional
                    calculated_fields=[quicksight.CfnTopic.TopicCalculatedFieldProperty(
                        calculated_field_name="calculatedFieldName",
                        expression="expression",
                
                        # the properties below are optional
                        aggregation="aggregation",
                        allowed_aggregations=["allowedAggregations"],
                        calculated_field_description="calculatedFieldDescription",
                        calculated_field_synonyms=["calculatedFieldSynonyms"],
                        cell_value_synonyms=[quicksight.CfnTopic.CellValueSynonymProperty(
                            cell_value="cellValue",
                            synonyms=["synonyms"]
                        )],
                        column_data_role="columnDataRole",
                        comparative_order=quicksight.CfnTopic.ComparativeOrderProperty(
                            specifed_order=["specifedOrder"],
                            treat_undefined_specified_values="treatUndefinedSpecifiedValues",
                            use_ordering="useOrdering"
                        ),
                        default_formatting=quicksight.CfnTopic.DefaultFormattingProperty(
                            display_format="displayFormat",
                            display_format_options=quicksight.CfnTopic.DisplayFormatOptionsProperty(
                                blank_cell_format="blankCellFormat",
                                currency_symbol="currencySymbol",
                                date_format="dateFormat",
                                decimal_separator="decimalSeparator",
                                fraction_digits=123,
                                grouping_separator="groupingSeparator",
                                negative_format=quicksight.CfnTopic.NegativeFormatProperty(
                                    prefix="prefix",
                                    suffix="suffix"
                                ),
                                prefix="prefix",
                                suffix="suffix",
                                unit_scaler="unitScaler",
                                use_blank_cell_format=False,
                                use_grouping=False
                            )
                        ),
                        is_included_in_topic=False,
                        never_aggregate_in_filter=False,
                        non_additive=False,
                        not_allowed_aggregations=["notAllowedAggregations"],
                        semantic_type=quicksight.CfnTopic.SemanticTypeProperty(
                            falsey_cell_value="falseyCellValue",
                            falsey_cell_value_synonyms=["falseyCellValueSynonyms"],
                            sub_type_name="subTypeName",
                            truthy_cell_value="truthyCellValue",
                            truthy_cell_value_synonyms=["truthyCellValueSynonyms"],
                            type_name="typeName",
                            type_parameters={
                                "type_parameters_key": "typeParameters"
                            }
                        ),
                        time_granularity="timeGranularity"
                    )],
                    columns=[quicksight.CfnTopic.TopicColumnProperty(
                        column_name="columnName",
                
                        # the properties below are optional
                        aggregation="aggregation",
                        allowed_aggregations=["allowedAggregations"],
                        cell_value_synonyms=[quicksight.CfnTopic.CellValueSynonymProperty(
                            cell_value="cellValue",
                            synonyms=["synonyms"]
                        )],
                        column_data_role="columnDataRole",
                        column_description="columnDescription",
                        column_friendly_name="columnFriendlyName",
                        column_synonyms=["columnSynonyms"],
                        comparative_order=quicksight.CfnTopic.ComparativeOrderProperty(
                            specifed_order=["specifedOrder"],
                            treat_undefined_specified_values="treatUndefinedSpecifiedValues",
                            use_ordering="useOrdering"
                        ),
                        default_formatting=quicksight.CfnTopic.DefaultFormattingProperty(
                            display_format="displayFormat",
                            display_format_options=quicksight.CfnTopic.DisplayFormatOptionsProperty(
                                blank_cell_format="blankCellFormat",
                                currency_symbol="currencySymbol",
                                date_format="dateFormat",
                                decimal_separator="decimalSeparator",
                                fraction_digits=123,
                                grouping_separator="groupingSeparator",
                                negative_format=quicksight.CfnTopic.NegativeFormatProperty(
                                    prefix="prefix",
                                    suffix="suffix"
                                ),
                                prefix="prefix",
                                suffix="suffix",
                                unit_scaler="unitScaler",
                                use_blank_cell_format=False,
                                use_grouping=False
                            )
                        ),
                        is_included_in_topic=False,
                        never_aggregate_in_filter=False,
                        non_additive=False,
                        not_allowed_aggregations=["notAllowedAggregations"],
                        semantic_type=quicksight.CfnTopic.SemanticTypeProperty(
                            falsey_cell_value="falseyCellValue",
                            falsey_cell_value_synonyms=["falseyCellValueSynonyms"],
                            sub_type_name="subTypeName",
                            truthy_cell_value="truthyCellValue",
                            truthy_cell_value_synonyms=["truthyCellValueSynonyms"],
                            type_name="typeName",
                            type_parameters={
                                "type_parameters_key": "typeParameters"
                            }
                        ),
                        time_granularity="timeGranularity"
                    )],
                    data_aggregation=quicksight.CfnTopic.DataAggregationProperty(
                        dataset_row_date_granularity="datasetRowDateGranularity",
                        default_date_column_name="defaultDateColumnName"
                    ),
                    dataset_description="datasetDescription",
                    dataset_name="datasetName",
                    filters=[quicksight.CfnTopic.TopicFilterProperty(
                        filter_name="filterName",
                        operand_field_name="operandFieldName",
                
                        # the properties below are optional
                        category_filter=quicksight.CfnTopic.TopicCategoryFilterProperty(
                            category_filter_function="categoryFilterFunction",
                            category_filter_type="categoryFilterType",
                            constant=quicksight.CfnTopic.TopicCategoryFilterConstantProperty(
                                collective_constant=quicksight.CfnTopic.CollectiveConstantProperty(
                                    value_list=["valueList"]
                                ),
                                constant_type="constantType",
                                singular_constant="singularConstant"
                            ),
                            inverse=False
                        ),
                        date_range_filter=quicksight.CfnTopic.TopicDateRangeFilterProperty(
                            constant=quicksight.CfnTopic.TopicRangeFilterConstantProperty(
                                constant_type="constantType",
                                range_constant=quicksight.CfnTopic.RangeConstantProperty(
                                    maximum="maximum",
                                    minimum="minimum"
                                )
                            ),
                            inclusive=False
                        ),
                        filter_class="filterClass",
                        filter_description="filterDescription",
                        filter_synonyms=["filterSynonyms"],
                        filter_type="filterType",
                        numeric_equality_filter=quicksight.CfnTopic.TopicNumericEqualityFilterProperty(
                            aggregation="aggregation",
                            constant=quicksight.CfnTopic.TopicSingularFilterConstantProperty(
                                constant_type="constantType",
                                singular_constant="singularConstant"
                            )
                        ),
                        numeric_range_filter=quicksight.CfnTopic.TopicNumericRangeFilterProperty(
                            aggregation="aggregation",
                            constant=quicksight.CfnTopic.TopicRangeFilterConstantProperty(
                                constant_type="constantType",
                                range_constant=quicksight.CfnTopic.RangeConstantProperty(
                                    maximum="maximum",
                                    minimum="minimum"
                                )
                            ),
                            inclusive=False
                        ),
                        relative_date_filter=quicksight.CfnTopic.TopicRelativeDateFilterProperty(
                            constant=quicksight.CfnTopic.TopicSingularFilterConstantProperty(
                                constant_type="constantType",
                                singular_constant="singularConstant"
                            ),
                            relative_date_filter_function="relativeDateFilterFunction",
                            time_granularity="timeGranularity"
                        )
                    )],
                    named_entities=[quicksight.CfnTopic.TopicNamedEntityProperty(
                        entity_name="entityName",
                
                        # the properties below are optional
                        definition=[quicksight.CfnTopic.NamedEntityDefinitionProperty(
                            field_name="fieldName",
                            metric=quicksight.CfnTopic.NamedEntityDefinitionMetricProperty(
                                aggregation="aggregation",
                                aggregation_function_parameters={
                                    "aggregation_function_parameters_key": "aggregationFunctionParameters"
                                }
                            ),
                            property_name="propertyName",
                            property_role="propertyRole",
                            property_usage="propertyUsage"
                        )],
                        entity_description="entityDescription",
                        entity_synonyms=["entitySynonyms"],
                        semantic_entity_type=quicksight.CfnTopic.SemanticEntityTypeProperty(
                            sub_type_name="subTypeName",
                            type_name="typeName",
                            type_parameters={
                                "type_parameters_key": "typeParameters"
                            }
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__759725ab113e70f3e650b49659e82a542dc9edfa60adbb5b9934a71cddeebe76)
                check_type(argname="argument dataset_arn", value=dataset_arn, expected_type=type_hints["dataset_arn"])
                check_type(argname="argument calculated_fields", value=calculated_fields, expected_type=type_hints["calculated_fields"])
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument data_aggregation", value=data_aggregation, expected_type=type_hints["data_aggregation"])
                check_type(argname="argument dataset_description", value=dataset_description, expected_type=type_hints["dataset_description"])
                check_type(argname="argument dataset_name", value=dataset_name, expected_type=type_hints["dataset_name"])
                check_type(argname="argument filters", value=filters, expected_type=type_hints["filters"])
                check_type(argname="argument named_entities", value=named_entities, expected_type=type_hints["named_entities"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "dataset_arn": dataset_arn,
            }
            if calculated_fields is not None:
                self._values["calculated_fields"] = calculated_fields
            if columns is not None:
                self._values["columns"] = columns
            if data_aggregation is not None:
                self._values["data_aggregation"] = data_aggregation
            if dataset_description is not None:
                self._values["dataset_description"] = dataset_description
            if dataset_name is not None:
                self._values["dataset_name"] = dataset_name
            if filters is not None:
                self._values["filters"] = filters
            if named_entities is not None:
                self._values["named_entities"] = named_entities

        @builtins.property
        def dataset_arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-datasetmetadata.html#cfn-quicksight-topic-datasetmetadata-datasetarn
            '''
            result = self._values.get("dataset_arn")
            assert result is not None, "Required property 'dataset_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def calculated_fields(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicCalculatedFieldProperty"]]]]:
            '''The list of calculated field definitions.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-datasetmetadata.html#cfn-quicksight-topic-datasetmetadata-calculatedfields
            '''
            result = self._values.get("calculated_fields")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicCalculatedFieldProperty"]]]], result)

        @builtins.property
        def columns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicColumnProperty"]]]]:
            '''The list of column definitions.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-datasetmetadata.html#cfn-quicksight-topic-datasetmetadata-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicColumnProperty"]]]], result)

        @builtins.property
        def data_aggregation(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.DataAggregationProperty"]]:
            '''The definition of a data aggregation.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-datasetmetadata.html#cfn-quicksight-topic-datasetmetadata-dataaggregation
            '''
            result = self._values.get("data_aggregation")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.DataAggregationProperty"]], result)

        @builtins.property
        def dataset_description(self) -> typing.Optional[builtins.str]:
            '''The description of the dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-datasetmetadata.html#cfn-quicksight-topic-datasetmetadata-datasetdescription
            '''
            result = self._values.get("dataset_description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def dataset_name(self) -> typing.Optional[builtins.str]:
            '''The name of the dataset.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-datasetmetadata.html#cfn-quicksight-topic-datasetmetadata-datasetname
            '''
            result = self._values.get("dataset_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def filters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicFilterProperty"]]]]:
            '''The list of filter definitions.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-datasetmetadata.html#cfn-quicksight-topic-datasetmetadata-filters
            '''
            result = self._values.get("filters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicFilterProperty"]]]], result)

        @builtins.property
        def named_entities(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicNamedEntityProperty"]]]]:
            '''The list of named entities definitions.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-datasetmetadata.html#cfn-quicksight-topic-datasetmetadata-namedentities
            '''
            result = self._values.get("named_entities")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicNamedEntityProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DatasetMetadataProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.DefaultFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "display_format": "displayFormat",
            "display_format_options": "displayFormatOptions",
        },
    )
    class DefaultFormattingProperty:
        def __init__(
            self,
            *,
            display_format: typing.Optional[builtins.str] = None,
            display_format_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.DisplayFormatOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A structure that represents a default formatting definition.

            :param display_format: The display format. Valid values for this structure are ``AUTO`` , ``PERCENT`` , ``CURRENCY`` , ``NUMBER`` , ``DATE`` , and ``STRING`` .
            :param display_format_options: The additional options for display formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-defaultformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                default_formatting_property = quicksight.CfnTopic.DefaultFormattingProperty(
                    display_format="displayFormat",
                    display_format_options=quicksight.CfnTopic.DisplayFormatOptionsProperty(
                        blank_cell_format="blankCellFormat",
                        currency_symbol="currencySymbol",
                        date_format="dateFormat",
                        decimal_separator="decimalSeparator",
                        fraction_digits=123,
                        grouping_separator="groupingSeparator",
                        negative_format=quicksight.CfnTopic.NegativeFormatProperty(
                            prefix="prefix",
                            suffix="suffix"
                        ),
                        prefix="prefix",
                        suffix="suffix",
                        unit_scaler="unitScaler",
                        use_blank_cell_format=False,
                        use_grouping=False
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__38757f97f575ef5532a16ecc041416069794e07721d9e59b03ee60c531b9e0cd)
                check_type(argname="argument display_format", value=display_format, expected_type=type_hints["display_format"])
                check_type(argname="argument display_format_options", value=display_format_options, expected_type=type_hints["display_format_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if display_format is not None:
                self._values["display_format"] = display_format
            if display_format_options is not None:
                self._values["display_format_options"] = display_format_options

        @builtins.property
        def display_format(self) -> typing.Optional[builtins.str]:
            '''The display format.

            Valid values for this structure are ``AUTO`` , ``PERCENT`` , ``CURRENCY`` , ``NUMBER`` , ``DATE`` , and ``STRING`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-defaultformatting.html#cfn-quicksight-topic-defaultformatting-displayformat
            '''
            result = self._values.get("display_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_format_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.DisplayFormatOptionsProperty"]]:
            '''The additional options for display formatting.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-defaultformatting.html#cfn-quicksight-topic-defaultformatting-displayformatoptions
            '''
            result = self._values.get("display_format_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.DisplayFormatOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.DisplayFormatOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "blank_cell_format": "blankCellFormat",
            "currency_symbol": "currencySymbol",
            "date_format": "dateFormat",
            "decimal_separator": "decimalSeparator",
            "fraction_digits": "fractionDigits",
            "grouping_separator": "groupingSeparator",
            "negative_format": "negativeFormat",
            "prefix": "prefix",
            "suffix": "suffix",
            "unit_scaler": "unitScaler",
            "use_blank_cell_format": "useBlankCellFormat",
            "use_grouping": "useGrouping",
        },
    )
    class DisplayFormatOptionsProperty:
        def __init__(
            self,
            *,
            blank_cell_format: typing.Optional[builtins.str] = None,
            currency_symbol: typing.Optional[builtins.str] = None,
            date_format: typing.Optional[builtins.str] = None,
            decimal_separator: typing.Optional[builtins.str] = None,
            fraction_digits: typing.Optional[jsii.Number] = None,
            grouping_separator: typing.Optional[builtins.str] = None,
            negative_format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.NegativeFormatProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            prefix: typing.Optional[builtins.str] = None,
            suffix: typing.Optional[builtins.str] = None,
            unit_scaler: typing.Optional[builtins.str] = None,
            use_blank_cell_format: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
            use_grouping: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
        ) -> None:
            '''A structure that represents additional options for display formatting.

            :param blank_cell_format: Determines the blank cell format.
            :param currency_symbol: The currency symbol, such as ``USD`` .
            :param date_format: Determines the ``DateTime`` format.
            :param decimal_separator: Determines the decimal separator.
            :param fraction_digits: Determines the number of fraction digits. Default: - 0
            :param grouping_separator: Determines the grouping separator.
            :param negative_format: The negative format.
            :param prefix: The prefix value for a display format.
            :param suffix: The suffix value for a display format.
            :param unit_scaler: The unit scaler. Valid values for this structure are: ``NONE`` , ``AUTO`` , ``THOUSANDS`` , ``MILLIONS`` , ``BILLIONS`` , and ``TRILLIONS`` .
            :param use_blank_cell_format: A Boolean value that indicates whether to use blank cell format. Default: - false
            :param use_grouping: A Boolean value that indicates whether to use grouping. Default: - false

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                display_format_options_property = quicksight.CfnTopic.DisplayFormatOptionsProperty(
                    blank_cell_format="blankCellFormat",
                    currency_symbol="currencySymbol",
                    date_format="dateFormat",
                    decimal_separator="decimalSeparator",
                    fraction_digits=123,
                    grouping_separator="groupingSeparator",
                    negative_format=quicksight.CfnTopic.NegativeFormatProperty(
                        prefix="prefix",
                        suffix="suffix"
                    ),
                    prefix="prefix",
                    suffix="suffix",
                    unit_scaler="unitScaler",
                    use_blank_cell_format=False,
                    use_grouping=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5a518fe1c79b565f9a3036522dcd63b238ba1fcfe71a03b4910fe1227edcf6aa)
                check_type(argname="argument blank_cell_format", value=blank_cell_format, expected_type=type_hints["blank_cell_format"])
                check_type(argname="argument currency_symbol", value=currency_symbol, expected_type=type_hints["currency_symbol"])
                check_type(argname="argument date_format", value=date_format, expected_type=type_hints["date_format"])
                check_type(argname="argument decimal_separator", value=decimal_separator, expected_type=type_hints["decimal_separator"])
                check_type(argname="argument fraction_digits", value=fraction_digits, expected_type=type_hints["fraction_digits"])
                check_type(argname="argument grouping_separator", value=grouping_separator, expected_type=type_hints["grouping_separator"])
                check_type(argname="argument negative_format", value=negative_format, expected_type=type_hints["negative_format"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
                check_type(argname="argument unit_scaler", value=unit_scaler, expected_type=type_hints["unit_scaler"])
                check_type(argname="argument use_blank_cell_format", value=use_blank_cell_format, expected_type=type_hints["use_blank_cell_format"])
                check_type(argname="argument use_grouping", value=use_grouping, expected_type=type_hints["use_grouping"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if blank_cell_format is not None:
                self._values["blank_cell_format"] = blank_cell_format
            if currency_symbol is not None:
                self._values["currency_symbol"] = currency_symbol
            if date_format is not None:
                self._values["date_format"] = date_format
            if decimal_separator is not None:
                self._values["decimal_separator"] = decimal_separator
            if fraction_digits is not None:
                self._values["fraction_digits"] = fraction_digits
            if grouping_separator is not None:
                self._values["grouping_separator"] = grouping_separator
            if negative_format is not None:
                self._values["negative_format"] = negative_format
            if prefix is not None:
                self._values["prefix"] = prefix
            if suffix is not None:
                self._values["suffix"] = suffix
            if unit_scaler is not None:
                self._values["unit_scaler"] = unit_scaler
            if use_blank_cell_format is not None:
                self._values["use_blank_cell_format"] = use_blank_cell_format
            if use_grouping is not None:
                self._values["use_grouping"] = use_grouping

        @builtins.property
        def blank_cell_format(self) -> typing.Optional[builtins.str]:
            '''Determines the blank cell format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-blankcellformat
            '''
            result = self._values.get("blank_cell_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def currency_symbol(self) -> typing.Optional[builtins.str]:
            '''The currency symbol, such as ``USD`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-currencysymbol
            '''
            result = self._values.get("currency_symbol")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def date_format(self) -> typing.Optional[builtins.str]:
            '''Determines the ``DateTime`` format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-dateformat
            '''
            result = self._values.get("date_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def decimal_separator(self) -> typing.Optional[builtins.str]:
            '''Determines the decimal separator.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-decimalseparator
            '''
            result = self._values.get("decimal_separator")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def fraction_digits(self) -> typing.Optional[jsii.Number]:
            '''Determines the number of fraction digits.

            :default: - 0

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-fractiondigits
            '''
            result = self._values.get("fraction_digits")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def grouping_separator(self) -> typing.Optional[builtins.str]:
            '''Determines the grouping separator.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-groupingseparator
            '''
            result = self._values.get("grouping_separator")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def negative_format(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.NegativeFormatProperty"]]:
            '''The negative format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-negativeformat
            '''
            result = self._values.get("negative_format")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.NegativeFormatProperty"]], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''The prefix value for a display format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''The suffix value for a display format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def unit_scaler(self) -> typing.Optional[builtins.str]:
            '''The unit scaler.

            Valid values for this structure are: ``NONE`` , ``AUTO`` , ``THOUSANDS`` , ``MILLIONS`` , ``BILLIONS`` , and ``TRILLIONS`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-unitscaler
            '''
            result = self._values.get("unit_scaler")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def use_blank_cell_format(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''A Boolean value that indicates whether to use blank cell format.

            :default: - false

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-useblankcellformat
            '''
            result = self._values.get("use_blank_cell_format")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        @builtins.property
        def use_grouping(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''A Boolean value that indicates whether to use grouping.

            :default: - false

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-displayformatoptions.html#cfn-quicksight-topic-displayformatoptions-usegrouping
            '''
            result = self._values.get("use_grouping")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DisplayFormatOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.NamedEntityDefinitionMetricProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation": "aggregation",
            "aggregation_function_parameters": "aggregationFunctionParameters",
        },
    )
    class NamedEntityDefinitionMetricProperty:
        def __init__(
            self,
            *,
            aggregation: typing.Optional[builtins.str] = None,
            aggregation_function_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, builtins.str]]] = None,
        ) -> None:
            '''A structure that represents a metric.

            :param aggregation: The aggregation of a named entity. Valid values for this structure are ``SUM`` , ``MIN`` , ``MAX`` , ``COUNT`` , ``AVERAGE`` , ``DISTINCT_COUNT`` , ``STDEV`` , ``STDEVP`` , ``VAR`` , ``VARP`` , ``PERCENTILE`` , ``MEDIAN`` , and ``CUSTOM`` .
            :param aggregation_function_parameters: The additional parameters for an aggregation function.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-namedentitydefinitionmetric.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                named_entity_definition_metric_property = quicksight.CfnTopic.NamedEntityDefinitionMetricProperty(
                    aggregation="aggregation",
                    aggregation_function_parameters={
                        "aggregation_function_parameters_key": "aggregationFunctionParameters"
                    }
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__30d0de58d685d1a779306717f3357202cfd2cea8b8407c7401ff618901aaca56)
                check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
                check_type(argname="argument aggregation_function_parameters", value=aggregation_function_parameters, expected_type=type_hints["aggregation_function_parameters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if aggregation is not None:
                self._values["aggregation"] = aggregation
            if aggregation_function_parameters is not None:
                self._values["aggregation_function_parameters"] = aggregation_function_parameters

        @builtins.property
        def aggregation(self) -> typing.Optional[builtins.str]:
            '''The aggregation of a named entity.

            Valid values for this structure are ``SUM`` , ``MIN`` , ``MAX`` , ``COUNT`` , ``AVERAGE`` , ``DISTINCT_COUNT`` , ``STDEV`` , ``STDEVP`` , ``VAR`` , ``VARP`` , ``PERCENTILE`` , ``MEDIAN`` , and ``CUSTOM`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-namedentitydefinitionmetric.html#cfn-quicksight-topic-namedentitydefinitionmetric-aggregation
            '''
            result = self._values.get("aggregation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def aggregation_function_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, builtins.str]]]:
            '''The additional parameters for an aggregation function.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-namedentitydefinitionmetric.html#cfn-quicksight-topic-namedentitydefinitionmetric-aggregationfunctionparameters
            '''
            result = self._values.get("aggregation_function_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, builtins.str]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NamedEntityDefinitionMetricProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.NamedEntityDefinitionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_name": "fieldName",
            "metric": "metric",
            "property_name": "propertyName",
            "property_role": "propertyRole",
            "property_usage": "propertyUsage",
        },
    )
    class NamedEntityDefinitionProperty:
        def __init__(
            self,
            *,
            field_name: typing.Optional[builtins.str] = None,
            metric: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.NamedEntityDefinitionMetricProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            property_name: typing.Optional[builtins.str] = None,
            property_role: typing.Optional[builtins.str] = None,
            property_usage: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A structure that represents a named entity.

            :param field_name: The name of the entity.
            :param metric: The definition of a metric.
            :param property_name: The property name to be used for the named entity.
            :param property_role: The property role. Valid values for this structure are ``PRIMARY`` and ``ID`` .
            :param property_usage: The property usage. Valid values for this structure are ``INHERIT`` , ``DIMENSION`` , and ``MEASURE`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-namedentitydefinition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                named_entity_definition_property = quicksight.CfnTopic.NamedEntityDefinitionProperty(
                    field_name="fieldName",
                    metric=quicksight.CfnTopic.NamedEntityDefinitionMetricProperty(
                        aggregation="aggregation",
                        aggregation_function_parameters={
                            "aggregation_function_parameters_key": "aggregationFunctionParameters"
                        }
                    ),
                    property_name="propertyName",
                    property_role="propertyRole",
                    property_usage="propertyUsage"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__38715088c0f5f57a344ffa137a60707c52b9a90db90176d3d99c3faf1af9dfa4)
                check_type(argname="argument field_name", value=field_name, expected_type=type_hints["field_name"])
                check_type(argname="argument metric", value=metric, expected_type=type_hints["metric"])
                check_type(argname="argument property_name", value=property_name, expected_type=type_hints["property_name"])
                check_type(argname="argument property_role", value=property_role, expected_type=type_hints["property_role"])
                check_type(argname="argument property_usage", value=property_usage, expected_type=type_hints["property_usage"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_name is not None:
                self._values["field_name"] = field_name
            if metric is not None:
                self._values["metric"] = metric
            if property_name is not None:
                self._values["property_name"] = property_name
            if property_role is not None:
                self._values["property_role"] = property_role
            if property_usage is not None:
                self._values["property_usage"] = property_usage

        @builtins.property
        def field_name(self) -> typing.Optional[builtins.str]:
            '''The name of the entity.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-namedentitydefinition.html#cfn-quicksight-topic-namedentitydefinition-fieldname
            '''
            result = self._values.get("field_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def metric(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.NamedEntityDefinitionMetricProperty"]]:
            '''The definition of a metric.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-namedentitydefinition.html#cfn-quicksight-topic-namedentitydefinition-metric
            '''
            result = self._values.get("metric")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.NamedEntityDefinitionMetricProperty"]], result)

        @builtins.property
        def property_name(self) -> typing.Optional[builtins.str]:
            '''The property name to be used for the named entity.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-namedentitydefinition.html#cfn-quicksight-topic-namedentitydefinition-propertyname
            '''
            result = self._values.get("property_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def property_role(self) -> typing.Optional[builtins.str]:
            '''The property role.

            Valid values for this structure are ``PRIMARY`` and ``ID`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-namedentitydefinition.html#cfn-quicksight-topic-namedentitydefinition-propertyrole
            '''
            result = self._values.get("property_role")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def property_usage(self) -> typing.Optional[builtins.str]:
            '''The property usage.

            Valid values for this structure are ``INHERIT`` , ``DIMENSION`` , and ``MEASURE`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-namedentitydefinition.html#cfn-quicksight-topic-namedentitydefinition-propertyusage
            '''
            result = self._values.get("property_usage")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NamedEntityDefinitionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.NegativeFormatProperty",
        jsii_struct_bases=[],
        name_mapping={"prefix": "prefix", "suffix": "suffix"},
    )
    class NegativeFormatProperty:
        def __init__(
            self,
            *,
            prefix: typing.Optional[builtins.str] = None,
            suffix: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A structure that represents a negative format.

            :param prefix: The prefix for a negative format.
            :param suffix: The suffix for a negative format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-negativeformat.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                negative_format_property = quicksight.CfnTopic.NegativeFormatProperty(
                    prefix="prefix",
                    suffix="suffix"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5b70c69387cd6497bee5dd0361aff1afc069ac32a0b5f2ece5581344c3336642)
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if prefix is not None:
                self._values["prefix"] = prefix
            if suffix is not None:
                self._values["suffix"] = suffix

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''The prefix for a negative format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-negativeformat.html#cfn-quicksight-topic-negativeformat-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''The suffix for a negative format.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-negativeformat.html#cfn-quicksight-topic-negativeformat-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NegativeFormatProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.RangeConstantProperty",
        jsii_struct_bases=[],
        name_mapping={"maximum": "maximum", "minimum": "minimum"},
    )
    class RangeConstantProperty:
        def __init__(
            self,
            *,
            maximum: typing.Optional[builtins.str] = None,
            minimum: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The value of the constant that is used to specify the endpoints of a range filter.

            :param maximum: The maximum value for a range constant.
            :param minimum: The minimum value for a range constant.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-rangeconstant.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                range_constant_property = quicksight.CfnTopic.RangeConstantProperty(
                    maximum="maximum",
                    minimum="minimum"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0453d6a9aa80984a83c9fc36baab6d1600c531ebf4b1b82f9e1e1664ece9ed5d)
                check_type(argname="argument maximum", value=maximum, expected_type=type_hints["maximum"])
                check_type(argname="argument minimum", value=minimum, expected_type=type_hints["minimum"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if maximum is not None:
                self._values["maximum"] = maximum
            if minimum is not None:
                self._values["minimum"] = minimum

        @builtins.property
        def maximum(self) -> typing.Optional[builtins.str]:
            '''The maximum value for a range constant.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-rangeconstant.html#cfn-quicksight-topic-rangeconstant-maximum
            '''
            result = self._values.get("maximum")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def minimum(self) -> typing.Optional[builtins.str]:
            '''The minimum value for a range constant.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-rangeconstant.html#cfn-quicksight-topic-rangeconstant-minimum
            '''
            result = self._values.get("minimum")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RangeConstantProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.SemanticEntityTypeProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sub_type_name": "subTypeName",
            "type_name": "typeName",
            "type_parameters": "typeParameters",
        },
    )
    class SemanticEntityTypeProperty:
        def __init__(
            self,
            *,
            sub_type_name: typing.Optional[builtins.str] = None,
            type_name: typing.Optional[builtins.str] = None,
            type_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, builtins.str]]] = None,
        ) -> None:
            '''A structure that represents a semantic entity type.

            :param sub_type_name: The semantic entity sub type name.
            :param type_name: The semantic entity type name.
            :param type_parameters: The semantic entity type parameters.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semanticentitytype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                semantic_entity_type_property = quicksight.CfnTopic.SemanticEntityTypeProperty(
                    sub_type_name="subTypeName",
                    type_name="typeName",
                    type_parameters={
                        "type_parameters_key": "typeParameters"
                    }
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6833ca411e149363a691fb6289ac45f28e170bd28660192519d306e46cf86e0d)
                check_type(argname="argument sub_type_name", value=sub_type_name, expected_type=type_hints["sub_type_name"])
                check_type(argname="argument type_name", value=type_name, expected_type=type_hints["type_name"])
                check_type(argname="argument type_parameters", value=type_parameters, expected_type=type_hints["type_parameters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sub_type_name is not None:
                self._values["sub_type_name"] = sub_type_name
            if type_name is not None:
                self._values["type_name"] = type_name
            if type_parameters is not None:
                self._values["type_parameters"] = type_parameters

        @builtins.property
        def sub_type_name(self) -> typing.Optional[builtins.str]:
            '''The semantic entity sub type name.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semanticentitytype.html#cfn-quicksight-topic-semanticentitytype-subtypename
            '''
            result = self._values.get("sub_type_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def type_name(self) -> typing.Optional[builtins.str]:
            '''The semantic entity type name.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semanticentitytype.html#cfn-quicksight-topic-semanticentitytype-typename
            '''
            result = self._values.get("type_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def type_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, builtins.str]]]:
            '''The semantic entity type parameters.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semanticentitytype.html#cfn-quicksight-topic-semanticentitytype-typeparameters
            '''
            result = self._values.get("type_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, builtins.str]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SemanticEntityTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.SemanticTypeProperty",
        jsii_struct_bases=[],
        name_mapping={
            "falsey_cell_value": "falseyCellValue",
            "falsey_cell_value_synonyms": "falseyCellValueSynonyms",
            "sub_type_name": "subTypeName",
            "truthy_cell_value": "truthyCellValue",
            "truthy_cell_value_synonyms": "truthyCellValueSynonyms",
            "type_name": "typeName",
            "type_parameters": "typeParameters",
        },
    )
    class SemanticTypeProperty:
        def __init__(
            self,
            *,
            falsey_cell_value: typing.Optional[builtins.str] = None,
            falsey_cell_value_synonyms: typing.Optional[typing.Sequence[builtins.str]] = None,
            sub_type_name: typing.Optional[builtins.str] = None,
            truthy_cell_value: typing.Optional[builtins.str] = None,
            truthy_cell_value_synonyms: typing.Optional[typing.Sequence[builtins.str]] = None,
            type_name: typing.Optional[builtins.str] = None,
            type_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, builtins.str]]] = None,
        ) -> None:
            '''A structure that represents a semantic type.

            :param falsey_cell_value: The semantic type falsey cell value.
            :param falsey_cell_value_synonyms: The other names or aliases for the false cell value.
            :param sub_type_name: The semantic type sub type name.
            :param truthy_cell_value: The semantic type truthy cell value.
            :param truthy_cell_value_synonyms: The other names or aliases for the true cell value.
            :param type_name: The semantic type name.
            :param type_parameters: The semantic type parameters.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semantictype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                semantic_type_property = quicksight.CfnTopic.SemanticTypeProperty(
                    falsey_cell_value="falseyCellValue",
                    falsey_cell_value_synonyms=["falseyCellValueSynonyms"],
                    sub_type_name="subTypeName",
                    truthy_cell_value="truthyCellValue",
                    truthy_cell_value_synonyms=["truthyCellValueSynonyms"],
                    type_name="typeName",
                    type_parameters={
                        "type_parameters_key": "typeParameters"
                    }
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__649f722425d32b10d8f225001fefd47663bcbf814fcf9af9e5876815765949dc)
                check_type(argname="argument falsey_cell_value", value=falsey_cell_value, expected_type=type_hints["falsey_cell_value"])
                check_type(argname="argument falsey_cell_value_synonyms", value=falsey_cell_value_synonyms, expected_type=type_hints["falsey_cell_value_synonyms"])
                check_type(argname="argument sub_type_name", value=sub_type_name, expected_type=type_hints["sub_type_name"])
                check_type(argname="argument truthy_cell_value", value=truthy_cell_value, expected_type=type_hints["truthy_cell_value"])
                check_type(argname="argument truthy_cell_value_synonyms", value=truthy_cell_value_synonyms, expected_type=type_hints["truthy_cell_value_synonyms"])
                check_type(argname="argument type_name", value=type_name, expected_type=type_hints["type_name"])
                check_type(argname="argument type_parameters", value=type_parameters, expected_type=type_hints["type_parameters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if falsey_cell_value is not None:
                self._values["falsey_cell_value"] = falsey_cell_value
            if falsey_cell_value_synonyms is not None:
                self._values["falsey_cell_value_synonyms"] = falsey_cell_value_synonyms
            if sub_type_name is not None:
                self._values["sub_type_name"] = sub_type_name
            if truthy_cell_value is not None:
                self._values["truthy_cell_value"] = truthy_cell_value
            if truthy_cell_value_synonyms is not None:
                self._values["truthy_cell_value_synonyms"] = truthy_cell_value_synonyms
            if type_name is not None:
                self._values["type_name"] = type_name
            if type_parameters is not None:
                self._values["type_parameters"] = type_parameters

        @builtins.property
        def falsey_cell_value(self) -> typing.Optional[builtins.str]:
            '''The semantic type falsey cell value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semantictype.html#cfn-quicksight-topic-semantictype-falseycellvalue
            '''
            result = self._values.get("falsey_cell_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def falsey_cell_value_synonyms(
            self,
        ) -> typing.Optional[typing.List[builtins.str]]:
            '''The other names or aliases for the false cell value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semantictype.html#cfn-quicksight-topic-semantictype-falseycellvaluesynonyms
            '''
            result = self._values.get("falsey_cell_value_synonyms")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def sub_type_name(self) -> typing.Optional[builtins.str]:
            '''The semantic type sub type name.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semantictype.html#cfn-quicksight-topic-semantictype-subtypename
            '''
            result = self._values.get("sub_type_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def truthy_cell_value(self) -> typing.Optional[builtins.str]:
            '''The semantic type truthy cell value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semantictype.html#cfn-quicksight-topic-semantictype-truthycellvalue
            '''
            result = self._values.get("truthy_cell_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def truthy_cell_value_synonyms(
            self,
        ) -> typing.Optional[typing.List[builtins.str]]:
            '''The other names or aliases for the true cell value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semantictype.html#cfn-quicksight-topic-semantictype-truthycellvaluesynonyms
            '''
            result = self._values.get("truthy_cell_value_synonyms")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def type_name(self) -> typing.Optional[builtins.str]:
            '''The semantic type name.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semantictype.html#cfn-quicksight-topic-semantictype-typename
            '''
            result = self._values.get("type_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def type_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, builtins.str]]]:
            '''The semantic type parameters.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-semantictype.html#cfn-quicksight-topic-semantictype-typeparameters
            '''
            result = self._values.get("type_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, builtins.str]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SemanticTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.TopicCalculatedFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "calculated_field_name": "calculatedFieldName",
            "expression": "expression",
            "aggregation": "aggregation",
            "allowed_aggregations": "allowedAggregations",
            "calculated_field_description": "calculatedFieldDescription",
            "calculated_field_synonyms": "calculatedFieldSynonyms",
            "cell_value_synonyms": "cellValueSynonyms",
            "column_data_role": "columnDataRole",
            "comparative_order": "comparativeOrder",
            "default_formatting": "defaultFormatting",
            "is_included_in_topic": "isIncludedInTopic",
            "never_aggregate_in_filter": "neverAggregateInFilter",
            "non_additive": "nonAdditive",
            "not_allowed_aggregations": "notAllowedAggregations",
            "semantic_type": "semanticType",
            "time_granularity": "timeGranularity",
        },
    )
    class TopicCalculatedFieldProperty:
        def __init__(
            self,
            *,
            calculated_field_name: builtins.str,
            expression: builtins.str,
            aggregation: typing.Optional[builtins.str] = None,
            allowed_aggregations: typing.Optional[typing.Sequence[builtins.str]] = None,
            calculated_field_description: typing.Optional[builtins.str] = None,
            calculated_field_synonyms: typing.Optional[typing.Sequence[builtins.str]] = None,
            cell_value_synonyms: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.CellValueSynonymProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            column_data_role: typing.Optional[builtins.str] = None,
            comparative_order: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.ComparativeOrderProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            default_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.DefaultFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            is_included_in_topic: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
            never_aggregate_in_filter: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
            non_additive: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
            not_allowed_aggregations: typing.Optional[typing.Sequence[builtins.str]] = None,
            semantic_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.SemanticTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A structure that represents a calculated field.

            :param calculated_field_name: The calculated field name.
            :param expression: The calculated field expression.
            :param aggregation: The default aggregation. Valid values for this structure are ``SUM`` , ``MAX`` , ``MIN`` , ``COUNT`` , ``DISTINCT_COUNT`` , and ``AVERAGE`` .
            :param allowed_aggregations: The list of aggregation types that are allowed for the calculated field. Valid values for this structure are ``COUNT`` , ``DISTINCT_COUNT`` , ``MIN`` , ``MAX`` , ``MEDIAN`` , ``SUM`` , ``AVERAGE`` , ``STDEV`` , ``STDEVP`` , ``VAR`` , ``VARP`` , and ``PERCENTILE`` .
            :param calculated_field_description: The calculated field description.
            :param calculated_field_synonyms: The other names or aliases for the calculated field.
            :param cell_value_synonyms: The other names or aliases for the calculated field cell value.
            :param column_data_role: The column data role for a calculated field. Valid values for this structure are ``DIMENSION`` and ``MEASURE`` .
            :param comparative_order: The order in which data is displayed for the calculated field when it's used in a comparative context.
            :param default_formatting: The default formatting definition.
            :param is_included_in_topic: A boolean value that indicates if a calculated field is included in the topic. Default: - false
            :param never_aggregate_in_filter: A Boolean value that indicates whether to never aggregate calculated field in filters. Default: - false
            :param non_additive: The non additive for the table style target. Default: - false
            :param not_allowed_aggregations: The list of aggregation types that are not allowed for the calculated field. Valid values for this structure are ``COUNT`` , ``DISTINCT_COUNT`` , ``MIN`` , ``MAX`` , ``MEDIAN`` , ``SUM`` , ``AVERAGE`` , ``STDEV`` , ``STDEVP`` , ``VAR`` , ``VARP`` , and ``PERCENTILE`` .
            :param semantic_type: The semantic type.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                topic_calculated_field_property = quicksight.CfnTopic.TopicCalculatedFieldProperty(
                    calculated_field_name="calculatedFieldName",
                    expression="expression",
                
                    # the properties below are optional
                    aggregation="aggregation",
                    allowed_aggregations=["allowedAggregations"],
                    calculated_field_description="calculatedFieldDescription",
                    calculated_field_synonyms=["calculatedFieldSynonyms"],
                    cell_value_synonyms=[quicksight.CfnTopic.CellValueSynonymProperty(
                        cell_value="cellValue",
                        synonyms=["synonyms"]
                    )],
                    column_data_role="columnDataRole",
                    comparative_order=quicksight.CfnTopic.ComparativeOrderProperty(
                        specifed_order=["specifedOrder"],
                        treat_undefined_specified_values="treatUndefinedSpecifiedValues",
                        use_ordering="useOrdering"
                    ),
                    default_formatting=quicksight.CfnTopic.DefaultFormattingProperty(
                        display_format="displayFormat",
                        display_format_options=quicksight.CfnTopic.DisplayFormatOptionsProperty(
                            blank_cell_format="blankCellFormat",
                            currency_symbol="currencySymbol",
                            date_format="dateFormat",
                            decimal_separator="decimalSeparator",
                            fraction_digits=123,
                            grouping_separator="groupingSeparator",
                            negative_format=quicksight.CfnTopic.NegativeFormatProperty(
                                prefix="prefix",
                                suffix="suffix"
                            ),
                            prefix="prefix",
                            suffix="suffix",
                            unit_scaler="unitScaler",
                            use_blank_cell_format=False,
                            use_grouping=False
                        )
                    ),
                    is_included_in_topic=False,
                    never_aggregate_in_filter=False,
                    non_additive=False,
                    not_allowed_aggregations=["notAllowedAggregations"],
                    semantic_type=quicksight.CfnTopic.SemanticTypeProperty(
                        falsey_cell_value="falseyCellValue",
                        falsey_cell_value_synonyms=["falseyCellValueSynonyms"],
                        sub_type_name="subTypeName",
                        truthy_cell_value="truthyCellValue",
                        truthy_cell_value_synonyms=["truthyCellValueSynonyms"],
                        type_name="typeName",
                        type_parameters={
                            "type_parameters_key": "typeParameters"
                        }
                    ),
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fffafec4d96f73a0bb2382083323859061af993381915fddf09ecc78fd5d5f36)
                check_type(argname="argument calculated_field_name", value=calculated_field_name, expected_type=type_hints["calculated_field_name"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
                check_type(argname="argument allowed_aggregations", value=allowed_aggregations, expected_type=type_hints["allowed_aggregations"])
                check_type(argname="argument calculated_field_description", value=calculated_field_description, expected_type=type_hints["calculated_field_description"])
                check_type(argname="argument calculated_field_synonyms", value=calculated_field_synonyms, expected_type=type_hints["calculated_field_synonyms"])
                check_type(argname="argument cell_value_synonyms", value=cell_value_synonyms, expected_type=type_hints["cell_value_synonyms"])
                check_type(argname="argument column_data_role", value=column_data_role, expected_type=type_hints["column_data_role"])
                check_type(argname="argument comparative_order", value=comparative_order, expected_type=type_hints["comparative_order"])
                check_type(argname="argument default_formatting", value=default_formatting, expected_type=type_hints["default_formatting"])
                check_type(argname="argument is_included_in_topic", value=is_included_in_topic, expected_type=type_hints["is_included_in_topic"])
                check_type(argname="argument never_aggregate_in_filter", value=never_aggregate_in_filter, expected_type=type_hints["never_aggregate_in_filter"])
                check_type(argname="argument non_additive", value=non_additive, expected_type=type_hints["non_additive"])
                check_type(argname="argument not_allowed_aggregations", value=not_allowed_aggregations, expected_type=type_hints["not_allowed_aggregations"])
                check_type(argname="argument semantic_type", value=semantic_type, expected_type=type_hints["semantic_type"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "calculated_field_name": calculated_field_name,
                "expression": expression,
            }
            if aggregation is not None:
                self._values["aggregation"] = aggregation
            if allowed_aggregations is not None:
                self._values["allowed_aggregations"] = allowed_aggregations
            if calculated_field_description is not None:
                self._values["calculated_field_description"] = calculated_field_description
            if calculated_field_synonyms is not None:
                self._values["calculated_field_synonyms"] = calculated_field_synonyms
            if cell_value_synonyms is not None:
                self._values["cell_value_synonyms"] = cell_value_synonyms
            if column_data_role is not None:
                self._values["column_data_role"] = column_data_role
            if comparative_order is not None:
                self._values["comparative_order"] = comparative_order
            if default_formatting is not None:
                self._values["default_formatting"] = default_formatting
            if is_included_in_topic is not None:
                self._values["is_included_in_topic"] = is_included_in_topic
            if never_aggregate_in_filter is not None:
                self._values["never_aggregate_in_filter"] = never_aggregate_in_filter
            if non_additive is not None:
                self._values["non_additive"] = non_additive
            if not_allowed_aggregations is not None:
                self._values["not_allowed_aggregations"] = not_allowed_aggregations
            if semantic_type is not None:
                self._values["semantic_type"] = semantic_type
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def calculated_field_name(self) -> builtins.str:
            '''The calculated field name.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-calculatedfieldname
            '''
            result = self._values.get("calculated_field_name")
            assert result is not None, "Required property 'calculated_field_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The calculated field expression.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation(self) -> typing.Optional[builtins.str]:
            '''The default aggregation.

            Valid values for this structure are ``SUM`` , ``MAX`` , ``MIN`` , ``COUNT`` , ``DISTINCT_COUNT`` , and ``AVERAGE`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-aggregation
            '''
            result = self._values.get("aggregation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def allowed_aggregations(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of aggregation types that are allowed for the calculated field.

            Valid values for this structure are ``COUNT`` , ``DISTINCT_COUNT`` , ``MIN`` , ``MAX`` , ``MEDIAN`` , ``SUM`` , ``AVERAGE`` , ``STDEV`` , ``STDEVP`` , ``VAR`` , ``VARP`` , and ``PERCENTILE`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-allowedaggregations
            '''
            result = self._values.get("allowed_aggregations")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def calculated_field_description(self) -> typing.Optional[builtins.str]:
            '''The calculated field description.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-calculatedfielddescription
            '''
            result = self._values.get("calculated_field_description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def calculated_field_synonyms(
            self,
        ) -> typing.Optional[typing.List[builtins.str]]:
            '''The other names or aliases for the calculated field.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-calculatedfieldsynonyms
            '''
            result = self._values.get("calculated_field_synonyms")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def cell_value_synonyms(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTopic.CellValueSynonymProperty"]]]]:
            '''The other names or aliases for the calculated field cell value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-cellvaluesynonyms
            '''
            result = self._values.get("cell_value_synonyms")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTopic.CellValueSynonymProperty"]]]], result)

        @builtins.property
        def column_data_role(self) -> typing.Optional[builtins.str]:
            '''The column data role for a calculated field.

            Valid values for this structure are ``DIMENSION`` and ``MEASURE`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-columndatarole
            '''
            result = self._values.get("column_data_role")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def comparative_order(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.ComparativeOrderProperty"]]:
            '''The order in which data is displayed for the calculated field when it's used in a comparative context.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-comparativeorder
            '''
            result = self._values.get("comparative_order")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.ComparativeOrderProperty"]], result)

        @builtins.property
        def default_formatting(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.DefaultFormattingProperty"]]:
            '''The default formatting definition.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-defaultformatting
            '''
            result = self._values.get("default_formatting")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.DefaultFormattingProperty"]], result)

        @builtins.property
        def is_included_in_topic(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''A boolean value that indicates if a calculated field is included in the topic.

            :default: - false

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-isincludedintopic
            '''
            result = self._values.get("is_included_in_topic")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        @builtins.property
        def never_aggregate_in_filter(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''A Boolean value that indicates whether to never aggregate calculated field in filters.

            :default: - false

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-neveraggregateinfilter
            '''
            result = self._values.get("never_aggregate_in_filter")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        @builtins.property
        def non_additive(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''The non additive for the table style target.

            :default: - false

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-nonadditive
            '''
            result = self._values.get("non_additive")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        @builtins.property
        def not_allowed_aggregations(
            self,
        ) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of aggregation types that are not allowed for the calculated field.

            Valid values for this structure are ``COUNT`` , ``DISTINCT_COUNT`` , ``MIN`` , ``MAX`` , ``MEDIAN`` , ``SUM`` , ``AVERAGE`` , ``STDEV`` , ``STDEVP`` , ``VAR`` , ``VARP`` , and ``PERCENTILE`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-notallowedaggregations
            '''
            result = self._values.get("not_allowed_aggregations")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def semantic_type(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.SemanticTypeProperty"]]:
            '''The semantic type.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-semantictype
            '''
            result = self._values.get("semantic_type")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.SemanticTypeProperty"]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccalculatedfield.html#cfn-quicksight-topic-topiccalculatedfield-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopicCalculatedFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.TopicCategoryFilterConstantProperty",
        jsii_struct_bases=[],
        name_mapping={
            "collective_constant": "collectiveConstant",
            "constant_type": "constantType",
            "singular_constant": "singularConstant",
        },
    )
    class TopicCategoryFilterConstantProperty:
        def __init__(
            self,
            *,
            collective_constant: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.CollectiveConstantProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            constant_type: typing.Optional[builtins.str] = None,
            singular_constant: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A constant used in a category filter.

            :param collective_constant: A collective constant used in a category filter. This element is used to specify a list of values for the constant.
            :param constant_type: The type of category filter constant. This element is used to specify whether a constant is a singular or collective. Valid values are ``SINGULAR`` and ``COLLECTIVE`` .
            :param singular_constant: A singular constant used in a category filter. This element is used to specify a single value for the constant.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccategoryfilterconstant.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                topic_category_filter_constant_property = quicksight.CfnTopic.TopicCategoryFilterConstantProperty(
                    collective_constant=quicksight.CfnTopic.CollectiveConstantProperty(
                        value_list=["valueList"]
                    ),
                    constant_type="constantType",
                    singular_constant="singularConstant"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3441530765d3e507907e4c6dd506e50fa8df155d9a072ac10b181a86a0b314d5)
                check_type(argname="argument collective_constant", value=collective_constant, expected_type=type_hints["collective_constant"])
                check_type(argname="argument constant_type", value=constant_type, expected_type=type_hints["constant_type"])
                check_type(argname="argument singular_constant", value=singular_constant, expected_type=type_hints["singular_constant"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if collective_constant is not None:
                self._values["collective_constant"] = collective_constant
            if constant_type is not None:
                self._values["constant_type"] = constant_type
            if singular_constant is not None:
                self._values["singular_constant"] = singular_constant

        @builtins.property
        def collective_constant(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.CollectiveConstantProperty"]]:
            '''A collective constant used in a category filter.

            This element is used to specify a list of values for the constant.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccategoryfilterconstant.html#cfn-quicksight-topic-topiccategoryfilterconstant-collectiveconstant
            '''
            result = self._values.get("collective_constant")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.CollectiveConstantProperty"]], result)

        @builtins.property
        def constant_type(self) -> typing.Optional[builtins.str]:
            '''The type of category filter constant.

            This element is used to specify whether a constant is a singular or collective. Valid values are ``SINGULAR`` and ``COLLECTIVE`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccategoryfilterconstant.html#cfn-quicksight-topic-topiccategoryfilterconstant-constanttype
            '''
            result = self._values.get("constant_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def singular_constant(self) -> typing.Optional[builtins.str]:
            '''A singular constant used in a category filter.

            This element is used to specify a single value for the constant.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccategoryfilterconstant.html#cfn-quicksight-topic-topiccategoryfilterconstant-singularconstant
            '''
            result = self._values.get("singular_constant")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopicCategoryFilterConstantProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.TopicCategoryFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_filter_function": "categoryFilterFunction",
            "category_filter_type": "categoryFilterType",
            "constant": "constant",
            "inverse": "inverse",
        },
    )
    class TopicCategoryFilterProperty:
        def __init__(
            self,
            *,
            category_filter_function: typing.Optional[builtins.str] = None,
            category_filter_type: typing.Optional[builtins.str] = None,
            constant: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.TopicCategoryFilterConstantProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            inverse: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
        ) -> None:
            '''A structure that represents a category filter.

            :param category_filter_function: The category filter function. Valid values for this structure are ``EXACT`` and ``CONTAINS`` .
            :param category_filter_type: The category filter type. This element is used to specify whether a filter is a simple category filter or an inverse category filter.
            :param constant: The constant used in a category filter.
            :param inverse: A Boolean value that indicates if the filter is inverse. Default: - false

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccategoryfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                topic_category_filter_property = quicksight.CfnTopic.TopicCategoryFilterProperty(
                    category_filter_function="categoryFilterFunction",
                    category_filter_type="categoryFilterType",
                    constant=quicksight.CfnTopic.TopicCategoryFilterConstantProperty(
                        collective_constant=quicksight.CfnTopic.CollectiveConstantProperty(
                            value_list=["valueList"]
                        ),
                        constant_type="constantType",
                        singular_constant="singularConstant"
                    ),
                    inverse=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__26614299f4f77619745072528f965f29cbf636bf92ea32101e10fc65b80d3baf)
                check_type(argname="argument category_filter_function", value=category_filter_function, expected_type=type_hints["category_filter_function"])
                check_type(argname="argument category_filter_type", value=category_filter_type, expected_type=type_hints["category_filter_type"])
                check_type(argname="argument constant", value=constant, expected_type=type_hints["constant"])
                check_type(argname="argument inverse", value=inverse, expected_type=type_hints["inverse"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_filter_function is not None:
                self._values["category_filter_function"] = category_filter_function
            if category_filter_type is not None:
                self._values["category_filter_type"] = category_filter_type
            if constant is not None:
                self._values["constant"] = constant
            if inverse is not None:
                self._values["inverse"] = inverse

        @builtins.property
        def category_filter_function(self) -> typing.Optional[builtins.str]:
            '''The category filter function.

            Valid values for this structure are ``EXACT`` and ``CONTAINS`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccategoryfilter.html#cfn-quicksight-topic-topiccategoryfilter-categoryfilterfunction
            '''
            result = self._values.get("category_filter_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def category_filter_type(self) -> typing.Optional[builtins.str]:
            '''The category filter type.

            This element is used to specify whether a filter is a simple category filter or an inverse category filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccategoryfilter.html#cfn-quicksight-topic-topiccategoryfilter-categoryfiltertype
            '''
            result = self._values.get("category_filter_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def constant(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicCategoryFilterConstantProperty"]]:
            '''The constant used in a category filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccategoryfilter.html#cfn-quicksight-topic-topiccategoryfilter-constant
            '''
            result = self._values.get("constant")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicCategoryFilterConstantProperty"]], result)

        @builtins.property
        def inverse(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''A Boolean value that indicates if the filter is inverse.

            :default: - false

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccategoryfilter.html#cfn-quicksight-topic-topiccategoryfilter-inverse
            '''
            result = self._values.get("inverse")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopicCategoryFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.TopicColumnProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_name": "columnName",
            "aggregation": "aggregation",
            "allowed_aggregations": "allowedAggregations",
            "cell_value_synonyms": "cellValueSynonyms",
            "column_data_role": "columnDataRole",
            "column_description": "columnDescription",
            "column_friendly_name": "columnFriendlyName",
            "column_synonyms": "columnSynonyms",
            "comparative_order": "comparativeOrder",
            "default_formatting": "defaultFormatting",
            "is_included_in_topic": "isIncludedInTopic",
            "never_aggregate_in_filter": "neverAggregateInFilter",
            "non_additive": "nonAdditive",
            "not_allowed_aggregations": "notAllowedAggregations",
            "semantic_type": "semanticType",
            "time_granularity": "timeGranularity",
        },
    )
    class TopicColumnProperty:
        def __init__(
            self,
            *,
            column_name: builtins.str,
            aggregation: typing.Optional[builtins.str] = None,
            allowed_aggregations: typing.Optional[typing.Sequence[builtins.str]] = None,
            cell_value_synonyms: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.CellValueSynonymProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            column_data_role: typing.Optional[builtins.str] = None,
            column_description: typing.Optional[builtins.str] = None,
            column_friendly_name: typing.Optional[builtins.str] = None,
            column_synonyms: typing.Optional[typing.Sequence[builtins.str]] = None,
            comparative_order: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.ComparativeOrderProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            default_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.DefaultFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            is_included_in_topic: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
            never_aggregate_in_filter: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
            non_additive: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
            not_allowed_aggregations: typing.Optional[typing.Sequence[builtins.str]] = None,
            semantic_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.SemanticTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Represents a column in a dataset.

            :param column_name: The name of the column.
            :param aggregation: The type of aggregation that is performed on the column data when it's queried.
            :param allowed_aggregations: The list of aggregation types that are allowed for the column. Valid values for this structure are ``COUNT`` , ``DISTINCT_COUNT`` , ``MIN`` , ``MAX`` , ``MEDIAN`` , ``SUM`` , ``AVERAGE`` , ``STDEV`` , ``STDEVP`` , ``VAR`` , ``VARP`` , and ``PERCENTILE`` .
            :param cell_value_synonyms: The other names or aliases for the column cell value.
            :param column_data_role: The role of the column in the data. Valid values are ``DIMENSION`` and ``MEASURE`` .
            :param column_description: A description of the column and its contents.
            :param column_friendly_name: A user-friendly name for the column.
            :param column_synonyms: The other names or aliases for the column.
            :param comparative_order: The order in which data is displayed for the column when it's used in a comparative context.
            :param default_formatting: The default formatting used for values in the column.
            :param is_included_in_topic: A Boolean value that indicates whether the column is included in the query results. Default: - false
            :param never_aggregate_in_filter: A Boolean value that indicates whether to aggregate the column data when it's used in a filter context. Default: - false
            :param non_additive: The non additive value for the column. Default: - false
            :param not_allowed_aggregations: The list of aggregation types that are not allowed for the column. Valid values for this structure are ``COUNT`` , ``DISTINCT_COUNT`` , ``MIN`` , ``MAX`` , ``MEDIAN`` , ``SUM`` , ``AVERAGE`` , ``STDEV`` , ``STDEVP`` , ``VAR`` , ``VARP`` , and ``PERCENTILE`` .
            :param semantic_type: The semantic type of data contained in the column.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                topic_column_property = quicksight.CfnTopic.TopicColumnProperty(
                    column_name="columnName",
                
                    # the properties below are optional
                    aggregation="aggregation",
                    allowed_aggregations=["allowedAggregations"],
                    cell_value_synonyms=[quicksight.CfnTopic.CellValueSynonymProperty(
                        cell_value="cellValue",
                        synonyms=["synonyms"]
                    )],
                    column_data_role="columnDataRole",
                    column_description="columnDescription",
                    column_friendly_name="columnFriendlyName",
                    column_synonyms=["columnSynonyms"],
                    comparative_order=quicksight.CfnTopic.ComparativeOrderProperty(
                        specifed_order=["specifedOrder"],
                        treat_undefined_specified_values="treatUndefinedSpecifiedValues",
                        use_ordering="useOrdering"
                    ),
                    default_formatting=quicksight.CfnTopic.DefaultFormattingProperty(
                        display_format="displayFormat",
                        display_format_options=quicksight.CfnTopic.DisplayFormatOptionsProperty(
                            blank_cell_format="blankCellFormat",
                            currency_symbol="currencySymbol",
                            date_format="dateFormat",
                            decimal_separator="decimalSeparator",
                            fraction_digits=123,
                            grouping_separator="groupingSeparator",
                            negative_format=quicksight.CfnTopic.NegativeFormatProperty(
                                prefix="prefix",
                                suffix="suffix"
                            ),
                            prefix="prefix",
                            suffix="suffix",
                            unit_scaler="unitScaler",
                            use_blank_cell_format=False,
                            use_grouping=False
                        )
                    ),
                    is_included_in_topic=False,
                    never_aggregate_in_filter=False,
                    non_additive=False,
                    not_allowed_aggregations=["notAllowedAggregations"],
                    semantic_type=quicksight.CfnTopic.SemanticTypeProperty(
                        falsey_cell_value="falseyCellValue",
                        falsey_cell_value_synonyms=["falseyCellValueSynonyms"],
                        sub_type_name="subTypeName",
                        truthy_cell_value="truthyCellValue",
                        truthy_cell_value_synonyms=["truthyCellValueSynonyms"],
                        type_name="typeName",
                        type_parameters={
                            "type_parameters_key": "typeParameters"
                        }
                    ),
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3a7e0dff07bd6260713cf650e291a6e355c22aa55f3c00636ee0c53606b1c548)
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
                check_type(argname="argument allowed_aggregations", value=allowed_aggregations, expected_type=type_hints["allowed_aggregations"])
                check_type(argname="argument cell_value_synonyms", value=cell_value_synonyms, expected_type=type_hints["cell_value_synonyms"])
                check_type(argname="argument column_data_role", value=column_data_role, expected_type=type_hints["column_data_role"])
                check_type(argname="argument column_description", value=column_description, expected_type=type_hints["column_description"])
                check_type(argname="argument column_friendly_name", value=column_friendly_name, expected_type=type_hints["column_friendly_name"])
                check_type(argname="argument column_synonyms", value=column_synonyms, expected_type=type_hints["column_synonyms"])
                check_type(argname="argument comparative_order", value=comparative_order, expected_type=type_hints["comparative_order"])
                check_type(argname="argument default_formatting", value=default_formatting, expected_type=type_hints["default_formatting"])
                check_type(argname="argument is_included_in_topic", value=is_included_in_topic, expected_type=type_hints["is_included_in_topic"])
                check_type(argname="argument never_aggregate_in_filter", value=never_aggregate_in_filter, expected_type=type_hints["never_aggregate_in_filter"])
                check_type(argname="argument non_additive", value=non_additive, expected_type=type_hints["non_additive"])
                check_type(argname="argument not_allowed_aggregations", value=not_allowed_aggregations, expected_type=type_hints["not_allowed_aggregations"])
                check_type(argname="argument semantic_type", value=semantic_type, expected_type=type_hints["semantic_type"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_name": column_name,
            }
            if aggregation is not None:
                self._values["aggregation"] = aggregation
            if allowed_aggregations is not None:
                self._values["allowed_aggregations"] = allowed_aggregations
            if cell_value_synonyms is not None:
                self._values["cell_value_synonyms"] = cell_value_synonyms
            if column_data_role is not None:
                self._values["column_data_role"] = column_data_role
            if column_description is not None:
                self._values["column_description"] = column_description
            if column_friendly_name is not None:
                self._values["column_friendly_name"] = column_friendly_name
            if column_synonyms is not None:
                self._values["column_synonyms"] = column_synonyms
            if comparative_order is not None:
                self._values["comparative_order"] = comparative_order
            if default_formatting is not None:
                self._values["default_formatting"] = default_formatting
            if is_included_in_topic is not None:
                self._values["is_included_in_topic"] = is_included_in_topic
            if never_aggregate_in_filter is not None:
                self._values["never_aggregate_in_filter"] = never_aggregate_in_filter
            if non_additive is not None:
                self._values["non_additive"] = non_additive
            if not_allowed_aggregations is not None:
                self._values["not_allowed_aggregations"] = not_allowed_aggregations
            if semantic_type is not None:
                self._values["semantic_type"] = semantic_type
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def column_name(self) -> builtins.str:
            '''The name of the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation(self) -> typing.Optional[builtins.str]:
            '''The type of aggregation that is performed on the column data when it's queried.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-aggregation
            '''
            result = self._values.get("aggregation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def allowed_aggregations(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of aggregation types that are allowed for the column.

            Valid values for this structure are ``COUNT`` , ``DISTINCT_COUNT`` , ``MIN`` , ``MAX`` , ``MEDIAN`` , ``SUM`` , ``AVERAGE`` , ``STDEV`` , ``STDEVP`` , ``VAR`` , ``VARP`` , and ``PERCENTILE`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-allowedaggregations
            '''
            result = self._values.get("allowed_aggregations")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def cell_value_synonyms(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTopic.CellValueSynonymProperty"]]]]:
            '''The other names or aliases for the column cell value.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-cellvaluesynonyms
            '''
            result = self._values.get("cell_value_synonyms")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTopic.CellValueSynonymProperty"]]]], result)

        @builtins.property
        def column_data_role(self) -> typing.Optional[builtins.str]:
            '''The role of the column in the data.

            Valid values are ``DIMENSION`` and ``MEASURE`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-columndatarole
            '''
            result = self._values.get("column_data_role")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def column_description(self) -> typing.Optional[builtins.str]:
            '''A description of the column and its contents.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-columndescription
            '''
            result = self._values.get("column_description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def column_friendly_name(self) -> typing.Optional[builtins.str]:
            '''A user-friendly name for the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-columnfriendlyname
            '''
            result = self._values.get("column_friendly_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def column_synonyms(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The other names or aliases for the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-columnsynonyms
            '''
            result = self._values.get("column_synonyms")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def comparative_order(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.ComparativeOrderProperty"]]:
            '''The order in which data is displayed for the column when it's used in a comparative context.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-comparativeorder
            '''
            result = self._values.get("comparative_order")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.ComparativeOrderProperty"]], result)

        @builtins.property
        def default_formatting(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.DefaultFormattingProperty"]]:
            '''The default formatting used for values in the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-defaultformatting
            '''
            result = self._values.get("default_formatting")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.DefaultFormattingProperty"]], result)

        @builtins.property
        def is_included_in_topic(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''A Boolean value that indicates whether the column is included in the query results.

            :default: - false

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-isincludedintopic
            '''
            result = self._values.get("is_included_in_topic")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        @builtins.property
        def never_aggregate_in_filter(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''A Boolean value that indicates whether to aggregate the column data when it's used in a filter context.

            :default: - false

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-neveraggregateinfilter
            '''
            result = self._values.get("never_aggregate_in_filter")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        @builtins.property
        def non_additive(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''The non additive value for the column.

            :default: - false

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-nonadditive
            '''
            result = self._values.get("non_additive")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        @builtins.property
        def not_allowed_aggregations(
            self,
        ) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of aggregation types that are not allowed for the column.

            Valid values for this structure are ``COUNT`` , ``DISTINCT_COUNT`` , ``MIN`` , ``MAX`` , ``MEDIAN`` , ``SUM`` , ``AVERAGE`` , ``STDEV`` , ``STDEVP`` , ``VAR`` , ``VARP`` , and ``PERCENTILE`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-notallowedaggregations
            '''
            result = self._values.get("not_allowed_aggregations")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def semantic_type(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.SemanticTypeProperty"]]:
            '''The semantic type of data contained in the column.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-semantictype
            '''
            result = self._values.get("semantic_type")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.SemanticTypeProperty"]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topiccolumn.html#cfn-quicksight-topic-topiccolumn-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopicColumnProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.TopicDateRangeFilterProperty",
        jsii_struct_bases=[],
        name_mapping={"constant": "constant", "inclusive": "inclusive"},
    )
    class TopicDateRangeFilterProperty:
        def __init__(
            self,
            *,
            constant: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.TopicRangeFilterConstantProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            inclusive: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
        ) -> None:
            '''A filter used to restrict data based on a range of dates or times.

            :param constant: The constant used in a date range filter.
            :param inclusive: A Boolean value that indicates whether the date range filter should include the boundary values. If set to true, the filter includes the start and end dates. If set to false, the filter excludes them. Default: - false

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicdaterangefilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                topic_date_range_filter_property = quicksight.CfnTopic.TopicDateRangeFilterProperty(
                    constant=quicksight.CfnTopic.TopicRangeFilterConstantProperty(
                        constant_type="constantType",
                        range_constant=quicksight.CfnTopic.RangeConstantProperty(
                            maximum="maximum",
                            minimum="minimum"
                        )
                    ),
                    inclusive=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__34064d7ce1fb0f0cd683f6101b1454976c569e78c8c96d72543b423a809dc8f5)
                check_type(argname="argument constant", value=constant, expected_type=type_hints["constant"])
                check_type(argname="argument inclusive", value=inclusive, expected_type=type_hints["inclusive"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if constant is not None:
                self._values["constant"] = constant
            if inclusive is not None:
                self._values["inclusive"] = inclusive

        @builtins.property
        def constant(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicRangeFilterConstantProperty"]]:
            '''The constant used in a date range filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicdaterangefilter.html#cfn-quicksight-topic-topicdaterangefilter-constant
            '''
            result = self._values.get("constant")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicRangeFilterConstantProperty"]], result)

        @builtins.property
        def inclusive(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''A Boolean value that indicates whether the date range filter should include the boundary values.

            If set to true, the filter includes the start and end dates. If set to false, the filter excludes them.

            :default: - false

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicdaterangefilter.html#cfn-quicksight-topic-topicdaterangefilter-inclusive
            '''
            result = self._values.get("inclusive")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopicDateRangeFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.TopicFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_name": "filterName",
            "operand_field_name": "operandFieldName",
            "category_filter": "categoryFilter",
            "date_range_filter": "dateRangeFilter",
            "filter_class": "filterClass",
            "filter_description": "filterDescription",
            "filter_synonyms": "filterSynonyms",
            "filter_type": "filterType",
            "numeric_equality_filter": "numericEqualityFilter",
            "numeric_range_filter": "numericRangeFilter",
            "relative_date_filter": "relativeDateFilter",
        },
    )
    class TopicFilterProperty:
        def __init__(
            self,
            *,
            filter_name: builtins.str,
            operand_field_name: builtins.str,
            category_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.TopicCategoryFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            date_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.TopicDateRangeFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            filter_class: typing.Optional[builtins.str] = None,
            filter_description: typing.Optional[builtins.str] = None,
            filter_synonyms: typing.Optional[typing.Sequence[builtins.str]] = None,
            filter_type: typing.Optional[builtins.str] = None,
            numeric_equality_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.TopicNumericEqualityFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.TopicNumericRangeFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relative_date_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.TopicRelativeDateFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A structure that represents a filter used to select items for a topic.

            :param filter_name: The name of the filter.
            :param operand_field_name: The name of the field that the filter operates on.
            :param category_filter: The category filter that is associated with this filter.
            :param date_range_filter: The date range filter.
            :param filter_class: The class of the filter. Valid values for this structure are ``ENFORCED_VALUE_FILTER`` , ``CONDITIONAL_VALUE_FILTER`` , and ``NAMED_VALUE_FILTER`` .
            :param filter_description: A description of the filter used to select items for a topic.
            :param filter_synonyms: The other names or aliases for the filter.
            :param filter_type: The type of the filter. Valid values for this structure are ``CATEGORY_FILTER`` , ``NUMERIC_EQUALITY_FILTER`` , ``NUMERIC_RANGE_FILTER`` , ``DATE_RANGE_FILTER`` , and ``RELATIVE_DATE_FILTER`` .
            :param numeric_equality_filter: The numeric equality filter.
            :param numeric_range_filter: The numeric range filter.
            :param relative_date_filter: The relative date filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                topic_filter_property = quicksight.CfnTopic.TopicFilterProperty(
                    filter_name="filterName",
                    operand_field_name="operandFieldName",
                
                    # the properties below are optional
                    category_filter=quicksight.CfnTopic.TopicCategoryFilterProperty(
                        category_filter_function="categoryFilterFunction",
                        category_filter_type="categoryFilterType",
                        constant=quicksight.CfnTopic.TopicCategoryFilterConstantProperty(
                            collective_constant=quicksight.CfnTopic.CollectiveConstantProperty(
                                value_list=["valueList"]
                            ),
                            constant_type="constantType",
                            singular_constant="singularConstant"
                        ),
                        inverse=False
                    ),
                    date_range_filter=quicksight.CfnTopic.TopicDateRangeFilterProperty(
                        constant=quicksight.CfnTopic.TopicRangeFilterConstantProperty(
                            constant_type="constantType",
                            range_constant=quicksight.CfnTopic.RangeConstantProperty(
                                maximum="maximum",
                                minimum="minimum"
                            )
                        ),
                        inclusive=False
                    ),
                    filter_class="filterClass",
                    filter_description="filterDescription",
                    filter_synonyms=["filterSynonyms"],
                    filter_type="filterType",
                    numeric_equality_filter=quicksight.CfnTopic.TopicNumericEqualityFilterProperty(
                        aggregation="aggregation",
                        constant=quicksight.CfnTopic.TopicSingularFilterConstantProperty(
                            constant_type="constantType",
                            singular_constant="singularConstant"
                        )
                    ),
                    numeric_range_filter=quicksight.CfnTopic.TopicNumericRangeFilterProperty(
                        aggregation="aggregation",
                        constant=quicksight.CfnTopic.TopicRangeFilterConstantProperty(
                            constant_type="constantType",
                            range_constant=quicksight.CfnTopic.RangeConstantProperty(
                                maximum="maximum",
                                minimum="minimum"
                            )
                        ),
                        inclusive=False
                    ),
                    relative_date_filter=quicksight.CfnTopic.TopicRelativeDateFilterProperty(
                        constant=quicksight.CfnTopic.TopicSingularFilterConstantProperty(
                            constant_type="constantType",
                            singular_constant="singularConstant"
                        ),
                        relative_date_filter_function="relativeDateFilterFunction",
                        time_granularity="timeGranularity"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5df6234bc745c16383a8590e30611a315f894b0388a92fdde6f8aac974faf62b)
                check_type(argname="argument filter_name", value=filter_name, expected_type=type_hints["filter_name"])
                check_type(argname="argument operand_field_name", value=operand_field_name, expected_type=type_hints["operand_field_name"])
                check_type(argname="argument category_filter", value=category_filter, expected_type=type_hints["category_filter"])
                check_type(argname="argument date_range_filter", value=date_range_filter, expected_type=type_hints["date_range_filter"])
                check_type(argname="argument filter_class", value=filter_class, expected_type=type_hints["filter_class"])
                check_type(argname="argument filter_description", value=filter_description, expected_type=type_hints["filter_description"])
                check_type(argname="argument filter_synonyms", value=filter_synonyms, expected_type=type_hints["filter_synonyms"])
                check_type(argname="argument filter_type", value=filter_type, expected_type=type_hints["filter_type"])
                check_type(argname="argument numeric_equality_filter", value=numeric_equality_filter, expected_type=type_hints["numeric_equality_filter"])
                check_type(argname="argument numeric_range_filter", value=numeric_range_filter, expected_type=type_hints["numeric_range_filter"])
                check_type(argname="argument relative_date_filter", value=relative_date_filter, expected_type=type_hints["relative_date_filter"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_name": filter_name,
                "operand_field_name": operand_field_name,
            }
            if category_filter is not None:
                self._values["category_filter"] = category_filter
            if date_range_filter is not None:
                self._values["date_range_filter"] = date_range_filter
            if filter_class is not None:
                self._values["filter_class"] = filter_class
            if filter_description is not None:
                self._values["filter_description"] = filter_description
            if filter_synonyms is not None:
                self._values["filter_synonyms"] = filter_synonyms
            if filter_type is not None:
                self._values["filter_type"] = filter_type
            if numeric_equality_filter is not None:
                self._values["numeric_equality_filter"] = numeric_equality_filter
            if numeric_range_filter is not None:
                self._values["numeric_range_filter"] = numeric_range_filter
            if relative_date_filter is not None:
                self._values["relative_date_filter"] = relative_date_filter

        @builtins.property
        def filter_name(self) -> builtins.str:
            '''The name of the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-filtername
            '''
            result = self._values.get("filter_name")
            assert result is not None, "Required property 'filter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def operand_field_name(self) -> builtins.str:
            '''The name of the field that the filter operates on.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-operandfieldname
            '''
            result = self._values.get("operand_field_name")
            assert result is not None, "Required property 'operand_field_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicCategoryFilterProperty"]]:
            '''The category filter that is associated with this filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-categoryfilter
            '''
            result = self._values.get("category_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicCategoryFilterProperty"]], result)

        @builtins.property
        def date_range_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicDateRangeFilterProperty"]]:
            '''The date range filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-daterangefilter
            '''
            result = self._values.get("date_range_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicDateRangeFilterProperty"]], result)

        @builtins.property
        def filter_class(self) -> typing.Optional[builtins.str]:
            '''The class of the filter.

            Valid values for this structure are ``ENFORCED_VALUE_FILTER`` , ``CONDITIONAL_VALUE_FILTER`` , and ``NAMED_VALUE_FILTER`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-filterclass
            '''
            result = self._values.get("filter_class")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def filter_description(self) -> typing.Optional[builtins.str]:
            '''A description of the filter used to select items for a topic.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-filterdescription
            '''
            result = self._values.get("filter_description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def filter_synonyms(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The other names or aliases for the filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-filtersynonyms
            '''
            result = self._values.get("filter_synonyms")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def filter_type(self) -> typing.Optional[builtins.str]:
            '''The type of the filter.

            Valid values for this structure are ``CATEGORY_FILTER`` , ``NUMERIC_EQUALITY_FILTER`` , ``NUMERIC_RANGE_FILTER`` , ``DATE_RANGE_FILTER`` , and ``RELATIVE_DATE_FILTER`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-filtertype
            '''
            result = self._values.get("filter_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def numeric_equality_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicNumericEqualityFilterProperty"]]:
            '''The numeric equality filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-numericequalityfilter
            '''
            result = self._values.get("numeric_equality_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicNumericEqualityFilterProperty"]], result)

        @builtins.property
        def numeric_range_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicNumericRangeFilterProperty"]]:
            '''The numeric range filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-numericrangefilter
            '''
            result = self._values.get("numeric_range_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicNumericRangeFilterProperty"]], result)

        @builtins.property
        def relative_date_filter(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicRelativeDateFilterProperty"]]:
            '''The relative date filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicfilter.html#cfn-quicksight-topic-topicfilter-relativedatefilter
            '''
            result = self._values.get("relative_date_filter")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicRelativeDateFilterProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopicFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.TopicNamedEntityProperty",
        jsii_struct_bases=[],
        name_mapping={
            "entity_name": "entityName",
            "definition": "definition",
            "entity_description": "entityDescription",
            "entity_synonyms": "entitySynonyms",
            "semantic_entity_type": "semanticEntityType",
        },
    )
    class TopicNamedEntityProperty:
        def __init__(
            self,
            *,
            entity_name: builtins.str,
            definition: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.NamedEntityDefinitionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            entity_description: typing.Optional[builtins.str] = None,
            entity_synonyms: typing.Optional[typing.Sequence[builtins.str]] = None,
            semantic_entity_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.SemanticEntityTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A structure that represents a named entity.

            :param entity_name: The name of the named entity.
            :param definition: The definition of a named entity.
            :param entity_description: The description of the named entity.
            :param entity_synonyms: The other names or aliases for the named entity.
            :param semantic_entity_type: The type of named entity that a topic represents.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnamedentity.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                topic_named_entity_property = quicksight.CfnTopic.TopicNamedEntityProperty(
                    entity_name="entityName",
                
                    # the properties below are optional
                    definition=[quicksight.CfnTopic.NamedEntityDefinitionProperty(
                        field_name="fieldName",
                        metric=quicksight.CfnTopic.NamedEntityDefinitionMetricProperty(
                            aggregation="aggregation",
                            aggregation_function_parameters={
                                "aggregation_function_parameters_key": "aggregationFunctionParameters"
                            }
                        ),
                        property_name="propertyName",
                        property_role="propertyRole",
                        property_usage="propertyUsage"
                    )],
                    entity_description="entityDescription",
                    entity_synonyms=["entitySynonyms"],
                    semantic_entity_type=quicksight.CfnTopic.SemanticEntityTypeProperty(
                        sub_type_name="subTypeName",
                        type_name="typeName",
                        type_parameters={
                            "type_parameters_key": "typeParameters"
                        }
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e5cb8be66d81e69534c842421108a0a2762c7522d4f6a9a60a9118728d463356)
                check_type(argname="argument entity_name", value=entity_name, expected_type=type_hints["entity_name"])
                check_type(argname="argument definition", value=definition, expected_type=type_hints["definition"])
                check_type(argname="argument entity_description", value=entity_description, expected_type=type_hints["entity_description"])
                check_type(argname="argument entity_synonyms", value=entity_synonyms, expected_type=type_hints["entity_synonyms"])
                check_type(argname="argument semantic_entity_type", value=semantic_entity_type, expected_type=type_hints["semantic_entity_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "entity_name": entity_name,
            }
            if definition is not None:
                self._values["definition"] = definition
            if entity_description is not None:
                self._values["entity_description"] = entity_description
            if entity_synonyms is not None:
                self._values["entity_synonyms"] = entity_synonyms
            if semantic_entity_type is not None:
                self._values["semantic_entity_type"] = semantic_entity_type

        @builtins.property
        def entity_name(self) -> builtins.str:
            '''The name of the named entity.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnamedentity.html#cfn-quicksight-topic-topicnamedentity-entityname
            '''
            result = self._values.get("entity_name")
            assert result is not None, "Required property 'entity_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def definition(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTopic.NamedEntityDefinitionProperty"]]]]:
            '''The definition of a named entity.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnamedentity.html#cfn-quicksight-topic-topicnamedentity-definition
            '''
            result = self._values.get("definition")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnTopic.NamedEntityDefinitionProperty"]]]], result)

        @builtins.property
        def entity_description(self) -> typing.Optional[builtins.str]:
            '''The description of the named entity.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnamedentity.html#cfn-quicksight-topic-topicnamedentity-entitydescription
            '''
            result = self._values.get("entity_description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def entity_synonyms(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The other names or aliases for the named entity.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnamedentity.html#cfn-quicksight-topic-topicnamedentity-entitysynonyms
            '''
            result = self._values.get("entity_synonyms")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def semantic_entity_type(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.SemanticEntityTypeProperty"]]:
            '''The type of named entity that a topic represents.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnamedentity.html#cfn-quicksight-topic-topicnamedentity-semanticentitytype
            '''
            result = self._values.get("semantic_entity_type")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.SemanticEntityTypeProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopicNamedEntityProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.TopicNumericEqualityFilterProperty",
        jsii_struct_bases=[],
        name_mapping={"aggregation": "aggregation", "constant": "constant"},
    )
    class TopicNumericEqualityFilterProperty:
        def __init__(
            self,
            *,
            aggregation: typing.Optional[builtins.str] = None,
            constant: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.TopicSingularFilterConstantProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A filter that filters topics based on the value of a numeric field.

            The filter includes only topics whose numeric field value matches the specified value.

            :param aggregation: An aggregation function that specifies how to calculate the value of a numeric field for a topic. Valid values for this structure are ``NO_AGGREGATION`` , ``SUM`` , ``AVERAGE`` , ``COUNT`` , ``DISTINCT_COUNT`` , ``MAX`` , ``MEDIAN`` , ``MIN`` , ``STDEV`` , ``STDEVP`` , ``VAR`` , and ``VARP`` .
            :param constant: The constant used in a numeric equality filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnumericequalityfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                topic_numeric_equality_filter_property = quicksight.CfnTopic.TopicNumericEqualityFilterProperty(
                    aggregation="aggregation",
                    constant=quicksight.CfnTopic.TopicSingularFilterConstantProperty(
                        constant_type="constantType",
                        singular_constant="singularConstant"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6e0e5a7d468fa4347b348c3038af29b5dbbc1b91122f7be6badb3ae8fdf4cb5e)
                check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
                check_type(argname="argument constant", value=constant, expected_type=type_hints["constant"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if aggregation is not None:
                self._values["aggregation"] = aggregation
            if constant is not None:
                self._values["constant"] = constant

        @builtins.property
        def aggregation(self) -> typing.Optional[builtins.str]:
            '''An aggregation function that specifies how to calculate the value of a numeric field for a topic.

            Valid values for this structure are ``NO_AGGREGATION`` , ``SUM`` , ``AVERAGE`` , ``COUNT`` , ``DISTINCT_COUNT`` , ``MAX`` , ``MEDIAN`` , ``MIN`` , ``STDEV`` , ``STDEVP`` , ``VAR`` , and ``VARP`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnumericequalityfilter.html#cfn-quicksight-topic-topicnumericequalityfilter-aggregation
            '''
            result = self._values.get("aggregation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def constant(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicSingularFilterConstantProperty"]]:
            '''The constant used in a numeric equality filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnumericequalityfilter.html#cfn-quicksight-topic-topicnumericequalityfilter-constant
            '''
            result = self._values.get("constant")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicSingularFilterConstantProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopicNumericEqualityFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.TopicNumericRangeFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation": "aggregation",
            "constant": "constant",
            "inclusive": "inclusive",
        },
    )
    class TopicNumericRangeFilterProperty:
        def __init__(
            self,
            *,
            aggregation: typing.Optional[builtins.str] = None,
            constant: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.TopicRangeFilterConstantProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            inclusive: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
        ) -> None:
            '''A filter that filters topics based on the value of a numeric field.

            The filter includes only topics whose numeric field value falls within the specified range.

            :param aggregation: An aggregation function that specifies how to calculate the value of a numeric field for a topic, Valid values for this structure are ``NO_AGGREGATION`` , ``SUM`` , ``AVERAGE`` , ``COUNT`` , ``DISTINCT_COUNT`` , ``MAX`` , ``MEDIAN`` , ``MIN`` , ``STDEV`` , ``STDEVP`` , ``VAR`` , and ``VARP`` .
            :param constant: The constant used in a numeric range filter.
            :param inclusive: A Boolean value that indicates whether the endpoints of the numeric range are included in the filter. If set to true, topics whose numeric field value is equal to the endpoint values will be included in the filter. If set to false, topics whose numeric field value is equal to the endpoint values will be excluded from the filter. Default: - false

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnumericrangefilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                topic_numeric_range_filter_property = quicksight.CfnTopic.TopicNumericRangeFilterProperty(
                    aggregation="aggregation",
                    constant=quicksight.CfnTopic.TopicRangeFilterConstantProperty(
                        constant_type="constantType",
                        range_constant=quicksight.CfnTopic.RangeConstantProperty(
                            maximum="maximum",
                            minimum="minimum"
                        )
                    ),
                    inclusive=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4dfcde0684a467ee1e05ff934af9bf1a4408c2ffd6ec63d92421939754740147)
                check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
                check_type(argname="argument constant", value=constant, expected_type=type_hints["constant"])
                check_type(argname="argument inclusive", value=inclusive, expected_type=type_hints["inclusive"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if aggregation is not None:
                self._values["aggregation"] = aggregation
            if constant is not None:
                self._values["constant"] = constant
            if inclusive is not None:
                self._values["inclusive"] = inclusive

        @builtins.property
        def aggregation(self) -> typing.Optional[builtins.str]:
            '''An aggregation function that specifies how to calculate the value of a numeric field for a topic, Valid values for this structure are ``NO_AGGREGATION`` , ``SUM`` , ``AVERAGE`` , ``COUNT`` , ``DISTINCT_COUNT`` , ``MAX`` , ``MEDIAN`` , ``MIN`` , ``STDEV`` , ``STDEVP`` , ``VAR`` , and ``VARP`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnumericrangefilter.html#cfn-quicksight-topic-topicnumericrangefilter-aggregation
            '''
            result = self._values.get("aggregation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def constant(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicRangeFilterConstantProperty"]]:
            '''The constant used in a numeric range filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnumericrangefilter.html#cfn-quicksight-topic-topicnumericrangefilter-constant
            '''
            result = self._values.get("constant")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicRangeFilterConstantProperty"]], result)

        @builtins.property
        def inclusive(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]]:
            '''A Boolean value that indicates whether the endpoints of the numeric range are included in the filter.

            If set to true, topics whose numeric field value is equal to the endpoint values will be included in the filter. If set to false, topics whose numeric field value is equal to the endpoint values will be excluded from the filter.

            :default: - false

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicnumericrangefilter.html#cfn-quicksight-topic-topicnumericrangefilter-inclusive
            '''
            result = self._values.get("inclusive")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopicNumericRangeFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.TopicRangeFilterConstantProperty",
        jsii_struct_bases=[],
        name_mapping={
            "constant_type": "constantType",
            "range_constant": "rangeConstant",
        },
    )
    class TopicRangeFilterConstantProperty:
        def __init__(
            self,
            *,
            constant_type: typing.Optional[builtins.str] = None,
            range_constant: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.RangeConstantProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A constant value that is used in a range filter to specify the endpoints of the range.

            :param constant_type: The data type of the constant value that is used in a range filter. Valid values for this structure are ``RANGE`` .
            :param range_constant: The value of the constant that is used to specify the endpoints of a range filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicrangefilterconstant.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                topic_range_filter_constant_property = quicksight.CfnTopic.TopicRangeFilterConstantProperty(
                    constant_type="constantType",
                    range_constant=quicksight.CfnTopic.RangeConstantProperty(
                        maximum="maximum",
                        minimum="minimum"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__76c8bc288bc5830e3afb27a78373c5162ba1b999e4c951977b26dacfdcbdb6fc)
                check_type(argname="argument constant_type", value=constant_type, expected_type=type_hints["constant_type"])
                check_type(argname="argument range_constant", value=range_constant, expected_type=type_hints["range_constant"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if constant_type is not None:
                self._values["constant_type"] = constant_type
            if range_constant is not None:
                self._values["range_constant"] = range_constant

        @builtins.property
        def constant_type(self) -> typing.Optional[builtins.str]:
            '''The data type of the constant value that is used in a range filter.

            Valid values for this structure are ``RANGE`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicrangefilterconstant.html#cfn-quicksight-topic-topicrangefilterconstant-constanttype
            '''
            result = self._values.get("constant_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def range_constant(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.RangeConstantProperty"]]:
            '''The value of the constant that is used to specify the endpoints of a range filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicrangefilterconstant.html#cfn-quicksight-topic-topicrangefilterconstant-rangeconstant
            '''
            result = self._values.get("range_constant")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.RangeConstantProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopicRangeFilterConstantProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.TopicRelativeDateFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "constant": "constant",
            "relative_date_filter_function": "relativeDateFilterFunction",
            "time_granularity": "timeGranularity",
        },
    )
    class TopicRelativeDateFilterProperty:
        def __init__(
            self,
            *,
            constant: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union["CfnTopic.TopicSingularFilterConstantProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relative_date_filter_function: typing.Optional[builtins.str] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A structure that represents a relative date filter.

            :param constant: The constant used in a relative date filter.
            :param relative_date_filter_function: The function to be used in a relative date filter to determine the range of dates to include in the results. Valid values for this structure are ``BEFORE`` , ``AFTER`` , and ``BETWEEN`` .
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicrelativedatefilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                topic_relative_date_filter_property = quicksight.CfnTopic.TopicRelativeDateFilterProperty(
                    constant=quicksight.CfnTopic.TopicSingularFilterConstantProperty(
                        constant_type="constantType",
                        singular_constant="singularConstant"
                    ),
                    relative_date_filter_function="relativeDateFilterFunction",
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__39c00c9a003de5da41ff1db4fa32e0f417a5d14993059ef78829e576578c8a89)
                check_type(argname="argument constant", value=constant, expected_type=type_hints["constant"])
                check_type(argname="argument relative_date_filter_function", value=relative_date_filter_function, expected_type=type_hints["relative_date_filter_function"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if constant is not None:
                self._values["constant"] = constant
            if relative_date_filter_function is not None:
                self._values["relative_date_filter_function"] = relative_date_filter_function
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def constant(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicSingularFilterConstantProperty"]]:
            '''The constant used in a relative date filter.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicrelativedatefilter.html#cfn-quicksight-topic-topicrelativedatefilter-constant
            '''
            result = self._values.get("constant")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, "CfnTopic.TopicSingularFilterConstantProperty"]], result)

        @builtins.property
        def relative_date_filter_function(self) -> typing.Optional[builtins.str]:
            '''The function to be used in a relative date filter to determine the range of dates to include in the results.

            Valid values for this structure are ``BEFORE`` , ``AFTER`` , and ``BETWEEN`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicrelativedatefilter.html#cfn-quicksight-topic-topicrelativedatefilter-relativedatefilterfunction
            '''
            result = self._values.get("relative_date_filter_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicrelativedatefilter.html#cfn-quicksight-topic-topicrelativedatefilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopicRelativeDateFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnTopic.TopicSingularFilterConstantProperty",
        jsii_struct_bases=[],
        name_mapping={
            "constant_type": "constantType",
            "singular_constant": "singularConstant",
        },
    )
    class TopicSingularFilterConstantProperty:
        def __init__(
            self,
            *,
            constant_type: typing.Optional[builtins.str] = None,
            singular_constant: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A structure that represents a singular filter constant, used in filters to specify a single value to match against.

            :param constant_type: The type of the singular filter constant. Valid values for this structure are ``SINGULAR`` .
            :param singular_constant: The value of the singular filter constant.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicsingularfilterconstant.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                topic_singular_filter_constant_property = quicksight.CfnTopic.TopicSingularFilterConstantProperty(
                    constant_type="constantType",
                    singular_constant="singularConstant"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__14bc182c255d35e0a589d78db2835512b0f14f93d9d7d7010a94a7258f51a0ea)
                check_type(argname="argument constant_type", value=constant_type, expected_type=type_hints["constant_type"])
                check_type(argname="argument singular_constant", value=singular_constant, expected_type=type_hints["singular_constant"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if constant_type is not None:
                self._values["constant_type"] = constant_type
            if singular_constant is not None:
                self._values["singular_constant"] = singular_constant

        @builtins.property
        def constant_type(self) -> typing.Optional[builtins.str]:
            '''The type of the singular filter constant.

            Valid values for this structure are ``SINGULAR`` .

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicsingularfilterconstant.html#cfn-quicksight-topic-topicsingularfilterconstant-constanttype
            '''
            result = self._values.get("constant_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def singular_constant(self) -> typing.Optional[builtins.str]:
            '''The value of the singular filter constant.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-topic-topicsingularfilterconstant.html#cfn-quicksight-topic-topicsingularfilterconstant-singularconstant
            '''
            result = self._values.get("singular_constant")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopicSingularFilterConstantProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="aws-cdk-lib.aws_quicksight.CfnTopicProps",
    jsii_struct_bases=[],
    name_mapping={
        "aws_account_id": "awsAccountId",
        "data_sets": "dataSets",
        "description": "description",
        "name": "name",
        "topic_id": "topicId",
        "user_experience_version": "userExperienceVersion",
    },
)
class CfnTopicProps:
    def __init__(
        self,
        *,
        aws_account_id: typing.Optional[builtins.str] = None,
        data_sets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.DatasetMetadataProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        description: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        topic_id: typing.Optional[builtins.str] = None,
        user_experience_version: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Properties for defining a ``CfnTopic``.

        :param aws_account_id: The ID of the AWS account that you want to create a topic in.
        :param data_sets: The data sets that the topic is associated with.
        :param description: The description of the topic.
        :param name: The name of the topic.
        :param topic_id: The ID for the topic. This ID is unique per AWS Region for each AWS account.
        :param user_experience_version: The user experience version of a topic.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-topic.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            from aws_cdk import aws_quicksight as quicksight
            
            cfn_topic_props = quicksight.CfnTopicProps(
                aws_account_id="awsAccountId",
                data_sets=[quicksight.CfnTopic.DatasetMetadataProperty(
                    dataset_arn="datasetArn",
            
                    # the properties below are optional
                    calculated_fields=[quicksight.CfnTopic.TopicCalculatedFieldProperty(
                        calculated_field_name="calculatedFieldName",
                        expression="expression",
            
                        # the properties below are optional
                        aggregation="aggregation",
                        allowed_aggregations=["allowedAggregations"],
                        calculated_field_description="calculatedFieldDescription",
                        calculated_field_synonyms=["calculatedFieldSynonyms"],
                        cell_value_synonyms=[quicksight.CfnTopic.CellValueSynonymProperty(
                            cell_value="cellValue",
                            synonyms=["synonyms"]
                        )],
                        column_data_role="columnDataRole",
                        comparative_order=quicksight.CfnTopic.ComparativeOrderProperty(
                            specifed_order=["specifedOrder"],
                            treat_undefined_specified_values="treatUndefinedSpecifiedValues",
                            use_ordering="useOrdering"
                        ),
                        default_formatting=quicksight.CfnTopic.DefaultFormattingProperty(
                            display_format="displayFormat",
                            display_format_options=quicksight.CfnTopic.DisplayFormatOptionsProperty(
                                blank_cell_format="blankCellFormat",
                                currency_symbol="currencySymbol",
                                date_format="dateFormat",
                                decimal_separator="decimalSeparator",
                                fraction_digits=123,
                                grouping_separator="groupingSeparator",
                                negative_format=quicksight.CfnTopic.NegativeFormatProperty(
                                    prefix="prefix",
                                    suffix="suffix"
                                ),
                                prefix="prefix",
                                suffix="suffix",
                                unit_scaler="unitScaler",
                                use_blank_cell_format=False,
                                use_grouping=False
                            )
                        ),
                        is_included_in_topic=False,
                        never_aggregate_in_filter=False,
                        non_additive=False,
                        not_allowed_aggregations=["notAllowedAggregations"],
                        semantic_type=quicksight.CfnTopic.SemanticTypeProperty(
                            falsey_cell_value="falseyCellValue",
                            falsey_cell_value_synonyms=["falseyCellValueSynonyms"],
                            sub_type_name="subTypeName",
                            truthy_cell_value="truthyCellValue",
                            truthy_cell_value_synonyms=["truthyCellValueSynonyms"],
                            type_name="typeName",
                            type_parameters={
                                "type_parameters_key": "typeParameters"
                            }
                        ),
                        time_granularity="timeGranularity"
                    )],
                    columns=[quicksight.CfnTopic.TopicColumnProperty(
                        column_name="columnName",
            
                        # the properties below are optional
                        aggregation="aggregation",
                        allowed_aggregations=["allowedAggregations"],
                        cell_value_synonyms=[quicksight.CfnTopic.CellValueSynonymProperty(
                            cell_value="cellValue",
                            synonyms=["synonyms"]
                        )],
                        column_data_role="columnDataRole",
                        column_description="columnDescription",
                        column_friendly_name="columnFriendlyName",
                        column_synonyms=["columnSynonyms"],
                        comparative_order=quicksight.CfnTopic.ComparativeOrderProperty(
                            specifed_order=["specifedOrder"],
                            treat_undefined_specified_values="treatUndefinedSpecifiedValues",
                            use_ordering="useOrdering"
                        ),
                        default_formatting=quicksight.CfnTopic.DefaultFormattingProperty(
                            display_format="displayFormat",
                            display_format_options=quicksight.CfnTopic.DisplayFormatOptionsProperty(
                                blank_cell_format="blankCellFormat",
                                currency_symbol="currencySymbol",
                                date_format="dateFormat",
                                decimal_separator="decimalSeparator",
                                fraction_digits=123,
                                grouping_separator="groupingSeparator",
                                negative_format=quicksight.CfnTopic.NegativeFormatProperty(
                                    prefix="prefix",
                                    suffix="suffix"
                                ),
                                prefix="prefix",
                                suffix="suffix",
                                unit_scaler="unitScaler",
                                use_blank_cell_format=False,
                                use_grouping=False
                            )
                        ),
                        is_included_in_topic=False,
                        never_aggregate_in_filter=False,
                        non_additive=False,
                        not_allowed_aggregations=["notAllowedAggregations"],
                        semantic_type=quicksight.CfnTopic.SemanticTypeProperty(
                            falsey_cell_value="falseyCellValue",
                            falsey_cell_value_synonyms=["falseyCellValueSynonyms"],
                            sub_type_name="subTypeName",
                            truthy_cell_value="truthyCellValue",
                            truthy_cell_value_synonyms=["truthyCellValueSynonyms"],
                            type_name="typeName",
                            type_parameters={
                                "type_parameters_key": "typeParameters"
                            }
                        ),
                        time_granularity="timeGranularity"
                    )],
                    data_aggregation=quicksight.CfnTopic.DataAggregationProperty(
                        dataset_row_date_granularity="datasetRowDateGranularity",
                        default_date_column_name="defaultDateColumnName"
                    ),
                    dataset_description="datasetDescription",
                    dataset_name="datasetName",
                    filters=[quicksight.CfnTopic.TopicFilterProperty(
                        filter_name="filterName",
                        operand_field_name="operandFieldName",
            
                        # the properties below are optional
                        category_filter=quicksight.CfnTopic.TopicCategoryFilterProperty(
                            category_filter_function="categoryFilterFunction",
                            category_filter_type="categoryFilterType",
                            constant=quicksight.CfnTopic.TopicCategoryFilterConstantProperty(
                                collective_constant=quicksight.CfnTopic.CollectiveConstantProperty(
                                    value_list=["valueList"]
                                ),
                                constant_type="constantType",
                                singular_constant="singularConstant"
                            ),
                            inverse=False
                        ),
                        date_range_filter=quicksight.CfnTopic.TopicDateRangeFilterProperty(
                            constant=quicksight.CfnTopic.TopicRangeFilterConstantProperty(
                                constant_type="constantType",
                                range_constant=quicksight.CfnTopic.RangeConstantProperty(
                                    maximum="maximum",
                                    minimum="minimum"
                                )
                            ),
                            inclusive=False
                        ),
                        filter_class="filterClass",
                        filter_description="filterDescription",
                        filter_synonyms=["filterSynonyms"],
                        filter_type="filterType",
                        numeric_equality_filter=quicksight.CfnTopic.TopicNumericEqualityFilterProperty(
                            aggregation="aggregation",
                            constant=quicksight.CfnTopic.TopicSingularFilterConstantProperty(
                                constant_type="constantType",
                                singular_constant="singularConstant"
                            )
                        ),
                        numeric_range_filter=quicksight.CfnTopic.TopicNumericRangeFilterProperty(
                            aggregation="aggregation",
                            constant=quicksight.CfnTopic.TopicRangeFilterConstantProperty(
                                constant_type="constantType",
                                range_constant=quicksight.CfnTopic.RangeConstantProperty(
                                    maximum="maximum",
                                    minimum="minimum"
                                )
                            ),
                            inclusive=False
                        ),
                        relative_date_filter=quicksight.CfnTopic.TopicRelativeDateFilterProperty(
                            constant=quicksight.CfnTopic.TopicSingularFilterConstantProperty(
                                constant_type="constantType",
                                singular_constant="singularConstant"
                            ),
                            relative_date_filter_function="relativeDateFilterFunction",
                            time_granularity="timeGranularity"
                        )
                    )],
                    named_entities=[quicksight.CfnTopic.TopicNamedEntityProperty(
                        entity_name="entityName",
            
                        # the properties below are optional
                        definition=[quicksight.CfnTopic.NamedEntityDefinitionProperty(
                            field_name="fieldName",
                            metric=quicksight.CfnTopic.NamedEntityDefinitionMetricProperty(
                                aggregation="aggregation",
                                aggregation_function_parameters={
                                    "aggregation_function_parameters_key": "aggregationFunctionParameters"
                                }
                            ),
                            property_name="propertyName",
                            property_role="propertyRole",
                            property_usage="propertyUsage"
                        )],
                        entity_description="entityDescription",
                        entity_synonyms=["entitySynonyms"],
                        semantic_entity_type=quicksight.CfnTopic.SemanticEntityTypeProperty(
                            sub_type_name="subTypeName",
                            type_name="typeName",
                            type_parameters={
                                "type_parameters_key": "typeParameters"
                            }
                        )
                    )]
                )],
                description="description",
                name="name",
                topic_id="topicId",
                user_experience_version="userExperienceVersion"
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__594e8a4ec85e161016ae0aa60a6538d619759944135cfd2b531b0f063b24a029)
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument data_sets", value=data_sets, expected_type=type_hints["data_sets"])
            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument topic_id", value=topic_id, expected_type=type_hints["topic_id"])
            check_type(argname="argument user_experience_version", value=user_experience_version, expected_type=type_hints["user_experience_version"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if aws_account_id is not None:
            self._values["aws_account_id"] = aws_account_id
        if data_sets is not None:
            self._values["data_sets"] = data_sets
        if description is not None:
            self._values["description"] = description
        if name is not None:
            self._values["name"] = name
        if topic_id is not None:
            self._values["topic_id"] = topic_id
        if user_experience_version is not None:
            self._values["user_experience_version"] = user_experience_version

    @builtins.property
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The ID of the AWS account that you want to create a topic in.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-topic.html#cfn-quicksight-topic-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def data_sets(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnTopic.DatasetMetadataProperty]]]]:
        '''The data sets that the topic is associated with.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-topic.html#cfn-quicksight-topic-datasets
        '''
        result = self._values.get("data_sets")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnTopic.DatasetMetadataProperty]]]], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''The description of the topic.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-topic.html#cfn-quicksight-topic-description
        '''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''The name of the topic.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-topic.html#cfn-quicksight-topic-name
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def topic_id(self) -> typing.Optional[builtins.str]:
        '''The ID for the topic.

        This ID is unique per AWS Region for each AWS account.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-topic.html#cfn-quicksight-topic-topicid
        '''
        result = self._values.get("topic_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def user_experience_version(self) -> typing.Optional[builtins.str]:
        '''The user experience version of a topic.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-topic.html#cfn-quicksight-topic-userexperienceversion
        '''
        result = self._values.get("user_experience_version")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnTopicProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_IInspectable_c2943556, _ITaggable_36806126)
class CfnVPCConnection(
    _CfnResource_9df397a6,
    metaclass=jsii.JSIIMeta,
    jsii_type="aws-cdk-lib.aws_quicksight.CfnVPCConnection",
):
    '''Creates a new VPC connection.

    :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html
    :cloudformationResource: AWS::QuickSight::VPCConnection
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        from aws_cdk import aws_quicksight as quicksight
        
        cfn_vPCConnection = quicksight.CfnVPCConnection(self, "MyCfnVPCConnection",
            availability_status="availabilityStatus",
            aws_account_id="awsAccountId",
            dns_resolvers=["dnsResolvers"],
            name="name",
            role_arn="roleArn",
            security_group_ids=["securityGroupIds"],
            subnet_ids=["subnetIds"],
            tags=[CfnTag(
                key="key",
                value="value"
            )],
            vpc_connection_id="vpcConnectionId"
        )
    '''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.Construct,
        id: builtins.str,
        *,
        availability_status: typing.Optional[builtins.str] = None,
        aws_account_id: typing.Optional[builtins.str] = None,
        dns_resolvers: typing.Optional[typing.Sequence[builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        role_arn: typing.Optional[builtins.str] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        subnet_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
        vpc_connection_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param scope: Scope in which this resource is defined.
        :param id: Construct identifier for this resource (unique in its scope).
        :param availability_status: The availability status of the VPC connection.
        :param aws_account_id: The AWS account ID of the account where you want to create a new VPC connection.
        :param dns_resolvers: A list of IP addresses of DNS resolver endpoints for the VPC connection.
        :param name: The display name for the VPC connection.
        :param role_arn: The ARN of the IAM role associated with the VPC connection.
        :param security_group_ids: The Amazon EC2 security group IDs associated with the VPC connection.
        :param subnet_ids: A list of subnet IDs for the VPC connection.
        :param tags: A map of the key-value pairs for the resource tag or tags assigned to the VPC connection.
        :param vpc_connection_id: The ID of the VPC connection that you're creating. This ID is a unique identifier for each AWS Region in an AWS account.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef620926701190b6847eccf16ab05ec1e84c9f36be88ca71e3fb46aa455b98f7)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnVPCConnectionProps(
            availability_status=availability_status,
            aws_account_id=aws_account_id,
            dns_resolvers=dns_resolvers,
            name=name,
            role_arn=role_arn,
            security_group_ids=security_group_ids,
            subnet_ids=subnet_ids,
            tags=tags,
            vpc_connection_id=vpc_connection_id,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _TreeInspector_488e0dd5) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dbabc322df97d909bf1356aabd6a09e621b84313d0fa72daff9cf7dc2cc11b77)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__420144ea2ee9a09db7bf5187781e8efeb19163e2f9a6e3cd99c47bbd9fe4fac4)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) of the VPC connection.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="attrCreatedTime")
    def attr_created_time(self) -> builtins.str:
        '''The time that the VPC connection was created.

        :cloudformationAttribute: CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrLastUpdatedTime")
    def attr_last_updated_time(self) -> builtins.str:
        '''The time that the VPC connection was last updated.

        :cloudformationAttribute: LastUpdatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastUpdatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrNetworkInterfaces")
    def attr_network_interfaces(self) -> _IResolvable_da3f097b:
        '''A list of network interfaces.

        :cloudformationAttribute: NetworkInterfaces
        '''
        return typing.cast(_IResolvable_da3f097b, jsii.get(self, "attrNetworkInterfaces"))

    @builtins.property
    @jsii.member(jsii_name="attrStatus")
    def attr_status(self) -> builtins.str:
        '''The HTTP status of the request.

        :cloudformationAttribute: Status
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrStatus"))

    @builtins.property
    @jsii.member(jsii_name="attrVpcId")
    def attr_vpc_id(self) -> builtins.str:
        '''The Amazon EC2 VPC ID associated with the VPC connection.

        :cloudformationAttribute: VPCId
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVpcId"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> _TagManager_0a598cb3:
        '''Tag Manager which manages the tags for this resource.'''
        return typing.cast(_TagManager_0a598cb3, jsii.get(self, "tags"))

    @builtins.property
    @jsii.member(jsii_name="availabilityStatus")
    def availability_status(self) -> typing.Optional[builtins.str]:
        '''The availability status of the VPC connection.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "availabilityStatus"))

    @availability_status.setter
    def availability_status(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__832984ca825d6bf8084cb48289d171ff480ae94b38204dfc1ebedcd4f8206a2b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "availabilityStatus", value)

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID of the account where you want to create a new VPC connection.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8658178452a3fcded2ee47d39dcf69f8847c5ffe765c14ccf964342546c84188)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="dnsResolvers")
    def dns_resolvers(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of IP addresses of DNS resolver endpoints for the VPC connection.'''
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "dnsResolvers"))

    @dns_resolvers.setter
    def dns_resolvers(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ac506209d6fac914f50d920a1c6663d643dd96d8cbeb0f81c873cfbc67571e7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dnsResolvers", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        '''The display name for the VPC connection.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "name"))

    @name.setter
    def name(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__511918fffce5781d52150f4e23e3ff1a72755f42339f1d83d8598a81d18f34df)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> typing.Optional[builtins.str]:
        '''The ARN of the IAM role associated with the VPC connection.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "roleArn"))

    @role_arn.setter
    def role_arn(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e01de73f6047bb36d86d0fd85a88f84de6a96ee28d9ae346f8cfb34842c304b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "roleArn", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The Amazon EC2 security group IDs associated with the VPC connection.'''
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "securityGroupIds"))

    @security_group_ids.setter
    def security_group_ids(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4cfb27ab2b9d66f7838d9fd4f35f59b6d9abe44b247bb339171e7d8f6942fe8d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "securityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of subnet IDs for the VPC connection.'''
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "subnetIds"))

    @subnet_ids.setter
    def subnet_ids(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bb5467e05e57753947434c47147705ee687d5a5e067c62e562c68422d7aad5ef)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="tagsRaw")
    def tags_raw(self) -> typing.Optional[typing.List[_CfnTag_f6864754]]:
        '''A map of the key-value pairs for the resource tag or tags assigned to the VPC connection.'''
        return typing.cast(typing.Optional[typing.List[_CfnTag_f6864754]], jsii.get(self, "tagsRaw"))

    @tags_raw.setter
    def tags_raw(self, value: typing.Optional[typing.List[_CfnTag_f6864754]]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa21ffd18f0d11f7c59636b3e143ff2b8838b628b1cf0dc74ebef9ad2b519c86)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "tagsRaw", value)

    @builtins.property
    @jsii.member(jsii_name="vpcConnectionId")
    def vpc_connection_id(self) -> typing.Optional[builtins.str]:
        '''The ID of the VPC connection that you're creating.'''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "vpcConnectionId"))

    @vpc_connection_id.setter
    def vpc_connection_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__968ed3c0730e6c72a1719a4c488de0314feafcf383509068874dc1e97ace5157)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "vpcConnectionId", value)

    @jsii.data_type(
        jsii_type="aws-cdk-lib.aws_quicksight.CfnVPCConnection.NetworkInterfaceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "availability_zone": "availabilityZone",
            "error_message": "errorMessage",
            "network_interface_id": "networkInterfaceId",
            "status": "status",
            "subnet_id": "subnetId",
        },
    )
    class NetworkInterfaceProperty:
        def __init__(
            self,
            *,
            availability_zone: typing.Optional[builtins.str] = None,
            error_message: typing.Optional[builtins.str] = None,
            network_interface_id: typing.Optional[builtins.str] = None,
            status: typing.Optional[builtins.str] = None,
            subnet_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The structure that contains information about a network interface.

            :param availability_zone: The availability zone that the network interface resides in.
            :param error_message: An error message.
            :param network_interface_id: The network interface ID.
            :param status: The status of the network interface.
            :param subnet_id: The subnet ID associated with the network interface.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from aws_cdk import aws_quicksight as quicksight
                
                network_interface_property = quicksight.CfnVPCConnection.NetworkInterfaceProperty(
                    availability_zone="availabilityZone",
                    error_message="errorMessage",
                    network_interface_id="networkInterfaceId",
                    status="status",
                    subnet_id="subnetId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__739acf70e62b97a09a7f5c798708670a2c0bc24d04d30df3dac04b1b4665abd6)
                check_type(argname="argument availability_zone", value=availability_zone, expected_type=type_hints["availability_zone"])
                check_type(argname="argument error_message", value=error_message, expected_type=type_hints["error_message"])
                check_type(argname="argument network_interface_id", value=network_interface_id, expected_type=type_hints["network_interface_id"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument subnet_id", value=subnet_id, expected_type=type_hints["subnet_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_zone is not None:
                self._values["availability_zone"] = availability_zone
            if error_message is not None:
                self._values["error_message"] = error_message
            if network_interface_id is not None:
                self._values["network_interface_id"] = network_interface_id
            if status is not None:
                self._values["status"] = status
            if subnet_id is not None:
                self._values["subnet_id"] = subnet_id

        @builtins.property
        def availability_zone(self) -> typing.Optional[builtins.str]:
            '''The availability zone that the network interface resides in.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html#cfn-quicksight-vpcconnection-networkinterface-availabilityzone
            '''
            result = self._values.get("availability_zone")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def error_message(self) -> typing.Optional[builtins.str]:
            '''An error message.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html#cfn-quicksight-vpcconnection-networkinterface-errormessage
            '''
            result = self._values.get("error_message")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def network_interface_id(self) -> typing.Optional[builtins.str]:
            '''The network interface ID.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html#cfn-quicksight-vpcconnection-networkinterface-networkinterfaceid
            '''
            result = self._values.get("network_interface_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the network interface.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html#cfn-quicksight-vpcconnection-networkinterface-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def subnet_id(self) -> typing.Optional[builtins.str]:
            '''The subnet ID associated with the network interface.

            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html#cfn-quicksight-vpcconnection-networkinterface-subnetid
            '''
            result = self._values.get("subnet_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NetworkInterfaceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="aws-cdk-lib.aws_quicksight.CfnVPCConnectionProps",
    jsii_struct_bases=[],
    name_mapping={
        "availability_status": "availabilityStatus",
        "aws_account_id": "awsAccountId",
        "dns_resolvers": "dnsResolvers",
        "name": "name",
        "role_arn": "roleArn",
        "security_group_ids": "securityGroupIds",
        "subnet_ids": "subnetIds",
        "tags": "tags",
        "vpc_connection_id": "vpcConnectionId",
    },
)
class CfnVPCConnectionProps:
    def __init__(
        self,
        *,
        availability_status: typing.Optional[builtins.str] = None,
        aws_account_id: typing.Optional[builtins.str] = None,
        dns_resolvers: typing.Optional[typing.Sequence[builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        role_arn: typing.Optional[builtins.str] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        subnet_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
        vpc_connection_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Properties for defining a ``CfnVPCConnection``.

        :param availability_status: The availability status of the VPC connection.
        :param aws_account_id: The AWS account ID of the account where you want to create a new VPC connection.
        :param dns_resolvers: A list of IP addresses of DNS resolver endpoints for the VPC connection.
        :param name: The display name for the VPC connection.
        :param role_arn: The ARN of the IAM role associated with the VPC connection.
        :param security_group_ids: The Amazon EC2 security group IDs associated with the VPC connection.
        :param subnet_ids: A list of subnet IDs for the VPC connection.
        :param tags: A map of the key-value pairs for the resource tag or tags assigned to the VPC connection.
        :param vpc_connection_id: The ID of the VPC connection that you're creating. This ID is a unique identifier for each AWS Region in an AWS account.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            from aws_cdk import aws_quicksight as quicksight
            
            cfn_vPCConnection_props = quicksight.CfnVPCConnectionProps(
                availability_status="availabilityStatus",
                aws_account_id="awsAccountId",
                dns_resolvers=["dnsResolvers"],
                name="name",
                role_arn="roleArn",
                security_group_ids=["securityGroupIds"],
                subnet_ids=["subnetIds"],
                tags=[CfnTag(
                    key="key",
                    value="value"
                )],
                vpc_connection_id="vpcConnectionId"
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58b1c31b33a7be8b7c5d102f60c41a81d1ffe3d57a15387f2812dfde0bb67d6d)
            check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument dns_resolvers", value=dns_resolvers, expected_type=type_hints["dns_resolvers"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument role_arn", value=role_arn, expected_type=type_hints["role_arn"])
            check_type(argname="argument security_group_ids", value=security_group_ids, expected_type=type_hints["security_group_ids"])
            check_type(argname="argument subnet_ids", value=subnet_ids, expected_type=type_hints["subnet_ids"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument vpc_connection_id", value=vpc_connection_id, expected_type=type_hints["vpc_connection_id"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if availability_status is not None:
            self._values["availability_status"] = availability_status
        if aws_account_id is not None:
            self._values["aws_account_id"] = aws_account_id
        if dns_resolvers is not None:
            self._values["dns_resolvers"] = dns_resolvers
        if name is not None:
            self._values["name"] = name
        if role_arn is not None:
            self._values["role_arn"] = role_arn
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if subnet_ids is not None:
            self._values["subnet_ids"] = subnet_ids
        if tags is not None:
            self._values["tags"] = tags
        if vpc_connection_id is not None:
            self._values["vpc_connection_id"] = vpc_connection_id

    @builtins.property
    def availability_status(self) -> typing.Optional[builtins.str]:
        '''The availability status of the VPC connection.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-availabilitystatus
        '''
        result = self._values.get("availability_status")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID of the account where you want to create a new VPC connection.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def dns_resolvers(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of IP addresses of DNS resolver endpoints for the VPC connection.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-dnsresolvers
        '''
        result = self._values.get("dns_resolvers")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''The display name for the VPC connection.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-name
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def role_arn(self) -> typing.Optional[builtins.str]:
        '''The ARN of the IAM role associated with the VPC connection.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-rolearn
        '''
        result = self._values.get("role_arn")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The Amazon EC2 security group IDs associated with the VPC connection.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-securitygroupids
        '''
        result = self._values.get("security_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def subnet_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of subnet IDs for the VPC connection.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-subnetids
        '''
        result = self._values.get("subnet_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[_CfnTag_f6864754]]:
        '''A map of the key-value pairs for the resource tag or tags assigned to the VPC connection.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-tags
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[_CfnTag_f6864754]], result)

    @builtins.property
    def vpc_connection_id(self) -> typing.Optional[builtins.str]:
        '''The ID of the VPC connection that you're creating.

        This ID is a unique identifier for each AWS Region in an AWS account.

        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-vpcconnectionid
        '''
        result = self._values.get("vpc_connection_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnVPCConnectionProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


__all__ = [
    "CfnAnalysis",
    "CfnAnalysisProps",
    "CfnDashboard",
    "CfnDashboardProps",
    "CfnDataSet",
    "CfnDataSetProps",
    "CfnDataSource",
    "CfnDataSourceProps",
    "CfnRefreshSchedule",
    "CfnRefreshScheduleProps",
    "CfnTemplate",
    "CfnTemplateProps",
    "CfnTheme",
    "CfnThemeProps",
    "CfnTopic",
    "CfnTopicProps",
    "CfnVPCConnection",
    "CfnVPCConnectionProps",
]

publication.publish()

def _typecheckingstub__5b3315f05d88d5e66533d2b20616a2e811e05c9fbafca2923d46fac3672de4c3(
    scope: _constructs_77d1e7e8.Construct,
    id: builtins.str,
    *,
    analysis_id: builtins.str,
    aws_account_id: builtins.str,
    name: builtins.str,
    definition: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AnalysisDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    errors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AnalysisErrorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sheets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SheetProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source_entity: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AnalysisSourceEntityProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    status: typing.Optional[builtins.str] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
    theme_arn: typing.Optional[builtins.str] = None,
    validation_strategy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ValidationStrategyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ca8147b17b844ffbc3c2a9cd090ca0e94480c6c7ae381cf94ebe71edace477d(
    inspector: _TreeInspector_488e0dd5,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53b97cfc102fb3684bd66abaed6039a9dfaeaec91be6718e5c5a729fb5bd4bce(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e97a6221e06dbf461b9aa4823e3454ea44abab8e0005d388c8a957afba6a7546(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9813c24d422123fdb92156bf969c5184775e9ae04365dcc922fbd64d9a6fa0d4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca318b234683f1f107ce9a5125554a5e0541143b8749b8bfddc3af01f3eec1e2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__312c03143f0646ddac921317c4beafd13435a22bac7731ca4c80df7cf1291f07(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnAnalysis.AnalysisDefinitionProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c6a0b9f84708043b6388b7cc2507e80b2ec92bee4c20a36299936a33e1260cb(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnAnalysis.AnalysisErrorProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef1f56dc35400e4931f1653bb22e70cc553ebe1114f5d755d003231b1324cba0(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnAnalysis.ParametersProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66d1950ca4f145650f0bbe6dd03ce20c1892373a45953eeae4c8d1e715e4e59f(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnAnalysis.ResourcePermissionProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ae5ac0286f6d69735847f21956cc7a189332cc0ba029898dc97822bc48ef4b8(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnAnalysis.SheetProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6af7e816d0168a8e494393a7d325b33b7608b06408d137df9bb53d12ddb0300(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnAnalysis.AnalysisSourceEntityProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__960fdb2a491ce9d35ff5cabbedc58835f6818653fdd7bf86d6f4bc8a77bb74cf(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96a82327f73591975826047cd88720f3f49b18acb2dd6e14a4795868ce2805b3(
    value: typing.Optional[typing.List[_CfnTag_f6864754]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63c9327e4ac918b6b057dc7c2832c61de3e22f29858922ea51482cc4bcc992e8(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4515d338bad3917a13aa84587ddde591fed0b18d3bc4dfedd4fa0f258fd89eb0(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnAnalysis.ValidationStrategyProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__925d009ba27261c4511ddbb792d28c7eb0661fd2f049ebff6d7260489c45c820(
    *,
    attribute_aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AttributeAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    categorical_aggregation_function: typing.Optional[builtins.str] = None,
    date_aggregation_function: typing.Optional[builtins.str] = None,
    numerical_aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78bad2ac32260dc84e2b7357f78d6b25ee5c88beec8c3afc46099f635c253b9e(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    sort_direction: builtins.str,
    aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50c31b61023716b7d8ba53618c337c56297b3ca7493ebffe7c2166feb816acf5(
    *,
    default_new_sheet_configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DefaultNewSheetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__743f6de00af3d8850478c1cec470f5e4bbc39e00ef3e785c354c25f2a4f0444f(
    *,
    data_set_identifier_declarations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataSetIdentifierDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AnalysisDefaultsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    calculated_fields: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CalculatedFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    column_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    filter_groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilterGroupProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AssetOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    parameter_declarations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sheets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SheetDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d24a90ca3aa452a90f96fcfd4a5a877d8b3420dac8dd89194eefc7cf2d995a3e(
    *,
    message: typing.Optional[builtins.str] = None,
    type: typing.Optional[builtins.str] = None,
    violated_entities: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.EntityProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ecdbd45ff5b11d9790994a68adfcf0f92e2edd71f85a3c48a1682c8262080ba(
    *,
    source_template: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AnalysisSourceTemplateProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e49cd94ff28900c4ae630948d7ccea67de75a0db33d071821700a175ccf1c97f(
    *,
    arn: builtins.str,
    data_set_references: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataSetReferenceProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5fcc6f6525e366303c9db7e8ff24617e72ce0a488feda6c9ad8187f55d8ab56e(
    *,
    anchor_option: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d54e637872882a6173bd225ee587908fd78c7f4daecbf84ec402376d4ffade92(
    *,
    range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ArcAxisDisplayRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reserve_range: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed3f8887663271e93178c46a42a1aeed0fa3ca1be562b706c4a69616b2752b6e(
    *,
    max: typing.Optional[jsii.Number] = None,
    min: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6467b443ad9493fad2ed833817e6e804c21ec4bb657ad9f80369ad9dc86cb37e(
    *,
    arc_angle: typing.Optional[jsii.Number] = None,
    arc_thickness: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f6963705589da3cdf278cf29ec86cc70224eb186ec79d898a87727068b732fc(
    *,
    arc_thickness: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b036419146adc925061a8649db3f06ee7cc3a080ffd431d521f4374dda141d4c(
    *,
    timezone: typing.Optional[builtins.str] = None,
    week_start: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__239322ef0f76b06b43847222b973f1c2dab05370b2ec6eb4609aa0ded5f6facc(
    *,
    simple_attribute_aggregation: typing.Optional[builtins.str] = None,
    value_for_multiple_values: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78edd36053c1005b13a557e025be3a3720bda781507e2e555c70560a0d7e3259(
    *,
    date_axis_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DateAxisOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_axis_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumericAxisOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b4c5af5cc74aa0ccdc5a34f6c71e69180d271c0d9deca42d71f6e7519e3b965(
    *,
    maximum: typing.Optional[jsii.Number] = None,
    minimum: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ce4112654b0cd5421008601c76af6b776bbd67f39c758fb78c8f8dc12fe8eb4(
    *,
    axis_line_visibility: typing.Optional[builtins.str] = None,
    axis_offset: typing.Optional[builtins.str] = None,
    data_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisDataOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    grid_line_visibility: typing.Optional[builtins.str] = None,
    scrollbar_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ScrollBarOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tick_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisTickLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d1f3cfb0e15cf882a7641e844dead6be56b0b912c5ad84ca6fbeb1a3f6708e2(
    *,
    data_driven: typing.Any = None,
    min_max: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisDisplayMinMaxRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bca9702cb7afaa3a7f9b3ad0e4acb34452f17e91211faa3d6f1d04077ab66e87(
    *,
    apply_to: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisLabelReferenceOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_label: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a41941fd4b6c34fbb36f8455884251f8e49d3a1bc0f3144be7b27b47f0d9a85(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de2ed81b442a112dc0e5d3f1eaa2866e34c18bd6582d5dfaf8da256fed592114(
    *,
    step_count: typing.Optional[jsii.Number] = None,
    step_size: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__381902f283cd7b9a04480082e8bdb608c28e6b8d6c5de55e66eb320c97567350(
    *,
    base: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c88b551eac07288842d97071c3029b47d5623858616e1fe83f80d2048ec76e9(
    *,
    linear: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisLinearScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    logarithmic: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisLogarithmicScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc6f05f510c841613789e96111c71665c3690785353fb7564171d840cff188b8(
    *,
    label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rotation_angle: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14d09f84e0529894a371328f931fac3530bd776eb35de0075819430e70ff8806(
    *,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f82e6ee1add2fdb859f27b13f529aafc1f0a7f416e16682c5d67e2df723a9e71(
    *,
    bars_arrangement: typing.Optional[builtins.str] = None,
    category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.BarChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    orientation: typing.Optional[builtins.str] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.BarChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57e94b3218a71f9a221c4546912c0125a1236895085ccf54fe565d569bf21a63(
    *,
    bar_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.BarChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9bfd09e91f4971d3675d55e8b7c84cc7b2d5d2b84f29fec31127f56611a737cf(
    *,
    category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad3846bbad8b69a74a650c9a66c96d4c5617a1d4379c57502d538c2439700765(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.BarChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c9a0dbb5a09986420c28ddb1fa6dbe46b74b4966dcd5e2134c71ddfe180df39(
    *,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5bf9a31675e53c4ed03f804fe10a9e945f4cb2d3265ed6fcb315ab9a91b63087(
    *,
    bin_count_limit: typing.Optional[jsii.Number] = None,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2470326817442ac7529c78646a6f521d33b36a0b4ce5470a868a1d02e2c13a38(
    *,
    content: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.BodySectionContentProperty, typing.Dict[builtins.str, typing.Any]]],
    section_id: builtins.str,
    page_break_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SectionPageBreakConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SectionStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52862e0cf0f944ba3a4d77a6336d986d75842281f1d4a4497c0ea8035c3aa5d7(
    *,
    layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe1567634ff247e915bad385ea901faa429b429895c09a83d0322d4c7cd8bdff(
    *,
    group_by: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df46651962cedb1ef6652ed395524dbc2b63cba61bdd0276f355d4aea35da887(
    *,
    box_plot_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.BoxPlotOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.BoxPlotFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.BoxPlotSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac1a8fba8f6c2f661b078e185c31574bc3d302ed5e28f085da15f15ce024416f(
    *,
    box_plot_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.BoxPlotAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f609ac1c7e2111a40dac58ec2bf94644d7ec89bb7e811f05ac3791b0bd840ca1(
    *,
    all_data_points_visibility: typing.Optional[builtins.str] = None,
    outlier_visibility: typing.Optional[builtins.str] = None,
    style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.BoxPlotStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c1d82075e81046c13020ab880f86084f3bffe25cd8098d935779d515db720da(
    *,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    pagination_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PaginationConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89d49edf39c70224f925125d76ee7b0de600605a2b15e684aa0b7ee96041320c(
    *,
    fill_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b3b42e671b910ca19129eb109ab58af3c253cd6b5c6f5c94a4b737e1287fcd6(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.BoxPlotChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b3e5b275e2f35fcdf8efe7f2989ea0bda663184c63636414e26198b88057139(
    *,
    data_set_identifier: builtins.str,
    expression: builtins.str,
    name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0374ef2482b9185adce203520bc3bf342ce2682847ee02c9c7de9eb4b573df1b(
    *,
    expression: builtins.str,
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e73299bcd6703fa1955807823fedc8668167418e46d6a1f346fdf0f2a291c90c(
    *,
    source_controls: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CascadingControlSourceProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d12dfeb0e547c026b1df8c2f6d543f7aa0dc0842e96b7484d1e6da2e024e49d(
    *,
    column_to_match: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    source_sheet_control_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f1f38bb0addf439daae4206b32dfabc93aced0cbdd4dc11840c7bc899eea7e3(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9fcef98715e02f90cb5e1a80001e6046d16394dec171ccd1c964880913fe68c(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    aggregation_function: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__723c70aef9408e55ed338e2c0930c0382941de2c4ef2a7418407d520c5de26b3(
    *,
    category_values: typing.Sequence[builtins.str],
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6e5a83eb58b86ba1db93dde36f36bc38753955033efcd6df85274323c052315(
    *,
    custom_filter_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CustomFilterConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_filter_list_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CustomFilterListConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    filter_list_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilterListConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cd5df25b1a6ff9a1098d6d573aaa7220ac13f7af43bbeca0f4bc97a2cef5b96f(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CategoryFilterConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cdb4eeafd511c20ae740891fafdc3d7f3d7cfde84fc43817149bce640d505ce6(
    *,
    axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sort_icon_visibility: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98f37cdd4ca6a15f7da6a38e0b8de29bb69f8019e6eed91dd94d65ca0e9ecd7f(
    *,
    cluster_marker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ClusterMarkerProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a2783133d20e8b551d6ea144cbd6b328f577eb8803ad9ccc941a6626951f69f(
    *,
    simple_cluster_marker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SimpleClusterMarkerProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f689b41b461f9d73e613d32fb06c81644f5d7da73bc45bce6809d7b5b2e1602c(
    *,
    color_fill_type: builtins.str,
    colors: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataColorProperty, typing.Dict[builtins.str, typing.Any]]]]],
    null_value_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f072c6c4e3112557f99bd411406e084171378a001e7229e58365a958f5a28e8(
    *,
    custom_colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CustomColorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0caa6540ab9ae618258469c56ddb4a7ac1db36480f095b1823437269d94846d9(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    colors_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColorsConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    role: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9af0953c9dd6d093bb97c949a7eafa66197bdadb0d2a6546efbbea740696b37e(
    *,
    date_time_hierarchy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DateTimeHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    explicit_hierarchy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ExplicitHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    predefined_hierarchy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PredefinedHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46742d202db724573544c68fcaf77bebd24074a6cfe5236855684fee3384e8ad(
    *,
    column_name: builtins.str,
    data_set_identifier: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5996308d06dca8fcdc4fccbb3e75d61da28c753855f270dcfe532b6588e65d4(
    *,
    direction: builtins.str,
    sort_by: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12db1f9cc37d2edf229e12062c9eab5719bcac0eab45d7cef4de82861fd08916(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    aggregation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__591a9749b2006f091f1b536872c6d1c0855cefdd0be4aee2b30d49d9fbfa0233(
    *,
    bar_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    line_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a515c71821e7f00825720a4573683ad269b842d55f7b80847bdc1398d91a83f9(
    *,
    bar_data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    bars_arrangement: typing.Optional[builtins.str] = None,
    category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ComboChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    line_data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    secondary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ComboChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3147af60ae2143d1a034a36f8c9a82e70085ccb8ab9084867cf2765ed2324af3(
    *,
    combo_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ComboChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__faaa8b2a496188587008b5c7df0d9610c9d579850447a07f3ed4c0e5d23a2ad5(
    *,
    category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b14c3bbad40e0afa7fd81b42e30c7725d3f3d5f2db8054112cc12f490640ad4c(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ComboChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__efcddd73fc9f096352e7d41e36263d6ac82160f33a961daa63e25016155bb1d7(
    *,
    comparison_format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ComparisonFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    comparison_method: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa91709855f99095961061d282729fba9d83b47411ddcd5cc76b3c7ee88b4975(
    *,
    number_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumberDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    percentage_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PercentageDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10d34f637e011375fff8ef66740a653ac3902a71882f8c6c5f45e4c23f09f53d(
    *,
    forecast: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ForecastComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    growth_rate: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GrowthRateComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    maximum_minimum: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MaximumMinimumComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    metric_comparison: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MetricComparisonComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    period_over_period: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PeriodOverPeriodComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    period_to_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PeriodToDateComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top_bottom_movers: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TopBottomMoversComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top_bottom_ranked: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TopBottomRankedComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    total_aggregation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TotalAggregationComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    unique_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.UniqueValuesComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d52148b7056c2d0312222fff65e42ec0e5fd53022ae05a99fa0d30f027edb590(
    *,
    gradient: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingGradientColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    solid: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingSolidColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c82e4ee5649da3ac08b6284e8b4daf22e5eaab886e5a4f96686f8adaf7eed9d5(
    *,
    expression: builtins.str,
    icon_options: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
    color: typing.Optional[builtins.str] = None,
    display_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2dadbe74f021f3e0e69b962cc389b96db48ba2bbdcd5e500656ada1005067aa(
    *,
    icon: typing.Optional[builtins.str] = None,
    unicode_icon: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e74308d9e744f21b3a92b03e46e01454a2c192b8b8db9cc813ec014cd56851ab(
    *,
    color: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GradientColorProperty, typing.Dict[builtins.str, typing.Any]]],
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8801e4508f2a867536d4c59d5f83793796e56c2f395e012b11fbfed0fc32915(
    *,
    icon_display_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6df240f326c7bda2dad75563204ea5754a7501cc88f6bd969e922137c95d803a(
    *,
    custom_condition: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingCustomIconConditionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    icon_set: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingIconSetProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37c00764af02fc0e5c936772d2729c7a412350549bea9dd4f115809c91ec66b6(
    *,
    expression: builtins.str,
    icon_set_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__79725fa3ccee01583125c515396717e5a6314accd5df430e08b159d27267cc2d(
    *,
    expression: builtins.str,
    color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14c868a949edd50a1aefe3b168b7430cd7748a22966fb04165749b9a8c09dc8e(
    *,
    contributor_dimensions: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]]],
    measure_field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d5fef0036b605708ff2c6f83939aef36f764848a1ea8b749ac6a7cb9f7bfac8(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    negative_value_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_scale: typing.Optional[builtins.str] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    suffix: typing.Optional[builtins.str] = None,
    symbol: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a383546d3eec1bdd3b061adab9ba14818917abd43a51c8f586e6db1ffaa56092(
    *,
    selected_fields_configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    target_visuals_configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0d2a1c805344be2956837393f966072a0c76504117dbac06fb620e8d3950734(
    *,
    local_navigation_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LocalNavigationConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9651a29ef076c161348b549e839408de6de0962e62f9664a79a5f1a6b6d899fa(
    *,
    parameter_value_configurations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SetParameterValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f737bd1c08cfbb480b0afd6dfcd8872739d8bf63785cf22f4d210654a386c28(
    *,
    url_target: builtins.str,
    url_template: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d872ac03245931eb5686c4a3f554633a94a804f7c635ee5d321186b3f751c581(
    *,
    color: builtins.str,
    field_value: typing.Optional[builtins.str] = None,
    special_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e3335fa4f454c6e8b71e44a4416f2d735b6a775ae146fc15d67b0c53b4cbc11(
    *,
    content_type: typing.Optional[builtins.str] = None,
    content_url: typing.Optional[builtins.str] = None,
    image_scaling: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebca1ef6a5d4a7a0ace89b9095ff8fdd543b79c30f056718329c56a45dcdef68(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CustomContentConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a271d758f3b9ebb8bd046ed3ce2bc4ce6c245d44ed2a96989f3803c36c1d12ee(
    *,
    match_operator: builtins.str,
    null_option: builtins.str,
    category_value: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5f1b84b0a9078e6b57b9051d15522aac25e644f5e28e8a62515c76a3e69cba6(
    *,
    match_operator: builtins.str,
    null_option: builtins.str,
    category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3661c9796a9728382d87c363f3bef8f8cf6723d1074574a85bd456d01ec1927(
    *,
    narrative: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a5be83345843551e0be466c923ea971b83e6b63668370180560da67f794fb896(
    *,
    date_time_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    decimal_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
    integer_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
    string_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6197934fa1bd9bfeab069abdfd02d7eaac44db71933bdecd67af20812e128e7(
    *,
    custom_values: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CustomParameterValuesProperty, typing.Dict[builtins.str, typing.Any]]],
    include_null_value: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b7c93e7f58e34129aee78309943f4c7156f17e5a06ed7a43c38285a625d878a(
    *,
    field_id: builtins.str,
    negative_color: typing.Optional[builtins.str] = None,
    positive_color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0336c5685cce8463a8784817939facd63e5d4858cbaf0a240808f76f9c35cfee(
    *,
    color: typing.Optional[builtins.str] = None,
    data_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e357f1d2093881569025e1138e344ed72afcb5baf371c67a4f89182cc5ecd479(
    *,
    axis_binding: builtins.str,
    field_id: builtins.str,
    field_value: typing.Optional[builtins.str] = None,
    settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LineChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d723fb6e0272cbb7a4b92a44aa3f1bc37eac283d3c2cd28d0a97f180b84be5a1(
    *,
    category_label_visibility: typing.Optional[builtins.str] = None,
    data_label_types: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    label_color: typing.Optional[builtins.str] = None,
    label_content: typing.Optional[builtins.str] = None,
    label_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    measure_label_visibility: typing.Optional[builtins.str] = None,
    overlap: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__baf45f94503ae9ca876cab034e08e9d0ffd39650ca278a4a24826388a6dee6c7(
    *,
    data_path_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataPathLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    maximum_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MaximumLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    minimum_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MinimumLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    range_ends_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.RangeEndsLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22d7ab72c9e58d8a805483a123dd94538f8a59bd4b43e25b3c94b8fbb4093b3b(
    *,
    color: builtins.str,
    element: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]]],
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92299d1328c6ec5763c4a2529888ce5ef3900ed776a8b1970a55b3c37c3b0dfb(
    *,
    field_id: typing.Optional[builtins.str] = None,
    field_value: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86d4fba3d65e1f121b841e1ea3ae51b09bf6d5742f286dbf05292fa7726c0166(
    *,
    direction: builtins.str,
    sort_paths: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9124deacbcb1f63197a3bd5a840753ac0339784eda57ade6bb68b6fcacb08d23(
    *,
    pivot_table_data_path_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba849ca69e22a9c090b73d793791dc533d8bf31d54e27c2ca76b1b941a6ce8d2(
    *,
    data_path_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataPathTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_id: typing.Optional[builtins.str] = None,
    field_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3de1e151dbe34974f8b59029404441fba53ab091ea12315947279f3102413d3(
    *,
    data_set_arn: builtins.str,
    identifier: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9a568b8d078664e0579c655148b615087e4791d2d616b8bec0caf8c3bff67c8(
    *,
    data_set_arn: builtins.str,
    data_set_placeholder: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9200345b8443d7700b28884e93da7759942bd2a60eb6f37859aa8714fe8a4ea8(
    *,
    missing_date_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd0d8474bb61fc8fe81036b6842e1cc601b74662e1cb56e92f82e04ed92343ba(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    date_granularity: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ec1ded69f32897bf459edf237407416761a83ddfcc44202f6659bbe97b15b2b(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    aggregation_function: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1da8f843d15a3d85a3e70a9ec36f8e4d6bc5d873c5af842246e2e9fa1285e22c(
    *,
    dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rolling_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.RollingDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a52a1effef6a37135b62fc99fba7a1801c65a2611508716eb6e2fc95a2a1d70(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10eb1a9ed2c4e66745e808132025ab28e7933d9384f2ad68e2a825f3210ff210(
    *,
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a68ab56c16f4db8843b372cb5d3ee1a3e4be61d10c8ef69ba820c5da2b8a931(
    *,
    name: builtins.str,
    default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DateTimeDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
    value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4df0ff05d2f7f0ede02161ea59214e17a3da562d2ba522d066c007b3508815e(
    *,
    name: builtins.str,
    values: typing.Sequence[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__16031b544a2c676bbfee7ed1c93e204aa5a7f2dab58622a274141ef9710b48c8(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SheetControlInfoIconLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__496e42293484deb5a0ef4cc356b965767bd664aee533cf7d9bcb6320cc824c66(
    *,
    custom_value: typing.Optional[builtins.str] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6041f968355c092078a2031614955bc07a4930897e0c000ded27c288989fb7ee(
    *,
    dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7a7efdffb85dad0fe095929a9da76445b466b9316260d44790824714f09c274(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DecimalDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c30fcfd3a96dfa875b3537e48e84a223b349d53190700099dc7830feb1f0b64(
    *,
    name: builtins.str,
    values: typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fdba937bce62805797d8bd38df0006794f78ccf7a86bb2a96afd1ccc3c7d830d(
    *,
    decimal_places: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5b58e947afff94824ee0192ed7fb58383917df19648d81c4312996d2c9149d1(
    *,
    custom_value: typing.Optional[jsii.Number] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2576800bc2c6797c492467497289cafee3725d83b8b2a0c3e9ada116b562fb6d(
    *,
    canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8086a8fa2fdaace4e00baac5605b96e46ed5fb1925470181b7056cabae70c506(
    *,
    canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GridLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d04354276f7247945ccd165e93cd180a01a97b610a00894675eb0c9f03759f12(
    *,
    free_form: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    grid: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DefaultGridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7279c174707162e2869656b88d69fa16e6e97a88e1e9041bec55319aab36d19(
    *,
    interactive_layout_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paginated_layout_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sheet_content_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5bd1fdbfb41878c1a01bf4ec5b04bee7584ad858147b67db1a2d05dda1702891(
    *,
    section_based: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__844118c582547d0457e97e77b0e34513191da4989820067b337b49d1e239a90b(
    *,
    canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b568ad7c5608ef334c1467a57d1b9916a10bda6f9c7696669cedd4a8a2c78a8c(
    *,
    custom_values_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CustomValuesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    select_all_value_options: typing.Optional[builtins.str] = None,
    source_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    source_field: typing.Optional[builtins.str] = None,
    source_parameter_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__47d2749256cc1777ad9f47e7272592b9ce95c8a7bb0694c352c23fabf36f8bed(
    *,
    categorical_dimension_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CategoricalDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    date_dimension_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DateDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numerical_dimension_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumericalDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be1f945d08f91a6a6f7b2701dbe881f346d1dca9634f685da7b97951943fd5b7(
    *,
    label_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36f3881197859f312008e2497b1f7133aeec48b33690834c8a3249cf7fed0f48(
    *,
    arc_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ArcOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    donut_center_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DonutCenterOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63714a0f5ddd94a6add28ab64356e46ddad604ffd9e4c7c5990527129eb07ae9(
    *,
    category_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CategoryDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_equality_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumericEqualityDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TimeRangeDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30f399901a109252449886599a579773134377fc9cf49eb2e30dfb58a7bafb35(
    *,
    info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SheetControlInfoIconLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    select_all_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ListControlSelectAllOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3d4b0670d07ee16280a547fe53b00b90cdb9a12ba231eb0dbdb9ea9ca830dc1(
    *,
    default_value_column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    group_name_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    user_name_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91c2446b2b894ede2d4797bf64f87f839affcb97fb0a4b0978a0dd8d78bd25db(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__800b433b7f82672440f865224ede9130f33730dda19b42651dd93929249b7291(
    *,
    path: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e13c0d1f2b524d378faf5d092530d94a87b58c2d430cad270aa2a67f655f967d(
    *,
    amount: jsii.Number,
    granularity: builtins.str,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__34dd11fb8a2f2d1be7b77d4774d2571ec51eed42de5ef8b76001040fb1074364(
    *,
    columns: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]]],
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__680d70d46ef4446a4baff79d816c51e2ac5f516ac8d178640e6eee60b890b0fb(
    *,
    aggregation_visibility: typing.Optional[builtins.str] = None,
    tooltip_fields: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TooltipItemProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    tooltip_title_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d8a084997e56f1f44aa4cbb8b67219df15c79c7067a582119e46d015ed3c5fe(
    *,
    field_id: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5024c98bfe0ffc4d25e2f6e024e903df5afee411cc1f0341e9d3554eeb83305(
    *,
    axis_binding: builtins.str,
    field_id: builtins.str,
    settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LineChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09b2a478bb48b8a35e68145d82a1103f14e17d408a63bee51b6cc6e656260892(
    *,
    column_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c342abcfaa5edb52d461f8d86d4843f430763e848397a672078e3cbc14582dc6(
    *,
    direction: builtins.str,
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c4bc4ebe959aca45b152955d00be66568532d3a9a70918e0b907c898d2525c0(
    *,
    field_id: builtins.str,
    label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e21654768a09627518420e739c98d80ccb9c26d519750bf53628439fb7fe9b0c(
    *,
    geospatial: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9772e47745d01f72dd9f2030f7be07be11dbade90b3280b435db961d0413ad0a(
    *,
    shape: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilledMapShapeConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e70b0cf46f1a44c9193e30c0aa909063226e6d64d1e563b8e66bfbabe12ec3da(
    *,
    conditional_formatting_options: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilledMapConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99afb2f4f36a4b3edd690faca9ffebf4ddfd77fccfd84731038c44e072b19685(
    *,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilledMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    map_style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GeospatialMapStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilledMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    window_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GeospatialWindowOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__092c4eda73a3a123e4407f658010f07c9bfba724b3bcfacb1d91adf1c32bf0b1(
    *,
    filled_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilledMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad5ace1e82268bfe9179bd98c493efc272bf172bbdc01e1ffa8d5cfb25bf4d26(
    *,
    field_id: builtins.str,
    format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ShapeConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6d3cba79f5d7156e9ef59b1a4b9999956bae25a6d6c5a18934537336c58c774(
    *,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c13faf467dc514b92b7ca29db46641e794b86d94dc41af1c6dc842560a64e5c(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilledMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilledMapConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f891ce6730f89d762147e5a41ef8552838308665394afca7cba59c6261421a4(
    *,
    date_time_picker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilterDateTimePickerControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    dropdown: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilterDropDownControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    list: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilterListControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relative_date_time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilterRelativeDateTimeControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    slider: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilterSliderControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_area: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilterTextAreaControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilterTextFieldControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a31e001b763f1cb36b8ef2f855857a0d498a62019ecaccf6d4a379426fe217e7(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DateTimePickerControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ebb604ee1289b475cb6bd411e972c68a17390bd59a08f2bf0171ed1e7691759(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DropDownControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e48fb275d6dda270ccf1167e8321070aacd0e881203a1c0c74a395a7efebde35(
    *,
    cross_dataset: builtins.str,
    filter_group_id: builtins.str,
    filters: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilterProperty, typing.Dict[builtins.str, typing.Any]]]]],
    scope_configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilterScopeConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b974c135517a956a54d1798d6a1cded03296e13b5d2939faad4af76a1cb0055c(
    *,
    match_operator: builtins.str,
    category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    null_option: typing.Optional[builtins.str] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8abf6a7704eac8483c2a9b81169ef7027a912c5d234ab272d9daa0a3d838381(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ListControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9288615b24c4f7a9a7f074e121e6e811e2e524049b19243814784b2b81345286(
    *,
    selected_columns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    selected_field_options: typing.Optional[builtins.str] = None,
    selected_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5490b40d7c62237df50c87f1ae3088084d263413035ee935290c574541f86a1(
    *,
    same_sheet_target_visual_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SameSheetTargetVisualConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5ec3a86d99768a1b2bd1ed74da1da68c4fcdc98b71db0a76af4dd3d698e1d03(
    *,
    category_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CategoryFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_equality_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumericEqualityFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumericRangeFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relative_dates_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.RelativeDatesFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_equality_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TimeEqualityFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TimeRangeFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top_bottom_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TopBottomFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5c9b044726cee5e7d0481c3871cd665c27926007e2b26bdcbe80a4ba9f8545b(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70a5f07709c49e9ea802a870316716ecedbe97516939a55dceba445d77cf6457(
    *,
    all_sheets: typing.Any = None,
    selected_sheets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cbcfc10d90502877786dae85b75d32aecd1aa2d996944b9890a28ab13bbe1369(
    *,
    values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__300315640c398eebc98d281ad0b8d598424a042f059c9a2e327e6eec203dbcef(
    *,
    filter_control_id: builtins.str,
    maximum_value: jsii.Number,
    minimum_value: jsii.Number,
    source_filter_id: builtins.str,
    step_size: jsii.Number,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SliderControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc536764886ec354b00eee87422c46819ed4f288594d069028faa6beff0c8492(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    delimiter: typing.Optional[builtins.str] = None,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TextAreaControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__160a2b14f69f63383b7675afc255198b7e38397f8278883db718b1c37320ae13(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TextFieldControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7d690fad0a2f6f831868512422f604b26b5221365d6878f0654a4e9a6686871(
    *,
    font_color: typing.Optional[builtins.str] = None,
    font_decoration: typing.Optional[builtins.str] = None,
    font_size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FontSizeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    font_style: typing.Optional[builtins.str] = None,
    font_weight: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FontWeightProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__780f10dfaa345c38c017c0745f17b71d06e7ff3ba11207f70c1a1f7a2c9a3bf4(
    *,
    relative: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46f74702553dccb4bfa142dc6d7a31cf148bc7c14f3675489d8970c4657eda17(
    *,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c92d9e711d8ae9f042a8e0269c5d1cb5d882fc89523e5544ee0ef11f92029973(
    *,
    computation_id: builtins.str,
    custom_seasonality_value: typing.Optional[jsii.Number] = None,
    lower_boundary: typing.Optional[jsii.Number] = None,
    name: typing.Optional[builtins.str] = None,
    periods_backward: typing.Optional[jsii.Number] = None,
    periods_forward: typing.Optional[jsii.Number] = None,
    prediction_interval: typing.Optional[jsii.Number] = None,
    seasonality: typing.Optional[builtins.str] = None,
    time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    upper_boundary: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55ee3f9c9949ac200dfb995903d71b28366ba3897b07124ed698fce60bc6bfc1(
    *,
    forecast_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TimeBasedForecastPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scenario: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ForecastScenarioProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18aee80c4c0b357676edee24744630662f9e337c087eadc389f409a3e5152fb0(
    *,
    what_if_point_scenario: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.WhatIfPointScenarioProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    what_if_range_scenario: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.WhatIfRangeScenarioProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__efcf1f5e9363b1373e5358c9586872769fcb3284c0ecffaec880cc8d92f7950b(
    *,
    date_time_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    string_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__698e8fd81e4aa68b07ce6cea19d4035e8a2f382c7e037a2a999ac4a10c1fad9f(
    *,
    screen_canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aaf6efb92d4cf93969fd221e0391d2751c34b3d74c2193f388a42438452b4c29(
    *,
    elements: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FreeFormLayoutElementProperty, typing.Dict[builtins.str, typing.Any]]]]],
    canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__adac39e36e75be1d2f7eaa4ca69f7f4e2b827196e4d531b052c4446fbcfafb87(
    *,
    color: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2267aeb863dc17444666c4d4c14c0d55a80504486991f6363d67db9ec700174a(
    *,
    color: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c154d668b63e927f0bd2b9f311a9e0b02b2a2db340096b0ad42a676a7282798a(
    *,
    element_id: builtins.str,
    element_type: builtins.str,
    height: builtins.str,
    width: builtins.str,
    x_axis_location: builtins.str,
    y_axis_location: builtins.str,
    background_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    border_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FreeFormLayoutElementBorderStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    loading_animation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LoadingAnimationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rendering_rules: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SheetElementRenderingRuleProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    selected_border_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FreeFormLayoutElementBorderStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9079092af38ceb7cdba1387b07783295f04fd5dc900a86ba153374da8a1e1222(
    *,
    optimized_view_port_width: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9e5c14817e88c14408adc420a17eb5c46f1c8a179df4ee1d49b5e998c0c37e2(
    *,
    elements: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FreeFormLayoutElementProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6af0bdb93ec1eaebe9fa6a0d12f67574de2b864cbe005104709a984c6c99fc51(
    *,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0ceb2f79431fef514821fc3b0a6b319b6a89b57cd69ecb43f4df332dad8681c(
    *,
    category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FunnelChartDataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FunnelChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FunnelChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__119735cd37500e682e128a306ae03b3fdcdac6ee732414d9a409f8107cafaa02(
    *,
    category_label_visibility: typing.Optional[builtins.str] = None,
    label_color: typing.Optional[builtins.str] = None,
    label_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    measure_data_label_style: typing.Optional[builtins.str] = None,
    measure_label_visibility: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12f1cfc87ca359e9f1f5bb1f72eb016743da084dcc2437c8e9537da5b96d2fc4(
    *,
    funnel_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FunnelChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd70df6fe2a086ff578149465483bb7a8c5202ed3429bf283bf9905bc646ae5b(
    *,
    category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__392520e04bb1b961d06bd10c924febe7d1e2b11a6d663bc25872e2edf5b1a760(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FunnelChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b374ec018743390b4521dfc3aa342f26565b8eb4ee0f053fd9791ff204e8f615(
    *,
    foreground_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f538edfa4fedce6e8dac39d02e58b25883f9d3571afe2e707d1157916af517d3(
    *,
    arc: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GaugeChartArcConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c6c904e3df29b8eac2d58a81cf044e707544a88d9ef2ac4642c3cd7406bc14c(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GaugeChartConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04e8e0e332bbcfd4f449ede609b0b25344f8501403e42ae88f789e995f285e83(
    *,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GaugeChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    gauge_chart_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GaugeChartOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac68757308c1ebd9814780dd8455cdfc4ee57167d6a012b4df3fc5ec4856eba6(
    *,
    target_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__526df1b911d4c47fec9f8cdcddd4a9d5050693feb76dd54539df1a51bd45c305(
    *,
    arc: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ArcConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    arc_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ArcAxisConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    comparison: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ComparisonConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_value_display_type: typing.Optional[builtins.str] = None,
    primary_value_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05cd51f4c2623976de54394f832cb186600ac7643d5d9e3215c098afd9a1fb61(
    *,
    icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db10659b7b6c7e891848e0cc3d42c70167896823fb2317ad92c10f5c8078ef60(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GaugeChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GaugeChartConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c69fee4597d6a6e52289c965dc69615cc99078bd4e55eafd2e189d0506ce8a3d(
    *,
    east: jsii.Number,
    north: jsii.Number,
    south: jsii.Number,
    west: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b2e1935b3f92bf7953fd6c5c1510e0db5fcfa10bdca91dc31934d137781b2ef(
    *,
    colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GeospatialHeatmapDataColorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec20340d5e164e926e09594b2dff74ff05b41cc216237f87e6b7673968fb66e5(
    *,
    heatmap_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GeospatialHeatmapColorScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ff0131f0ddc655a12db2314b1d42e47bee9e4b5ec3fe9c3c2d30f381303e986(
    *,
    color: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39dbfd9468a705a82826afd15f6f727c87ee9cdbf2a0c017e2c18c162a04f47e(
    *,
    colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    geospatial: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60d57edb34f563d63db66a41f0e9e2f72571d6fee2bc11156b17cabc0db57153(
    *,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GeospatialMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    map_style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GeospatialMapStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    point_style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GeospatialPointStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    window_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GeospatialWindowOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b35fb60d54f698e768871c04d9bc83b2ffdfeaf90be9c7d7a7ff855c373b6b0(
    *,
    geospatial_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da4c763b91dac10c5731141417c32a202a7ab85b5a46f08058fcc455d7c50aa0(
    *,
    base_map_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7285c62652ed38c015ec301e5d9f8177678997b524fd20a0d43c688fea50f1c(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GeospatialMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b8e51d51b46915c6e8131ab17aae68901c47973d9a47f99d3df8bf878210a2b(
    *,
    cluster_marker_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ClusterMarkerConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    heatmap_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GeospatialHeatmapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selected_point_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3701bb8b52fddc028e19d6f383a1ebd415dfc7d7e09e7d2aad6498b94016524(
    *,
    bounds: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GeospatialCoordinateBoundsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    map_zoom_mode: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__efd154cde8886acf419124fd05fb50e244943d8507a453540554430d066fb50a(
    *,
    side_specific_border: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableSideBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    uniform_border: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__764cda6c5613192b186c772a28cf3f3d3a8007ba7eabffeab1d3f89d1b4a0575(
    *,
    stops: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GradientStopProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f72df1511db50e88a6e0c8cdf93031107526c7cfa28cd63ca52e30a6d5ec2d4(
    *,
    gradient_offset: jsii.Number,
    color: typing.Optional[builtins.str] = None,
    data_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9032999c1d5c23a20c178ae6a0ea418c966b47c69e7e38db22e981a9eec9dfb9(
    *,
    screen_canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fde6163e0ef9c8dd6175bd498780f77956152c35734dc1dc27dcbefdd08a7ec4(
    *,
    elements: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GridLayoutElementProperty, typing.Dict[builtins.str, typing.Any]]]]],
    canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GridLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__307481ce8409315cf6663d7274d00b4e65eb0d0f6bc8595d43345f711f024373(
    *,
    column_span: jsii.Number,
    element_id: builtins.str,
    element_type: builtins.str,
    row_span: jsii.Number,
    column_index: typing.Optional[jsii.Number] = None,
    row_index: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__221750db38bb8676e3648a48a1c5cc108d0d3b29458039df5cfe92100370ce38(
    *,
    resize_option: builtins.str,
    optimized_view_port_width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba3a1d3fae573c9d9556225f15a510102810b06ed491a8765e3fad28f9ed47bd(
    *,
    computation_id: builtins.str,
    name: typing.Optional[builtins.str] = None,
    period_size: typing.Optional[jsii.Number] = None,
    time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35fc4e97fb490a88b80fcd818812b0805d66bda99cf40754fae7d8891edf0465(
    *,
    layout: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    section_id: builtins.str,
    style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SectionStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aeb3ce7bbd15d1a2dfa8706acb5ac470849c443e00789d502870a865bfbcb347(
    *,
    columns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    rows: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__949b7ee985e07924144c5df8e37b24bba5628cbf367269af4925c9846e69b555(
    *,
    color_scale: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColorScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.HeatMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.HeatMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3300b757c8e6e50e090686798cce09a8cc9ebb6a6bd46f7e6d686ff74f942442(
    *,
    heat_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.HeatMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4944be76fc7bcb2cc426caeae1cac5134fe30802b90c87dcdd9ebb9bf00a246e(
    *,
    heat_map_column_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    heat_map_column_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    heat_map_row_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    heat_map_row_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e923cce50a7350257179452cc78b6089af9611cfbaff594980761a3911f45b86(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.HeatMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74130651daf0ff3d0f9179df3cfa23ca1d80c9f7f98dba04a6eb3dd0234169bc(
    *,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4ae0c269410b7cca139ecef4fbf1458d675742c259682c6b6f9c33460bab271(
    *,
    bin_count: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.BinCountOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    bin_width: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.BinWidthOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selected_bin_type: typing.Optional[builtins.str] = None,
    start_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6dd1f42f6ea90a578204ceb138560811902ee27d218128f302a027eb5136062d(
    *,
    bin_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.HistogramBinOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.HistogramFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93a58fe1aec089289e51347f4e2f15663a5ef0b83ddd44b4a1716fbb42c19c2f(
    *,
    histogram_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.HistogramAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b9d5c9507d3323958409c1c9d4a9fb9fddaca4d0d02309f8baf8d0df465dbd8(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.HistogramConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b1f4686e9a6b17ff8f88eae015d754bae635d12717476852207d861895839dc(
    *,
    computations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ComputationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    custom_narrative: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CustomNarrativeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__254ef8f13eadc2eb0c8c2650c71c7477803594d57b8261e9bd8939491d1edeef(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    insight_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.InsightConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df75ce26bb2c4132a288b64c361aa58aee8d1bd0275f7f70da125f2c1384667e(
    *,
    dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4e46f79877c1d5ea7200cce72e4cbb3bda41b536d11cb23aee669ec7505903d(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.IntegerDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a95b208567e290650bcc53e94792f3f667e4fc822766c0c7c77ba80c05129063(
    *,
    name: builtins.str,
    values: typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13e33c685845db910a2cdb302f29c7dda9e37dd6927464bb7e458d04fc597d70(
    *,
    custom_value: typing.Optional[jsii.Number] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7837f741338797d7b367bd8f818d5d6f2f733c9366fac33fba11eea113da7c4(
    *,
    items_limit: typing.Optional[jsii.Number] = None,
    other_categories: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62fd79d6d6b83de52fd9c66519b63f99afe25d2524c06723daaf72c4fcb8b997(
    *,
    icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fbd6a01397645828bcae2c115e1d8f217c81792121ff843ce7c7a98717d66bbd(
    *,
    icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c47a8a963b224d51f9eebe235dee2686c303a35b7bb953424d4470373ae23c31(
    *,
    actual_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.KPIActualValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    comparison_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.KPIComparisonValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    progress_bar: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.KPIProgressBarConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__093405de0b0ece6949aa37731977a76c567dde63c113f2b4cf6d1fde67890b15(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.KPIConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7347e7f7d3e790a3415bf9ae796ab09590ea8b172cb4b5232d8a04a1224e09c(
    *,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.KPIFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    kpi_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.KPIOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.KPISortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2ab3d1139c92a9534efac3fb34060891ab135e5d400b370632c9f4961718d65(
    *,
    target_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    trend_groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14494fc1848bd55db71c296019baf22f78b5e68a3679d356c04f82b341453996(
    *,
    comparison: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ComparisonConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_value_display_type: typing.Optional[builtins.str] = None,
    primary_value_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    progress_bar: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ProgressBarOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SecondaryValueOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_value_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sparkline: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.KPISparklineOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    trend_arrows: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TrendArrowOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_layout_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.KPIVisualLayoutOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dda5b2471fce86de1f1bd82ecf7f9238e5c42052d573d16257139b9739a9e972(
    *,
    icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e03285437fef32f601a5efd046f8046ff96be24d19819f31f01d45934510eda(
    *,
    foreground_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e93019a993ee84e58e6d870f4d5ee82c10125c910ab2214510a26d9b3c471fed(
    *,
    trend_group_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3be4495469d6e19fe8ef384eec06f1df885d3447466904ecdffe0f7ac2355ebd(
    *,
    type: builtins.str,
    color: typing.Optional[builtins.str] = None,
    tooltip_visibility: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48fbce62cfa096a37c10afd1546006b403110253ae89f9ad8d55fc91cd7f6f30(
    *,
    standard_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.KPIVisualStandardLayoutProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d5d36bea3f6023d9c8597cca3babeb32cbeb0db83e22f9d75ccda908876eee36(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.KPIConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.KPIConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d68e110b12f2158f2717a768c70570e746f7d8a26d6352fb02468e589306879b(
    *,
    type: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43cac7e826338cc7ef6b1274b75855f2c64aa3f565868ee802e58284861f9b22(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42b1d13e0d93684e8246d6f5cefcdf9b4d463c7b0c1a53be36ad708b74065fc2(
    *,
    free_form_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FreeFormLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    grid_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    section_based_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SectionBasedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24b97aabe72e04ae9d89a8fa6e9fa491403d4b8cfcbb7ff5396d3725df5e83c2(
    *,
    configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48c8ae8b06a6c4e8b5a9c55d8d55df5647a9884b662ab141ba34300e08b77046(
    *,
    height: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68f9310cfaab3eacca20f4fe82f1c526cf71f490e0bf430e6f0efeb8728bcda5(
    *,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e4502981ca8885c526c0c955a0d5f3d3b8508216fe092b6d829c86bf6862b90(
    *,
    contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    default_series_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LineChartDefaultSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LineChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    forecast_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ForecastConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LineSeriesAxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    secondary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LineSeriesAxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    series: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SeriesItemProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LineChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a5a7d0cd55f4d54e05c5d22c88d2a1adabfaecff26e9671f1d691b1a6545d12(
    *,
    axis_binding: typing.Optional[builtins.str] = None,
    line_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LineChartLineStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    marker_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LineChartMarkerStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e43be70b1c36384b647ea13ae980a10f1ecafa0ffa642d90b02785ad8c9efd4(
    *,
    line_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LineChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3fc3c5f5cfe1e65e4cb7ba3389c83c14e1094b948d8f635c80339d44a8a87e5b(
    *,
    line_interpolation: typing.Optional[builtins.str] = None,
    line_style: typing.Optional[builtins.str] = None,
    line_visibility: typing.Optional[builtins.str] = None,
    line_width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b81789298d598d65075f668b5d50e8064e42add88450e3a59131c2e9f601952(
    *,
    marker_color: typing.Optional[builtins.str] = None,
    marker_shape: typing.Optional[builtins.str] = None,
    marker_size: typing.Optional[builtins.str] = None,
    marker_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__719b2ae1f716ca1978f946cb87bb19acac4b968b72ca7e4528dfa79b485ae933(
    *,
    line_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LineChartLineStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    marker_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LineChartMarkerStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff6d65ce53fd5502b502b61555bb7c4fedef0ea515b369f50ff903626e398eea(
    *,
    category_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdab8c410a0336e9ae1bb1bf86f581d932f24bb158be83ea0ff9f4927382b4fc(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LineChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__785381c00bdcd271c76ce148cd8e40602b2901db410eb397ed365fa6f89973b4(
    *,
    axis_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    missing_data_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MissingDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11d6276e4ba5436512b67cd6bf0cabbf0596e0531ba8962545576b3e67f326f4(
    *,
    info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SheetControlInfoIconLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    search_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ListControlSearchOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    select_all_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ListControlSelectAllOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f576914c1297ac516dbc6dd540a06cc81aa553b79cd3e449979af00a754ce442(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1fe92e2b8f7160aef769b651c7fa4273580fda6211aa73a1cf91b6634fbf3239(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93b5b2ef7375666d961408b29bf636eee1853366f4448ef58a64b828fd415ae0(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5df000507cfe706fe7cdc113ae0477d02c3ec38758dae029987c2a222a87b37b(
    *,
    target_sheet_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25972d14881d2916d8f2106914671470333465f27bf4d55f09f2241af6a1b1ea(
    *,
    plain_text: typing.Optional[builtins.str] = None,
    rich_text: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3bb16eb58d41f3a41812e41ea150331419a4965847be9bae55002d381b03308a(
    *,
    data_set_identifier: builtins.str,
    data_set_parameter_name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__286c43f9a143ec482dc3f27f678e5b04b0874c082f9b3e87dcf41eebe0b99f33(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91509d04a0e8ae4917832fd46882ec304495325653d7e06f260ef76a23f38651(
    *,
    computation_id: builtins.str,
    type: builtins.str,
    name: typing.Optional[builtins.str] = None,
    time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__912ecd28ec0047466f479d848db03397eb408315496ae14d8c424d1a04107006(
    *,
    calculated_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CalculatedMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    categorical_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CategoricalMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    date_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DateMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numerical_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumericalMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50bb05b9db78e8a22fb074f318a4866d592109593030fb6706a040baed1f2206(
    *,
    computation_id: builtins.str,
    from_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    name: typing.Optional[builtins.str] = None,
    target_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee324b937890d03d5a527a28a012b13e6020cd2133e1e8c889d87abce930afa5(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75ea413e2315799674d8c1d76cbcf36d232cd3a0684dca86ab92e2b289e560fc(
    *,
    treatment_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__793176bb726227d6768a798703e6f55c058d7fd7161ce55ae77842a75b0869c3(
    *,
    display_mode: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6accfef980def7683166f161eccc3f4a0a522aa91f8b2fa7091e4657cdd10079(
    *,
    null_string: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d380b69e23daf3c044546cdc60f14115db7d64c7d369b74fcf220fd554be2a3(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    negative_value_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_scale: typing.Optional[builtins.str] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    suffix: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1239e4ae15d858e0b513656d1ed9b69c68f9c3e40fce2226f8533bb5b3b8b919(
    *,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6a23def5664c62fb5c22d6673c08d3a48e1204498d14f7530509b276a64bbda(
    *,
    range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisDisplayRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scale: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5f75b38709c3141a0ae29eef4d16460261d12ff8569c81cceae3f651568cb4b(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28c9e7c1d69e0ffde206a0f71403aeea3130f5112ee45c6c70db7fca94d22408(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    match_operator: builtins.str,
    null_option: builtins.str,
    aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    select_all_options: typing.Optional[builtins.str] = None,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e32dd597a791c590be66197299edd4ff20c24b7a392a55360ff88c62d5848e5(
    *,
    currency_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CurrencyDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumberDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    percentage_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PercentageDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22121b996d17d1f69aed09532525dd7473a2a7435181784f7a383c84827a4a8b(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    null_option: builtins.str,
    aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
    include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
    range_maximum: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumericRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    range_minimum: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumericRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94b66a9875fdff413b818df8868b864ccb89e25196ca329ba757670f4eabf6bc(
    *,
    parameter: typing.Optional[builtins.str] = None,
    static_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35127550d5767c629ae21cfca2c3501eee97480296df3162a9d4444efcfaa787(
    *,
    decimal_separator: typing.Optional[builtins.str] = None,
    thousands_separator: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ThousandSeparatorOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3699075a07bdf0da1b9b1cd6175755a4f1bd3ab16ec2487d515407f560ee9c4(
    *,
    percentile_aggregation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PercentileAggregationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    simple_numerical_aggregation: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c884448e58886a2cd093fa60765ed534cb3ce6ccf9f4e7726904392be8fb1a88(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f1c6489007cf21aeca1aed2e4c6a71300c68f91d9e433f5b58d4cbba2ef0f73(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f399c1aaf81d1ec0b93e1de9bb2452d78823166b84f409c470082903a9007a7d(
    *,
    page_number: jsii.Number,
    page_size: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62ff6dc42b0e964ae6d9aa22bd3fa707ca34b4bf7933246833e06ab836a72bfb(
    *,
    background_color: typing.Optional[builtins.str] = None,
    background_visibility: typing.Optional[builtins.str] = None,
    border_color: typing.Optional[builtins.str] = None,
    border_style: typing.Optional[builtins.str] = None,
    border_thickness: typing.Optional[builtins.str] = None,
    border_visibility: typing.Optional[builtins.str] = None,
    gutter_spacing: typing.Optional[builtins.str] = None,
    gutter_visibility: typing.Optional[builtins.str] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PanelTitleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__420cc8bf6553fc030a994a97a56037a8c6ae2dfd085c7e8ddfc6446751aca562(
    *,
    font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    horizontal_text_alignment: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60327b150984223494769cd6a0d97c0e2e6eb3b5c17091364485d519da83f42b(
    *,
    date_time_picker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ParameterDateTimePickerControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    dropdown: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ParameterDropDownControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    list: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ParameterListControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    slider: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ParameterSliderControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_area: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ParameterTextAreaControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ParameterTextFieldControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b947c55505b1138b27122fbf28b6cd6397c31aea7b933155d1fdb1b62181cff(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DateTimePickerControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7f9503f996228753475510f1868569a83191bf0466dca548b445ea0134b6200(
    *,
    date_time_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DateTimeParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    decimal_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DecimalParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    integer_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.IntegerParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    string_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.StringParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ffee6e4397e03ece63c1d82997f046791b6c95a0aed66aafa947c2c12873d70(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DropDownControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ParameterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46c6c2e726ece85a94eaed4b6a42b2fd10c25b40e9a848649b6e8f7479005e28(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ListControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ParameterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9db77e230e585a4678dc0cb2fab8d12e011198969384173fb938948f444397f(
    *,
    link_to_data_set_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bde7f633ffe57c8bd9fb30ef7b449ee66036bed77faa582e75a4aaa49ae2ba4e(
    *,
    maximum_value: jsii.Number,
    minimum_value: jsii.Number,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    step_size: jsii.Number,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SliderControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__242e7927bb747c15898e306165b8b35c0c02c95070a0e16d9596fbeb66e6a5f0(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    delimiter: typing.Optional[builtins.str] = None,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TextAreaControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0cd8bb9ad011a95ad6fa12b6fe0e13c2fe9df3921fc471bd6b9e0031cead6374(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TextFieldControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c42f460c9d73b0fdb3e26fa1e8f471087532a0157acd6382fae430e5636b95bc(
    *,
    date_time_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DateTimeParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    decimal_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DecimalParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    integer_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.IntegerParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    string_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.StringParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6cbf715fdd3a2e720ecfa77cee9035e99c3b3b01308a907e8a1885bbf22db2f8(
    *,
    from_: typing.Optional[jsii.Number] = None,
    to: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57ce990bfa06d51987647cf514f9a8e16fde67d724df4f7d2cf788dccdb93125(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    negative_value_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    suffix: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__049fe0843ccff40544d214fb7ec1f9bafd5175190fe04d33179dc68fa17e8a2d(
    *,
    percentile_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19abb806312347d369d990a7bb54b20d3a7767497ca5fc56c09168efbc1ffb70(
    *,
    computation_id: builtins.str,
    name: typing.Optional[builtins.str] = None,
    time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe85ace06e99d6c2d932a6aa27764fdf899d91a8fa36393bf94f4d593596c62f(
    *,
    computation_id: builtins.str,
    name: typing.Optional[builtins.str] = None,
    period_time_granularity: typing.Optional[builtins.str] = None,
    time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b55211ea304f1ba435ed044a6533c8f5fd12bc96eb05251261916d02bb93fd55(
    *,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06e6889a741bd706b6aa9c48db14c01e76697b34f5e2500f53c7f3657475fca4(
    *,
    category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    donut_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DonutOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PieChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PieChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab54105dabb13e29c9576abcfa5bbeb882c91302b0041e5ea9046cf95659429b(
    *,
    pie_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PieChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a198c936c49f9e68a2f73d8d57b554e2757aa506639569158c4fb5f01fc27ea5(
    *,
    category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87e7c14dfca412c496b31d4eab981e0d21211ce4789fd4bf0fce546b17f97846(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PieChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83e21cb6b3c5836506b0141e8fc413cc57cc44830800cb3aad9bb415285d817e(
    *,
    field_id: builtins.str,
    sort_by: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTableSortByProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99497a9dc0b93024e0ed1774ff7c52e31641478c8255b5451cd89c08495cf683(
    *,
    columns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    rows: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__092c32f9e13e00666ba0509805eff7259870fc11c01a190b4309dd640ba880d7(
    *,
    field_id: builtins.str,
    scope: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTableConditionalFormattingScopeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scopes: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTableConditionalFormattingScopeProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    text_format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TextConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22adcc402876cc329159f35f7bb36f2c228bf514ddc3d120c6a13c1742c1dd76(
    *,
    cell: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTableCellConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e648166813ac500d0d524b4ef391d6c6d4bbf3fb791b9d966ef0fef150b01f7(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTableConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce31bd45e61e635a94490d1892ae11b119c36b6495f844c1222db3409df1a886(
    *,
    role: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4434f54ddcd50c24d2ee3ebd81aa73e692d8e676fbf16df83642137b261af73(
    *,
    field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTableFieldOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTableFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paginated_report_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTablePaginatedReportOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTableSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTableOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTableTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2dbcae52b863a76a15d188d1ac324b673884416c60cada64111334eb0d006c5d(
    *,
    data_path_list: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]]]]],
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6bbb18f34d16d53e931277e5afae73f4b2e5db3202f4afd6ccec4f44f44128a0(
    *,
    target: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTableFieldCollapseStateTargetProperty, typing.Dict[builtins.str, typing.Any]]],
    state: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df673c36b8f0e452dc6b082c849ea50fe2fdafe3aea57e30666bd146508b9b94(
    *,
    field_data_path_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    field_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a93e7598f842be1c4206dd58bc937dd54c6815dc3bbbbf57f27c2727cc4c7b6(
    *,
    field_id: builtins.str,
    custom_label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f91436b5f1fd818eea1f37d669c26e7d919a8a787b97ec680904837320b7c12a(
    *,
    collapse_state_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTableFieldCollapseStateOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_path_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTableDataPathOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    selected_field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTableFieldOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__466ef70e11d0eca6ffbed8c594fa2e80b8aaa8db73225578e9dc0ba0b2acd5dc(
    *,
    field_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cbc3fbfa45d45d972e8d1a693a9dedd631616b09d2367fc9eae8c64c3fe4998a(
    *,
    pivot_table_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTableAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9531b24d9fa16286d9c2255b197252d964a583a8ba3a64d974d6bc5a5bbba143(
    *,
    cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    collapsed_row_dimensions_visibility: typing.Optional[builtins.str] = None,
    column_header_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_names_visibility: typing.Optional[builtins.str] = None,
    default_cell_width: typing.Optional[builtins.str] = None,
    metric_placement: typing.Optional[builtins.str] = None,
    row_alternate_color_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.RowAlternateColorOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_field_names_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_header_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rows_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTableRowsLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rows_layout: typing.Optional[builtins.str] = None,
    single_metric_visibility: typing.Optional[builtins.str] = None,
    toggle_buttons_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__044288d5534df62c8d1c60d17271f802eb72d58a59aacf39863d17e461ea9959(
    *,
    overflow_column_header_visibility: typing.Optional[builtins.str] = None,
    vertical_overflow_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b28f39c728a912f7a1db539ae54a7e0e4532f76d89484bde663e8b6b61d2b72(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd98202b9ffefccacfbe39eab82674f0d1789ca78a912eab1bf89ace900c613a(
    *,
    column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_path: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataPathSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__201fbaa4313fc073bd3c5df27f6936d11ff61a3f79b8f970642c8f7a5d55b055(
    *,
    field_sort_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotFieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76b32a5384b9698f8fab50938b7df243ef7deac4a95d356fb266adac4a406177(
    *,
    column_subtotal_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_subtotal_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5bcca7d2b66c29bee62ccb437cd3f4de82a019cdaff497b5160d61a7c99cf19(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTableConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTableConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c081b5f6f16d592bde87159b2375816297265c384b4198d9e8464f37d56d3635(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    metric_header_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    placement: typing.Optional[builtins.str] = None,
    scroll_status: typing.Optional[builtins.str] = None,
    total_aggregation_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TotalAggregationOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    total_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
    value_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__954204a704fcb35949afef9e42af208d2e15803f6ce4c3c70c77e2f6ca629ed0(
    *,
    columns: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]]],
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d2a0d75dfef36d1e1bdd541b1b87ca5099f709e8e2dcea66428e7aaed8ff01b(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45f39c45ac242411b7c269731f281995cb8e54a35969dbceb1ddd3b5ff128800(
    *,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__81fc0fef972e910af62d17fd49f01ae9efcf62b169855fa0fc18045fbb5635f5(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96a7d9a8bcdc51262f1a45bdf1dd0522bf5be71c987ca3a4e3553326870dd66e(
    *,
    alternate_band_colors_visibility: typing.Optional[builtins.str] = None,
    alternate_band_even_color: typing.Optional[builtins.str] = None,
    alternate_band_odd_color: typing.Optional[builtins.str] = None,
    axes_range_scale: typing.Optional[builtins.str] = None,
    base_series_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.RadarChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.RadarChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    shape: typing.Optional[builtins.str] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.RadarChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    start_angle: typing.Optional[jsii.Number] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__453e7f7618881f8a73c114f6e2fb35e3341662dd7fb53a09c4c3ccefcd192d4b(
    *,
    radar_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.RadarChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d324e35f5d4ddf9a4b1566fcfbb808c9b2ac1accd4ad7e6a8f3389267b9390a8(
    *,
    area_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.RadarChartAreaStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2937e11266a0001836817467942d2259f27288bb64d2a75a32c17c3fd81fa9c(
    *,
    category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb550baaac51820f5bb336fd8259e463a83d8083d629dc5cc76d779c3c165fbb(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.RadarChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5fc9853b1f5e62f28eb13991cfdc6d455aa5e01eba6d6fa5c718163e99d91e68(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9dbe4a6d4fe26dc2bb54aeae720796e32e7400656f367d2720d0db312db674a4(
    *,
    custom_label: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1cb097a15cdcf0fb69d650791b2ff1429bb0aa7e52a91254b4770b80c29121d5(
    *,
    axis_binding: typing.Optional[builtins.str] = None,
    dynamic_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    series_type: typing.Optional[builtins.str] = None,
    static_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ReferenceLineStaticDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c5c6f098cca8f793d79d54880ab08cb572654f3456afcc7ef4d420b197d6613(
    *,
    calculation: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]],
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    measure_aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5bb1f9557aa32bcc5aa2306bd1df9653caa2016d934f038d1e82434c441f59c(
    *,
    custom_label_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    font_color: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    horizontal_position: typing.Optional[builtins.str] = None,
    value_label_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ReferenceLineValueLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    vertical_position: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a08f19110bc4edafd30ad79e373cecf086f672f8948ddaf1d1cc441e3eeba33c(
    *,
    data_configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ReferenceLineDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    label_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ReferenceLineLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    status: typing.Optional[builtins.str] = None,
    style_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ReferenceLineStyleConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d18223189006e114ac4efa7ab47d49cd5392f3d633768997b28d258d6f23b6df(
    *,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcc94f78c7d9a63e188d0568f4e7f6b13b9a7454c4d317983a824e2f8a44a8d7(
    *,
    color: typing.Optional[builtins.str] = None,
    pattern: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a46e5945af0e46a2dd4cde0c3feef1396df82d6c7180394ec12586329475418(
    *,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relative_position: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7019f6ccffd795caef1cac5d1319ebe3300486c56f97572d179ad59e690d616d(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SheetControlInfoIconLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7cf02371d12b49ad2afa25a53a6f5e622eacc7d10a4db18e560ce1298407017(
    *,
    anchor_date_configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AnchorDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    null_option: builtins.str,
    relative_date_type: builtins.str,
    time_granularity: builtins.str,
    exclude_period_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ExcludePeriodConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    minimum_granularity: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    relative_date_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3fc259c5b8c788d6d869a47ae793532e020a49da8fe79d4b395dbea801e2a2ba(
    *,
    actions: typing.Sequence[builtins.str],
    principal: builtins.str,
    resource: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__072c8a685207594ee5bd1ecf5bae08b2827f5eb3a7072e1e1cfca7c4232a9211(
    *,
    expression: builtins.str,
    data_set_identifier: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c070161f43d2fc8edbe9d6c68b6eb5cfbe06a5ce5598e138dc0991c22a3d58c(
    *,
    row_alternate_colors: typing.Optional[typing.Sequence[builtins.str]] = None,
    status: typing.Optional[builtins.str] = None,
    use_primary_background_color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89e526567fb30074913a6862beafdb279487dfb95d0b6fdaa90fef9496e03be6(
    *,
    target_visual_options: typing.Optional[builtins.str] = None,
    target_visuals: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50299c6f810ee6463d3f47777302d443da6a8c9db881dd5c4375616077b89b7b(
    *,
    destination: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    weight: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5a5533c4ca22fd4d80f034a87056d31f75b96e2deb491503c35d0a60209168b(
    *,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SankeyDiagramFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SankeyDiagramSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4059e9b42014a9d3db916fd3c4db2cd2ebbbaeb44fd25b78f27646655e3599b(
    *,
    sankey_diagram_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2bfb095608374613b7cc02d318d9945afb9ad79d77907c4fa782441e3bf54a9f(
    *,
    destination_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    source_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    weight_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2353770320f91671da6dd30bf1a1d0bf55664663dc4fe05b4ac973a2aae51ca3(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SankeyDiagramChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__faa44e5cb215d7adb725a5c8a0f77e69ca1295ee1a5d6ff71800b7da005fd513(
    *,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    label: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    x_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    y_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d3558e5a1dd91d7ad934b186aca3f342288f486c4aa011b888c3a6931ff09ed9(
    *,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ScatterPlotFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7e7a9e207db7329012d816002b5869adc45404d6f220108d397752c7de99343(
    *,
    scatter_plot_categorically_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scatter_plot_unaggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__324ea17b5f516a9f672c539911f13d7467cb4a350317a6326e8a1c5b4fe4b068(
    *,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    label: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    x_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    y_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad04c34cf5d4ce97fd40417bbbd85dc659c5df4f5b628ab84eec51d046d328de(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ScatterPlotConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__faa25bee43d1791f93596ed4633b3a4c843fb3d5965d93b28ebd221e6bc3af57(
    *,
    visibility: typing.Optional[builtins.str] = None,
    visible_range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisibleRangeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2dd76bf736d3e5632977889f5090daaf4044ab1614c1f86c6ef522aeb640104(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__88ec9551bb5dee706cc3d3782ed825d3dfc9f41b36092eeb3ede128f138774f5(
    *,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__777bb33b4832168efefbc4ab232bed80c935c2e9eacbfab8c276b6340a5546a8(
    *,
    paper_canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a3267d1b6d1fbe17cee04ffdf5ff17a7fe7df847cc8e442e054953efce15a4e(
    *,
    body_sections: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.BodySectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
    footer_sections: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.HeaderFooterSectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    header_sections: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.HeaderFooterSectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d590df6a368659c4d4ecfc52def43dec31727bec51d00dd7a438e813b6e2afd(
    *,
    paper_margin: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SpacingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paper_orientation: typing.Optional[builtins.str] = None,
    paper_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c65f04561e71fc4a19fb3d1ac1cda84e2a78daad416381565d1349cf083a67a(
    *,
    free_form_layout: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FreeFormSectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__defdb7bfada569e5f2c1020b3a96bb6774eafc9634dc86cecac3628e230ee973(
    *,
    after: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SectionAfterPageBreakProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0697b4fa2716229534da9c6fee84dc9de18d7d03738eaccc0fdafbf7fd495793(
    *,
    height: typing.Optional[builtins.str] = None,
    padding: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SpacingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad9033f84e25c4425f427965b03952db637cf11d92af34433afc52b7b5b47b49(
    *,
    sheet_visual_scoping_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SheetVisualScopingConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__efd787a350939d10901b7e5bc810e65e208713666be87e6829df664426981f1e(
    *,
    data_field_series_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataFieldSeriesItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_series_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSeriesItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aedce8df67ce22c917db59aef867b8fd6bf5034c72d7f80f6675439d8dd08681(
    *,
    destination_parameter_name: builtins.str,
    value: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DestinationParameterValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e0733bca0c1f8ee8fc46df84996390623d311b8ecfd7b77b2383d22ceba53b1(
    *,
    background_color: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e353f2a6a8caeb0e2a758cfd608d620197c3071f69d05e49e318aa117caadd65(
    *,
    info_icon_text: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__900d3a0a0f9ea5d3eea4d1ad691a3d9db273acdff56340a1125779a252a70e4e(
    *,
    grid_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f533c8857e8a92377dea47384ae82306d231e834285a3024834fe22049d4c79(
    *,
    configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SheetControlLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__444d28cb486ba1164dd020bc7463801728002da0058ea20910a57c1354b73fbe(
    *,
    sheet_id: builtins.str,
    content_type: typing.Optional[builtins.str] = None,
    description: typing.Optional[builtins.str] = None,
    filter_controls: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilterControlProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    layouts: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LayoutProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    name: typing.Optional[builtins.str] = None,
    parameter_controls: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ParameterControlProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sheet_control_layouts: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SheetControlLayoutProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    text_boxes: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SheetTextBoxProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    title: typing.Optional[builtins.str] = None,
    visuals: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2454e8a4231cee409a6a522180530bb5a80782f7d884021fa3949718ecad255b(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2edb43696086015de50681bdc9e50bf3a95081b0bf9af02af8a8c2bd38fc7c88(
    *,
    configuration_overrides: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SheetElementConfigurationOverridesProperty, typing.Dict[builtins.str, typing.Any]]],
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc7433bf24865199eabab7626a356c448f05a915887952c4a2780712050f4f7b(
    *,
    name: typing.Optional[builtins.str] = None,
    sheet_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c11f3c0decba2e94eb6cd10f2ebc916ccb6c9fb2b5a2f1337a971d1e0c1b2502(
    *,
    sheet_text_box_id: builtins.str,
    content: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f871c830482a742c2d47597062ce7160448858d0eb4aec9ca1323c6d3e2c1e3(
    *,
    scope: builtins.str,
    sheet_id: builtins.str,
    visual_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8acbf14306b0d4386ff90d2e8d282f658306641e2b39833e7dfaa076d1ef7d0e(
    *,
    plain_text: typing.Optional[builtins.str] = None,
    rich_text: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f4a055a47f0538eca137de3275943606ae2840c4df9da8eba48407751bdd907(
    *,
    color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__680207b3c486d874ece8a1090dd922474d41adabcd8426ad4ea5182a9ebb18e6(
    *,
    info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SheetControlInfoIconLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__525e3f793bfdedaa2c2a78f882fd6dbda738d0988a76cdc5055da1facf015a90(
    *,
    placement: typing.Optional[builtins.str] = None,
    scale: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d76f5307fa5855024b7b03891a98f0c653788b08e89ee70e480b9a224693d673(
    *,
    max_visible_columns: typing.Optional[jsii.Number] = None,
    max_visible_rows: typing.Optional[jsii.Number] = None,
    panel_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PanelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SmallMultiplesAxisPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    y_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SmallMultiplesAxisPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93a9c0b71a789a9a6753aff39c48b82714e50d6f70f27de79485d7ff5004650f(
    *,
    bottom: typing.Optional[builtins.str] = None,
    left: typing.Optional[builtins.str] = None,
    right: typing.Optional[builtins.str] = None,
    top: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b359254c6f8fe384458a61511ff8ae0a2c3bd5a0c9eaa89cd1e2cb9ec767be0b(
    *,
    dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68653c83770caa5cbfaf25386c1832c4e54fceae84611a32d57ed2743fcd99ec(
    *,
    null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b44eb1c0291cf5dd68a2688e3a71e5e58179106f24cea169041818bae36610f9(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.StringDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.StringValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ec4069b8eaf48d878fb98ab75830bf982b6f3ede4454ee340b48ddf71f0e7ab(
    *,
    name: builtins.str,
    values: typing.Sequence[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e595612b4356f9a83c2c2ace559c78cf6e1e88c93f5cfe5e11fb120a37b83cc(
    *,
    custom_value: typing.Optional[builtins.str] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e930f8b6f4e75f7f203526058e059dfd426ce57b19160806172e87de2f679a65(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    field_level: typing.Optional[builtins.str] = None,
    field_level_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTableFieldSubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    metric_header_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    style_targets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableStyleTargetProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    total_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
    value_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7df4c749435be88997e66195988368c40ca30a0927a406feb41c9ba653148ada(
    *,
    group_by: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51a8c2b6852c2d23b50f95cf588e45c481a2eba16e9778d2f5697f3d8862df0e(
    *,
    color: typing.Optional[builtins.str] = None,
    style: typing.Optional[builtins.str] = None,
    thickness: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9139deb319cc7938945526cf487e4625cb693d034ef0c8dc39f3bf43dc32057(
    *,
    field_id: builtins.str,
    text_format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TextConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b3e711cb7976d7cd94bddd7931f5b7a74e1a8c6a200e960995c9f19b3af8dcc(
    *,
    table_cell_image_scaling_configuration: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdcbd7af1c2204ce271393208454e9f0e2964ff896f50f21f6f3583b1f8d1556(
    *,
    background_color: typing.Optional[builtins.str] = None,
    border: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GlobalTableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    height: typing.Optional[jsii.Number] = None,
    horizontal_text_alignment: typing.Optional[builtins.str] = None,
    text_wrap: typing.Optional[builtins.str] = None,
    vertical_text_alignment: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9cdf869d1249d677d97a668a3b96be6e28a187fb43ef3eff78363fc4a3537c69(
    *,
    cell: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableCellConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableRowConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4fccc271167ce71a03385d6677025882f8b2d3b5c01722d7d6e82fcb541e4f15(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d479d7b59ced444940f30c08826632cf29685d2eabe615aa98c6e35d7f7df7c5(
    *,
    field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableFieldOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paginated_report_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TablePaginatedReportOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_inline_visualizations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableInlineVisualizationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    table_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d772be5cbd5e3987bd745c9b0f10ee81bb1f29b601e445782fc139f81b5f388c(
    *,
    icon: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3db2acd9e14cb038b557d6e50e2d21b975a89f5a46c9c38448db432d3a57287(
    *,
    font_configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3ef444ac27c5feabed3f7957db9f333898dfc2b6548f21156f6d020aaf37aad(
    *,
    sizing_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableCellImageSizingConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be14eae3127037193252ac11a55fa9913ef8bc09d02cfe83885f57966dda16a4(
    *,
    content: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableFieldLinkContentConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    target: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f9166017a92518eeedadfbe16d02a0d969909159406cc6155ffce3aec828478(
    *,
    custom_icon_content: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableFieldCustomIconContentProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_text_content: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableFieldCustomTextContentProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e2fbb1b2e487ba844b115dc8c6c8e9e7d13396a1c9163a272f6cc5237232a28(
    *,
    field_id: builtins.str,
    custom_label: typing.Optional[builtins.str] = None,
    url_styling: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableFieldURLConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b1581ac01a2a6068fe7519e9017b2a7cf534ecaa479c68cb2a0e30864b41438(
    *,
    order: typing.Optional[typing.Sequence[builtins.str]] = None,
    pinned_field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TablePinnedFieldOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selected_field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableFieldOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3fdea35643ddf9297e747860efc7c7229baa86dfc971776257b482e1f652762(
    *,
    image_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableFieldImageConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    link_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableFieldLinkConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd14fef22d98862a207b478c3118cb9f6030eb2fa414716578f4b629aab25e71(
    *,
    table_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_unaggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableUnaggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__810e05c0a905353900a83e8ee198d496eeff6cbbf388cff25e8ac22b0c3e6541(
    *,
    data_bars: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataBarsOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10fa49cf346714935975a4b77d4bf031a5df3e29edbc8792455f5863265ead89(
    *,
    cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    header_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    orientation: typing.Optional[builtins.str] = None,
    row_alternate_color_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.RowAlternateColorOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea5c6548516cd73443b2c8ca738d90c5d45f6c6d183d60f11d28d228b404cf20(
    *,
    overflow_column_header_visibility: typing.Optional[builtins.str] = None,
    vertical_overflow_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77c1903cf87e0cd86e49cbaf852606e51b0ebc014ef8e0eec7540fbab943946e(
    *,
    pinned_left_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7158087ab33dc66b9914fb7e235c4a5085d753991dc219088d154df66fa5a712(
    *,
    background_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f92106246e4f4db8102d1f6a7103f1060c88395281fc50e23c4618493e511906(
    *,
    bottom: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    inner_horizontal: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    inner_vertical: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    left: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    right: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d0cde3a0e979aba1c778ad7af547de4a799a7f027a559f18325130fe479b6b1(
    *,
    pagination_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PaginationConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe62e22e099a5ed5a887a278cdd3fffd1bdb6a32c6ef3727c7eb6d076dd2e880(
    *,
    cell_type: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__01dccc33f12dd41827ae118d6858cf5b812b7596731ca5d9b1f4ec62401d1ec8(
    *,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.UnaggregatedFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b1d32cf007ed6361655217afb26978623793bdc6386c3378e333494bebead8f(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62227d81d7f79659a91b57c80c2d9b79fe22947cd125b71d46f55315864adae9(
    *,
    info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SheetControlInfoIconLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    placeholder_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TextControlPlaceholderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__82cc65cd3f6af3cdc1a4cbff102520a82c4a8f0581ff816803ef4d21615908e1(
    *,
    background_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b0c4784d2a7a0eac281890ccc7318934a741558158cf58bfc2f756d599d014d(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c69caedc5c0054033434114a10cc23c28a2ca34b55f79a221720febf8966ca66(
    *,
    info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SheetControlInfoIconLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    placeholder_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TextControlPlaceholderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22d4a6cb9abc6ec1f35afdb861c719850a2d5d1aa38f4fb1ab6f4d14a2d652b3(
    *,
    symbol: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2b183c9976b41cd50bef5eef0913ff9e90922c570ffdf3211e59c9555b9e513(
    *,
    lower_boundary: typing.Optional[jsii.Number] = None,
    periods_backward: typing.Optional[jsii.Number] = None,
    periods_forward: typing.Optional[jsii.Number] = None,
    prediction_interval: typing.Optional[jsii.Number] = None,
    seasonality: typing.Optional[jsii.Number] = None,
    upper_boundary: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5261cc45c74d4595359f0c36c5f0cdfbb6bd77676f6a05b1da5cc5e3c1cad0a(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    parameter_name: typing.Optional[builtins.str] = None,
    rolling_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.RollingDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
    value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31707933e62e4bb441ca44e793fcd7b850d92ec40f8afad5fbf0866039c76e35(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    range_maximum: builtins.str,
    range_minimum: builtins.str,
    time_granularity: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f8ccf49248be5697abf1c959c4220e99d49abb8c65dc25bb44e648bbeffef1f(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    null_option: builtins.str,
    exclude_period_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ExcludePeriodConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
    include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
    range_maximum_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TimeRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    range_minimum_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TimeRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5ac68f0a19c8f46798572c936b379a0a7776666dd4ebfb8c3fe1acf6fa17f40(
    *,
    parameter: typing.Optional[builtins.str] = None,
    rolling_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.RollingDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3289d94cc42dcc093fdc87e358875e83c5c1ce3e66b270faeedda2c33b7bca47(
    *,
    column_tooltip_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnTooltipItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_tooltip_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldTooltipItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c83462475afd4a1e5f404ecaa84f1b3a88d90c73412b37833fc1303e8648a85(
    *,
    field_based_tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldBasedTooltipProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selected_tooltip_type: typing.Optional[builtins.str] = None,
    tooltip_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__797cab8d6c63536edf46d79183956235577ff52f6151c755628360993af35153(
    *,
    aggregation_sort_configurations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AggregationSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    limit: typing.Optional[jsii.Number] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8add4baf39d0c008085931a458a6dabc8a0398f7d526ac3812f3fdd977c6ffa3(
    *,
    computation_id: builtins.str,
    type: builtins.str,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mover_size: typing.Optional[jsii.Number] = None,
    name: typing.Optional[builtins.str] = None,
    sort_order: typing.Optional[builtins.str] = None,
    time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28735e743dd0651f6b742574ac00814fc1a0f6d214e1106c81085facf5ef67a1(
    *,
    computation_id: builtins.str,
    type: builtins.str,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    name: typing.Optional[builtins.str] = None,
    result_size: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__32f39adfbd8ec8fb473b1a5b4ed6c65df8be4d61566a8fbfcb5b5e164717629f(
    *,
    computation_id: builtins.str,
    name: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c454514da67d5bc4e329556a6bfdf3bd41b48a98461affad16103890078f34e(
    *,
    simple_total_aggregation_function: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f2203386ff7dbe43c0f91a466eb584b39055cdc3f8385733ef3f20d01c3ba80(
    *,
    field_id: builtins.str,
    total_aggregation_function: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TotalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3cb9d3d986ec951750d2fa88755ce590fd2b1a0ccf297c5bb4e33c75aaceba54(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    placement: typing.Optional[builtins.str] = None,
    scroll_status: typing.Optional[builtins.str] = None,
    total_aggregation_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TotalAggregationOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    total_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00f03c70e82683586cbc7648798b3e82e87a1f835ad6b4820077ed676d11c138(
    *,
    colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sizes: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93a6b0d40965a02d73b77d2d474696c59c68c0869ffcd790194093a704ee2250(
    *,
    color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_scale: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColorScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TreeMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    group_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    size_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TreeMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83130f39540a83f1e210175fe90ca34238d440a8c276f05557269bf72a378098(
    *,
    tree_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TreeMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__267bd6a67c18b49c2ce0cfb16e0aaf4407aa19766c92fd828fa8d158290dea72(
    *,
    tree_map_group_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tree_map_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__987c134dcdfc1a8aad1f606a18f8e3de2feb30ff23e7bc1fb4e8c208de05831d(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TreeMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa687045085dc8d72af87858985acf96ef909e9f440a2dcdc152e45f6d7ceaf4(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d265618d94c82fa33595fa63cf601981fc46655fc4e54c08237a64a02f0e8e7c(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__694d5d0b7cd15aed71341557fca998d4eb548ee61966a5ea32f3acd7f3fb6dce(
    *,
    computation_id: builtins.str,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__456be41f5014f6703a82594f94da2668fdb18d0ecf4d83c19f807a998aade12f(
    *,
    mode: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d102b1a87dae33760dd66fce1802286441d09b8befc4e9f886fa64b0359ab043(
    *,
    percent_range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PercentVisibleRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d730b715d9e6cdd475e9a82496f99af47fe31dfb0ff5679d9658ae40227ae56(
    *,
    filter_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CustomActionFilterOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    navigation_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CustomActionNavigationOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    set_parameters_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CustomActionSetParametersOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    url_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CustomActionURLOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26f7459afa8caf596af826ad5a11c161931b24cc757b9501abfe4c8f6c46ecc2(
    *,
    action_operations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionOperationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    custom_action_id: builtins.str,
    name: builtins.str,
    trigger: builtins.str,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff6c93ffc3eca56e7f0801d3fa31d4e3847be4e43ecc2931cb65086f639b9ce3(
    *,
    chart_color: typing.Optional[builtins.str] = None,
    color_map: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataPathColorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f255411e656ca1f80f15bc1962254eae5a33e9f73c7698b1cc40068a94f39e20(
    *,
    bar_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.BarChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    box_plot_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.BoxPlotVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    combo_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ComboChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_content_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.CustomContentVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    empty_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.EmptyVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    filled_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FilledMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    funnel_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FunnelChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    gauge_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GaugeChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    geospatial_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.GeospatialMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    heat_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.HeatMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    histogram_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.HistogramVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    insight_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.InsightVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    kpi_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.KPIVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    line_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LineChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    pie_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PieChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    pivot_table_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.PivotTableVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    radar_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.RadarChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sankey_diagram_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SankeyDiagramVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scatter_plot_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ScatterPlotVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TableVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tree_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.TreeMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    waterfall_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.WaterfallVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    word_cloud_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.WordCloudVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d683e2ad0f21809d44229a086ce440f5462ae165dd3a315ab74869b0e5b0b762(
    *,
    format_text: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LongFormatTextProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9883ad736a97a666a3231edbd524ba550df305268911cf601e2ca8c945ed4162(
    *,
    format_text: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ShortFormatTextProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__343b90d1d1f60be1da3b32504455647c43c866d0cd8d04ce82e70d749476640d(
    *,
    breakdowns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    categories: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75ae0cd00a859a42a1332a4d93c1d71b4e79cc32c4fc2987b7e7ce1a632b86ba(
    *,
    category_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.WaterfallChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.WaterfallChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    waterfall_chart_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.WaterfallChartOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ec4f9ec60221194aff4531500e7d5af0acea034a948f159b18d9fe6ecaf54c0(
    *,
    waterfall_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e5d92a2cd1f949db1beff67c02d8dd87b474b8230ee6de91d7c93aeaacf647e(
    *,
    total_bar_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f35cc442456795e1468b1cc1cde921a548f247049594e35047bd94da4729cab(
    *,
    breakdown_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf59b78ee88dbb638d6c2a941030ec8725a7095b2ae1c9a64b544ca521444d12(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.WaterfallChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52aff22a9290b492f489ce7b770ce0dc729b9674414758e503ba5b8bcc95233b(
    *,
    date: builtins.str,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92496b50237d86b48e4daf1d174f99a542d6b83b3ccfa0138826df49d28221a8(
    *,
    end_date: builtins.str,
    start_date: builtins.str,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__373a402df7e927c2c85e65fa94a21613232d0a972e423ade32a703dc3b1a4ced(
    *,
    group_by: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c61f02db0f5b87a3117c8981ab8e656e1cb96625e8bdd63f06db8c476b3f4298(
    *,
    category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.WordCloudFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.WordCloudSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    word_cloud_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.WordCloudOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f7474daf95a3ffcf615923aa66f95fa514281ad7c6a888ec688e31f801b6b7a(
    *,
    word_cloud_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.WordCloudAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a5fe959060fd86dc83a2189d6257e9981928a92b0c4ed0b8683201c03e90770c(
    *,
    cloud_layout: typing.Optional[builtins.str] = None,
    maximum_string_length: typing.Optional[jsii.Number] = None,
    word_casing: typing.Optional[builtins.str] = None,
    word_orientation: typing.Optional[builtins.str] = None,
    word_padding: typing.Optional[builtins.str] = None,
    word_scaling: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0904993cf85c74d5ad6d90c98ebddc9295efd54a60aa45dac229ea25f0697daf(
    *,
    category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d8cc190e86df93e83a4af8c07e28d53ce2bd0cfe3305e61db3cfef703acd44d(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.WordCloudChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__abc87c90adc8752b5b24a67c2541ecb565aedcfc0265e29359b671502ad3539f(
    *,
    analysis_id: builtins.str,
    aws_account_id: builtins.str,
    name: builtins.str,
    definition: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AnalysisDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    errors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AnalysisErrorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sheets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.SheetProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source_entity: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.AnalysisSourceEntityProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    status: typing.Optional[builtins.str] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
    theme_arn: typing.Optional[builtins.str] = None,
    validation_strategy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnAnalysis.ValidationStrategyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb817240753e3d59e412d7399827ca12667d95592c4f14cac4aa2bc90e05aac9(
    scope: _constructs_77d1e7e8.Construct,
    id: builtins.str,
    *,
    aws_account_id: builtins.str,
    dashboard_id: builtins.str,
    name: builtins.str,
    dashboard_publish_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DashboardPublishOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    definition: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DashboardVersionDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    link_sharing_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LinkSharingConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source_entity: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DashboardSourceEntityProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
    theme_arn: typing.Optional[builtins.str] = None,
    validation_strategy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ValidationStrategyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    version_description: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__412eac5ba9b84fad29d3fb0fc5bc08a39c12fde7fe443b5d36f14a92962aa789(
    inspector: _TreeInspector_488e0dd5,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97bb1e16e0dd8cb01d1fd3d923b8a8a113088cdb29859897b478c5f49b7473fa(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__615e0bd2b1c3bd4595e9d0ea4ed6f68b41ca848ac8c3c1cf2ba39792a8771b44(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c89a833c31b0fc06912b32690c09f2a8802775534838f0ffbef4ea3672c0ea9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c30d525ed240c5dd3551080fdf34334a76db433f35c8086308f632d5e12516f9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6922d759425c2e9eea8660b1308a87edb23ef8f1ae2ac877cff87014f13b9343(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDashboard.DashboardPublishOptionsProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__401dc566ec96e95f727379b41bac659021acc2d797b3988116201d56fa8c05d8(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDashboard.DashboardVersionDefinitionProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7fda2bf7eb1470e85b100b1d47852c3742a93f9f7e2b54931f0b4796a4e232a7(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDashboard.LinkSharingConfigurationProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2bf4c69a2a3050bf7570d3061c6ad8502b1f961fd6c97d7c1485c095c648aea2(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDashboard.ParametersProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f59a510ec4cdf0a418a9845b18e0f18e35eaaa4656abc24ad2fea0d4d19f388(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnDashboard.ResourcePermissionProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f26a2d47ee4e9448c33ec5aa138cdb72b5d9471a7548e1c79563d427ac834024(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDashboard.DashboardSourceEntityProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4157d1e43ba9269c34a9144492ba9d8b026c8ad8b806f6f0e6f37879005b2f7d(
    value: typing.Optional[typing.List[_CfnTag_f6864754]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46c4aa8ff62c92f0ce2798499a03c58f9959885ce816cb9469ed1d4779a76ab7(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62fb6c466147b908ac2657c256baa86531607acd72249e030ebe5469c50cd22b(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDashboard.ValidationStrategyProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4e2c4c6bc181883a6266972f618c6a00770ccdb0e57d73a95f61def1f2e65ff(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80d1f8fd6845423e319bb8174878b6a29f2f7963379f7f8c451ccb38af7b08dd(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8d4df527a885403ed8019364af71fb386efea9c65e5986b9cb0e65bb7dd8e76(
    *,
    attribute_aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AttributeAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    categorical_aggregation_function: typing.Optional[builtins.str] = None,
    date_aggregation_function: typing.Optional[builtins.str] = None,
    numerical_aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87de744665253e4cca52f594ac3382d9eb4a61d617bd92b8b43f9c2d1fc42820(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    sort_direction: builtins.str,
    aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e66a4877ba1c474f6bbcc57dbe4e56056271dd2d6abb4a9a4381350408d60b6a(
    *,
    default_new_sheet_configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DefaultNewSheetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7cb9daee34ebdd50819f56f8d83bc6aface0248fdc107ababc393ffaad4a2d92(
    *,
    anchor_option: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9dc01a84a29061262b25649d5568967863dad18aacccf2197b0708ac48b92f99(
    *,
    range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ArcAxisDisplayRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reserve_range: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5649f4fd37011ee236c577679430af27d7ca3e76dda160958575f38193c6b6cf(
    *,
    max: typing.Optional[jsii.Number] = None,
    min: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8d36a7bc2680302d589cab761ee9ff97e7c873d9f1cdee854cf8844dcdbb049c(
    *,
    arc_angle: typing.Optional[jsii.Number] = None,
    arc_thickness: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__481cb554cc890bb96e4eda3f6a02011deec5a79bda05bdb3da22002fe160dee6(
    *,
    arc_thickness: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ef7224a58786a2e22a434b451d86c92e851f6806306809a88f0fbe39f212105(
    *,
    timezone: typing.Optional[builtins.str] = None,
    week_start: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ca70fe3ccaa6fc1d88b1b2ca26586296956ad88d392ddc9c6bec881f6862bc6(
    *,
    simple_attribute_aggregation: typing.Optional[builtins.str] = None,
    value_for_multiple_values: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa2762d74557d61b2a9607be978b6ae2e7747e81adedbe834f60012b3d9530f6(
    *,
    date_axis_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DateAxisOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_axis_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumericAxisOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5e6d56dd32f73723d00e039ca2aa3946b1be5e335ad0252d16173a7ea5b0ae1(
    *,
    maximum: typing.Optional[jsii.Number] = None,
    minimum: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b8d9c49a4641f149f4e798dc4b5ac9b09bcb9f5eefdeba4ea7752c803a4ba34(
    *,
    axis_line_visibility: typing.Optional[builtins.str] = None,
    axis_offset: typing.Optional[builtins.str] = None,
    data_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisDataOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    grid_line_visibility: typing.Optional[builtins.str] = None,
    scrollbar_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ScrollBarOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tick_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisTickLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d922b60b7031c4ed20c7f87045d35b7d2c6cadc6d572114f4bb88d4e7ebd95b(
    *,
    data_driven: typing.Any = None,
    min_max: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisDisplayMinMaxRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26f01f53047b36789cdd9eff7482799552aaef6a4e512fadd96ab690a34e8a23(
    *,
    apply_to: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisLabelReferenceOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_label: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf532ce08c0ea9f48c9be0918c2611c5f0876418688222f7a99a25db0eceab7f(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb6db4c2d0d9c586c058b692d5b6e1e98f66d1ef04af899644f8b234aa8cb3c1(
    *,
    step_count: typing.Optional[jsii.Number] = None,
    step_size: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ccc37977aa419d9a622b33647ead381959402d7c3be9adc4c45524782da0e92d(
    *,
    base: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd1850237626981d9668ea38df38f3effa756b373f7a650ba4e578a40ceeab1a(
    *,
    linear: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisLinearScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    logarithmic: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisLogarithmicScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec5f01cd553710c3fc06803a8fc9f80232f647d4e67ef1ba28934f926f1650ff(
    *,
    label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rotation_angle: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e599230a609a8a880efa0612bb0a7effbc9f24060decc9b29887f5b874aced74(
    *,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1ff0bb5689a9ba65351ed14a14017a9194ce5dc1ece1f84c4658f087286e46f(
    *,
    bars_arrangement: typing.Optional[builtins.str] = None,
    category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.BarChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    orientation: typing.Optional[builtins.str] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.BarChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93d79566d5f799cf9659899378dd246ea2fde3c6d132c7ced0e20c5dde3b663b(
    *,
    bar_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.BarChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__449b0053804e16ec30a454f821cb952ae185e3546706d3f119064c2072fa15cc(
    *,
    category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13bc9ee0dfc8b3edb99af3d075bc421a183b0db9f7faeb1687c866447c07f3fe(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.BarChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__158023b1b7442c555790d0e08899f7a174d506adcefa2ca8e9eab6397c7403c1(
    *,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f26b9de7e7198f77ed125fd5fbb1ef13cafe9e3cc5e9f1a39c635456f8c2ae0(
    *,
    bin_count_limit: typing.Optional[jsii.Number] = None,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1a29e2f869a375361f1457d2d8d2d62bb6da12ce784c6a841edb821bcabf32f(
    *,
    content: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.BodySectionContentProperty, typing.Dict[builtins.str, typing.Any]]],
    section_id: builtins.str,
    page_break_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SectionPageBreakConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SectionStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d656bf89c920f00562e5e81dd1b005dcc04092818a276279f64efa0894c43e6(
    *,
    layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f43d0c132e73d4c4fb3185440fb489afbe7cdca06b70ebc0cf5048e68683e00(
    *,
    group_by: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__01df5e1eb0635348166c2d99fc223dfa1d5b1e8e830385bf311f3de56d7005a3(
    *,
    box_plot_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.BoxPlotOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.BoxPlotFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.BoxPlotSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68c14f4ba8e1d9c0e7b8a5047e66270d26e8b3fb4402ef1c8e59200bf235a5bf(
    *,
    box_plot_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.BoxPlotAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5bf206ce413babb986996d60b6decb3eab4d40bb05923a5b5000fde519f2de89(
    *,
    all_data_points_visibility: typing.Optional[builtins.str] = None,
    outlier_visibility: typing.Optional[builtins.str] = None,
    style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.BoxPlotStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d4c47e5ff8be5d2e1c80d5dace93d8d3c7b83ea3a46a74db659e4a2bf895fea(
    *,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    pagination_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PaginationConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78f1d53f124a66b7fd71695a56d4755f435c5db02e2c4ab2fd0e16fcbf6ea831(
    *,
    fill_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e7d07262a49481c1b16d3eb00e514013399279dbc4b987427e9d553f396f0de(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.BoxPlotChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f12ce35813ba424693d1bffa215127246838647ff2a48f4e10407a6b36ffed36(
    *,
    data_set_identifier: builtins.str,
    expression: builtins.str,
    name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68ee0c43e3791511488fbd00cb4903c434ee2ab14120f95bf33394e3d75af65d(
    *,
    expression: builtins.str,
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a32bbc3f9db67b28f010d69ebbeab91fbad354e6f54009a3893f2dccb3a8a18b(
    *,
    source_controls: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CascadingControlSourceProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c02a590bcd0eaadcc7074756fce7fad5e61b1a9c0eebb0c647871898b2721209(
    *,
    column_to_match: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    source_sheet_control_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6e5c66bf00442c0eebdc5de0c7b9d2a38f50ea8eae071438274ab96ec42f7ff(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af71f7d7520e1e79839cde391f8a3e325b9eec9ace905498bc58af1a02b60d25(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    aggregation_function: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7319d068924e45b7795aa89f7eb88e392e746c224673742657c94782a36c2a1a(
    *,
    category_values: typing.Sequence[builtins.str],
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ffab7ada39f61dd0aa2dfa460d57cb66bcaf9438627f6d913ee997f170a8652(
    *,
    custom_filter_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CustomFilterConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_filter_list_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CustomFilterListConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    filter_list_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilterListConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f69313d9472c41cb99afc1e0281076733ee261b50594b22b59ec1b43d81a685e(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CategoryFilterConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c83f5a1113c0da518a3850e90d9d9ac8ff08085a4eca5440484a162b0c459183(
    *,
    axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sort_icon_visibility: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06b5323baf0942a5cce8f4420ba55857c98b8ad01ca16abb52b10bb4f34c57d1(
    *,
    cluster_marker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ClusterMarkerProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37859f9ab1588836940dc064c2713f729b55ad4a5260f19ed5bab1a3b0db82b9(
    *,
    simple_cluster_marker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SimpleClusterMarkerProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ef6d004039d77188e133eb812b5bb1a71e2f59ea99edf0658ba4310036867c8(
    *,
    color_fill_type: builtins.str,
    colors: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataColorProperty, typing.Dict[builtins.str, typing.Any]]]]],
    null_value_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52954c514bd9a5c2a13250713fc7bd9334e24f7fa9b821dbf31d62fe42d76c87(
    *,
    custom_colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CustomColorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66e8622dd0c8db8493d8da8c1167e0b0a505d50767f6e093b2b735f2df9803e6(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    colors_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColorsConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    role: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b63144265450fdc5b5275547424ee378cbcf9fc800a0977b591e602816678322(
    *,
    date_time_hierarchy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DateTimeHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    explicit_hierarchy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ExplicitHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    predefined_hierarchy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PredefinedHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6093774649cb04a44dfc42910e63be012b473b61ae6f7c9d7f87a698cb17b9f(
    *,
    column_name: builtins.str,
    data_set_identifier: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1fb2eeff7f74c0642923c7c6e763c4172f199943d0c6394282e00bd021bba412(
    *,
    direction: builtins.str,
    sort_by: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96d6011056d24680d9b2e7f70ada41725b936a7dcab8464ea73d0a8637c042b7(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    aggregation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4601f505db680f166cbaa94b69275e49fbce5a7804dcde939f285ff4ff26d28(
    *,
    bar_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    line_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d19c08bcb98b3e98b8a21eef8b0850a746a9fd4262bb397c2526d270dd02022(
    *,
    bar_data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    bars_arrangement: typing.Optional[builtins.str] = None,
    category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ComboChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    line_data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    secondary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ComboChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__750fddcd66a75ce8d856b0e7bd0d5297eae44b30206f4c923d0754bf3e356142(
    *,
    combo_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ComboChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e14489ee2ac7dda0e959d77faf1914af7855fdd711ea4bfae95df20f58bf5960(
    *,
    category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c56dc3108e3f8ec1fedb5f5c02e509a7604241deed933a5e46a9d86a8d190e71(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ComboChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8e196894b8ac8b385cdaf8540ab8726ea2d1ab17972f01e9fad60382741eb32(
    *,
    comparison_format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ComparisonFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    comparison_method: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f59f1dd8d6d0e102801b593d59d5dace1c52310955f5ee932bd59dbe8ac4e24(
    *,
    number_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumberDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    percentage_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PercentageDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c88e0fb81b82b5b5c849eba51d2c22b27aa4a826273a1235cf0706d2a766bed(
    *,
    forecast: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ForecastComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    growth_rate: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GrowthRateComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    maximum_minimum: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MaximumMinimumComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    metric_comparison: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MetricComparisonComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    period_over_period: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PeriodOverPeriodComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    period_to_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PeriodToDateComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top_bottom_movers: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TopBottomMoversComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top_bottom_ranked: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TopBottomRankedComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    total_aggregation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TotalAggregationComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    unique_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.UniqueValuesComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__88a8387bfb2cbcecb9460319453a7db8b6a2c5f735ae4e8608a1d6b47037d026(
    *,
    gradient: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingGradientColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    solid: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingSolidColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed3cc39ecaf3fd90a69e4d089e00af009bc69b9e288971097164c04094802f4f(
    *,
    expression: builtins.str,
    icon_options: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingCustomIconOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
    color: typing.Optional[builtins.str] = None,
    display_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee2f39575eff053694b3d8008cdbd992af0fd6cf3fca2df85843e51416b61812(
    *,
    icon: typing.Optional[builtins.str] = None,
    unicode_icon: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2597a121e0ae9bb968ae505e70d399bf5ae60328f6d14047e43b01b88daa0a76(
    *,
    color: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GradientColorProperty, typing.Dict[builtins.str, typing.Any]]],
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe4245d68dd9ae181a10d86eac3b16ff18b9d1a07aecd186d06803116461c310(
    *,
    icon_display_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76b7c03283d97079c4d4bd096728b150b22eaeb518146d704b9a7aca34445ea5(
    *,
    custom_condition: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingCustomIconConditionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    icon_set: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingIconSetProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdb3a9d1c8c1ab25c7a5f72bc88b9738eba5d6bab1d5ca4d29bd0e4d42224e3f(
    *,
    expression: builtins.str,
    icon_set_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__272578562644e2eb61241c8c390a9e6b789d45f67326ebbe68b342827bd61c44(
    *,
    expression: builtins.str,
    color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e03029700976e5cffc01742a3eb8eb3645dac78c9ae9b02746e90c0a2455565(
    *,
    contributor_dimensions: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]]],
    measure_field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__235a95352eaac3f8dd43f46a556706a771a21cf49fe0fa4a1349fdfaff4de4bc(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    negative_value_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_scale: typing.Optional[builtins.str] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    suffix: typing.Optional[builtins.str] = None,
    symbol: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca93d409bb0ca5acf790524575431726482f03d6f24a12edf6f6c380d27d8ae0(
    *,
    selected_fields_configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    target_visuals_configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilterOperationTargetVisualsConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3492367ac39471d6d5e9f4bc6d5027d2a5b3ba696c04f259be40cccace6ba539(
    *,
    local_navigation_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LocalNavigationConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ea98618066df7305ad3e0f620deeeffed1af87a2316908d6dd39be7650ec331(
    *,
    parameter_value_configurations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SetParameterValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b831c7ba679c3665ff690d272674eaaa1db367da2162f5a4827cab1ae43ea72(
    *,
    url_target: builtins.str,
    url_template: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e9f957c9df98206ae11864f8584f7c563586a42c9db0556ecb3d00aa0c9f012(
    *,
    color: builtins.str,
    field_value: typing.Optional[builtins.str] = None,
    special_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64f037fd56898a28a550e2ed664bd5a58ddfca34ba1a572582230ffbe7b7bb1f(
    *,
    content_type: typing.Optional[builtins.str] = None,
    content_url: typing.Optional[builtins.str] = None,
    image_scaling: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__354d93a497099427a608068f40c1d32059de70bdd997fced2346f971a5114404(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CustomContentConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a321f2a48177fd94bc6c941da6234b88fa63b0c5a72a7a8debc04d6db62f368f(
    *,
    match_operator: builtins.str,
    null_option: builtins.str,
    category_value: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44b72029c0f8352cba8c7b55ff03212461cd317ede5e2c548ad957630eb7d9d5(
    *,
    match_operator: builtins.str,
    null_option: builtins.str,
    category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c65e3cae33c0dc61d3615e127c179e32db1f7411cde8ad49580649d899f06c1b(
    *,
    narrative: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33466e20565e5347076222755427f3d07f86ba3912eac79845bebaa14b278bc4(
    *,
    date_time_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    decimal_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
    integer_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
    string_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7fa24bde9f040db1bb0899a06916f6b95315c730d7af9ae814a68caba3800645(
    *,
    custom_values: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CustomParameterValuesProperty, typing.Dict[builtins.str, typing.Any]]],
    include_null_value: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__61c0c303f4ca0cb34d1d364e3a84603385cd100cd97983f58920860f89aef2a4(
    *,
    message: typing.Optional[builtins.str] = None,
    type: typing.Optional[builtins.str] = None,
    violated_entities: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.EntityProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9e09587ab720431f5373014612c24f6d414533d5702638a33a14c36c7d8f81a(
    *,
    ad_hoc_filtering_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AdHocFilteringOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_point_drill_up_down_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataPointDrillUpDownOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_point_menu_label_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataPointMenuLabelOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_point_tooltip_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataPointTooltipOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    export_to_csv_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ExportToCSVOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    export_with_hidden_fields_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ExportWithHiddenFieldsOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sheet_controls_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SheetControlsOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sheet_layout_element_maximization_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SheetLayoutElementMaximizationOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_axis_sort_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualAxisSortOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_menu_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualMenuOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_publish_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DashboardVisualPublishOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b22ad6b4df9586231a28572e714cb9eb5a398d4bdac27b13e2d1834997ec0d6(
    *,
    source_template: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DashboardSourceTemplateProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95b9662dc196870a44ca7342023a1657b392214f06ee6115f1f9507f842aabf4(
    *,
    arn: builtins.str,
    data_set_references: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataSetReferenceProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1e773460c007615acde57e73c58a06ad78362ee67cca8db11e785b394622e44(
    *,
    data_set_identifier_declarations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataSetIdentifierDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AnalysisDefaultsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    calculated_fields: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CalculatedFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    column_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    filter_groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilterGroupProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AssetOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    parameter_declarations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sheets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SheetDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02747fd699d99b0ae57df7fb8479638c8d4ee9c3ac6b8674fad0ad725a1c466d(
    *,
    arn: typing.Optional[builtins.str] = None,
    created_time: typing.Optional[builtins.str] = None,
    data_set_arns: typing.Optional[typing.Sequence[builtins.str]] = None,
    description: typing.Optional[builtins.str] = None,
    errors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DashboardErrorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sheets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SheetProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source_entity_arn: typing.Optional[builtins.str] = None,
    status: typing.Optional[builtins.str] = None,
    theme_arn: typing.Optional[builtins.str] = None,
    version_number: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__408958d561c48a3ffa2d0cb52dd8fc2ab0cb9121e11f9f6aa3bbd8e0fbe9780f(
    *,
    export_hidden_fields_option: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ExportHiddenFieldsOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e762c8a306c685fc81eb9f9ac5fb29bad77d9a83bdfef9c21ef788c7eb6d2f11(
    *,
    field_id: builtins.str,
    negative_color: typing.Optional[builtins.str] = None,
    positive_color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff858a4698c777414bebc3e80e4b098f61cd252dc6c4039b7f6f2df9bc6b6b5b(
    *,
    color: typing.Optional[builtins.str] = None,
    data_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d13131552e8cba6227c967cc9c165670b2e73eb08f2baa34ef0de7f638ba9f1(
    *,
    axis_binding: builtins.str,
    field_id: builtins.str,
    field_value: typing.Optional[builtins.str] = None,
    settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LineChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f90116c0c378202ed19ef75ca4423f1481dfc4314406661e137ae66ce4ee2ef9(
    *,
    category_label_visibility: typing.Optional[builtins.str] = None,
    data_label_types: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    label_color: typing.Optional[builtins.str] = None,
    label_content: typing.Optional[builtins.str] = None,
    label_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    measure_label_visibility: typing.Optional[builtins.str] = None,
    overlap: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a3b2866435d1823bb1d6c4d241168cf11d7944c2c8af72f1491542605e626e9(
    *,
    data_path_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataPathLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    maximum_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MaximumLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    minimum_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MinimumLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    range_ends_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.RangeEndsLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__939a8b10369228e2d550044997e4717f7015bedb3638c36441ae5fa61abfeba8(
    *,
    color: builtins.str,
    element: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]]],
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20efdc01250971060f769b4d3d1d3683c4b2af4a4c62cbd865becb49dd1e80bf(
    *,
    field_id: typing.Optional[builtins.str] = None,
    field_value: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86a2aa8b069cab21c5f19ed1464a235ba31dc5042b5ed2e0c7eaea1a9194b01f(
    *,
    direction: builtins.str,
    sort_paths: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38b24f0de1a215ef94744ac397948cf3f58954b385a4af3005fb01fe6f9ca6e2(
    *,
    pivot_table_data_path_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87f049f31df40ffc5c192a50ab46cff21e148d108d92cf10d0d9b6b6269d6371(
    *,
    data_path_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataPathTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_id: typing.Optional[builtins.str] = None,
    field_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7171910ea4dde254edc15b1d1632dbb4e005794bd8989ea533a292e85c45061b(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87cdfa681edcc17bb2bff1a0485212a0780e425b67f48ee06d44f67561cc4da4(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96c647bd5166be9e741815d6acf00a0fa2522e200ea452f9e7fe12d6073b6f52(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c2de2aa62a91bb21ddbfe6e508333eb0b4dd2396f8fd30f3899cda7426aaefe(
    *,
    data_set_arn: builtins.str,
    identifier: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f916781b7071e5a0e35e8dc0a8b9fae5ff8314c5baaeefb50c0769a3463a848(
    *,
    data_set_arn: builtins.str,
    data_set_placeholder: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7622ec7beb65b878ece677b0ae426935fe2a72a4581abc480e0157a7eab03a9a(
    *,
    missing_date_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65e6e13e88922fa8c8283b4c80a542fe26f5b4b1016bab559e96cbcf4af80735(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    date_granularity: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2f2d0df47996350b04a49c28c7e4bfc9a2001cdabe2a4c3d1c11829ec2da577(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    aggregation_function: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a322af65ddd2559f08ada6b32f3cedd34ba1e46f320f3322497e15adcf47fcff(
    *,
    dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rolling_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.RollingDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__927b666ae44de8c1741c7b79a487bc1e3521427748c18a164ff02d721b657be5(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d11b2f7a0e52f24fad6c7123e2bdd12b12d6ab1098bb93b4150bd7bd2b860de(
    *,
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__483baa308f6cfa1ba3f021837dce98bdb34180d183674301b2ed09410fd41568(
    *,
    name: builtins.str,
    default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DateTimeDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
    value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5bb492b85dd26afa0e0a0a44d9b6d3e843e5ca7f2532e74369bc4fa81a47cd32(
    *,
    name: builtins.str,
    values: typing.Sequence[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90e69e789349808e2dd1f4e3618f32bb7adc79e96050c62b7bac8d4c93987833(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SheetControlInfoIconLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8c807c3455810693e49813aeed10819fe9aa62d8a125e2183604b02ed8fec45(
    *,
    custom_value: typing.Optional[builtins.str] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86abb8b5e2412c864c791e7d7d718932bf206adcc683c8eb64021cedef34bde6(
    *,
    dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__493cbc9becd13ff6e4b0932b7cfc11e2c50d6fe07cd083d18977551416b6ffa2(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DecimalDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DecimalValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0374f299306ea49d96a80a06e399d71cf788801ce5ead0d587a2c27b0519b2a3(
    *,
    name: builtins.str,
    values: typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__810f14e63dfcfe16d8a2f1cd7186b1bb7852edc493057b58a2a2a94e35f1c855(
    *,
    decimal_places: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffc6e7c59e3e07f6b1ec5099c92200960ba85988e1b545901df9e24c7b4d244f(
    *,
    custom_value: typing.Optional[jsii.Number] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d39e97411686f88df1ab9f7b1a77ffcca0bd59ae74b683d51772f2f2b82efb9a(
    *,
    canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38ff44a7d24b9c7656d9f3eda759ad3d180955f180dc852ec17bc66f6f6ec722(
    *,
    canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GridLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea14aeb09317551633f58ca2d3bc4e54974792dbd1ed21854e72d32d1ba80ee8(
    *,
    free_form: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DefaultFreeFormLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    grid: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DefaultGridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__56eea1585b07f7f2c3a40432abd531967f87d24eed0fda5a6e2be08d6417b73e(
    *,
    interactive_layout_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DefaultInteractiveLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paginated_layout_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DefaultPaginatedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sheet_content_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dbf88a4accfa6c839334fbab2361d44b01977cd33f36f5d92413f3ad23056102(
    *,
    section_based: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2de36f258c529330394e6e04556e307357bccc72c2039ee1fd796872f1e73748(
    *,
    canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2967c2f7f112aa455423258fd03cbd20b6108b6d170855e75a5fb046fd75ff43(
    *,
    custom_values_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CustomValuesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    select_all_value_options: typing.Optional[builtins.str] = None,
    source_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    source_field: typing.Optional[builtins.str] = None,
    source_parameter_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f13427962c0b6c9aa8bb064ca5ebe13bded7171a506ce55828534c5acb7af781(
    *,
    categorical_dimension_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CategoricalDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    date_dimension_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DateDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numerical_dimension_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumericalDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aff1e2eb9a1c2600f67efc0797fe03c739576b352bb30d9cb902503991e4a538(
    *,
    label_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__204d9f4c3acc927e3a4fb916dab8ae30a397452434329da28d3f42677909fa90(
    *,
    arc_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ArcOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    donut_center_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DonutCenterOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a57b90130b9805eb215653ca43c03a593f7cd11bc59cbc7b53ee3e0c571bacf(
    *,
    category_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CategoryDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_equality_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumericEqualityDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TimeRangeDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__355aeea49a7fad6b4a1a346bd823cda58b43b32bec7044ac9122977e1c23714e(
    *,
    info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SheetControlInfoIconLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    select_all_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ListControlSelectAllOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d675ac8a86048db958c90c51de98db3c58d4ffcbe17e8397f30ee68e31d74c6(
    *,
    default_value_column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    group_name_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    user_name_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__604dd475dca9ac1a9cec890c4ca9cbaa82fc5789da3dd6746e358d9712a56c8a(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6cf24f107ec2fd6520772b006c6a35713e11f36165ea69f4ecbfe2522465cf3(
    *,
    path: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__315a64b5a54ec0e4314b4e2461ac459b120f16876aff5304c7d486848069ad67(
    *,
    amount: jsii.Number,
    granularity: builtins.str,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a917725d612aafa12d8d0c1a105a2d73f203127b6a08252afd54f0488fcee902(
    *,
    columns: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]]],
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ccc7b7919fe9bff8b58d9914e3408ddc601f119bb566a521c9ba330108021166(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1b31bc0e0d8ecfdfaa4ea2ea823bb9e0f3b9b39115478ab8d612a79942da86c(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__951b93a6bd5a29ecd51b86f3f98148422298ea3c1ff8545e6e22e166a7e05335(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f95445a18533857ef283056719d18541fe202fa20c0a5eaec800a7f2fd74847(
    *,
    aggregation_visibility: typing.Optional[builtins.str] = None,
    tooltip_fields: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TooltipItemProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    tooltip_title_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d73962d6db6d9d7d01e259ac5c319f46d5598e0facaf47cc82082c11c21d6574(
    *,
    field_id: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6de4ea2be24b42686f57223b63c6775199dac756d45769f5a0fda1a7d55b426b(
    *,
    axis_binding: builtins.str,
    field_id: builtins.str,
    settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LineChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__703c022d70e47dc536d3b84b0fab66de512a3d2f42b5806c2030ea4aa9dbbf15(
    *,
    column_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d96dac125009282df2800c265b69ee315d440a1ebe6cb4c048fa9cea413603b(
    *,
    direction: builtins.str,
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b39cb7f5cb9b4fe2e4a6850ae1e2aebcadcb37b16fbc7431330772f250faf46(
    *,
    field_id: builtins.str,
    label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__560833d96ba2f94dae161fd8edc6f1d6cb9e0e3abd174bb20b4ff8d4525a225f(
    *,
    geospatial: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92568506a0b7eac5da521ce1e8fb0bce5258abc90c6a94838dffd0a03b214ea1(
    *,
    shape: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilledMapShapeConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6dd37dbac75444f21387e81f2a86a710e907c622778879fcb0f11925af1f290(
    *,
    conditional_formatting_options: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilledMapConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dfbb3e48b89cd28bbd6e8c24af60f9d5fee5663d3154f1c7e83f8dfaa588562a(
    *,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilledMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    map_style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GeospatialMapStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilledMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    window_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GeospatialWindowOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7d475d5525d818bb42442611b254c215fe179788b82491e663964db4a9face4(
    *,
    filled_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilledMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__41738324d641a58ffbaaee8a6fe4b354222a034d4d72aad36feeec5ed6b5aa19(
    *,
    field_id: builtins.str,
    format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ShapeConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__82e3253f6e68896072aac3be7604bbf0741c45a93bb52513b47daca075a7c043(
    *,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__368d66b0d5e169afda9cf70e70a66d450d0559e333ac6b4f67fca18f415bcdc2(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilledMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilledMapConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3de36a833439e9279b496af4596b88285b5a80e52020a02cc1d918bc3caf8a63(
    *,
    date_time_picker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilterDateTimePickerControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    dropdown: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilterDropDownControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    list: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilterListControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relative_date_time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilterRelativeDateTimeControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    slider: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilterSliderControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_area: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilterTextAreaControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilterTextFieldControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d4dc823ed0b42bce5fa5201fff6d7738b35fe75bcd098d2d11ab7106684e6db(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DateTimePickerControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1266fccd2cb683bbf30033038fd0b67f0c8037ac8dd77a92a464511099766b1(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DropDownControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce4cf47935a3ae4c473d594d89b4d8807ac704b2960631354034ef58f07b298f(
    *,
    cross_dataset: builtins.str,
    filter_group_id: builtins.str,
    filters: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilterProperty, typing.Dict[builtins.str, typing.Any]]]]],
    scope_configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilterScopeConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd1881e6a42963794726bb270a28ec83d9d6eadb7785c1bf6cc95443879be88a(
    *,
    match_operator: builtins.str,
    category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    null_option: typing.Optional[builtins.str] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__403b2a94ff321ce0bd8b6439dab935c45cb3a984d7342cc0bfc042fb89f91f5d(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ListControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5b5e5d482610e8b383a02eabcbfd4bc9f65085804d9c1c745d051f3ddf4947b(
    *,
    selected_columns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    selected_field_options: typing.Optional[builtins.str] = None,
    selected_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__413ed1cbfd1047c2147c27cfc0b0ae60bc33e6bae22446da36a79d3fdc277ab4(
    *,
    same_sheet_target_visual_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SameSheetTargetVisualConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__409a9ada70537b5b198a9297213605c443d07089acc597a347aed1b89af1fd00(
    *,
    category_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CategoryFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_equality_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumericEqualityFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumericRangeFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relative_dates_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.RelativeDatesFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_equality_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TimeEqualityFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TimeRangeFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top_bottom_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TopBottomFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe7bdb0ee36689d0f3888592fe2c5e415e7128d38d6bc414f6b5e8f15996dc4e(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__efb1f0d726575795de7c1bc1743a357d70f197f085d1b1a859344beaf57af343(
    *,
    all_sheets: typing.Any = None,
    selected_sheets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf3a69b2044179c514a37eb8de1bf2d7c8863ea4288b0fbea70e60407873a3af(
    *,
    values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e33f693f0cd3872c53b5519898c8c1204c4e5b7949e6651059ef65d15ef1ea62(
    *,
    filter_control_id: builtins.str,
    maximum_value: jsii.Number,
    minimum_value: jsii.Number,
    source_filter_id: builtins.str,
    step_size: jsii.Number,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SliderControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aff6992b42407f813dd49b07602424a15f4a5bd9dcfb70625da0055df7195ed0(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    delimiter: typing.Optional[builtins.str] = None,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TextAreaControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__07b6a627f5bf3da40af7a2bd33995eaebca4bc7d53a56462a0d40b6e1f8c711d(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TextFieldControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b48855a807262480043342a23f56c41acad1677b4c6bc1911063c9f4033d5eb7(
    *,
    font_color: typing.Optional[builtins.str] = None,
    font_decoration: typing.Optional[builtins.str] = None,
    font_size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FontSizeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    font_style: typing.Optional[builtins.str] = None,
    font_weight: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FontWeightProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87370eaa416d91722053871ba89812b2d930c3fa9cd16a54352a4cf9c36d9c24(
    *,
    relative: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb1820b444eb7285c5d903348397d79b1b218ecd395042fecf1881a3cfb07656(
    *,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f91e691a746e8b818f00f28461113260257720e2f02fcbf51c4f79d80e4d9638(
    *,
    computation_id: builtins.str,
    custom_seasonality_value: typing.Optional[jsii.Number] = None,
    lower_boundary: typing.Optional[jsii.Number] = None,
    name: typing.Optional[builtins.str] = None,
    periods_backward: typing.Optional[jsii.Number] = None,
    periods_forward: typing.Optional[jsii.Number] = None,
    prediction_interval: typing.Optional[jsii.Number] = None,
    seasonality: typing.Optional[builtins.str] = None,
    time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    upper_boundary: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3dc530549bc6019bca764db8795b5e3acd8f88a710e7e98e121c2bcc2f9a812(
    *,
    forecast_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TimeBasedForecastPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scenario: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ForecastScenarioProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__829e76534c57a3e2f285027a428362cc8dc3cee7af117c595ada8b70012df488(
    *,
    what_if_point_scenario: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.WhatIfPointScenarioProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    what_if_range_scenario: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.WhatIfRangeScenarioProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90959d3e0ee71e29b41c19db0cd1f5b51611a3b9af7d2bb83eeca51b89d68780(
    *,
    date_time_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    string_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f481aadfa74edce1b66d1816988d464c1f72af28e18dccbc2c01c0121f1dfdf(
    *,
    screen_canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__07bbe87652872f78234fbeb060e181f658867cedffb02337adc12cbf96d13de3(
    *,
    elements: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FreeFormLayoutElementProperty, typing.Dict[builtins.str, typing.Any]]]]],
    canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a972e6dc4bf756339d7c3a8094ff7c1248e0e85efb004f5fdd1bdf23b0ac329(
    *,
    color: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1efb68c56f7c19acb251fb30163e7ac379fcc6b5040fb694928a8d86ad08666(
    *,
    color: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2cb05e72a9acce67f4442e314c4130c787e3a61f511d8475ed2c9e323d816338(
    *,
    element_id: builtins.str,
    element_type: builtins.str,
    height: builtins.str,
    width: builtins.str,
    x_axis_location: builtins.str,
    y_axis_location: builtins.str,
    background_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    border_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FreeFormLayoutElementBorderStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    loading_animation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LoadingAnimationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rendering_rules: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SheetElementRenderingRuleProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    selected_border_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FreeFormLayoutElementBorderStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70f5968d224145b77864fe3e212a23fefddd12d98d4f16ad65f82862d26c4118(
    *,
    optimized_view_port_width: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05b8ccdd5307faf5a757a70e1b706a486b996457d2b944a58a72c592ecf00ba1(
    *,
    elements: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FreeFormLayoutElementProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aace408b5c9a77434abc078712f8b959e3ece3f10cc2292577592c845a953a54(
    *,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a56fa8bef7c45a37b0f6d57489f85aa4bcf476e3005e754a161693aa18450109(
    *,
    category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FunnelChartDataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FunnelChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FunnelChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5bacc08479d189c88550d455b346769521b7ce35e9d537b88edd8f0592b7e4c(
    *,
    category_label_visibility: typing.Optional[builtins.str] = None,
    label_color: typing.Optional[builtins.str] = None,
    label_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    measure_data_label_style: typing.Optional[builtins.str] = None,
    measure_label_visibility: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__427263f05cdce6f497bd2cc0818ec31767bf2aec215e5c863da0dabe71eeb941(
    *,
    funnel_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FunnelChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63de974df528ed8a6f65f8a7861a94176c8253fcf631e2e94eb458a6da15efda(
    *,
    category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11eb4360e3908a74c4d1c2eac25bd4c2f3fb92610f398c4d029394d82c94a674(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FunnelChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3193770941793ac48d16e4b4cdbeb6e3d875cbfeb9cdc14d327d05694ea1a6b1(
    *,
    foreground_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee3c24d3e86ef2aeb08344f18648d5ff677d0cc9da4dca46857b7f2b5d1ec2a7(
    *,
    arc: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GaugeChartArcConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db3bb7f458c5bb03088ea72306d6b41fdaa355726755bafc8674afec9c715eb0(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GaugeChartConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fea0ba99ad1b3d15526d38a27c8008590d5844786e9587800c5a8514183744c3(
    *,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GaugeChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    gauge_chart_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GaugeChartOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__daf0ee523aee63965b511d70b72de53c3390d01f1816827484208a8f970682ee(
    *,
    target_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8c17bdd93f0eec1fe081eb70a918a76490915edf0849cc6e373f3433517057f(
    *,
    arc: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ArcConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    arc_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ArcAxisConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    comparison: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ComparisonConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_value_display_type: typing.Optional[builtins.str] = None,
    primary_value_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4325066aeedbf8956d0d2df46ce10a24eb071592875bd468395073a06d5d39ba(
    *,
    icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b9f11cfc17a7b5c10021167342d4df018195c51992933bcc7ad4f3960ab0664(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GaugeChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GaugeChartConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7515d114e0451a7d5606e6a7f4a3dd9e88dcef9e1fe68358e144d6827cbb91dd(
    *,
    east: jsii.Number,
    north: jsii.Number,
    south: jsii.Number,
    west: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f01ffbeb07e8e6645fd7010279d5161810dda96eefaeff99b6feb9773e8467ce(
    *,
    colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GeospatialHeatmapDataColorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ade06e39a7c8f7181d2a5baf6246bee04dd897bf4e00d308088a09a7d7b2773e(
    *,
    heatmap_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GeospatialHeatmapColorScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7765677970819760ce3a84b37a74b17865bae3f99d6d12d36f844713ba72f805(
    *,
    color: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0081ce6bc2bc7286f3c3dde4cef1576fa5ec0d3d81d922acd1160502c6acaee3(
    *,
    colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    geospatial: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c94bbf4d0514fb89546f03bc3d9bba05117b5d6eb67cec997161c719fc3064c(
    *,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GeospatialMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    map_style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GeospatialMapStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    point_style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GeospatialPointStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    window_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GeospatialWindowOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f24adf7d5f2edab16a8d998d8e290c3075ae0fc4687dee027bb9f43024f4e3a4(
    *,
    geospatial_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GeospatialMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0bf9a88bcd93f122219813203be22ab19e3bd2409bc9c15271ad6b318d1b86b(
    *,
    base_map_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a9dbd6ba6cceac988fa2dc9fbbd35f1368447584a2e2700e6fdde8e9a9d8d10(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GeospatialMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8d4508d35d96aec21a12e6d288ad6950dbed353a7024772ea7842902a22015cf(
    *,
    cluster_marker_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ClusterMarkerConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    heatmap_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GeospatialHeatmapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selected_point_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc7f40fe34a00233ceecbc2e3c35e5dcee432a6d0db96de1cb0c58c0ae1776cb(
    *,
    bounds: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GeospatialCoordinateBoundsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    map_zoom_mode: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27a7446208bfe67d687aee519cbaaed4ac8efa54c443cbbdf9708bd6c305a776(
    *,
    side_specific_border: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableSideBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    uniform_border: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5cb0751a4418198f0765973b54a98a09757aa3ce4e3e4922b434672e646f8b33(
    *,
    stops: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GradientStopProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9785be233d22cda38939c462a2167fdb51a9701bb2ef9909bdfad544a88e5c60(
    *,
    gradient_offset: jsii.Number,
    color: typing.Optional[builtins.str] = None,
    data_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f5628cde5e59ad163ad239a741d0284d2880b8d85b6b9f2cc881247a1867701(
    *,
    screen_canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__07ddf3867d702eb7d8212af0e65e1a706db30e2f3da951b94d6da034d2a13a04(
    *,
    elements: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GridLayoutElementProperty, typing.Dict[builtins.str, typing.Any]]]]],
    canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GridLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d41dff837bdfa0fda2ee1f5027f9ae683257cd1c33a07f86e7756bc5de4be6ec(
    *,
    column_span: jsii.Number,
    element_id: builtins.str,
    element_type: builtins.str,
    row_span: jsii.Number,
    column_index: typing.Optional[jsii.Number] = None,
    row_index: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0762b2492578471646a9ea2bd2aa6807395415b286cfd01b979f4c772217c915(
    *,
    resize_option: builtins.str,
    optimized_view_port_width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89d788cd539eba2c8371dacb20e21bc3c5f714c002dad436e7d9ea1854c0224c(
    *,
    computation_id: builtins.str,
    name: typing.Optional[builtins.str] = None,
    period_size: typing.Optional[jsii.Number] = None,
    time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f55e9b5efe8317be49ec8dd44c387505ab557653b7fa784a61182a8e083c31f2(
    *,
    layout: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    section_id: builtins.str,
    style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SectionStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2aebeb90e30c4dc284a705b12b49faa78a3788d9d66c42ea86e49230ee6efd16(
    *,
    columns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    rows: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33b2cc83619b5207a3569782ee4e7ca1b05e84142345469cadcd0df6113dfe0c(
    *,
    color_scale: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColorScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.HeatMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.HeatMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46d251a3808c6dbd9def272fd8f48092651d1d5f20cb52799c4e6be95a10435e(
    *,
    heat_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.HeatMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97e7e218c841d1919af9453d3724140467e7d3a37e0ccb3c7c54738c6f7e5131(
    *,
    heat_map_column_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    heat_map_column_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    heat_map_row_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    heat_map_row_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce1d7823e45e9c769613b464cbdd93ab8f7a04d1f4bb2683dd1879f3167929b1(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.HeatMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55f052416da79b3a6acdb5f9c369802d9f69e969829c042b9d8fa3ab6411af37(
    *,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6561e35b100703863a6577e11984bcc9c29eeb96e642b079f44894e6be5ac19(
    *,
    bin_count: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.BinCountOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    bin_width: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.BinWidthOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selected_bin_type: typing.Optional[builtins.str] = None,
    start_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55fb22b8f131ca0355cf2363ede9227a9566eaf41711d6e583a7548354ee63e7(
    *,
    bin_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.HistogramBinOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.HistogramFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a57245b80f90a48fe9bc98fd8ba608c332cd9005ea0a92838c1e75a7714eff68(
    *,
    histogram_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.HistogramAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78952f3cbccea943cf440ea987f75700f709d9dd4fc6a9dac06b7492108a6a11(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.HistogramConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8235743ecc0286b79753dfcdda1de4970acead6aaa3259160c576abc6de630fc(
    *,
    computations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ComputationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    custom_narrative: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CustomNarrativeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6a7019df5bf36ddbab4f46b699320b02f7a35b0bbc6000e7642677af41bbe97(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    insight_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.InsightConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ccb4695c74fd56c3b39e1050d3ae136fcdcaf4af35bc03fed020ce96607802bb(
    *,
    dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf138192dc9283275cb3acece8f0b5e40e3ab00313635a18480433bb8a70c44b(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.IntegerDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.IntegerValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ddb7a0b570f94a09892a440b237a12441b8b493eb0917532a86339b9a5651ff4(
    *,
    name: builtins.str,
    values: typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d720c615e5ea3ac62477a614355b7d8007940696895b128072d21154ae8a95c(
    *,
    custom_value: typing.Optional[jsii.Number] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62652aaab644d6381c34df14cdb253620c9017787c2daa67a97c79a88afda818(
    *,
    items_limit: typing.Optional[jsii.Number] = None,
    other_categories: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__919a286d11388cef9537fdc99786898889b85fc6f3875b56f0e6305dfa083ae9(
    *,
    icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c10a5ebe510e02cb10399ecb639ce46b626d86fb5843157da57238e274fc67f(
    *,
    icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__054ca1d8afce6838bbd147fe7ef428987b8990694493d50a2c27acfa33440267(
    *,
    actual_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.KPIActualValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    comparison_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.KPIComparisonValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.KPIPrimaryValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    progress_bar: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.KPIProgressBarConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d09139b8ba0d36404275bbaaa9d5c0754a9a5d5d6e7f73f9aad683dcef24dfd3(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.KPIConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9159fd9adf82ef769630d8281064cd20f26eb2741b067214d01dcf1dc1516e8f(
    *,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.KPIFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    kpi_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.KPIOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.KPISortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28b222716791c98b68a10fdc386c86011553fce98c9bcf9f05df0a77ebd3c794(
    *,
    target_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    trend_groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__59853c403e669ab17e13d6f88be86de38bedce05a11c9ccf87f43262aaa7e8d8(
    *,
    comparison: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ComparisonConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_value_display_type: typing.Optional[builtins.str] = None,
    primary_value_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    progress_bar: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ProgressBarOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SecondaryValueOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_value_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sparkline: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.KPISparklineOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    trend_arrows: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TrendArrowOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_layout_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.KPIVisualLayoutOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7f3446d8e2592c7e0ebc309a027eb735d94e3c3d6e90d988c2627118831e564(
    *,
    icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00958e997d3d3d1685c892bb73fd4e9829d963d1d7d3960a66b1dbb4e4c97cb5(
    *,
    foreground_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__830e3123ef066906448dfaa37c5cc66f39a978b0ec1a8616349a89766eb2d1db(
    *,
    trend_group_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__663aba93d0b6c71a0c5ce59ead14a6dc298172e3c9f326b0ffda40298b8980bf(
    *,
    type: builtins.str,
    color: typing.Optional[builtins.str] = None,
    tooltip_visibility: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3863a82f0561bdb9b66f36a181b4bf3558c5e1d26ac7d046102aa3cf6a4b22a(
    *,
    standard_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.KPIVisualStandardLayoutProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7b926a06aee010f1ae9cc3385634ef06b770bfdeb88431b5e104610f5aac99d(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.KPIConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.KPIConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f172711b23d093cf923c9ef61a740b893f564403053d124223b83bab08c6723f(
    *,
    type: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed3aea282a5c2eb2cd77ddf8885ac91a026dcc243dc633f7e35b5b626157d81a(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__41d36737cec4c19d32ca9ef9050db8ac9846f44bf5cd395414df4eda7b29b2d1(
    *,
    free_form_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FreeFormLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    grid_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    section_based_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SectionBasedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e55b9832974289c97fcd95560d0704a4b3f8f52a5d295492fe6420a37a16789(
    *,
    configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e82b7d2caeb5e63fcc81af6545407f35a2d85c92fe4afa322baa617613486b6(
    *,
    height: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3eb579202bb305cf3c724f33e50675ec7fc5dc6959c987e3851d5837f580e609(
    *,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__325e94055957a7a4fa28fbb3ed26c873db36927077f3686d2bb2a695a498a6f2(
    *,
    contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    default_series_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LineChartDefaultSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LineChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    forecast_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ForecastConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LineSeriesAxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    secondary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LineSeriesAxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    series: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SeriesItemProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LineChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3cd4b39bb4a67901a51b3654698af1994671e560594c357fb303db580274922f(
    *,
    axis_binding: typing.Optional[builtins.str] = None,
    line_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LineChartLineStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    marker_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LineChartMarkerStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__23c446a0a24491ea27ce9de9e6f8399830bdcd50e00cf3bf9a24d2ada71a484d(
    *,
    line_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LineChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80f5ae999d7ee0c6716e616c20a253a968cf221318d4f99c2dc28b18c626a598(
    *,
    line_interpolation: typing.Optional[builtins.str] = None,
    line_style: typing.Optional[builtins.str] = None,
    line_visibility: typing.Optional[builtins.str] = None,
    line_width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b8ee22ce77e49d5edfba08634bd4e383f230c469aba781ae7dc3648b0e8f7da(
    *,
    marker_color: typing.Optional[builtins.str] = None,
    marker_shape: typing.Optional[builtins.str] = None,
    marker_size: typing.Optional[builtins.str] = None,
    marker_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45ca02cd5ccaf4e3acd3f5e37dd78686d05d152a7cb398b4e8b93370fcf39fd2(
    *,
    line_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LineChartLineStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    marker_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LineChartMarkerStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f72384473101adc505fee80a396d4ef68c8f333e0d08de6f8265233017598f3a(
    *,
    category_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a17c46da1e334e21bb122680b41efbece4e896f58e9aa984f17c1c3e0e88d35(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LineChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa43b755d3e8cd729f0c22230227242df86ac6b0ae3c511bdaac2765b9959692(
    *,
    axis_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    missing_data_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MissingDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77e811ecdbaede7841b1061f8849cf7f395967476f906911777c1594226fea98(
    *,
    permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5febadad439ef006025d123dc685e375e9130f929ac04be04802492a54f216c(
    *,
    info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SheetControlInfoIconLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    search_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ListControlSearchOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    select_all_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ListControlSelectAllOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f2bfe88b96feac05893272a6933f32c0cbb36085d7a87747d54d2134855d4d4(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e342c52e23ca2e5cf5121b6c99dfe2ee42d9d8523d26c51bf160ba3d6cee1218(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea6969bd08c6863508c0b35f70105fdb7d54dd6d741313463507879699d9f231(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e727b4e5afe9dcf7ee17567cbece49b8405a4d61ff102fda4699ca24813e33b(
    *,
    target_sheet_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8c82e7585849d11a8eb98093cf1ec0ed05a67b818e40cfb8125e131200fd6a0(
    *,
    plain_text: typing.Optional[builtins.str] = None,
    rich_text: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f9c65987afa3e8ecb810a48c09d13991a4e50e35d888cff0de15d2f81c4ac78(
    *,
    data_set_identifier: builtins.str,
    data_set_parameter_name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7eba20f4560008a2bd679cb6c33f50b8f1d0ff2085b15f74a56aa9e9b27cb548(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6b3c965bc0f32ee00be3157ab64b431f4d8304cd8016a419e48638795caccad(
    *,
    computation_id: builtins.str,
    type: builtins.str,
    name: typing.Optional[builtins.str] = None,
    time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7bda39b861408c2eb1e8cfa89817d96de06554de544f2e1c091d4672bf14619e(
    *,
    calculated_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CalculatedMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    categorical_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CategoricalMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    date_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DateMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numerical_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumericalMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63e8a49c397729aa75566f224e0d131f29ebf8029dcc57744bb63bb5568aa2ae(
    *,
    computation_id: builtins.str,
    from_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    name: typing.Optional[builtins.str] = None,
    target_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2dd6328c694c87ce7bc8e71398688e001f3b30fc6be372cf80de64f3ee2948ba(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e3f6e47ae79491a472a008f3e692fb130c1355a3131b42ea8b4113d051cf300(
    *,
    treatment_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25a251d32a4f0c00a9eef760d498031f541fc3c71caf4c3ee65823d077b187f9(
    *,
    display_mode: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f51b09eae900dd10cd29e9f1885f421f017f3caf1e8e21b09b84868e7a5f8ba(
    *,
    null_string: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a96d7074de53c21a8e539d6cb48e65c7e85d1cbf67eca4ca61b9b1473906ed7(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    negative_value_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_scale: typing.Optional[builtins.str] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    suffix: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6fb36f5050e3d16814ea7055ce44e84526b9fbf9a283f7f6f42b4dd802161c40(
    *,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96ee0575ac0d4099f362576200d818e04a24f0fdce06d4c3533b75aca6cb247e(
    *,
    range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisDisplayRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scale: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a73d37b65e8c2f2d75e447208c2ed3a35accf3a4673c415bb91faf8a8fcc2e68(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33c1d8a8b144259cd2333132730c2b585497c63f012cc936b5a58dcdc1660291(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    match_operator: builtins.str,
    null_option: builtins.str,
    aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    select_all_options: typing.Optional[builtins.str] = None,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef98e28d628760cd44e353d86bb69f21ec9fcd73daede27f00c572f318a86c5b(
    *,
    currency_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CurrencyDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumberDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    percentage_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PercentageDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c681777f29fc0374af076bf89718e3e161e2ca13842f8fb6844762b9658ae3a(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    null_option: builtins.str,
    aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
    include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
    range_maximum: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumericRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    range_minimum: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumericRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7aab34efaf66b9df9b735b4608cdf96bb949e3ba505714bc8eff4ed94daaa2a(
    *,
    parameter: typing.Optional[builtins.str] = None,
    static_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5dea558533477bbcc10607d4b35c93f02497d7e0f1260540b9949fdcd953df29(
    *,
    decimal_separator: typing.Optional[builtins.str] = None,
    thousands_separator: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ThousandSeparatorOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a031996b9f7bbdd777729799f7e91919f186288677074ff2f3027c84d552d263(
    *,
    percentile_aggregation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PercentileAggregationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    simple_numerical_aggregation: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d76f073619eb37e9e71fbf3ebf78782331b851f2ab756ee9131116d2fef3143(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__329f754bdd9a2bf2422eda37f6a20073d93e96fcf8bf689ccd957aa8ecce472d(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__310fcb29ab91bd65346b543d1d0297b090a7bc9447cf55751a416392d9d18835(
    *,
    page_number: jsii.Number,
    page_size: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__faa7c6a00adee9dc4ba6f91728f5ce014b59bcc63fb564cd2d34d597a6c68ece(
    *,
    background_color: typing.Optional[builtins.str] = None,
    background_visibility: typing.Optional[builtins.str] = None,
    border_color: typing.Optional[builtins.str] = None,
    border_style: typing.Optional[builtins.str] = None,
    border_thickness: typing.Optional[builtins.str] = None,
    border_visibility: typing.Optional[builtins.str] = None,
    gutter_spacing: typing.Optional[builtins.str] = None,
    gutter_visibility: typing.Optional[builtins.str] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PanelTitleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5de53ca22e1a3fe648e6b4daf781a351c3cb42a2fb15908472df8d6009793d64(
    *,
    font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    horizontal_text_alignment: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9ccbef0e5e038633af739accbfa89308dadbb10cadb53ba45143c546424ab8d(
    *,
    date_time_picker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ParameterDateTimePickerControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    dropdown: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ParameterDropDownControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    list: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ParameterListControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    slider: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ParameterSliderControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_area: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ParameterTextAreaControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ParameterTextFieldControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6fb8438f75d54be2e2704b76000c4c7685f2c8c0548fe82d3a4d7664a45d430(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DateTimePickerControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a05860ff5b329e2cbc2cf4547a1e0a254e5d56d6df8897a033522f8ab01b6d1e(
    *,
    date_time_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DateTimeParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    decimal_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DecimalParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    integer_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.IntegerParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    string_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.StringParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6323a39d1aaf0938addd2bd3f5756d8f1844ffc27e7d2130636cfc342dbcdd3(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DropDownControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ParameterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a488e59915305b593c54f724cdabe9d29499ccb831d2ad64fd2e73bec399048(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ListControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ParameterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6b317eac2c33db00b8c09bd1340a5c09f2b4ce7e3a3e0283c33f32df0a475c2(
    *,
    link_to_data_set_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f335200a996cfc311bc6eaf56f89ebcd68c9ee97b0bff54556bea2ea8e99387(
    *,
    maximum_value: jsii.Number,
    minimum_value: jsii.Number,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    step_size: jsii.Number,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SliderControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25e1bc62de5af7f068adbb2392c15bcc529db2321930937b15c36ff9b1c77095(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    delimiter: typing.Optional[builtins.str] = None,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TextAreaControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__710574e730ad930b46c151023887cf834fa8a5f71fd91d84929925ec0b603391(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TextFieldControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92d931d0fba6b11706d8e4c3181b34b41c26c6c1042657baa27632cc682c6a12(
    *,
    date_time_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DateTimeParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    decimal_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DecimalParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    integer_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.IntegerParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    string_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.StringParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__454af327f68004c0443555741b9f580a14dcdfe09ec03aea2ebca143ed597bdb(
    *,
    from_: typing.Optional[jsii.Number] = None,
    to: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a82125074cdf02d6f8401dd17680960f778c7f86df989fdee09ffe73e250bf9(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    negative_value_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    suffix: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a5b3017a1482c9ab5debf5891233c374814387651af82f8a7e521a2fb54dea5a(
    *,
    percentile_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63068691f97a26ea9b52587611422559b470d0f4c8d79093773b261b88829854(
    *,
    computation_id: builtins.str,
    name: typing.Optional[builtins.str] = None,
    time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a80fd5af62a1f437e68660af73210c54d2dc9d98ff6bdddda9606d46cbe8ab04(
    *,
    computation_id: builtins.str,
    name: typing.Optional[builtins.str] = None,
    period_time_granularity: typing.Optional[builtins.str] = None,
    time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c017b6b08a6a48b214dbe969a491c25387eb7e3ab88e9782ce5ad34ca75ffe22(
    *,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5646f673e0a66a4e291c909b66c41668edc2c647e1d1553f6a5348ac36ccf011(
    *,
    category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    donut_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DonutOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PieChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PieChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89af0932ba7d86389a68553331219856efcb0fd7e5915a67a8393d7f330a4ce9(
    *,
    pie_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PieChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdcbd7303f50d7a7d0ac68d8896f1ea0a99cb4146701b5d9a5aebcdccd1cd218(
    *,
    category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d6df5178bd6d68f561cb2d13506da5c5df63858264f05d2e99af0995bc68d4e(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PieChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b7a6252c77a5343750b3a158ed34ede9f8f2fdcb13ec1c792508ae20f0db47a(
    *,
    field_id: builtins.str,
    sort_by: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTableSortByProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99d93595e591308d67b9db0ab0ff1f07011c065172687176a1ecc6c7ab9f3c2c(
    *,
    columns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    rows: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f8925cdb5343b18965f4a79b2fb5619ae156f764754d77883c9aa6f4456b032(
    *,
    field_id: builtins.str,
    scope: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTableConditionalFormattingScopeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scopes: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTableConditionalFormattingScopeProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    text_format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TextConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04a83fbff7c12281297bf71879f6cc1210a30a86cf28df5275565b1d0c040e56(
    *,
    cell: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTableCellConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__761b9c337605bed798719853421ef487f48123877d14ec5b706fbe06d543ad0a(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTableConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8d1932fc7354734a1205d21d8846379573920557e14c417bb6a92a70998b1724(
    *,
    role: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e065e6a3b2f37689738a4b2e07811ce8f6e87add015e42c66a7806947832ca71(
    *,
    field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTableFieldOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTableFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paginated_report_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTablePaginatedReportOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTableSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTableOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTableTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d2e668c60b8ac8bc95aa18f481f8c30486eef2a20e7b4f9e4ecec04a05d9d14(
    *,
    data_path_list: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]]]]],
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69c348be65b74f4a060c424046f7921502df34cfd947cea9105546b2f4ba86ba(
    *,
    target: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTableFieldCollapseStateTargetProperty, typing.Dict[builtins.str, typing.Any]]],
    state: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb1a080b4975a48de553c244a7a0e3ae1cdd3fdac6bd777b3bc5cbfee3049fe7(
    *,
    field_data_path_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    field_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0cc77c3bf5ee12e812c49de984b022379e1a733f2d905182816a4c36f6ffd8c(
    *,
    field_id: builtins.str,
    custom_label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc9e2dbfbe3589245e73f83c34f9db73054fd84f0ad392eb306d5d2e5f78ee3b(
    *,
    collapse_state_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTableFieldCollapseStateOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_path_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTableDataPathOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    selected_field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTableFieldOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7b3b6281f5250110629c115d4d3320188b38d92d180c2458031a5b631a9be9b(
    *,
    field_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80921cb7c502eceb637b3c7f3fa875fa80369256ed3db956566b70a9b8bb96fd(
    *,
    pivot_table_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTableAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__647bc3514c4755920ad2bc82545b3653fb6bca626410bc3b47ce4f6ab59093cc(
    *,
    cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    collapsed_row_dimensions_visibility: typing.Optional[builtins.str] = None,
    column_header_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_names_visibility: typing.Optional[builtins.str] = None,
    default_cell_width: typing.Optional[builtins.str] = None,
    metric_placement: typing.Optional[builtins.str] = None,
    row_alternate_color_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.RowAlternateColorOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_field_names_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_header_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rows_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTableRowsLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rows_layout: typing.Optional[builtins.str] = None,
    single_metric_visibility: typing.Optional[builtins.str] = None,
    toggle_buttons_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f3c0005696cb23fd498b71c5de2425da46f04c93805086400da946862377e82(
    *,
    overflow_column_header_visibility: typing.Optional[builtins.str] = None,
    vertical_overflow_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96429ea8e3ed4ba817d09eed2497a2a71cbae45bbb215ca360cb79ccfaaa00e0(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18992597bc6d52b2cd3a0a7d81f5ad09cec19f639c3421b146611bdeff7f1871(
    *,
    column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_path: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataPathSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__128ecd0c48f46fd1ef9c2887afca956252afdfc417006cefc8994174c0a49d3c(
    *,
    field_sort_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotFieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7ffe22539985673bb9a56d7a28def50da65e12afff107cda6f85953e112a8c3(
    *,
    column_subtotal_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_subtotal_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__17f823054c3b5510a12fe64995f8311fffb344955711669303c5c7d75692f19a(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTableConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTableConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c9f9ef553aa6664e46fd6b9709a239463e1b02039328214aad0792872cafe00(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    metric_header_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    placement: typing.Optional[builtins.str] = None,
    scroll_status: typing.Optional[builtins.str] = None,
    total_aggregation_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TotalAggregationOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    total_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
    value_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a1728d0c09a8313ef184532312285397fa5c2dc0820846adf497ed679e05522(
    *,
    columns: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]]],
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b749fd545ef26437f40040ce3d66eb5fc1f74dd885bdbd215d96299ae633448(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62e03423d11f9d7c54d2dbabdc23b969f7868353b929e4d5ed40a4a2e3caac79(
    *,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3574d25bb1ec71053c4a291fcc2d7fa3e00d83cbc5635aee40652325bfc3fc2b(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8b2b95ea63c2d804761b6d030d52bbc1ab1dda02416747db69f54542b5ffb3b(
    *,
    alternate_band_colors_visibility: typing.Optional[builtins.str] = None,
    alternate_band_even_color: typing.Optional[builtins.str] = None,
    alternate_band_odd_color: typing.Optional[builtins.str] = None,
    axes_range_scale: typing.Optional[builtins.str] = None,
    base_series_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.RadarChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.RadarChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    shape: typing.Optional[builtins.str] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.RadarChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    start_angle: typing.Optional[jsii.Number] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d27f31b10381cf6b0b6ed55c67b45cd75c7a2ded433efdc724930790753d71c4(
    *,
    radar_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.RadarChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4004a3e1c32d894c31463894410a7a70880545fbf036b9ec5bd72fd6638e46a(
    *,
    area_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.RadarChartAreaStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d9eac0d17c16fd208c75930518bd566ad2f9eec8739688a8d5c0cb256ac414f(
    *,
    category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6d067660fed84a2ae13210d98360271bc1aea0cffe8c96910b68705ed5251d5(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.RadarChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa68ac0dee70640e44360e40bcd349230a00eff9342a2feaa8aa638ad3f4e726(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee64c1f668eea654b8957c17488ee38a60038469bf8dc04ce4689a01508c5781(
    *,
    custom_label: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8d33a2d7c5fd4d4c51fd48a8a96752ae149d40e45bd87bab473c5a4ceafce71f(
    *,
    axis_binding: typing.Optional[builtins.str] = None,
    dynamic_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ReferenceLineDynamicDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    series_type: typing.Optional[builtins.str] = None,
    static_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ReferenceLineStaticDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__21da6679fe329754114304fa280ba42be3e8008c471e4782bbd89f5e9bb2c3e5(
    *,
    calculation: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]],
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    measure_aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62967aa6515f20b6aecf5b6c0b61f4f605dcfc33d23a40962adceed2559c71f6(
    *,
    custom_label_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ReferenceLineCustomLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    font_color: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    horizontal_position: typing.Optional[builtins.str] = None,
    value_label_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ReferenceLineValueLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    vertical_position: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c838752ba4837b2434d363756aa31b60049b628a02ada11c1bf7a5fa7a5de955(
    *,
    data_configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ReferenceLineDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    label_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ReferenceLineLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    status: typing.Optional[builtins.str] = None,
    style_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ReferenceLineStyleConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b30b9703c5dbcaf4cd9c0e32404ef5b45ed3a46cbf071cf138aef9a262e0a27(
    *,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a3de76085c19eb5a66bd01b1a0630ba106a324c78389fa048377ffd821b8370(
    *,
    color: typing.Optional[builtins.str] = None,
    pattern: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3247f974de1aad308687fd85c41b9a628efd021717e77a6c5c0dab4822c8f49c(
    *,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relative_position: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c342e4ed494f223863cfc40aab4ebc0bef453336b864af3eda85f85d4a084b37(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SheetControlInfoIconLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0008784bd98efe44d920740108b262dbb255d2b3791bc7026913dde3cd832e92(
    *,
    anchor_date_configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AnchorDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    null_option: builtins.str,
    relative_date_type: builtins.str,
    time_granularity: builtins.str,
    exclude_period_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ExcludePeriodConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    minimum_granularity: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    relative_date_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76baf4fdfbee4ab96cf6c6ee179d48b7f41788ca1c0f3b487a3068b2a53ceff0(
    *,
    actions: typing.Sequence[builtins.str],
    principal: builtins.str,
    resource: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d26546e673b70144dd615534198e359d326a13a387cfcebc6115efd3706a9f72(
    *,
    expression: builtins.str,
    data_set_identifier: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de90f049fc7af8d233e801e1edd3c66ff98671bb99f41a27bd52e4c8e31173ac(
    *,
    row_alternate_colors: typing.Optional[typing.Sequence[builtins.str]] = None,
    status: typing.Optional[builtins.str] = None,
    use_primary_background_color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42e16bb197e37e28120a16bae2760af644cdd84794cbc104da17753006df235f(
    *,
    target_visual_options: typing.Optional[builtins.str] = None,
    target_visuals: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee4a2eaf929abf485229c8d2440a138583328585facb13b77cbc368a3249320e(
    *,
    destination: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    weight: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0636b945f2ef0e5d19120e4627fc00b3fbd5e631c051ee43b365ee48f51b5c86(
    *,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SankeyDiagramFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SankeyDiagramSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9a0f8249543a1cd1e7253bbb36240b21fc3f228b0827ac37f8802c7425bc501(
    *,
    sankey_diagram_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc1fb051324d447ccc2b575ed29849ff5b7aa81520770576276b3bdc64c1da1f(
    *,
    destination_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    source_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    weight_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c795d90423eb073ac50c0e342dd78fc3141a08747d1a0d0ffe92c763882d5d51(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SankeyDiagramChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afb04368edb6462289491b2ee7238ddf87123656f93f6a48d968ab46b63f1964(
    *,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    label: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    x_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    y_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9ec0c108590fc491b71bdbd53aa8553faba4c081a35edbf7a454da967b5f430(
    *,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ScatterPlotFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80b49b59e41a288cf59f6f1fc2e0325c9914f3ec5eca29c9b1893a9c2cf5b3da(
    *,
    scatter_plot_categorically_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scatter_plot_unaggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0baab9465872a9e82200203dfc1817299d65d6033fedfa4b613d6f7a54098dfe(
    *,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    label: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    x_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    y_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c7eeeaa3747d4234f74ffa1969b0ff67487d36a9b2cd6ab792ae5ebe9f6abb8(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ScatterPlotConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67187c0ea52237b7a1309d55d73f1ec005aaef59acdccfb29202ec38502e851f(
    *,
    visibility: typing.Optional[builtins.str] = None,
    visible_range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisibleRangeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d0d4223d7f393790d88a12cfd85e5412183ce22f19d2061932a7ddd429d1c946(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24e09d22397f0380bf044ac43d3963b66fb0f68511ba7e86dc1c91ecb4271fd2(
    *,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__495327177acafd80c66111e7551a848e8e9dd4c01a38fc0fbe69aa5edfedddc2(
    *,
    paper_canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__587b23641d0ea9bbaf975c38c597885abfe3e7a2bc26dd1e872f9ef93c7e3719(
    *,
    body_sections: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.BodySectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
    footer_sections: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.HeaderFooterSectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    header_sections: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.HeaderFooterSectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d985ce1432be0a9a0d2d1a3117155a415cca72f565e156ba54202458e98363e(
    *,
    paper_margin: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SpacingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paper_orientation: typing.Optional[builtins.str] = None,
    paper_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c8e818c306efc959258be69024de08ca92ae96e91aba1a71a3007ff59c1fc89(
    *,
    free_form_layout: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FreeFormSectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b78fcebc9723e8f7123340cb0bb1d0a299a2938ae8dc76b038c1a7333e8ac56(
    *,
    after: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SectionAfterPageBreakProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5c6b58857ccef291e8a9afd5e061889c39dc7ff97611c8b6b79fa22a4ed431f(
    *,
    height: typing.Optional[builtins.str] = None,
    padding: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SpacingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44d84419a2ccaeba2d2d8ab98032c9a8ce5a0e884fcc08a683154634a3fa0c98(
    *,
    sheet_visual_scoping_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SheetVisualScopingConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6807c28b152ac4c8984cc472ce658edff6ac0f5fda4be920d4b956e59968fccf(
    *,
    data_field_series_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataFieldSeriesItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_series_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSeriesItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14b79606996bfaf0121a4d5c43b698f35c8ec425311d759a972dac3514280bdc(
    *,
    destination_parameter_name: builtins.str,
    value: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DestinationParameterValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de2604ab9ac3d695300a68b68c8b29b113661d1999fe8c5bfce193f70b394c0f(
    *,
    background_color: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__599adf629d949910b210780f4a78dc6f061309d68fa4524092a633f4ec352c7d(
    *,
    info_icon_text: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac462e2787833fe5b6163c4a32a6170dd269b1e564b46c30555f5715308ccad2(
    *,
    grid_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d689e338dfa6b8e3395217b892a787ce6e5bd14bcde45e27b12d2f99d322e1b1(
    *,
    configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SheetControlLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42787bc8f0211e44eff888e419c7529757d9bde5886a97c9673a45a0ea3c0e53(
    *,
    visibility_state: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__637ce407686da3a298cdda27878a91a61d365d7bec20a48b7fc6bb6d13de60cb(
    *,
    sheet_id: builtins.str,
    content_type: typing.Optional[builtins.str] = None,
    description: typing.Optional[builtins.str] = None,
    filter_controls: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilterControlProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    layouts: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LayoutProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    name: typing.Optional[builtins.str] = None,
    parameter_controls: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ParameterControlProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sheet_control_layouts: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SheetControlLayoutProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    text_boxes: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SheetTextBoxProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    title: typing.Optional[builtins.str] = None,
    visuals: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe51cb7cd4e5b9d742998a2d14d76c934dbb381558ef1d842903a487376fdddd(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__499b540c99ada6d60c4dde2ea7bf4eb135be45d43d14bffa9f2d7b0f25f8b0d7(
    *,
    configuration_overrides: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SheetElementConfigurationOverridesProperty, typing.Dict[builtins.str, typing.Any]]],
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c21837468111244c3de56b5fe2dacbe15de4699bb18a76919a5f3901e2f4cc1(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea1cfc41e0d0c9d637e38e0e7c0c54ba218ec89243b7b2666a061612e4ba1568(
    *,
    name: typing.Optional[builtins.str] = None,
    sheet_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74c00d97e53826dff384253ef732f8c7e273f9a87d88b52bce179fff04f324de(
    *,
    sheet_text_box_id: builtins.str,
    content: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9279f1b0b78c57fec0f29c8290a407cce9b28e9beb086d1ef3a3b460002d9148(
    *,
    scope: builtins.str,
    sheet_id: builtins.str,
    visual_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__befd7183370b0dc4bfd2047acab63e998cb7a8c5356e897d8988828ed460470b(
    *,
    plain_text: typing.Optional[builtins.str] = None,
    rich_text: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__882e164d216977769910a03fd5a932d20e987923108ac1451ca186ea5481d49f(
    *,
    color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e239d7632b9f718c785c202aa5d162b9f047c8bd0bf05dcd02582a4eace25922(
    *,
    info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SheetControlInfoIconLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4dbf2cee4d3cacab4653209bfaec3505dfa674374f7efbfcc5cd60580804b33(
    *,
    placement: typing.Optional[builtins.str] = None,
    scale: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a014fd4be360a4c78a4686a8a43e25bd3e6547115381267b0fa1145da9a130f(
    *,
    max_visible_columns: typing.Optional[jsii.Number] = None,
    max_visible_rows: typing.Optional[jsii.Number] = None,
    panel_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PanelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SmallMultiplesAxisPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    y_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SmallMultiplesAxisPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d10af48042761075c34e6231d9ffa8fcffc93a894863bf3364b3dc12157b229c(
    *,
    bottom: typing.Optional[builtins.str] = None,
    left: typing.Optional[builtins.str] = None,
    right: typing.Optional[builtins.str] = None,
    top: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7c2c1d26ecfc57ea393a168f598cba69bab52250071aaa23976fd4e22ce1152(
    *,
    dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__579192884d4af9500fc2c9fb480930669120e1c45145b4a731200b153f76cbfa(
    *,
    null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8919687a098bd84dfbce9e9db5766d8a599df1749c9283ee17350f1ae11ab322(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.StringDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.StringValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b4982b38fff331d5bba21e46051ef446b46e234e4a98ea8e852a803b149d26c(
    *,
    name: builtins.str,
    values: typing.Sequence[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__018e089951fc42c095c3906a3363edc2a9e6acd283d4e41e332d6e000612e362(
    *,
    custom_value: typing.Optional[builtins.str] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26b5761cb80bd4eb296fb14cc2ace3e489d48b01f174b636486e6b67e10ee691(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    field_level: typing.Optional[builtins.str] = None,
    field_level_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTableFieldSubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    metric_header_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    style_targets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableStyleTargetProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    total_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
    value_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06ec3e26048e42a36acdc448a052cbfb6d8f79af7a0c7a45d9c4329ecf139a6c(
    *,
    group_by: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91428afe0f06f4a2f7f630653be17e89c86fc298d88dae4cd7b46bd937dc832f(
    *,
    color: typing.Optional[builtins.str] = None,
    style: typing.Optional[builtins.str] = None,
    thickness: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97dd9d6b6f88b3cbbeae34b532eeb67c5dbf9bbfee4b2843b60ad5927f1c340e(
    *,
    field_id: builtins.str,
    text_format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TextConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__148cb2bb5db864bd1928be0914a1f93b9a8fc631677ceeb9ca88c364c4ea9889(
    *,
    table_cell_image_scaling_configuration: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4725b1bc64b9968cf7bf1909f7e619eb95067c9cc334cd0cb73d8a67cf676531(
    *,
    background_color: typing.Optional[builtins.str] = None,
    border: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GlobalTableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    height: typing.Optional[jsii.Number] = None,
    horizontal_text_alignment: typing.Optional[builtins.str] = None,
    text_wrap: typing.Optional[builtins.str] = None,
    vertical_text_alignment: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__904f4095015ac5d1118f1e032355f861ae96504172670bef5fcc07d0db2a06b9(
    *,
    cell: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableCellConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableRowConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af82137c10212c69fa09dafa2375d4ac0f88d3d4321f11717643d592af28a491(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a5829fc9800027963440705a81ef3be5c95d9cb4321812c444350ba9dce447e3(
    *,
    field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableFieldOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paginated_report_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TablePaginatedReportOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_inline_visualizations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableInlineVisualizationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    table_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e528dd56da6f2bdc132410b8b05cc00ffdfe869350cab673bed9637be7ebd36(
    *,
    icon: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ce9d7bc7f8a9c4dac84ada50400eb4f79abac8466d390fa3739627e5d182eba(
    *,
    font_configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a737949c68d33bc9425fec6a238be37344aa023096329fce23b2b3dd7d03eb9(
    *,
    sizing_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableCellImageSizingConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4670d1d0f5e8b98564c1607bafb6ff8568818c9c78279ba45bea1c5726cdf17f(
    *,
    content: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableFieldLinkContentConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    target: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e6c8d36af961087ba9d67e20be2e0a3e98078b4f0a03250a01f0ab491d64581(
    *,
    custom_icon_content: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableFieldCustomIconContentProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_text_content: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableFieldCustomTextContentProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__202a64e8c6661e5c0dd724d0e71c19aab1a8e9922ae97db8496df4d4544b0a24(
    *,
    field_id: builtins.str,
    custom_label: typing.Optional[builtins.str] = None,
    url_styling: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableFieldURLConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72ee146032d78abdf24c9225b55a85b01c617371b25550f6b22f15a263905c19(
    *,
    order: typing.Optional[typing.Sequence[builtins.str]] = None,
    pinned_field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TablePinnedFieldOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selected_field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableFieldOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83d9aa30bd42df19076e9b2ca1e2f474c465a691f0bfecd4fcd15ce4ed41f12f(
    *,
    image_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableFieldImageConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    link_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableFieldLinkConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f779abd17ec8354f58f4dcd429883d6cbc69963b366968f0877f9a8f43d9b370(
    *,
    table_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_unaggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableUnaggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__075d2b8a76bbea5648b0262047449d5700569c47654e81c5220160437f892365(
    *,
    data_bars: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataBarsOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c635b9421451d4c53104a38c4586b7ed4a7d7cd618e641c768344bf83477e3f9(
    *,
    cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    header_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    orientation: typing.Optional[builtins.str] = None,
    row_alternate_color_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.RowAlternateColorOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f0aadb280e9d6f01117c85a605f50b9cfeaa5c244f047b536abf34b9d5a1fe4(
    *,
    overflow_column_header_visibility: typing.Optional[builtins.str] = None,
    vertical_overflow_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33457a3c8423dbaa75e524d9d1499fa98efa3094dce4e543d7e40e78a1dd9165(
    *,
    pinned_left_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a70ca40b8f7620081051428a4a06534fac14d4125c7f387a10c5d9ad65d28245(
    *,
    background_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c5b25638ec93acd618d1393d3489d3835cd716296efe5fc56d51fd38a8a196e(
    *,
    bottom: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    inner_horizontal: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    inner_vertical: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    left: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    right: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c742ce7f5c9426ba306a01098393e8e152d4115fcd77fda54e5a32c9c56d012b(
    *,
    pagination_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PaginationConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__100658bc93c03c66f2266c5b34775cb90d2fb3deeccec60f4ce7aa8b7fb51a0e(
    *,
    cell_type: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2bd9325300d3bc1219d7551e1c8b8fcabf75cb9898fe57abd0ef8bc497b63e4(
    *,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.UnaggregatedFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ec6aa6562cd1657a3a4d99afedd9f68d0d4c922d8e322a694e892f62d854120(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e96346e2e0d21e86aa1d52552e64994342afdef67dbcf38bb1f565c355f1ae5d(
    *,
    info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SheetControlInfoIconLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    placeholder_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TextControlPlaceholderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4c9b1c8be6ed1e8a3d995c65d03262c03b6789bf9be98ab76ab401bbb158d9b(
    *,
    background_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db0456c8bedcaf2160cb6972a01b4b75ff071d5904c9ae688269b540b2fc6a09(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f042fa9f65668c58aeeacd2a40752f44945cf74b3e2c26be6285ba0048ad7a28(
    *,
    info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SheetControlInfoIconLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    placeholder_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TextControlPlaceholderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__481e106c212c71713aba9a31e49487994eefaf5c8029e7105d2e9ed0cb2143b9(
    *,
    symbol: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd94fab62c2c39db7fd878a6725a388a9ddb30a6ab99012874b606c8405a4404(
    *,
    lower_boundary: typing.Optional[jsii.Number] = None,
    periods_backward: typing.Optional[jsii.Number] = None,
    periods_forward: typing.Optional[jsii.Number] = None,
    prediction_interval: typing.Optional[jsii.Number] = None,
    seasonality: typing.Optional[jsii.Number] = None,
    upper_boundary: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c16f147af64b9d1eea3e12eda2458de69cb410351d05e72cc4d552dddeac78b5(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    parameter_name: typing.Optional[builtins.str] = None,
    rolling_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.RollingDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
    value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6926d6f7438814f850f457ce463359fbf7ce0acdae4350dcab06806ea44abaaf(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    range_maximum: builtins.str,
    range_minimum: builtins.str,
    time_granularity: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7d6ff152c92765570086d7d642fd87966432b2c80384c704edc04415162060a(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    null_option: builtins.str,
    exclude_period_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ExcludePeriodConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
    include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
    range_maximum_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TimeRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    range_minimum_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TimeRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3da8049a47704beec28b810be20d8ec123f13cf41311c4c1b4d0e470ef2c1e7d(
    *,
    parameter: typing.Optional[builtins.str] = None,
    rolling_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.RollingDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a03f0377cbe55f598c272899419f61a9e1ad0e44bffd279007bd41a69bfe13cd(
    *,
    column_tooltip_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnTooltipItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_tooltip_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldTooltipItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7a503d2cbf643ce64daf5b14fa13c0f188bb34d44528b229b80696067b5e58a(
    *,
    field_based_tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldBasedTooltipProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selected_tooltip_type: typing.Optional[builtins.str] = None,
    tooltip_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0001e11b06c63e33cd7b2f3b6e7bec4ac8e5dfb8cb8b05fe132d59864e80e80e(
    *,
    aggregation_sort_configurations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AggregationSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    limit: typing.Optional[jsii.Number] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d0c2bf9ae4b5f907a3760a6863a5b44047c3dfe6624d4072a3d7b13749d9b492(
    *,
    computation_id: builtins.str,
    type: builtins.str,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mover_size: typing.Optional[jsii.Number] = None,
    name: typing.Optional[builtins.str] = None,
    sort_order: typing.Optional[builtins.str] = None,
    time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac5f83641526bd59afbacd5fe960eca2bf930211b9c0a203855eee191c6166b8(
    *,
    computation_id: builtins.str,
    type: builtins.str,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    name: typing.Optional[builtins.str] = None,
    result_size: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12b50a808892fb708508224e48921824e5642b34f79bc3859879a83386d66354(
    *,
    computation_id: builtins.str,
    name: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__111fe23d82009affd215f44e006244102c4ad2f4016b003d064509d1bf621cf3(
    *,
    simple_total_aggregation_function: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d25344f72a4f3714539caee04de57bb3f85250ce722ef9daf8d4b3a7d37ea29b(
    *,
    field_id: builtins.str,
    total_aggregation_function: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TotalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7fc179aae0ac597c1c7159cbab8982679a211fb2e95fa4887f018e61956a2171(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    placement: typing.Optional[builtins.str] = None,
    scroll_status: typing.Optional[builtins.str] = None,
    total_aggregation_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TotalAggregationOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    total_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13a1765b077c5f3d55533e4d4b702a544c3a66e9b0e70ecbd0c56008193a408e(
    *,
    colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sizes: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fbe7f2abf62b52b7c12391a741ab9378cddd5611467bd29c3ee5643fa6cdc2e0(
    *,
    color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_scale: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColorScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TreeMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    group_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    size_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TreeMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc1ed4b157d486792fe2995df45d70dec38c9055a4d217cc2c596cc31fc213e3(
    *,
    tree_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TreeMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e487c2bf562f77d2421b558a0726ff982725189d022ae5475ce059d4571f032(
    *,
    tree_map_group_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tree_map_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c415fbc50da0b54310da83c3cb3e6830cc15263c6d31a905fdb3c67d8b6b8c15(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TreeMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__790821eed201a9e42659e23dc0e5569f31f85eb1f007460ceb349c1c1087d15a(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9edce176783b802e7011e635b84c0ec5f1e5117e23c0fbcf26f42108389f8cc0(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8cb3da93863693b3294cd64796ece90af0a94a38f860b8a7457dd0ab73ad00ef(
    *,
    computation_id: builtins.str,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9866c0121e30b0debc4dba0dc43db31d1a4f10b2c29c992c5457fbfd011d0414(
    *,
    mode: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb10b50aa2435e54c2b4f09d4df8f9c42c20f0167eb7c3d20b92f3d7b5ccd4dc(
    *,
    percent_range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PercentVisibleRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d33d5dcd3d748910eab608644e829b1955d62d5dd0cba3d106e413f4f1ed4277(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53f0a1da4f6a76661864aa4737c512d664b39d14e0aba25468ee2c44da469bd2(
    *,
    filter_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CustomActionFilterOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    navigation_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CustomActionNavigationOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    set_parameters_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CustomActionSetParametersOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    url_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CustomActionURLOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb0f39821608039a7811382a5857633915dcb72f45adf6050cf21c3fd43f3134(
    *,
    action_operations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionOperationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    custom_action_id: builtins.str,
    name: builtins.str,
    trigger: builtins.str,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2812a2f0ead91339e0ad280e56a2126e5c88c7dd642bee0c3bbe02d4c146d875(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d567e9d819c5aeded7e23d832da9d24b91fa74244eac355da593ae3780d415e(
    *,
    chart_color: typing.Optional[builtins.str] = None,
    color_map: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataPathColorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db7a7e19c2aa0584ce468063502cc098c100d0ffba0208af1f984e822f260f09(
    *,
    bar_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.BarChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    box_plot_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.BoxPlotVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    combo_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ComboChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_content_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.CustomContentVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    empty_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.EmptyVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    filled_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FilledMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    funnel_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FunnelChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    gauge_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GaugeChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    geospatial_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.GeospatialMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    heat_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.HeatMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    histogram_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.HistogramVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    insight_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.InsightVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    kpi_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.KPIVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    line_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LineChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    pie_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PieChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    pivot_table_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.PivotTableVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    radar_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.RadarChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sankey_diagram_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.SankeyDiagramVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scatter_plot_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ScatterPlotVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TableVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tree_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.TreeMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    waterfall_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.WaterfallVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    word_cloud_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.WordCloudVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bed265a8cc34abdd36eaf527e2cbf0f5d70e44fa104d04a26ae31b32cfa05ae5(
    *,
    format_text: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LongFormatTextProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__574aa79ab37beabdf8a2fa1398505f48d0cf2a4662cf29561433ceacf291f26f(
    *,
    format_text: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ShortFormatTextProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f15cd7e197704ff4a3b3e7538fae0832f807a52bcc5b6b98d16c47c4273ddb83(
    *,
    breakdowns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    categories: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad38f0eb69b8cad148b7d6c01c1f46d46616e386d0867fe699ceb550feeb9ddf(
    *,
    category_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.WaterfallChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.WaterfallChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    waterfall_chart_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.WaterfallChartOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b3e2e432ab1177d5a569cbb7519e42a3a7cadd71db940881d20cee54c60145a(
    *,
    waterfall_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.WaterfallChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83f1a91b7244b7831b478de44a6d6cb01c27206e29f5768f88284bd10a9ab21d(
    *,
    total_bar_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8d55dfb376fae774c51ae8486cda285719fc93fb8ac18dc30405f86c1a9f5a21(
    *,
    breakdown_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aab4332ec94b68c3229bed0be35e50a8defe85b13beb74e469caf6f98a37c781(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.WaterfallChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d450cff5883e4559c682e32b90005a4e929478190db5fef38b7c43f32c780467(
    *,
    date: builtins.str,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46bc58f6ee30c901779762ffc386a8ceaf3d3d6554323851ae2a7eaa3eb02963(
    *,
    end_date: builtins.str,
    start_date: builtins.str,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__79e77d16dd6a4dc68eac07b992f227ec5ff37edeed8ece760ece3c87aa27878f(
    *,
    group_by: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d18660a6c55f5407acd69f460a89f7eae547013400ae1751fdd008021f68204d(
    *,
    category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.WordCloudFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.WordCloudSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    word_cloud_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.WordCloudOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__993ffd94b28f2b97e5e6ce988e6a60d0df0710996e198b1ef1422a3b551a2dc6(
    *,
    word_cloud_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.WordCloudAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3de2ee4c24514cef4d4c9febe81b96f78843d3a88347340d5f97dd1e88964130(
    *,
    cloud_layout: typing.Optional[builtins.str] = None,
    maximum_string_length: typing.Optional[jsii.Number] = None,
    word_casing: typing.Optional[builtins.str] = None,
    word_orientation: typing.Optional[builtins.str] = None,
    word_padding: typing.Optional[builtins.str] = None,
    word_scaling: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d7858c0cd2937d4ef09cf5618dae906097d90d87f0357b28790183303e3f675(
    *,
    category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a1870e6ad824dc17b4907d57e71b903f2d02b7a13c0351e5de4340d15c08a59(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.WordCloudChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b83b0d20e5f4dc99e603d3a3d5cffb1cc46142034276d5f015ae3ed7f334ead3(
    *,
    aws_account_id: builtins.str,
    dashboard_id: builtins.str,
    name: builtins.str,
    dashboard_publish_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DashboardPublishOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    definition: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DashboardVersionDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    link_sharing_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.LinkSharingConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source_entity: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.DashboardSourceEntityProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
    theme_arn: typing.Optional[builtins.str] = None,
    validation_strategy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDashboard.ValidationStrategyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    version_description: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72d075b7003c65fe0f5754c362b528fce8eccbf0c8bca521f7a3200fbe0f67f5(
    scope: _constructs_77d1e7e8.Construct,
    id: builtins.str,
    *,
    aws_account_id: typing.Optional[builtins.str] = None,
    column_groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.ColumnGroupProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    column_level_permission_rules: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.ColumnLevelPermissionRuleProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_set_id: typing.Optional[builtins.str] = None,
    dataset_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.DatasetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_set_refresh_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.DataSetRefreshPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_set_usage_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.DataSetUsageConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_folders: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.FieldFolderProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    import_mode: typing.Optional[builtins.str] = None,
    ingestion_wait_policy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.IngestionWaitPolicyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    logical_table_map: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.LogicalTableProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    physical_table_map: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.PhysicalTableProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    row_level_permission_data_set: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.RowLevelPermissionDataSetProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_level_permission_tag_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.RowLevelPermissionTagConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec5ac6f5f08d1896a0e729a544f16b9dd14b6ca545e08c0ed29f38402c3ea53c(
    inspector: _TreeInspector_488e0dd5,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5aabb7b753ce9305d116e2ef3c8cfeabdc2a4633bf23b84eeed79bc90969ab0e(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2aca042c4006d0815bbe3f37fabf0c6c4a17108a63b68bf2c62d9d0bb69c6d8(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bfc1b3a06d0828187a15e4f2444856f0d38ece159fc7179e0bdc666fa156231d(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnDataSet.ColumnGroupProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ade1676b50bbf68ddcdc602d5e40307a31f3822c63e277a8cf478e2c5872640(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnDataSet.ColumnLevelPermissionRuleProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__057a8daa561746a60e341f0a5ece96f4eca188303835b43304bb19fce6aec643(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a893621de91975c4909cf8242c00f4482f5c447cdd22eb27c686ac2fb4b69464(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnDataSet.DatasetParameterProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ed4af1aba9ebff3fbb06e99636946af8c88ed6fe7c6a450684d9b4b6c14a5ab(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSet.DataSetRefreshPropertiesProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf3408380f9b3ee1c1ea22fb4f4a824ff5f9de5a846e28e604c80597826c5806(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSet.DataSetUsageConfigurationProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__376e551a3e7551cc01277dd007428ce4ffd31dd297b01d97d2e891fc2e9be07f(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, CfnDataSet.FieldFolderProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2d4f671f44dcd084b30794fd761c8eac3c1b00283622fa5674fdf0e00f49832(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78487a367319f7d35b3fb5065e030e5843500f800bfe4b40f1ac2ad6fb9140cd(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSet.IngestionWaitPolicyProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74c2bc6065a9fbf14a6895d8ade28cdfd09ca0b45c8a7d9736168fac1cfcf726(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, CfnDataSet.LogicalTableProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea6faccf86873209626a4e60dd29bcaad05116e37856cb62be693bbdac8407af(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e96079d694dd059bb9a8c40170f70894c1f86392667641611d31edf7787111a(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnDataSet.ResourcePermissionProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__209e835d9289f136344058e886fce3fcdedbaa0f7384ae32dbf6f9cad4559b54(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, CfnDataSet.PhysicalTableProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43d473d210e7648e9c1f74143bdd02ab2782474ae542ae1332653506abca38f2(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSet.RowLevelPermissionDataSetProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8bc00e5cb53b8e610ea4e4002e1ad1d313e453c8dd37779836bbe1c1d3e3be03(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSet.RowLevelPermissionTagConfigurationProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e864069859eae5b6577c26a255c633579a87c4792fb22892d990896aff4b48d(
    value: typing.Optional[typing.List[_CfnTag_f6864754]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1231ad01a76710b79ae378de78ccc76bb05c75d0f0df4211be06aa6a0b32293(
    *,
    column_id: builtins.str,
    column_name: builtins.str,
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2fded724bbc6640c2fbe9fe33aee3a869a672cc8cfd40186128cdc1c929ffb6(
    *,
    column_name: builtins.str,
    new_column_type: builtins.str,
    format: typing.Optional[builtins.str] = None,
    sub_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2759b7d3d1f57d4d62490bc88bd45b76a794157c5475aa21855cd5babb42b5a(
    *,
    text: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73b46bfcd2001ac56263a167bea84d22e838ed2c267d9bf17cf6ef4bbeea2eb1(
    *,
    geo_spatial_column_group: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.GeoSpatialColumnGroupProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d7c23cfccd7b2f4aa3ff0e3759008536670b1877eb51b3a21d05d689f576e1c(
    *,
    column_names: typing.Optional[typing.Sequence[builtins.str]] = None,
    principals: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8810951f5cd6f00a3afedc51ad0485b75cccc19bb1600c05ce272802125fa30b(
    *,
    column_description: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.ColumnDescriptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_geographic_role: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__126d3e583c2ac58ef2048d1e7c04201d7b8c4b386e6e2ce57b085e7d0ff1622f(
    *,
    columns: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.CalculatedColumnProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97e4fcb997b025bd8b8162d5528bd73bc1c489c80a53a49d2bf3f33ac9c086df(
    *,
    columns: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.InputColumnProperty, typing.Dict[builtins.str, typing.Any]]]]],
    data_source_arn: builtins.str,
    name: builtins.str,
    sql_query: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8112e3ac95c271ef07e7d73f3bc230c7463e9b93fdcd125f136b968bd641daf(
    *,
    refresh_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.RefreshConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c2217374e9d2612c47d1985150add42b7d78a1798adb4fac5639f8defafe339(
    *,
    disable_use_as_direct_query_source: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
    disable_use_as_imported_source: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef36215242063cda2d33900c2c2fef0ac49848b20c0d6c04fcddd8979789e8ed(
    *,
    date_time_dataset_parameter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.DateTimeDatasetParameterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    decimal_dataset_parameter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.DecimalDatasetParameterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    integer_dataset_parameter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.IntegerDatasetParameterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    string_dataset_parameter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.StringDatasetParameterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e36ba687feb666979008fc6b88da1e17e793fb11294f74256c7f8ae228cd57b6(
    *,
    static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__894b07f7014062eced8643f6a0d92ce5374c5693a6a7b9b8cd77720e35860c7a(
    *,
    id: builtins.str,
    name: builtins.str,
    value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.DateTimeDatasetParameterDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9418fccbc2d752e06362b56183f744c34efefaef5371339619d0242e79ff1e3(
    *,
    static_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b306f04311f0c5a1df60b04c1d4fca8611ffa84e4c685592259379808aa8a8e6(
    *,
    id: builtins.str,
    name: builtins.str,
    value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.DecimalDatasetParameterDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97cb8c9f7dc46795d3b83cc33aee13ecdc65adbbd69b727121697bc461d22b95(
    *,
    columns: typing.Optional[typing.Sequence[builtins.str]] = None,
    description: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c6b79c4b080379d4b3ed9c423474bdb63328a6739ddab0e95e9149b59558c0a(
    *,
    condition_expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bec18505abc90d3d5642a41efec26e4f721ea187d8c10ac74e83c1b18d207db7(
    *,
    columns: typing.Sequence[builtins.str],
    name: builtins.str,
    country_code: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__050d6b5255b31d4ab7c73f6aafa1a5fe608236a3cccebca823246b22b90fee38(
    *,
    lookback_window: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.LookbackWindowProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8536853a045c3529e56b7bfc46c1ae5b6100a9f6cb8981313c803c9a20ff6529(
    *,
    ingestion_wait_time_in_hours: typing.Optional[jsii.Number] = None,
    wait_for_spice_ingestion: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a852fc3befc2e6064fd6912323731a8a0b86c3ca7f67d0d75cbbf9419d455a23(
    *,
    name: builtins.str,
    type: builtins.str,
    sub_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a2b84bdb27f8413d6ddc09d4db29c8d1f82dcc80a10e9a1b7c10a61ea4642d5(
    *,
    static_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6cc6bd26b7cacbfaf5fce187a5a5a3f1f8276cce8a1385e49a7117be4392ebae(
    *,
    id: builtins.str,
    name: builtins.str,
    value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.IntegerDatasetParameterDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fcd61f3ad3bf1aebb609f93c32618cfde562f536e68a0a3f9b823b3292cb52b6(
    *,
    left_operand: builtins.str,
    on_clause: builtins.str,
    right_operand: builtins.str,
    type: builtins.str,
    left_join_key_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.JoinKeyPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    right_join_key_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.JoinKeyPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6028e05db913817056fdfb25ccbeccdc09bf308fc013a40a77d78e696106d73f(
    *,
    unique_key: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38cd7d58d2457b1fb9072a61390c2dda39d5c68c12a8d0ccf51486b4c76134b9(
    *,
    alias: builtins.str,
    source: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.LogicalTableSourceProperty, typing.Dict[builtins.str, typing.Any]]],
    data_transforms: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.TransformOperationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a293e2912f440646f6682b968c3dd42e6638d2854a474189be20da75b501e09(
    *,
    data_set_arn: typing.Optional[builtins.str] = None,
    join_instruction: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.JoinInstructionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    physical_table_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a459912c2016e678aba1d9960ab86b8b700c551da63e7414e8aa04fea6e0a95e(
    *,
    column_name: typing.Optional[builtins.str] = None,
    size: typing.Optional[jsii.Number] = None,
    size_unit: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a90b073999772595b969c4ca3e1f4a4a267b14053b9e5be552cdb4a3651adecf(
    *,
    date_time_static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    decimal_static_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
    integer_static_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
    string_static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2a67afa64d9d72d2c43cc61c225d894d4da6eec0bf0190a7f8bdc51a726ab03(
    *,
    description: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
    sub_type: typing.Optional[builtins.str] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05437bd66651aa702397107d20c1d1962ac4ebf0f44f61c0fb4205d3efeef39e(
    *,
    parameter_name: builtins.str,
    new_default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.NewDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    new_parameter_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f588cf2770fa7b702b2e4f637de59610c15f0ce583be4cd711a33839b2a470b(
    *,
    custom_sql: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.CustomSqlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relational_table: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.RelationalTableProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    s3_source: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.S3SourceProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8e4e442aa58a18179ff77f915ae9041c15500b9de7cc923ee465cc5be9a021b(
    *,
    projected_columns: typing.Sequence[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f5b07a3830c8168aac61eee81da7fe4ea32166016cf2c4406b473b412992eb3(
    *,
    incremental_refresh: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.IncrementalRefreshProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc43d1be088dad877549378a89c5cca422c52436d49d6b5d4f473a7370858ebd(
    *,
    data_source_arn: builtins.str,
    input_columns: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.InputColumnProperty, typing.Dict[builtins.str, typing.Any]]]]],
    name: builtins.str,
    catalog: typing.Optional[builtins.str] = None,
    schema: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d5b477884d5da5b0f50ad9bab47f315489aa821b4b6099b0c110eaa21199d621(
    *,
    column_name: builtins.str,
    new_column_name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9bb58f071bef44343c863821ef329aa5bd07933ca53b18fb0f34a115344ab505(
    *,
    actions: typing.Sequence[builtins.str],
    principal: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a13ff3b14ed90f74324c82b665fb05dfc0a9a4bf781a94ddd25d089945a8396a(
    *,
    arn: builtins.str,
    permission_policy: builtins.str,
    format_version: typing.Optional[builtins.str] = None,
    namespace: typing.Optional[builtins.str] = None,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ece2bf00916836eda450eb8cfff561ba36b89c9d49d36929ccf01d12e6459e89(
    *,
    tag_rules: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.RowLevelPermissionTagRuleProperty, typing.Dict[builtins.str, typing.Any]]]]],
    status: typing.Optional[builtins.str] = None,
    tag_rule_configurations: typing.Any = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__81cfe18daaf7f1cce3330a7282c27dcdf7db3dfda4816cbbf0d13de8875a33f4(
    *,
    column_name: builtins.str,
    tag_key: builtins.str,
    match_all_value: typing.Optional[builtins.str] = None,
    tag_multi_value_delimiter: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__79cf313addf8aafc0315b078c7ce60c5b690622f4de3e59d06a4acc66261b863(
    *,
    data_source_arn: builtins.str,
    input_columns: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.InputColumnProperty, typing.Dict[builtins.str, typing.Any]]]]],
    upload_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.UploadSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f668bce303788d496afc1ab8d65a300b75b6b9f33a139302c49944746ce693f(
    *,
    static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__56f5fcfd7982ecefc35542f2188875aef069ca10ddc427320367c2fa8840e5f5(
    *,
    id: builtins.str,
    name: builtins.str,
    value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.StringDatasetParameterDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93fc79585789eee04ffca88f090e606a6fa427e4c69b3f619a922b666c3ecd49(
    *,
    column_name: builtins.str,
    tags: typing.Sequence[typing.Union[CfnDataSet.ColumnTagProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c858116d8ca183e35074dc7ac22d6e02615a61e79e9558dc2d96336d92a9201e(
    *,
    cast_column_type_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.CastColumnTypeOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    create_columns_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.CreateColumnsOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    filter_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.FilterOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    override_dataset_parameter_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.OverrideDatasetParameterOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    project_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.ProjectOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rename_column_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.RenameColumnOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tag_column_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.TagColumnOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2351ca9dadd3fd462a352b80b2d2c36c320b5ef214657b3f26b548908b97913(
    *,
    contains_header: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
    delimiter: typing.Optional[builtins.str] = None,
    format: typing.Optional[builtins.str] = None,
    start_from_row: typing.Optional[jsii.Number] = None,
    text_qualifier: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__61032f5c9704bd9765ba5fe5f2862434b85348f65b701e3a44b806fef0a9d31b(
    *,
    aws_account_id: typing.Optional[builtins.str] = None,
    column_groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.ColumnGroupProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    column_level_permission_rules: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.ColumnLevelPermissionRuleProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_set_id: typing.Optional[builtins.str] = None,
    dataset_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.DatasetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_set_refresh_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.DataSetRefreshPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_set_usage_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.DataSetUsageConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_folders: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.FieldFolderProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    import_mode: typing.Optional[builtins.str] = None,
    ingestion_wait_policy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.IngestionWaitPolicyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    logical_table_map: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.LogicalTableProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    physical_table_map: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.PhysicalTableProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    row_level_permission_data_set: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.RowLevelPermissionDataSetProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_level_permission_tag_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSet.RowLevelPermissionTagConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__374b42679a82ae47079989dc56d79f0d0b7c439a3c9f7e6d2725ab4c7c4ad6fd(
    scope: _constructs_77d1e7e8.Construct,
    id: builtins.str,
    *,
    alternate_data_source_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.DataSourceParametersProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    aws_account_id: typing.Optional[builtins.str] = None,
    credentials: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.DataSourceCredentialsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_source_id: typing.Optional[builtins.str] = None,
    data_source_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.DataSourceParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    error_info: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.DataSourceErrorInfoProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    ssl_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.SslPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
    vpc_connection_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.VpcConnectionPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8fa1e203bf4b07b7670ba58872971e5952794a17f74a3653f28a8a93005f9e7(
    inspector: _TreeInspector_488e0dd5,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8eb54a2aed0a06bc64a0703fdcc2a5b9961317d6f25e712e1f9a65307f1a7b9(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb379c4375e37df7dc712f334701ec783760f5e486678e89408afeef7d9be1be(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnDataSource.DataSourceParametersProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83eec7204a5e7c9b0b6d35d76242df7c8ad9260aea2231bd8790238ea6c41808(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87f61c5ab7589e751ededa73d48183d342b2d819796cb4eb9698c13b888f19ec(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSource.DataSourceCredentialsProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f495157a0559c40a1200ce0ccad2884a38332d25013afd4d581522e9d39ac109(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d38329c0865968e6c2896e5d42f0ce5ab7b9b828f6f517d45f76625d218a8e5(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSource.DataSourceParametersProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8c906a2be130881812bea32c60ce64f9dd123ce92cb93ebef14967c3ee2f5db(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSource.DataSourceErrorInfoProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__052425c353cfb69cd3d7b21804a17d34c4d718ab05be68ee000a42ec3d089d5e(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67967cbb0c0393ec55fe203f29b3078095f17848804e7a81297e61fe75f5c3ce(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnDataSource.ResourcePermissionProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c040d8fcbe7f80fd38249a6eb377548190fb36b04c193a25bb5844870cde0ee(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSource.SslPropertiesProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0230d4ce77e973f3a7590b7ac180996f418a6d85fa113e78f28e1431f1ce924(
    value: typing.Optional[typing.List[_CfnTag_f6864754]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9629e48048b57721b64306d8b9ec36a4da85373ef960e1d47fd336a6048d3e7(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0f6342c628ea6be2cf1fb1d8a9ac0fcd7e1758472fe1379db22be3198f00bcd(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnDataSource.VpcConnectionPropertiesProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d158e65e94acb7281e6cccc31aef5aff5e52a44d7b01f2e84b33bf228f00754(
    *,
    domain: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9fa436370baac124e212cd999680e59dee51cb3fc88dc417c84a4c5981e5015(
    *,
    domain: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f9751c0f8af713f14cec50a0ea45b4d181e33d0be4649de1d52c5018ba83ee1(
    *,
    role_arn: typing.Optional[builtins.str] = None,
    work_group: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c2a99b8deedd0833045006463a1d33c513b46aa2addc0240f5494a7cb1f68ea(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4fea3df2f87ec4d3b988b7119749d549e5c2bd912e8dae45b7737d90a71711a8(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f99dad3b5f23ffc55f6425b1a4d35ebcb963eff5247a6a5be8fe9bc65b4fc9bd(
    *,
    password: builtins.str,
    username: builtins.str,
    alternate_data_source_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.DataSourceParametersProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8b72e1e41d38f4ceadb2a3b3eacb8937288be1b3b3365202ae7bdda7240a6f0(
    *,
    copy_source_arn: typing.Optional[builtins.str] = None,
    credential_pair: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.CredentialPairProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secret_arn: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57dc1d9b0f11ad204af8757464086e51aedc2372b4ce8e48e02099623234e368(
    *,
    message: typing.Optional[builtins.str] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dda9acee13d5eb627377ef88243d72bfd812d92c22ba8df2ddd7c7001335b871(
    *,
    amazon_elasticsearch_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.AmazonElasticsearchParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    amazon_open_search_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.AmazonOpenSearchParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    athena_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.AthenaParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    aurora_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.AuroraParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    aurora_postgre_sql_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.AuroraPostgreSqlParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    databricks_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.DatabricksParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    maria_db_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.MariaDbParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    my_sql_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.MySqlParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    oracle_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.OracleParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    postgre_sql_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.PostgreSqlParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    presto_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.PrestoParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rds_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.RdsParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    redshift_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.RedshiftParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    s3_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.S3ParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    snowflake_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.SnowflakeParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    spark_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.SparkParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sql_server_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.SqlServerParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    starburst_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.StarburstParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    teradata_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.TeradataParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    trino_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.TrinoParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98e6719897c204ef53c2b23b648a88d9061d63939585326b00645a40dbf1b613(
    *,
    host: builtins.str,
    port: jsii.Number,
    sql_endpoint_path: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__591da15ac3abdbcdfb930993f40dcd32733d6a857e43cec22d71f2596f387283(
    *,
    bucket: builtins.str,
    key: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96fbc9251b1f3ce8d1d57413e29ad2a01fc6cf5c0f2932696069b1805836e831(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e2e40985366cbbc121572739d313b83bf11f9b7c050e592ad7e02d8d8971746(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf876de431aaf56f73ba4abd947cffbe8be9feb3c6a773f4c8d14cbb6e3d1857(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5278b7494520b97a14bd648cbe0a65fa7b0de6b16432c86b003f34c7a33c684a(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1554b3c6dc71110767c433b9379d93378c01fae501057e19dac440df752137f(
    *,
    catalog: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a30b6f28dd8cca8fc2818f609862550035863c318c920a79331e1ac25de5d68b(
    *,
    database: builtins.str,
    instance_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3696c4fb0f434d94a61c7c2824c7fa2d13ab009450487f1d83d0a7116c573ce2(
    *,
    database: builtins.str,
    cluster_id: typing.Optional[builtins.str] = None,
    host: typing.Optional[builtins.str] = None,
    port: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a0d9b8b7745b89b7ad28ec581b2f119c802dde16a26174f65e9d15a40a7ec3a(
    *,
    actions: typing.Sequence[builtins.str],
    principal: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f069a6aef4c854b0ac69ced47783e6b4984dde1bdad5255457297e062757cd23(
    *,
    manifest_file_location: typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.ManifestFileLocationProperty, typing.Dict[builtins.str, typing.Any]]],
    role_arn: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74a75243f71c1f458ba441efa6b1ed83942a35c740ae1f76ccb413de630bf2e6(
    *,
    database: builtins.str,
    host: builtins.str,
    warehouse: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7f1b320351d2ab2e0df1b096a7232368833c11d754d5f46d8c03bab65ffee79(
    *,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78cf4474920aae5ac05faa6ea40b3898aaadc3004a70bca063f1ad8960837180(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0527a039fd4fe9483d9241ba57693fc4698377446bd9454feabe39377ec2629(
    *,
    disable_ssl: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f2aa9471e955cd600412f1750933ac79c8c63536aa9a69f8307c8a446b61796(
    *,
    catalog: builtins.str,
    host: builtins.str,
    port: jsii.Number,
    product_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9aef79f2a949416c28b2a8ca1bd37dda7cd7b9cc340813e2bc2ed1364a1d8847(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae7353c1289a19f3a71f414b52a5a49760d845f3e6ec9f8b5ab78a5e9c264835(
    *,
    catalog: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__595650930405b9b965c7b84dd2e513079a1e79f8b32e4a0f00eb530dbafae6f4(
    *,
    vpc_connection_arn: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b7c8e8d2c1cd22ebd57a1044126743d7661d34244f6d106bdbdbab5f407abce(
    *,
    alternate_data_source_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.DataSourceParametersProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    aws_account_id: typing.Optional[builtins.str] = None,
    credentials: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.DataSourceCredentialsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_source_id: typing.Optional[builtins.str] = None,
    data_source_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.DataSourceParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    error_info: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.DataSourceErrorInfoProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    ssl_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.SslPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
    vpc_connection_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnDataSource.VpcConnectionPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4ad4732abfe72da45af3b75a4f86e13e01f71bbd1c4cf8fd558ce9ae1e3f95b(
    scope: _constructs_77d1e7e8.Construct,
    id: builtins.str,
    *,
    aws_account_id: typing.Optional[builtins.str] = None,
    data_set_id: typing.Optional[builtins.str] = None,
    schedule: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnRefreshSchedule.RefreshScheduleMapProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__945b9e35938c7da340f7d0ada11e6418d6280968ee00dfe592ab3d96b632a08c(
    inspector: _TreeInspector_488e0dd5,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__634038d6ad8a870a16dc09755a0b60c2a4fca196a10286b27404b2341942b63c(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec2c57885f2f67ce627b1a42ad0426f41f7fd104fcfa5e461b3f158cf2c2ff9f(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93f377e11628ad839630ace14f55a70cc5e6ba1e63645d0eedc961f5d94d6c07(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36dbe680f5d7d47ac225fee3430988958753aa10ccf851b25cd6306c5c5dc279(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnRefreshSchedule.RefreshScheduleMapProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0467509e48f18eb095ae995864afd79deb4be252e6b3f56b97ac4d488e2e59f1(
    *,
    day_of_month: typing.Optional[builtins.str] = None,
    day_of_week: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05a08f9e06b3c2605c0ba0ff7dfb4c380508e4b05bbec80e75ba82d7e7b430f3(
    *,
    refresh_type: typing.Optional[builtins.str] = None,
    schedule_frequency: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnRefreshSchedule.ScheduleFrequencyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    schedule_id: typing.Optional[builtins.str] = None,
    start_after_date_time: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__21333ac741c5e658a6c1fc0729934347733dccd666b039ee73de268a25f12467(
    *,
    interval: typing.Optional[builtins.str] = None,
    refresh_on_day: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnRefreshSchedule.RefreshOnDayProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_of_the_day: typing.Optional[builtins.str] = None,
    time_zone: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a670ee5c70bad484737825e5e6eada7f15d88c0b7f9999d233cec3f5709297d9(
    *,
    aws_account_id: typing.Optional[builtins.str] = None,
    data_set_id: typing.Optional[builtins.str] = None,
    schedule: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnRefreshSchedule.RefreshScheduleMapProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0c8e24cc78f3ad01c92781c5833871e8c3706c8182c732d67807ebd0270faca(
    scope: _constructs_77d1e7e8.Construct,
    id: builtins.str,
    *,
    aws_account_id: builtins.str,
    template_id: builtins.str,
    definition: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TemplateVersionDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source_entity: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TemplateSourceEntityProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
    validation_strategy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ValidationStrategyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    version_description: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea41f284e6ee55e6da96665e32a383a979628758f6938fbc128e6408b5be1337(
    inspector: _TreeInspector_488e0dd5,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8c2081be2828dc7c619e0cb33d33870093dfe07b9e5b15fd7866de0542110e6(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f78480e1c1261c6794d46bf12dda9cb4cc8611907c19903b3c13269cb3d1f863(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__323dcf801b1d629158f29c0b88b39cd6b715a3f7e518ba34a005eb76cd1ae4b2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb5ca79f801aad4beca65f22dadde1da626309f4a75061d30e892889b9ebd670(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnTemplate.TemplateVersionDefinitionProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18358e54fd872d6c74a81bd0c3771c61f9d4e0a1a8b928dfb0472cfe45674647(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83811617320114a1932526f92b4fc096a7a21e6f85d36cf26ba5b408a156f5fd(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnTemplate.ResourcePermissionProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95d2e2f9180ec98478cb3a1bf45085f44ba67d37a8813c116abd6df1f1079cd8(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnTemplate.TemplateSourceEntityProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45a0a6a1e0fb3cf2628a59a5f9bddca32815c39a4591ee49eace15fcce0733ae(
    value: typing.Optional[typing.List[_CfnTag_f6864754]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee883791fbdc37cd8bb91a87ef0a3677d4d39fd6a8ca6218c2d9cfc28c1ae63b(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, CfnTemplate.ValidationStrategyProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc48791621f807f516449184e985fed858b7954a64ffb179b2a5b0b1185b9f79(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ae15f6a0d1c0da0b60823cdf82891d19ba1834aaacc2d72f3f95ac978cd22f5(
    *,
    attribute_aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AttributeAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    categorical_aggregation_function: typing.Optional[builtins.str] = None,
    date_aggregation_function: typing.Optional[builtins.str] = None,
    numerical_aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__899b150396efb6193ecfc923e792cfdb69986c414162280980c319c2b3e9d89b(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    sort_direction: builtins.str,
    aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d88efac6a22f5aef2091eb78077eb883d5cb2bb01d3b1283d1bb943ca7d317f9(
    *,
    default_new_sheet_configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DefaultNewSheetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f39641ee4786836892cebe29ab3156870e88f985c155a0a113eacfc7911e0160(
    *,
    anchor_option: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c98bfd1daf818935e1fe927405194f2f3ad49b2e6da76a3e9fc694950518238(
    *,
    range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ArcAxisDisplayRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reserve_range: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5ddb158c4901c1644c76119c1567b809dde75544e560045767e104c92b3828d(
    *,
    max: typing.Optional[jsii.Number] = None,
    min: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49ec559a8c18c88262c9b699271d00d95fe148f809f4d6e536e1cce9d5ccb0d3(
    *,
    arc_angle: typing.Optional[jsii.Number] = None,
    arc_thickness: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ed30d2caa9cc85ec7208853f8d5c87e739853df0073a7bc38aa817ccc5b2a16(
    *,
    arc_thickness: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31ddeadf30bd54c1b83fce4a017f2d5347a82683359d2d7943c4b13efd506dd7(
    *,
    timezone: typing.Optional[builtins.str] = None,
    week_start: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bfc0192b93008407246e8099dc9f5380dbf14f95482c35fa5e2075c0ccfb9b34(
    *,
    simple_attribute_aggregation: typing.Optional[builtins.str] = None,
    value_for_multiple_values: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__892c2c6739dea9d4f226df0563919792795b7795083b6427f1e63c2fecbb1ef5(
    *,
    date_axis_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DateAxisOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_axis_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumericAxisOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__299e628c4c605e541194e9e1d129f3842271f250c689c00c1475c8ae4d703f97(
    *,
    maximum: typing.Optional[jsii.Number] = None,
    minimum: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de16eb692bce6d664ba2d9c38d1d83231bc03e3350b346ce4ccc6c574dee5710(
    *,
    axis_line_visibility: typing.Optional[builtins.str] = None,
    axis_offset: typing.Optional[builtins.str] = None,
    data_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisDataOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    grid_line_visibility: typing.Optional[builtins.str] = None,
    scrollbar_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ScrollBarOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tick_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisTickLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e329fad5b17cde26f47118e45d4aa94d0c850ecd22c23c8002fab8675d20c08f(
    *,
    data_driven: typing.Any = None,
    min_max: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisDisplayMinMaxRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e99511c18ed98a732c74a27da27fef9104d2ddafb0ff322038eb4b4e4233b8f(
    *,
    apply_to: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisLabelReferenceOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_label: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24570836df727f018b47ef322dd3a61d5a8e8eb9a18c1e71f6d9a8c1859eb78d(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8a4b29505afbad0ca6b088e6c7a30d5bcbb9efb9db42a0c4109ac0b73418cad(
    *,
    step_count: typing.Optional[jsii.Number] = None,
    step_size: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__917b40a75680ae4ff5a1f96159a02ba72380fb311945bf8e24e5a75b8a18ce2d(
    *,
    base: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__721d9220a3113f9a49fe2d367328323ffb99773a62f1a6d4e7c35a90a0756903(
    *,
    linear: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisLinearScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    logarithmic: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisLogarithmicScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03d82cd095e47eb37815bb93b179f3cdc725c00a999fe8e1b6ed7f8d467db3c4(
    *,
    label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rotation_angle: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c1c547ea11ddc025bd8acf2ac59074484488e050b3a2719a3e83dec317982d7(
    *,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5365f6038450b55f4f2629b83773a006ba0ca194c88b2804d31e823add586ba0(
    *,
    bars_arrangement: typing.Optional[builtins.str] = None,
    category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.BarChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    orientation: typing.Optional[builtins.str] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.BarChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__127ad02a45eb0822d9d86b5658043155c77cd7c8806d485816a889fa5e5c6059(
    *,
    bar_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.BarChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__968874fce4e23d6938bbdf3a77c42ff110ea9e93ffd38e96dd576fe41f8f9ee5(
    *,
    category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__925db1448c529d5054d62c94edb5dcb90a3629f37641c88f267904704ea02f1b(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.BarChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__190eced312de1d362e6c65a03af74c36d8f57d09e1f2513d30a323b70bde704c(
    *,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad592ec5d03d0efa21db4a7baff48a76ef8f10a2dbd9333728f382fffb4d5507(
    *,
    bin_count_limit: typing.Optional[jsii.Number] = None,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea55503ff61b3f3ed59cbf6c276aa33b5e5f3a127ef8624ebe8061050d9efe84(
    *,
    content: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.BodySectionContentProperty, typing.Dict[builtins.str, typing.Any]]],
    section_id: builtins.str,
    page_break_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SectionPageBreakConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SectionStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70d71407c268cfe839fccff09a3b0bf66dfbafa150032495508c90bd430d55c5(
    *,
    layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cd7624ca2a8ec092df8678ee16699f1613bbaf10dee1a086828354dd5743e3c0(
    *,
    group_by: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c75e3d4a502621a26088dd1dbe75785d35feb297837876c22f25727741883e5(
    *,
    box_plot_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.BoxPlotOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.BoxPlotFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.BoxPlotSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6de5fedb60d8a2060a7d33b391329bf5913f84f9f78d1051be4b26f10e085073(
    *,
    box_plot_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.BoxPlotAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcef52145288cb9f4f13ce0af7da3fe3ec8657582a9fd284dfd2e3539e275cb0(
    *,
    all_data_points_visibility: typing.Optional[builtins.str] = None,
    outlier_visibility: typing.Optional[builtins.str] = None,
    style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.BoxPlotStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dfd3569e0adb8de16a1e02dfd33e0786522d159c9e9cde3ecd8c8869fcd728d3(
    *,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    pagination_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PaginationConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c10a3b25816cb61784d81739f036143d88e5ab7a5a05fde1fac62835c366f2b(
    *,
    fill_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4cec78280cbfee63ecc31cb38d9b2e2cf3240643e10113e8ca98e925d29d30fa(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.BoxPlotChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73faab9c40099774737839775a079cf9d4749cb3ae30a70746a7656fea6d4c8a(
    *,
    data_set_identifier: builtins.str,
    expression: builtins.str,
    name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d319b5fd5184ce055d310fb382015eee9b4eb50946103cb49f53ab2e2257d854(
    *,
    expression: builtins.str,
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2484221a273a9056386fc2362eae583d53799b9e17d5d661f9428c6b55014816(
    *,
    source_controls: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CascadingControlSourceProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00210ff2791c4d1c37569b3292c956c4aebd57844b5bfa98b064e85c2836977e(
    *,
    column_to_match: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    source_sheet_control_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e8c50905be1739cfa42cbfef1c53f007904980cfc7c0cbb10999c6bdc402820(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8290fed180c39bbff9330a45eb3b7c279eaa298d6d25c1d656f107f3fdbda667(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    aggregation_function: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1fd192b5773de245c4754f9b8f53e298e77a08334c9443652f34772cd4816e17(
    *,
    category_values: typing.Sequence[builtins.str],
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49b0232f63d21f0936830f237364bee66c3e438be12db99c87f73417fe0343f6(
    *,
    custom_filter_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CustomFilterConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_filter_list_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CustomFilterListConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    filter_list_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilterListConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3017eded9b1bfc6448b1469ba204c8bbc08e95788b728881eddce09680baf24e(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CategoryFilterConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cd3c711efd09d7544fe28d319f0ce82f22d9327f74110415786c318d4f8c545d(
    *,
    axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sort_icon_visibility: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2c2f574712970589527fe6a64594e55f0fd028d0cee702c43e39314a5274a28(
    *,
    cluster_marker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ClusterMarkerProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40e61b2a20bb12f98d7cb562c5152411c5fdad0f38cf38b7c44205e02804adc8(
    *,
    simple_cluster_marker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SimpleClusterMarkerProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c5d43e7f90822e1aa826bb9f5ab3d65685d3ef249184df4b1b0f34baadb329b(
    *,
    color_fill_type: builtins.str,
    colors: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataColorProperty, typing.Dict[builtins.str, typing.Any]]]]],
    null_value_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5922f18311fbff11cf0dbfc35c9c36329e93df64a3b6b7d15ac7dffda51f0fe6(
    *,
    custom_colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CustomColorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65e6958e3f1ef4998c0a87dcdad7ce409d3cd5ac36f085eee425bcc4a56bbe6c(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    colors_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColorsConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    role: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90b2c13f09982755b418a9c5e58709d9a1a5f8303e1a5e5f49fd8937dbfd2555(
    *,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d0f54e560d7039d07bdd2f554612c445992d7cdee8d18c8b96786920a1da29d(
    *,
    column_group_column_schema_list: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnGroupColumnSchemaProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7cd94a2e28d455d3788f132c173fe3afbaef17d63118c334f1b4a8e88977d8b(
    *,
    date_time_hierarchy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DateTimeHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    explicit_hierarchy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ExplicitHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    predefined_hierarchy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PredefinedHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__154e7348d1c24862f3f981b823ac7120e05a82d936c7b0a4101a89bc45b1ef0b(
    *,
    column_name: builtins.str,
    data_set_identifier: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2197d9d4e00ae9b0022846d0b7f500cdbbb640a1ca573edf02b61474ada568ba(
    *,
    data_type: typing.Optional[builtins.str] = None,
    geographic_role: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ca9307fef2c1e8baa3f0981de7e28837533afb919d862725675ffee3edcb7b1(
    *,
    direction: builtins.str,
    sort_by: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e72a81bfa16daea305420ebfe224e8705acae996707ffe9c3e4fca7ca67c7293(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    aggregation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e76002c75d8316d5a0df86666698505e975b594f3600af284e3b9030c0403455(
    *,
    bar_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    line_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__496e3c5d8f6852db264d3824e5f25aa9e1d76b510ca6a813cf6cfc9067dcf2dc(
    *,
    bar_data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    bars_arrangement: typing.Optional[builtins.str] = None,
    category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ComboChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    line_data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    secondary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ComboChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f8efdbb6f4ba41c7c726b2f199055bb65b1fdb972b6fcab3c3b7da924aa9770(
    *,
    combo_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ComboChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31f2c50709535ef151b74758ba6feab72c3b1cb5a3a4f50ce4f3df6d9547c37b(
    *,
    category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b05e422f6320b8c265d1060c04db301f61299a462f25ccf1d7b3a52dfb0e08f(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ComboChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69c996d7434b46a89b71a4c5230e5944e6e2950d17d010a0a0784199bbdfa112(
    *,
    comparison_format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ComparisonFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    comparison_method: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dabee068e2b731910b73a04bd94f3c61e64a93997b9b7b8e2dfc7a0247d6158b(
    *,
    number_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumberDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    percentage_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PercentageDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77632b79111ed8253df8855a77a888ca9c207be91ca1e365273e54f1b7bc8059(
    *,
    forecast: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ForecastComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    growth_rate: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GrowthRateComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    maximum_minimum: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MaximumMinimumComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    metric_comparison: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MetricComparisonComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    period_over_period: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PeriodOverPeriodComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    period_to_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PeriodToDateComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top_bottom_movers: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TopBottomMoversComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top_bottom_ranked: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TopBottomRankedComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    total_aggregation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TotalAggregationComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    unique_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.UniqueValuesComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c8a6a54650c3b7a7d19a29e10350a9aa0b79747e9b258051d6ae497c5fdbb4d(
    *,
    gradient: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingGradientColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    solid: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingSolidColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96aa1eee01991551417ed2ff01717785059d604c11d48025e17bbac5a4c22072(
    *,
    expression: builtins.str,
    icon_options: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingCustomIconOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
    color: typing.Optional[builtins.str] = None,
    display_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af6db9db8c98022f02ac1d3dc89a99ccb5264e210b2df65c4cb84aba21ce30b9(
    *,
    icon: typing.Optional[builtins.str] = None,
    unicode_icon: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f2de55f86e1ae86889d85c2e511e3072fb65a2e377f3e26d911521b8969d8e4(
    *,
    color: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GradientColorProperty, typing.Dict[builtins.str, typing.Any]]],
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c9f7176c5d1ca667628430307f3e6f0cc47ccdd005902b951025196b31e4efa(
    *,
    icon_display_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf36215e467d3f2b3d313a6270a594f2c90a1fd3e0a5b35698f1b271753e5d5c(
    *,
    custom_condition: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingCustomIconConditionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    icon_set: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingIconSetProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1cf2f5557ed2a89e93f7c6712410d0eb91d14766de9c9e7fbeccda2931c2f9ac(
    *,
    expression: builtins.str,
    icon_set_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__71ad6505c5babab15a9ed7f209c1cf65024e1762926ca213a0235faaee0a96bc(
    *,
    expression: builtins.str,
    color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66651eb3331d8765f1aa91e48973735db342945916472bc018482a57ef1fcb0b(
    *,
    contributor_dimensions: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]]],
    measure_field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e28af5c95538bbeae34825f5df88224c130daf5a377edb14bbc46be99fdeea0(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    negative_value_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_scale: typing.Optional[builtins.str] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    suffix: typing.Optional[builtins.str] = None,
    symbol: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0cd1ddf41ef3de81bbc707b01eac1a10418a48d1a32c7d1d42f03d4bc8df9f36(
    *,
    selected_fields_configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    target_visuals_configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilterOperationTargetVisualsConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42c952d1cd8e1a86f54cadd2c745e98286d41b837588458d1ce75f3226818de0(
    *,
    local_navigation_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LocalNavigationConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30a146d57320d60f1ed6d23e9f2a17a8a577f2fb06356d435a5d9721c8c3a724(
    *,
    parameter_value_configurations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SetParameterValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5025c653b1496d1f4f3382a8dab323fdb13f26ab4f6f5cace16022cb0a19e395(
    *,
    url_target: builtins.str,
    url_template: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c0a44f45a754148ed98c3c1411f5d2aaf53de63fecc91002cdf99b74c84a04a(
    *,
    color: builtins.str,
    field_value: typing.Optional[builtins.str] = None,
    special_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45ecf9bd25689ad2f828879e5f20050fa80cdec18a755159b44fdb420e3e498a(
    *,
    content_type: typing.Optional[builtins.str] = None,
    content_url: typing.Optional[builtins.str] = None,
    image_scaling: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4ef672a4936a4dd2c5ac133be582537a5cb86c0d1f7b6c7f0f228f74fed16f9(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CustomContentConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9bb088dc5e7e43b3c5f9141073112054c6d229d0b043199e57d50f85999d74a2(
    *,
    match_operator: builtins.str,
    null_option: builtins.str,
    category_value: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d92e42778be63999e9af811ecb5f3a5c3901b30aa3d5326181060b0a0fbd3fd1(
    *,
    match_operator: builtins.str,
    null_option: builtins.str,
    category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afdb262079e0e26aef37a00a3372dd7773a4f2a85af67ea3c23606c53e3157d0(
    *,
    narrative: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc7a52cbcd0f391a56598bdcf7ac2a0fdcc4bace6a14bf5e49b915aa2656b7b2(
    *,
    date_time_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    decimal_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
    integer_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
    string_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd84e73c60fac5d450066273e23de5dc97021788becef8a98dca537fe48b8791(
    *,
    custom_values: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CustomParameterValuesProperty, typing.Dict[builtins.str, typing.Any]]],
    include_null_value: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ddab4ee208bfe1b72c92ffb67b46f447f0652db33f9226ffdad9e5aadccab99(
    *,
    field_id: builtins.str,
    negative_color: typing.Optional[builtins.str] = None,
    positive_color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a01bd5ae434eefde64b5a1c75b82798139688763e61ed565ae1bececf1ccb82(
    *,
    color: typing.Optional[builtins.str] = None,
    data_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1bfe82893082073a288ce95596137993bf99e592d5868f15ffd67de88dd99f82(
    *,
    axis_binding: builtins.str,
    field_id: builtins.str,
    field_value: typing.Optional[builtins.str] = None,
    settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LineChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__995e7575445ef7c162160579433dc4b618b1e250b854adba56794678326c9389(
    *,
    category_label_visibility: typing.Optional[builtins.str] = None,
    data_label_types: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    label_color: typing.Optional[builtins.str] = None,
    label_content: typing.Optional[builtins.str] = None,
    label_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    measure_label_visibility: typing.Optional[builtins.str] = None,
    overlap: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a2c695a2624499a41473f19325db50e1542d236aed1e23797015a5b582ede7b(
    *,
    data_path_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataPathLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    maximum_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MaximumLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    minimum_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MinimumLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    range_ends_label_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.RangeEndsLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__875140c1eea1717e0dde0c6d2f35478ce481e2c6d10cb3f0f56725e8efeb3734(
    *,
    color: builtins.str,
    element: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]]],
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e915c6a3fee8f8fb17440847c56eaa67dfa6df9f11721c61457cdbec37b883c6(
    *,
    field_id: typing.Optional[builtins.str] = None,
    field_value: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__396225c307eed402475b3bab5089677883d3bb87f212d4d5da055e034115855b(
    *,
    direction: builtins.str,
    sort_paths: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed5da29da1a549486e1dd3203d56e63d68b2ee2d0ff2cbaa0dceb7262206bca0(
    *,
    pivot_table_data_path_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e04bfec14b8d51fc22ec61aabb0b7e1834dccf8ebad59c991cb5c7766c3182f(
    *,
    data_path_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataPathTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_id: typing.Optional[builtins.str] = None,
    field_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1883bfbe02ab6abc3619f987f1929794734a4c1721bdb4b1889c825c189b119(
    *,
    column_group_schema_list: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnGroupSchemaProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_set_schema: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataSetSchemaProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    placeholder: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__34cd250355f66ef094f8bf4236684b609cc82a0ab91d166a45fcd715895d9213(
    *,
    data_set_arn: builtins.str,
    data_set_placeholder: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10cdddf57a0e8c0c6d38148ff644fd1761ea7e573a8bf58d1c5f843806763533(
    *,
    column_schema_list: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnSchemaProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8b27489657993a2a6782e22027de3b6151ece013bdbf8b293ea6ad0d97a9ca5(
    *,
    missing_date_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31435b58c08934e7951a43c6c56ee1fcd395dde36a0f48329da06d3830b326d7(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    date_granularity: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1560ba41f7285670910c317ea264e0b72a9dc7e42e9e4ad580d57634e2f7194c(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    aggregation_function: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f32fc19f4c057c2a2cbe06f9b32ff5b6625ca952a5caac9b5677fddfac39ce7b(
    *,
    dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rolling_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.RollingDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__387218ed9131df4da4fcec10b97b56411a8744d9a8aca0113505e7554ce63bb8(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__600db28efb4756d643dc84db6d6354a66d6ac2b3b8d315e5cea7bf832e5109e3(
    *,
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7bb94cd6032e3f0506aff5592e90e5d72b9057c51c0d9a67a286464b6014282e(
    *,
    name: builtins.str,
    default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DateTimeDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
    value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__400fad16d79e9b1c8c236281649c4f38d0175ad36cdf6096c1aed88d8dcb7ec4(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SheetControlInfoIconLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0254d2d507667662407f4476fb9cbdd31864d55ad69a3ddf1a8a132fc4c239d2(
    *,
    custom_value: typing.Optional[builtins.str] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45c7bd4f87aaf9d9ad0cd787bf00b8b8217df5ca1f83b1f04d64acd006150015(
    *,
    dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__595364948f9e14a42bc42f9d12a4ef1943a83410f2b89a407e171d4ccaf9bb89(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DecimalDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DecimalValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a36a9620eb65337911b054129318b32487f923ee6fdd603b127c4635f300a72c(
    *,
    decimal_places: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9078977010fb2b1821bab1c11791be7229453b880f6a7a115450ac49a63061a7(
    *,
    custom_value: typing.Optional[jsii.Number] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6311f9cbc866df56f8e45d5a24ebc39e460605ec4cb5a25a249eba4411cf4a11(
    *,
    canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e175e3d68e389ce0a28a8c0c694123c6f30db22c4842f99ef70f2e09a22fca3(
    *,
    canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GridLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc0e4bcc549de7ff742e72d1a317d01c1ac1a833d76c9964255ca15a86d34f9e(
    *,
    free_form: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DefaultFreeFormLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    grid: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DefaultGridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bfbd48cfb6718d17dcabb693158d2c948bd3c00fc1e034a03154a5ab48ccec67(
    *,
    interactive_layout_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DefaultInteractiveLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paginated_layout_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DefaultPaginatedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sheet_content_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c131b4d9a2aa5b67ba6b274e56c0d1988d073ae28c95adf8fa0d6ff4701859c3(
    *,
    section_based: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8f9186cb96df41c5b157940c7c99eaaa2ea37b15cc111e51340895cad7eda06(
    *,
    canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aba08da7d814b258ff3e2e6d34cda7b9dddd4b57f89d611e1c57af10391aaaa4(
    *,
    custom_values_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CustomValuesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    select_all_value_options: typing.Optional[builtins.str] = None,
    source_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    source_field: typing.Optional[builtins.str] = None,
    source_parameter_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8c02c72897035f8e1fca272cd87bf2ea0a4a02c584ea26677bf58a3ce1e72f8(
    *,
    categorical_dimension_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CategoricalDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    date_dimension_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DateDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numerical_dimension_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumericalDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2d100bdafc76427866ae8213c38f91a2ac406357a5a3b4abec6643d68778ec0(
    *,
    label_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c393b70dce31f5ff171ea97ce085d14fd9f0ab5ce5b054f145ceeff13ae0115f(
    *,
    arc_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ArcOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    donut_center_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DonutCenterOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b087350cd5169d11c01b910bfb40bae0cce5811b1dfe5656a5c56c36e021017(
    *,
    category_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CategoryDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_equality_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumericEqualityDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TimeRangeDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__063246ac8fd75fc93cf7d4ee5b4eade385b65be86925075f9cf31fc664213706(
    *,
    info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SheetControlInfoIconLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    select_all_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ListControlSelectAllOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4d28086b7a8945bf67ff7c05c555a817f15bef22809cf1f3b510436dee4866c(
    *,
    default_value_column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    group_name_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    user_name_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1ce82fab3120ccb09d446a7e5d3e7c4741884668d69c461a58548da297ed25e(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7945b229d13e7f6413e3973305f7232329bb6be04db562f4dd466a94568af172(
    *,
    path: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de2cf26916aea6d152855499da4a5882c69fcc4a6c4d442e71f66acce5b87716(
    *,
    amount: jsii.Number,
    granularity: builtins.str,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e01d9b6a41f2cfa1a0ebe11134c4b304e55ca36a00723a86f03d87d0420ca4e1(
    *,
    columns: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]]],
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e02c1c64a4fc22c0fc0c54cbcef1d363794af1a2617ce66824e72d68c469461a(
    *,
    aggregation_visibility: typing.Optional[builtins.str] = None,
    tooltip_fields: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TooltipItemProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    tooltip_title_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d324dce70fc25603c5d85a251b1734468f0c0b145424d4885254a72685306e47(
    *,
    field_id: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14c844d9acddaf2240111640aa98c6500fdcec36bbb80cf5c7b0f4e25bc32a35(
    *,
    axis_binding: builtins.str,
    field_id: builtins.str,
    settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LineChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96c89da174b3d15590d444e938a68fbef9762448db2dc5c78991102f82aceef1(
    *,
    column_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__85c581ae9abf255fb48266bb24a81c07deff5ab8bfb1729d4f3efddf58034f13(
    *,
    direction: builtins.str,
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__297ede735671a624776585becdbf3f66ab88b4a2caeee3f00dd4b384c2e8dc58(
    *,
    field_id: builtins.str,
    label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce7d943404d9c4487ea9e5503b7c80bd6ff1741384dfde148b364fbd479a133f(
    *,
    geospatial: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02ebf1bf7a85a1d96bde2d6c1703fc1397d0f0311a234101190c3c558b46c84b(
    *,
    shape: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilledMapShapeConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df3826794046129ebc4d625e9b39ef7f2725b27c256a82dda0cdfaddabf692a6(
    *,
    conditional_formatting_options: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilledMapConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e04f7abc1692fee86faeb19440ee5471fb5ad802c888a0ea25d3935c6dad873(
    *,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilledMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    map_style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GeospatialMapStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilledMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    window_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GeospatialWindowOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a0087a39747e1867ca27880bb626ed9e93d21e7a7eae2e0fb3c2f03744b1d969(
    *,
    filled_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilledMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c21337cb52b8bbebbb570a4086a66643672d1468aeaf742277621de100bad21(
    *,
    field_id: builtins.str,
    format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ShapeConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__433bb89fcafe7552154706cbdcbea46758758c8750794f0e9c8e64178b0e432e(
    *,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20b159b9596e4213827becba8daa6be2855e3ab9c4f383574a15398d838c9630(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilledMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilledMapConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__17c85186d7b47b18464b3e0c6561277bf174ea650ce639d4ce9028e1e46d9553(
    *,
    date_time_picker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilterDateTimePickerControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    dropdown: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilterDropDownControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    list: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilterListControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relative_date_time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilterRelativeDateTimeControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    slider: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilterSliderControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_area: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilterTextAreaControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilterTextFieldControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6dcb3713c6fee5fa1f08d0cb0f2027bf0f0d073e2ad8cf57da9058b54a81c95b(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DateTimePickerControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6746085d5cb80d1bab46d5212600b8db63b0f525d4f0afb856c441b62009214(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DropDownControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d006f785e58af6b52d38a79b763948bfd9a9cc46f049c94d82e0d8a7ba3f911(
    *,
    cross_dataset: builtins.str,
    filter_group_id: builtins.str,
    filters: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilterProperty, typing.Dict[builtins.str, typing.Any]]]]],
    scope_configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilterScopeConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a2d40da847e970d8867a6188195be0f5ee377e79e9b8d73253d8fbfcfc78de5(
    *,
    match_operator: builtins.str,
    category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    null_option: typing.Optional[builtins.str] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7fcd1280333091b90bcb153b1e8e0751159d5e57dd92667b95e74a9f9cdfcf0(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ListControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99c48630a4143e91c66097748bf20c5581cc437a1d8aa8adaf0b018817107cac(
    *,
    selected_columns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    selected_field_options: typing.Optional[builtins.str] = None,
    selected_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b57cf8043ee4ba481fbb66efe48b5c56ba864f070b676ad8c0a30c31db8d3bf(
    *,
    same_sheet_target_visual_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SameSheetTargetVisualConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__88122957d84b62e3e46e2cbb5339eea38b7214fb962331dc061a86be966da1f1(
    *,
    category_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CategoryFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_equality_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumericEqualityFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumericRangeFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relative_dates_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.RelativeDatesFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_equality_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TimeEqualityFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TimeRangeFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top_bottom_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TopBottomFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb1c600dbeff75cffaf00fb3a32280ca5bbe390a750d74f195c117ad62829b0b(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca54961ef8f7ff0fa30d3349b60168a444bd2ecc63a1e3543e0d4d8f9021fd39(
    *,
    all_sheets: typing.Any = None,
    selected_sheets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a10ef4a35c7db75c0d20ea5166cf2b4d2f17bc776713086d69c39337a2e5372(
    *,
    values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__59d4d25e91fd0d533f6bb1bd01396691d6607dcfb129a172d5ef6f81bff34752(
    *,
    filter_control_id: builtins.str,
    maximum_value: jsii.Number,
    minimum_value: jsii.Number,
    source_filter_id: builtins.str,
    step_size: jsii.Number,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SliderControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b5ffc0a588507ef89ff8b034495114519b749283e4d61e1b9073fa3a542e032(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    delimiter: typing.Optional[builtins.str] = None,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TextAreaControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91cd23b096753aa5d23f510cff715dc438567b0d757007b15459db5af0ce2ba5(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TextFieldControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3469b62ba533651a28a78b890d4deee38bc93ca1181de1f427d8c2ed4ee2f7c(
    *,
    font_color: typing.Optional[builtins.str] = None,
    font_decoration: typing.Optional[builtins.str] = None,
    font_size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FontSizeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    font_style: typing.Optional[builtins.str] = None,
    font_weight: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FontWeightProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96a1a2797f4159ba4fd559ac100ca3dd9d695503a82e5babb2c27c636550f204(
    *,
    relative: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15121e71351856eb590573e619b4b9bab28f8d3501aa2324291f86ef4af3db52(
    *,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b268a89adfb2419a179e2d39f72efde8c0e4db3a1ed16bdb473a924b4f54be0(
    *,
    computation_id: builtins.str,
    custom_seasonality_value: typing.Optional[jsii.Number] = None,
    lower_boundary: typing.Optional[jsii.Number] = None,
    name: typing.Optional[builtins.str] = None,
    periods_backward: typing.Optional[jsii.Number] = None,
    periods_forward: typing.Optional[jsii.Number] = None,
    prediction_interval: typing.Optional[jsii.Number] = None,
    seasonality: typing.Optional[builtins.str] = None,
    time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    upper_boundary: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1b6fc5c895b13eaec515b23f4f8a4692c6d4f5014112a41f729fe4eb5256acd(
    *,
    forecast_properties: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TimeBasedForecastPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scenario: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ForecastScenarioProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb886964e5d61c15d79cc1aa4baa8d8bcdbd6ae6472ac35351ee5ede86476e27(
    *,
    what_if_point_scenario: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.WhatIfPointScenarioProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    what_if_range_scenario: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.WhatIfRangeScenarioProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__acdc6b41040857bec7b41583d6aa2ca903d7c372d0fd7b65e57f47207b1b2ed1(
    *,
    date_time_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    string_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__578614b125fa78db8c3ebb5abac4c2182b919c173af35ff2427c33aeb5edb423(
    *,
    screen_canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4cac125aca61112d564bc6e57da7fa96c4ae6e3550c01d3b1d6caceb0d8e1ba(
    *,
    elements: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FreeFormLayoutElementProperty, typing.Dict[builtins.str, typing.Any]]]]],
    canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5c2a2026e2d524c7e248d3811cd8d5b8eaf86ff1dcece91281d063c70baf7dc(
    *,
    color: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f56b915d4e5cc7d588d0f18eb9fd3d08c59522395df40438804d9d4bbeb58248(
    *,
    color: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25cb30344f75b27e4dad55332b21f1de2d8134f89b0322a8c2001b30746f08cb(
    *,
    element_id: builtins.str,
    element_type: builtins.str,
    height: builtins.str,
    width: builtins.str,
    x_axis_location: builtins.str,
    y_axis_location: builtins.str,
    background_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    border_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FreeFormLayoutElementBorderStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    loading_animation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LoadingAnimationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rendering_rules: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SheetElementRenderingRuleProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    selected_border_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FreeFormLayoutElementBorderStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4627784e9a82be5a483f9fee328533ba95d23dbbf4afd5ee1fff8bd408376a01(
    *,
    optimized_view_port_width: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb8df5f871659ca72d6d13167d406149f8d88621342aeb61ff2ff094a4651b91(
    *,
    elements: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FreeFormLayoutElementProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7bd6bb6806b5fddb8ca871b0b0c39956897753f18b6c16d5c6e23a6cefe5ead(
    *,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e476041f68cbbf567dd0859194b5d26f6a98f02f72e5998caef5736c738d7324(
    *,
    category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FunnelChartDataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FunnelChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FunnelChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12be43077e9b40ff95dcd923411975cf5f8242d6f3b4857924875d52bf02fbfa(
    *,
    category_label_visibility: typing.Optional[builtins.str] = None,
    label_color: typing.Optional[builtins.str] = None,
    label_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    measure_data_label_style: typing.Optional[builtins.str] = None,
    measure_label_visibility: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__471f8fdec66cf65d5903c99b6be5980372b1618781ebf0e5b062408fd2b22bd8(
    *,
    funnel_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FunnelChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aef80e1ad1d3108bae0d0ea9e9a03fbd222dffe680b6fb323c6f8f02eb75d914(
    *,
    category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__88c327ab778f2f7154850fbba1d3978086640da4a25649e5bea6b8b06c90f458(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FunnelChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__436ef0ce4c9cb6675bcb93e940ebfb1ec177942857d43bd23aaf9aaa170a5d80(
    *,
    foreground_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5112906a24edd8e035bb15545d6cd7dd1b156e881499b860838a93532ee13e4b(
    *,
    arc: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GaugeChartArcConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2aae0062f023b94b466eeae30f381f8dfd52660e394b4fe0b9d7da3f755935d3(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GaugeChartConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31660e5ea9cf2cbc922be62c6cada90255349936dda5d364ea4c7bb12ee13fb2(
    *,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GaugeChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    gauge_chart_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GaugeChartOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51f564322d2b7236e526362ce70069f02d33a5dd91614daa635235ce5cc7ed53(
    *,
    target_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7496bf2790efb8bb0918a64ba138509ffeeedab22e886649e39297d2ff212196(
    *,
    arc: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ArcConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    arc_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ArcAxisConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    comparison: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ComparisonConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_value_display_type: typing.Optional[builtins.str] = None,
    primary_value_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d5330716651cc74d353267430eddc96f133a2deb8edf9c27c2037953bd31eac(
    *,
    icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9911ce5c489454303eb190a9103b593ed6610d87bdd3d22d992f3b5e0134d617(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GaugeChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GaugeChartConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0618b503ed66a7115e609c691ee63ca56267ff9fcc56f5a2d7505e1bb6d5dc6(
    *,
    east: jsii.Number,
    north: jsii.Number,
    south: jsii.Number,
    west: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97f4e71fe84a69e8594d5a40d3c3565168672613da4e1197fa5a3ba3228d3823(
    *,
    colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GeospatialHeatmapDataColorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8d9d0a9eae4bec20f2a35fd69381cbcbb6593ed91307368c75c57b775387bae8(
    *,
    heatmap_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GeospatialHeatmapColorScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68c180291553dcefd48063c6a1fbcb141cd6df09cc6e9b3afee8302f4f93feb3(
    *,
    color: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4078270ae0d1f0826052a34ba441c52f3fe6b93c16d193c5e80a8cb9797c99d5(
    *,
    colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    geospatial: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc257a355d98660cc467f4dde2d7433949be71dda663428f3f7a77c40098f56e(
    *,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GeospatialMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    map_style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GeospatialMapStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    point_style_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GeospatialPointStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    window_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GeospatialWindowOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__900c4bd8978e855594c12f2d2a001ac72365ed9de1052ed0c5397c8d7781ead6(
    *,
    geospatial_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GeospatialMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__243f3d486b014da7bc3129533b25ed3166fc37e43bf1c28e2c278a8513e2299f(
    *,
    base_map_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5befc48a60f2c98e0a66d26e02857cead97b29898f87167c6dce7fa06b246e0a(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GeospatialMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7250866c1e062e814d7bc295f99ef4045964f162e73b7504e4bb6d09cf6ecaea(
    *,
    cluster_marker_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ClusterMarkerConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    heatmap_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GeospatialHeatmapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selected_point_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9b20c1f2b079db907121d78fdb1a3b1cb7085825284d6698626d9c2ee256fab(
    *,
    bounds: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GeospatialCoordinateBoundsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    map_zoom_mode: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b8dab5ec645a241806e0c0fe4b80c09c77db8527e25c1fa693e6a861cb35231(
    *,
    side_specific_border: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableSideBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    uniform_border: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__324594fd3eb246dff0062859e62e8359eec861fdef2d9a4c638018855885098e(
    *,
    stops: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GradientStopProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1cad120cd737f86590ac108db01fec92be4a595434342ab7d5979f7593270ea(
    *,
    gradient_offset: jsii.Number,
    color: typing.Optional[builtins.str] = None,
    data_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b538f92423ed565546fbf5fa1af8beb1ebae8fae8b3f594a77ceb6d65a3981d(
    *,
    screen_canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb6821d9ce0cd248060c5d69c86be08d139652c15fc7c9146ff709923a9e7938(
    *,
    elements: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GridLayoutElementProperty, typing.Dict[builtins.str, typing.Any]]]]],
    canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GridLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0476bb9be385036ba1ded41436c1d18d98418591f5604c24add296e6a7082ac3(
    *,
    column_span: jsii.Number,
    element_id: builtins.str,
    element_type: builtins.str,
    row_span: jsii.Number,
    column_index: typing.Optional[jsii.Number] = None,
    row_index: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__666e086df81d6ddf24a4db1db8727dc8fc96ccff2f22d4991ad47540df006ff1(
    *,
    resize_option: builtins.str,
    optimized_view_port_width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e23629184cc8bcc77e48bfad82c0395bd45f57fae4a87a1903c384ec9b7e938(
    *,
    computation_id: builtins.str,
    name: typing.Optional[builtins.str] = None,
    period_size: typing.Optional[jsii.Number] = None,
    time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5eedffe8b1923c1b4959afcc98d580c04810c5a5a7136fb3104eb8ea10892ac5(
    *,
    layout: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    section_id: builtins.str,
    style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SectionStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb2f335086420535886b7b890cb7334bdd85b67c36b9582107b1577391ad537f(
    *,
    columns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    rows: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__edfb12f03d10b80f1864da2a88fc64bae09071d1826b0c67bde492b2c55b7bb0(
    *,
    color_scale: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColorScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.HeatMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.HeatMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0bc87f4ac11a24f2f0019220d7db037b8a62737500be9e8c8b116418b6088e80(
    *,
    heat_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.HeatMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55062ffc9247875871d29b8980ee36d9298aaa0a058adf79cc80ec698a954e9b(
    *,
    heat_map_column_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    heat_map_column_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    heat_map_row_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    heat_map_row_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51db201590a51b4b46194728f07968555086c7604ae37997cc981e1b65a70620(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.HeatMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa06b8fff735d5b0c496941e0d1f46d6b1d9107ccde96ef32ff9cf0ef95b977e(
    *,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8109468b73b8c175e7bb158ebb357f62ccde320883059c7580950d2a49191968(
    *,
    bin_count: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.BinCountOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    bin_width: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.BinWidthOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selected_bin_type: typing.Optional[builtins.str] = None,
    start_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f664855874f20d709d8a65d458c6265073033475c63a3a0a7bb1ea3839c30bf(
    *,
    bin_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.HistogramBinOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.HistogramFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e5ca3b8c77ba7e660696d744e6654b4550fd6a8639a9924be9c8906a93a8ebc(
    *,
    histogram_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.HistogramAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab527615f6b21e9430a86b65d119a808df9a319645b768620dc48e1435719fdd(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.HistogramConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de5ac8843b10f13c98afb9192d6451f0f353ef81e8a1df734101a8111749fc37(
    *,
    computations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ComputationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    custom_narrative: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CustomNarrativeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8256e5a80490f1dd152d5cf322d9537f166c7ccd6874c322ea73fe341cac3898(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    insight_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.InsightConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__79c0c995261a52fa2d3c8e7d958cfd9b62c06e970f6667960a5147834a7e7b8d(
    *,
    dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[jsii.Number]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7ddb6f8183831a28a8aa246d5fda74b1c818950c976a659b5544bb38c333bf8(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.IntegerDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.IntegerValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75ff7f588d57c9e801a21bed4bd3061b461d5e16cdf4e009fdbef448ef1adc39(
    *,
    custom_value: typing.Optional[jsii.Number] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84a93917bca10c20c9e72df34deb76834cb5aa1fd09a4b6e524e4b2457f02703(
    *,
    items_limit: typing.Optional[jsii.Number] = None,
    other_categories: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2dffb3b08c0efb00a2dd126ef1eecafaa340228f3b5732b6f1d50f773826188a(
    *,
    icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9eb1b23ffff0116e21e69887a057315fe696819cec0f84f46f7e640234cd30d(
    *,
    icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__339f1d2a70fcfa43c5d28bf4f6c1fd73d3f069c24d0058071e781bec0defed3c(
    *,
    actual_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.KPIActualValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    comparison_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.KPIComparisonValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.KPIPrimaryValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    progress_bar: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.KPIProgressBarConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83d6fa0f7ed288b5a525a299e1675e97c59e1d6d8b235fdd2c5f863984ec0f67(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.KPIConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e55893839361c4728001fbde8d39d86cedebff69aebc787aa4a187a8a74444cf(
    *,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.KPIFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    kpi_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.KPIOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.KPISortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2ae2a5817a435d9920364dd415989561d0ec363f433f1401a5732d7bf7be4fe(
    *,
    target_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    trend_groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2dfbd0856000c8b9e8e7a25558c9b5d729907669af77294b37213426b6978baa(
    *,
    comparison: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ComparisonConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_value_display_type: typing.Optional[builtins.str] = None,
    primary_value_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    progress_bar: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ProgressBarOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SecondaryValueOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_value_font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sparkline: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.KPISparklineOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    trend_arrows: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TrendArrowOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_layout_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.KPIVisualLayoutOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__71079005fc8aa875e9f07e6ec40fd725dd0b13f0c0b9532feb777fffd050e39c(
    *,
    icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__611a890ed03201d98fc7af48b56ddc52c0a3ace963baa20e6254ad47740c1e34(
    *,
    foreground_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f4b39ef55b680cbb12fafd91103298c38998b9e927dab4376ad6265175dacf94(
    *,
    trend_group_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6183b3ba8f4515a9d5b9bc06343a7a906895257c322dfbb96589aad73a5ca5fc(
    *,
    type: builtins.str,
    color: typing.Optional[builtins.str] = None,
    tooltip_visibility: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1cfb28ab26a94a06d33f496c4a03e8d245c5004dbd2a4f95e49c9cb17ee76386(
    *,
    standard_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.KPIVisualStandardLayoutProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4d8219c64814a915b6f55ee6fbea36745a1eb67e9d3762944f7a1dc303f8d24(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.KPIConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.KPIConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__267de0f3e92d4c6362e4104fe04fde215f6781fc0ddaebad08ac75372afe8c30(
    *,
    type: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3fd818a7c255c79287bf84b2a124248eb218f11289ab7fb4a22c849ded8e80a8(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b525a1aaad5609f117a600ffed9d6c618d1e78b9132a41d45c2a39f07f0a24af(
    *,
    free_form_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FreeFormLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    grid_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    section_based_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SectionBasedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33a24a96d0ad68626e1112b855ca8dd98a11abb380e1c0876a0ac1f814328e69(
    *,
    configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8673c92d2f96698e2403e46aa2954b7739f2970492853314dcc1ffa3db8a2c45(
    *,
    height: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c317d36d4b278b652f3242d8b2de5a8347800f39c2fb751bfbbcceaf3a379f81(
    *,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5512c77f2e4a1702a8c594533133d44abba69e618642372c6dbeccc102cf3d54(
    *,
    contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    default_series_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LineChartDefaultSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LineChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    forecast_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ForecastConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LineSeriesAxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    secondary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LineSeriesAxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    series: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SeriesItemProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LineChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92044b7be0ca37011a03642dd917371b696c8a4ac918d17b9c960de67598af40(
    *,
    axis_binding: typing.Optional[builtins.str] = None,
    line_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LineChartLineStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    marker_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LineChartMarkerStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__022c66ee2a6f952d5efb3250eaf32c3f0babd14415f6722a5113bdbf0264decf(
    *,
    line_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LineChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aae75a71d83e54e3b20a2643ba8871a3ae5264f9d8b7e9bcae8ddaa89deda19e(
    *,
    line_interpolation: typing.Optional[builtins.str] = None,
    line_style: typing.Optional[builtins.str] = None,
    line_visibility: typing.Optional[builtins.str] = None,
    line_width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ed467167c488109aa9bf06c701d587d3346e7a4ccd6729073280a8eb9a2e52d(
    *,
    marker_color: typing.Optional[builtins.str] = None,
    marker_shape: typing.Optional[builtins.str] = None,
    marker_size: typing.Optional[builtins.str] = None,
    marker_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8502b89cafafdbf3399b7a94abe4819063ea7034731a35b721557ad60395e2f5(
    *,
    line_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LineChartLineStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    marker_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LineChartMarkerStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f7936e46a8b600d8690037a0869afdc0f413c715a5f0f59d4bbb2593d5e4602(
    *,
    category_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e19cca65c746b1f803157557ecfc1e6cd720a70dce62910e5a0d55c63c36102(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LineChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44dc37136cfaae10bb2310298b57d1421b364f7819ec02ff088f1fdf28e40d97(
    *,
    axis_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    missing_data_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MissingDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca8cba505438f9cc90d295b2d3da50b8e8c8feb94f873f2ada533b9fe8f8a089(
    *,
    info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SheetControlInfoIconLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    search_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ListControlSearchOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    select_all_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ListControlSelectAllOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__619d434836756e0902fe7f71906803e4e2c3977837d91d51178e7f6b47ad63f1(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__496c17dd9f8144236cddbe3bf135a2c4ea2601c94f841e25b9902b1822a7ee57(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c786885e8082b3b3457d8ec95c9eb5836ea170a678aac001f47406157e1f344e(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e3a6c3c5bf767ba83e8c991e07df42198274e5ded97e47305b195b7d7b92e8d(
    *,
    target_sheet_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65bdec78f38ce1afe5db408d8940b5fe563893e6e91d7740622358620cc94ee6(
    *,
    plain_text: typing.Optional[builtins.str] = None,
    rich_text: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c6ae60e451fe7dff8753ad0d950d26682e2f3ab5be66b26b771d70abb5c5f79(
    *,
    data_set_identifier: builtins.str,
    data_set_parameter_name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac6cf684662783fe0378195f35ffe1875e4d7baae65cd6777baae1964cdf7bca(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15dd15ed61f2c2e17a6d1829ac2976b57cf91069b8bb28fab8202b92ceac09d2(
    *,
    computation_id: builtins.str,
    type: builtins.str,
    name: typing.Optional[builtins.str] = None,
    time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3bd18060e8ab68dbd312d5880484954da32dfa2e19eb25a7ffa1eb190c8c271(
    *,
    calculated_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CalculatedMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    categorical_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CategoricalMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    date_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DateMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numerical_measure_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumericalMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51ce5b40674bb03088d888ca46951ae63eb7409301c5120f31de7353649c627c(
    *,
    computation_id: builtins.str,
    from_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    name: typing.Optional[builtins.str] = None,
    target_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3379fed9e190f7ceb91e3580e038ddada30db775f39391d082d4c9e949a82715(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__660d39b682dcb70af4c7f14448b4f3d65dd00c45cd9613f3a74dbf817ba4e237(
    *,
    treatment_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__861dacb150b9116530cacc74aeb5fef839aa760953bb470a63908c93a5d65c88(
    *,
    display_mode: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ef2703bb84434a9c18efac4a8fe2867f5900bb19178ac0f4e9a9e81b63125ca(
    *,
    null_string: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__32d6a92fcbcf2ed74695382053c5d78ad7aee0a3d227f0ad9308f1c9a79fd4b2(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    negative_value_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_scale: typing.Optional[builtins.str] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    suffix: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5b337fd34b602376c2d4b2a56c499171ad222d849e3826259e72cbfc560ac95(
    *,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f05adaa975168b09a3c5a5b4ebee87c01d6fa8b72b3c3d742e44124e4419115(
    *,
    range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisDisplayRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scale: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da6dafc8fe3785b9a50e89ba100d517e376fd5564f2be7f84e16710256f392b9(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__077d3058a3ae75f8e36d381073421b87da859085b5b2d17726a9cb51677e04c1(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    match_operator: builtins.str,
    null_option: builtins.str,
    aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    select_all_options: typing.Optional[builtins.str] = None,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__255f8d073f54dec93bd2c56bb6a5a7f43a33751ea474002c12e635fb4a27fb42(
    *,
    currency_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CurrencyDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumberDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    percentage_display_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PercentageDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7c41df0822b558a329cc70bdd5a20bc6c7ff2cdfa1e87de73209c354f5a86ab(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    null_option: builtins.str,
    aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
    include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
    range_maximum: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumericRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    range_minimum: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumericRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4eb10de204924c8f371165138bd4aa3765f920645f18a3ec41d52ccb14760af(
    *,
    parameter: typing.Optional[builtins.str] = None,
    static_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6388026317ac90b875b9560e9ffaf93e3f7fd7d23c01d8ca1a3db65f342bbe3a(
    *,
    decimal_separator: typing.Optional[builtins.str] = None,
    thousands_separator: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ThousandSeparatorOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__976084e0b8f503e1d4a3cc34315384fd7458cd243b551586f2e765f1b75bc560(
    *,
    percentile_aggregation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PercentileAggregationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    simple_numerical_aggregation: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1fc40f6a0439d409cb0f32912334e2b232712f81f4cde7ca9164d72426dfb3c7(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8dbff5970ac76bcbe5f856c919a637aa0e845c724320f1b388dc32ed62b0771d(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__270b59e4b6a2e8a93161529222f4ea2238f653fb098e010d7896eea3a69f216f(
    *,
    page_number: jsii.Number,
    page_size: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0fac64ca9f41312eb62a68abd7c113da3c7eebab0c12065d4078969746227026(
    *,
    background_color: typing.Optional[builtins.str] = None,
    background_visibility: typing.Optional[builtins.str] = None,
    border_color: typing.Optional[builtins.str] = None,
    border_style: typing.Optional[builtins.str] = None,
    border_thickness: typing.Optional[builtins.str] = None,
    border_visibility: typing.Optional[builtins.str] = None,
    gutter_spacing: typing.Optional[builtins.str] = None,
    gutter_visibility: typing.Optional[builtins.str] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PanelTitleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45ab70b3fd95e49ef3268cc1edce400bb46b4a415c8091086a630aa8383a4e05(
    *,
    font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    horizontal_text_alignment: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__47d5e3a66805c54a34bfe8d0e68d7e8d019846c76d7516bf16ae89cf5b21bdda(
    *,
    date_time_picker: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ParameterDateTimePickerControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    dropdown: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ParameterDropDownControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    list: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ParameterListControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    slider: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ParameterSliderControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_area: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ParameterTextAreaControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ParameterTextFieldControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9ecad2e18890766f2c4aca0e0f85799fbaf55dc846f14a7f89c858279412498(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DateTimePickerControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7702a729402847cd3b9f7ff918a131852b209d248928eee0cc7914f2e2c6cd19(
    *,
    date_time_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DateTimeParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    decimal_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DecimalParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    integer_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.IntegerParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    string_parameter_declaration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.StringParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7aa165991c6350bb966a26a09859966bdfeaa334d539dc305d12cfac86b56c19(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DropDownControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ParameterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2b9011b851175e8cabd06e74494d4ba410de5a0604e0bd305959d960be42c4a(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ListControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ParameterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02febe921a1aae761973af4de966ca120691e228959c6290908875cc28f8200f(
    *,
    link_to_data_set_column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__debaa75b83a5c74194078475b0f788270d3c456ba5c124f6401ed3f4a96210fb(
    *,
    maximum_value: jsii.Number,
    minimum_value: jsii.Number,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    step_size: jsii.Number,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SliderControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8036ec596e30eaf8755087de485ebc547948d90258011a864e4cccac4ca82900(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    delimiter: typing.Optional[builtins.str] = None,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TextAreaControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2201056e2e7e9e630572eb58fe4a67aa8d3d9e11cfccc33365981d45c4aebb99(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TextFieldControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93375d06c22852c4caa7f5ef789ecbb1759add926a659101140431d71482e369(
    *,
    from_: typing.Optional[jsii.Number] = None,
    to: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e28c16030570b3912964aafd4b26f1fa75b4133594c8cb00202f799bf436f9a(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    negative_value_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    suffix: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2dd05d8b08387ab86292cc30c74083647c706f46201ecc59a494fe1b2912614(
    *,
    percentile_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53f9997128020d044b3f06eabf7741d00417d19712b9ac21cdd48187ac4885ff(
    *,
    computation_id: builtins.str,
    name: typing.Optional[builtins.str] = None,
    time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__119c047085a74c43e8ed6ef2cd82bd8ba8f88b1a847c008c69588aa6a9bde55c(
    *,
    computation_id: builtins.str,
    name: typing.Optional[builtins.str] = None,
    period_time_granularity: typing.Optional[builtins.str] = None,
    time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67a594736efda49ae352612e8753174881b3d3a7a5874efabf9803ef2c56350d(
    *,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__753ed9f6b9b7f0426a2e0c4bce80bc7e939f0a5d150e85d66f2207a29f7fa05b(
    *,
    category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    donut_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DonutOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PieChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PieChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b107ffd40a92c542d866a2f96f95d07c6f8410c207d831f748256eca4f30654a(
    *,
    pie_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PieChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c169cd1f70c1bf335049afe1918d08491ff5dc90e37bd3a98c7f9c787cfcf96d(
    *,
    category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6fcdea99db171d2a0f21d5b13ae314e1dc3d13454f406e8ede6c5d2e39e71b0(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PieChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aea4fab7f5fea27b9021ac76a6b8b14d11881784a0e1e07e1a4fcab04a8f7ebf(
    *,
    field_id: builtins.str,
    sort_by: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTableSortByProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1aaf9f615751c99146a946cbb53e523cb25228c3272f1a4ed4475f8aaee6dc48(
    *,
    columns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    rows: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c0a9dabb25bb51951b8353fa11224adb471304577a761fd86824f26214787ca(
    *,
    field_id: builtins.str,
    scope: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTableConditionalFormattingScopeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scopes: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTableConditionalFormattingScopeProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    text_format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TextConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60d1ad0a17f98540768122e7a693c51331b270b1c39d4d09e6536b86709a8664(
    *,
    cell: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTableCellConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66a2cd3955a034899ff5325feab9f88dfc7e9e0dcde2daf65a61963ce934303e(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTableConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__172ad52c74b1ac21a38b984944da4f33e60ed5fdd833f09346cfd57646078383(
    *,
    role: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__721a1a2646b528a0f39a6d54c430519c81b71e531c079d47fa37528046e0990c(
    *,
    field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTableFieldOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTableFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paginated_report_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTablePaginatedReportOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTableSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTableOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTableTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65d2f7cee829af963ae66906b27517f97dbcdc4089a2c84a398496d15146e0bf(
    *,
    data_path_list: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]]]]],
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c664424ee2ee8340d6471477dd4b4151305f25205b910c022c3ac7a2f783e35(
    *,
    target: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTableFieldCollapseStateTargetProperty, typing.Dict[builtins.str, typing.Any]]],
    state: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7834d29ffa6ca6dbc548e8ed48b94f44a1d193103bdce641f1b7f2ba8893ac37(
    *,
    field_data_path_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    field_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8eebf08bbbc71497293b914df7065a880198d46c5fa9fc98fb69d7df131f9767(
    *,
    field_id: builtins.str,
    custom_label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2f73bf13a652217ea66bad7282ca340406c63df7e24fb9957788dd86087b499(
    *,
    collapse_state_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTableFieldCollapseStateOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_path_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTableDataPathOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    selected_field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTableFieldOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78f5f1418344785a12a2059eed9d6f7a257807d04da28d814d2f38d8f862850d(
    *,
    field_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d559863b89a60184d3b7448898dfa331551dda6628e33e60f7c35feb479a01d1(
    *,
    pivot_table_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTableAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7b18650c965a207638aa8c482bb96d77b098414dd1fed613958eb169969c580(
    *,
    cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    collapsed_row_dimensions_visibility: typing.Optional[builtins.str] = None,
    column_header_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_names_visibility: typing.Optional[builtins.str] = None,
    default_cell_width: typing.Optional[builtins.str] = None,
    metric_placement: typing.Optional[builtins.str] = None,
    row_alternate_color_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.RowAlternateColorOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_field_names_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_header_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rows_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTableRowsLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rows_layout: typing.Optional[builtins.str] = None,
    single_metric_visibility: typing.Optional[builtins.str] = None,
    toggle_buttons_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0b3d9b74952ab7869387bd736f5945e3b0867cd27d99ef24ffb44c366ab4d47(
    *,
    overflow_column_header_visibility: typing.Optional[builtins.str] = None,
    vertical_overflow_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__708c2ee8fa6ad42c9119986aa20e9f62968254e5f0c9bb479d9fbbcff8fa1413(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b16f94d643e218a8c2ab38374ef5850297aadb59ef53cc0bcefb632c0ca8b82(
    *,
    column: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_path: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataPathSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef85321f15888e8c0f3a5fa0bcc8a12f931c4d5066414db4e5fde06478d3e67e(
    *,
    field_sort_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotFieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be59d283da376e9d42d7ecb599df249f829dffe04e932db375724da27ee38386(
    *,
    column_subtotal_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_subtotal_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d39c1ec15f49a6d8169c96a134105a89975ec3248982335d2109a987d67982b(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTableConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTableConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c18ce2a83acb5dd2cdd206b9990dc5e18b46c2f9e3769414b4d5c304e6632bcb(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    metric_header_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    placement: typing.Optional[builtins.str] = None,
    scroll_status: typing.Optional[builtins.str] = None,
    total_aggregation_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TotalAggregationOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    total_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
    value_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad591b783fa5fa196df370a4f4402b4128b38a891b2fdc1575856a9a944d1a92(
    *,
    columns: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]]],
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb41668f45eb37d8d64df1fa71a745e5417dbc9277dd4ca8c0c665d1a2a40ba1(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46c93b0194d8213c14a61ec775d8aa1349dd19712c87d825c6d2fe73f5e37968(
    *,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb539595ab9b08310e48bd065032dfcf316fac36084aff51215bdb8a7e4b7275(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__106a5058bf6fa7ca94cf2199e6968a77010c71510f006e0362301aaa16d11628(
    *,
    alternate_band_colors_visibility: typing.Optional[builtins.str] = None,
    alternate_band_even_color: typing.Optional[builtins.str] = None,
    alternate_band_odd_color: typing.Optional[builtins.str] = None,
    axes_range_scale: typing.Optional[builtins.str] = None,
    base_series_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.RadarChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.RadarChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    shape: typing.Optional[builtins.str] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.RadarChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    start_angle: typing.Optional[jsii.Number] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4bae251f32c771911ca8b2be63d86c15669ebbe793125cf3cd5ea5e9a703f1dd(
    *,
    radar_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.RadarChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5eab408b399dad4a06a7313fffa42352e787d1bd99de1ba672af562069b2df91(
    *,
    area_style_settings: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.RadarChartAreaStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c6675a95eeacf8a9db24b3acfeddb075b954352d556c59fd200f8b055fcda26(
    *,
    category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3cf5b3fffb435c163304fe45aeed443d272acb7ee1fc6313bb1d30b78f4feeb8(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.RadarChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__650d8a6baa5221eddd94d67bb0c9303c2b5e4817e5d47fc4c018515e03cbae6b(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f71115fae8644cef2d84477c85bad8fd377d7d191469b59e52f89d62ea9a798(
    *,
    custom_label: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da5de79943e1959490d8aa872550015dd5047b5e9a13e47dd41b0cc4192c6bf4(
    *,
    axis_binding: typing.Optional[builtins.str] = None,
    dynamic_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ReferenceLineDynamicDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    series_type: typing.Optional[builtins.str] = None,
    static_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ReferenceLineStaticDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb6f388ca1e7726651534509a34615205e188e11705fef02d546d7276c3fe353(
    *,
    calculation: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]],
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    measure_aggregation_function: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f77bc8bf89c9f0e27a1b8c85487033d2dcada397afb0553a86302a8b3914741b(
    *,
    custom_label_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ReferenceLineCustomLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    font_color: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    horizontal_position: typing.Optional[builtins.str] = None,
    value_label_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ReferenceLineValueLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    vertical_position: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5cccbf131d76f477371049fef51f604cfb16a84b126f423e4e2b3c70b6c6f75a(
    *,
    data_configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ReferenceLineDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    label_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ReferenceLineLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    status: typing.Optional[builtins.str] = None,
    style_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ReferenceLineStyleConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20157a5288f35eb360ed5849d2a6efce6750ddf16135829250ed59447015cd7f(
    *,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cbcf012995ca009b92f00c1dac21c0f15c968a37d25d2b356a13b11cc48ce39b(
    *,
    color: typing.Optional[builtins.str] = None,
    pattern: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9a9cf2a5e90fccbbedddb9230bb64c130cf8bedbd44c7ebd715f87319c2058a(
    *,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relative_position: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35f8219e8a55bacee9602344d4869eb77b9e343298c47b6959fe9e989c1eecfd(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SheetControlInfoIconLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92fd36912f41fb616fcc2ea44b0301396ac5aeb0d8b751da8a7ca19993715ded(
    *,
    anchor_date_configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AnchorDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    null_option: builtins.str,
    relative_date_type: builtins.str,
    time_granularity: builtins.str,
    exclude_period_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ExcludePeriodConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    minimum_granularity: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    relative_date_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45b749995134d34d827369dbbb9838430a21db65d9f345e3d90ab4119be7f4ce(
    *,
    actions: typing.Sequence[builtins.str],
    principal: builtins.str,
    resource: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37a50dd839a676dd9dc51bfffd04661b36646f859856fd4fadeacd2fb342ae88(
    *,
    expression: builtins.str,
    data_set_identifier: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ef83b8a5b599b6d25d136eb812da4b37ed9e81a2ea99419d4d71d48156cf928(
    *,
    row_alternate_colors: typing.Optional[typing.Sequence[builtins.str]] = None,
    status: typing.Optional[builtins.str] = None,
    use_primary_background_color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c7e60056e3b5cbe822ab42d550b65a6e94b3023aefc8057a91e122d6e831d0c(
    *,
    target_visual_options: typing.Optional[builtins.str] = None,
    target_visuals: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e245ef9b2d48edb0045aeb023cd9de4a0ef751b92c86eaa8c3c2b9803aa56ad2(
    *,
    destination: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    weight: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d09679114b9bf9d034a4a2e73ce075aa2b8913c3fcb664a905099e7ecff45e6(
    *,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SankeyDiagramFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SankeyDiagramSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8918193e2be2a8d34f73cc2dbc1c1de479bb1b75e545e92f12aeb84e9f7acd95(
    *,
    sankey_diagram_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9694f4b68ce3b50d527e73d5c0c4a9a74ef14f98061a504476145f49e78cbdb4(
    *,
    destination_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    source_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    weight_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a885e901778bedce1f2ebda579b9189e8b0c4e41459173af6bc298ca1e0a3b3(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SankeyDiagramChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6746ff4b87ff0a299e29af4269c999a5ef7d4e252e4e2102fa4e82aac925648(
    *,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    label: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    x_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    y_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__258bf8090d349be6903de00f58a3ca9d2e589346e08d480950437072326c047d(
    *,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ScatterPlotFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29da102eef55bc93c228f4ac0e24ff94c2d527af918d2a61f5ed6031a4c61279(
    *,
    scatter_plot_categorically_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scatter_plot_unaggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e207ffaafa8cdfaf404f62a6555d52c0e9e5a07242a8038d2d16f32ec284a1df(
    *,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    label: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    x_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    y_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__879575b049e53b3daa0d983662cc655e11b4d69d4c8f5ca28013cb537ecf487c(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ScatterPlotConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ee368d35744531b8573eff531ffb1d0ad1e891e30d9b365574b131167fca688(
    *,
    visibility: typing.Optional[builtins.str] = None,
    visible_range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisibleRangeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97f044f8cc96381e546020326f02d820f630974a369eb22d2213428fa19a12ff(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a5d86e966b487b229aaa556fa1931deb9adc5b7323cf139727280a9f7fab4dd(
    *,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33052b6e45bf47c0da040740720240f654800dca3ca1098ffd1fd52e795be469(
    *,
    paper_canvas_size_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b808d8e615270149e5e6d77d1642245ca3d9612e469b8ec5e554d04ad0083824(
    *,
    body_sections: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.BodySectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    canvas_size_options: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
    footer_sections: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.HeaderFooterSectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    header_sections: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.HeaderFooterSectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d042ffe0f1c54f771a4e20da8edb49b765bd89dbb4c4a113b6408a39a1437a04(
    *,
    paper_margin: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SpacingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paper_orientation: typing.Optional[builtins.str] = None,
    paper_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2da0fb63ea8d987243457aaf1d3ca394c90fb7e0c6ee28ac40f811b99100305f(
    *,
    free_form_layout: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FreeFormSectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db30e6b419845c46570e29203ae83399f8721ffa1a91e707ca14f0bb9235817e(
    *,
    after: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SectionAfterPageBreakProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcbe0aaba90a7cc6014902ad99b3dd94c4aaa3f24e57d836a5b672fe0348bd05(
    *,
    height: typing.Optional[builtins.str] = None,
    padding: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SpacingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03f2659c419f0277a65415d4deb56ae640b6d784c92fc471ad8fd48b4816abbd(
    *,
    sheet_visual_scoping_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SheetVisualScopingConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3338eb15b7d38ba0122fc3b24cc043290799e60c6db15e789f6cf17872fa9515(
    *,
    data_field_series_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataFieldSeriesItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_series_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSeriesItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__034463d50982832ccf6825757352509454b017d2493f262ce5689009916f43e8(
    *,
    destination_parameter_name: builtins.str,
    value: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DestinationParameterValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__34c6c10c5e3e0a20e7e9f04dd2ddcc33ce9bcce5ddddaf4435788da1ec64efb9(
    *,
    background_color: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ae88d5fea8298f0a719902b0f6021e6dad59cc5b8411d69e95be72c9ad5c726(
    *,
    info_icon_text: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9ec99a58e33bd9b37220b93a7ed75aa3d5e4ad1d68f36cd2a575a89974d900d(
    *,
    grid_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aaaac5ff5ebdc4bf0b37374bb4f4c95c0de18091f8c90146a8d801a536f0c870(
    *,
    configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SheetControlLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3313b0e171ff99a25b9ac017fb854e9c54356e9a7a0634c13fbdd9a3cdf4102(
    *,
    sheet_id: builtins.str,
    content_type: typing.Optional[builtins.str] = None,
    description: typing.Optional[builtins.str] = None,
    filter_controls: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilterControlProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    layouts: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LayoutProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    name: typing.Optional[builtins.str] = None,
    parameter_controls: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ParameterControlProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sheet_control_layouts: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SheetControlLayoutProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    text_boxes: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SheetTextBoxProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    title: typing.Optional[builtins.str] = None,
    visuals: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ed1f65dff6275ad4cb009a9fd7432d542c83e61fb75e3c9c4ec1e00b1ba2a81(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__edfd223307d1b10f72a1e801ddedce4a7b4b235b74b97c41d72e52fbc6309c62(
    *,
    configuration_overrides: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SheetElementConfigurationOverridesProperty, typing.Dict[builtins.str, typing.Any]]],
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6df9b86d781b54d6d5a62373d1345c592393c94d85fdb7b8cbfaf9bad004e072(
    *,
    name: typing.Optional[builtins.str] = None,
    sheet_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9b83b0fa0f3bbeb8b8bb8cb25987a9de88b749ef27c4f94c0eeed905842d767(
    *,
    sheet_text_box_id: builtins.str,
    content: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__296ed0698acc06e604e3df4f98123b4a27cf35e5a1da56a14e80d1aa42094f8e(
    *,
    scope: builtins.str,
    sheet_id: builtins.str,
    visual_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5bb36f4dc8887a2f1b11dbd613818886546e0a9a0e0ac28df0a483c056326983(
    *,
    plain_text: typing.Optional[builtins.str] = None,
    rich_text: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f980a5ef17fbfcec69f5d6a4e065d2bf7bd9d99c1982054307ca27101bd0d4dc(
    *,
    color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a7c7b522b4a45f40e638d2984c0d7a3e0bb412595353b539c1ca5b0ca4ee15f(
    *,
    info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SheetControlInfoIconLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7374f243a60a5ee5bac2c475f2e77ad74a7148487962df0214189de2d3a0ccf(
    *,
    placement: typing.Optional[builtins.str] = None,
    scale: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d922fb4c3c198cbe3fd5d6044cdd8fbd7f8a975e5055d9c32a66ea8c4c242ffa(
    *,
    max_visible_columns: typing.Optional[jsii.Number] = None,
    max_visible_rows: typing.Optional[jsii.Number] = None,
    panel_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PanelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SmallMultiplesAxisPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    y_axis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SmallMultiplesAxisPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb46ceb73d3a6b2d9198e936558664a2b60d7e30b7aba7e01b77f71e23cc96af(
    *,
    bottom: typing.Optional[builtins.str] = None,
    left: typing.Optional[builtins.str] = None,
    right: typing.Optional[builtins.str] = None,
    top: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cabefb15919c8ee02103755c5a017477d19667a351a29b3b267d047452ec8102(
    *,
    dynamic_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49861957d453963c2eca90276acc8ba15f9b268877dc2a273da6d00d996395d2(
    *,
    null_value_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe8646d53ea6c4deb3b1e7d298342695f471d38be987914d361e12b4e39d86d3(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.StringDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    value_when_unset: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.StringValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22b81d54727c77a339eb4d008d5c483ae06b25abdcb20befff536eba1ee3735b(
    *,
    custom_value: typing.Optional[builtins.str] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__835884f6f4c1d755581fd9bdc65529e47e3d99fd69106dc8e604086a4b07daa6(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    field_level: typing.Optional[builtins.str] = None,
    field_level_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTableFieldSubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    metric_header_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    style_targets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableStyleTargetProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    total_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
    value_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2caf71a40f9c72ee8a7c06fd6e2c10a5f9ef4571000fe3c2ae6b37afca04c803(
    *,
    group_by: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48fec0f69acb2e5339f552b662a39b4d5bd8b376097bab6d917a82e94ce1d8b0(
    *,
    color: typing.Optional[builtins.str] = None,
    style: typing.Optional[builtins.str] = None,
    thickness: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6533f9a293da2b7b7fe3b874be774bdaca01b7cf111f0027e20294b13f92765(
    *,
    field_id: builtins.str,
    text_format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TextConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7d0b13a76f1aaf645209ca42a07ff53cb21f72c71d29f55fff8519ce7134e9e(
    *,
    table_cell_image_scaling_configuration: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4efb4aa43b4a101c11102e25898dd6ad18500f86e682b74456292880d731a853(
    *,
    background_color: typing.Optional[builtins.str] = None,
    border: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GlobalTableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    font_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    height: typing.Optional[jsii.Number] = None,
    horizontal_text_alignment: typing.Optional[builtins.str] = None,
    text_wrap: typing.Optional[builtins.str] = None,
    vertical_text_alignment: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06365328764f7ef94fe9f0f304f6cf93d96ea0bffa6303928547d170bc09f445(
    *,
    cell: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableCellConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableRowConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7636513daad776039befdfc20d7d5d664e1e53c61dca3af43bbffdd81b0a46e(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78e6e21c76adbe4208f10f052675a816389a108f79b0f9e3970324b3daadda06(
    *,
    field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableFieldOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paginated_report_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TablePaginatedReportOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_inline_visualizations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableInlineVisualizationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    table_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    total_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b92f803cfb445a663dd5996de264bb637b182c6eb6c3efa7e1fb945da29b848a(
    *,
    icon: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86d64eebc27a31236e17d644270b05e6bb9993e683f24bf7ea4ceda3e5e1d26b(
    *,
    font_configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b24f39dc5525a2bbd0e65127a3ecf08cf567859527e3c53d13adbaf1c4472bc(
    *,
    sizing_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableCellImageSizingConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b4623085f8dfac9e24d556bd10d59a883f44dfb076fe1d955b9c51f3e8bfc86a(
    *,
    content: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableFieldLinkContentConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    target: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bbc0e4260a6c448007ce1648f53594e5fe639da096f4466f29d660bc7e28950f(
    *,
    custom_icon_content: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableFieldCustomIconContentProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_text_content: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableFieldCustomTextContentProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__779e6a5f975a683bc59b05bce4b3c638ac2dd48df1efff42a514cf6d6fd25461(
    *,
    field_id: builtins.str,
    custom_label: typing.Optional[builtins.str] = None,
    url_styling: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableFieldURLConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2796b1737ad870376487761ac141740bbac607a367593f554b3fd534c5f32a36(
    *,
    order: typing.Optional[typing.Sequence[builtins.str]] = None,
    pinned_field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TablePinnedFieldOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selected_field_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableFieldOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04c4cefd3fa19c90120d27e9ddd55e2ce8bcd220fba3f34242468d6152e1abfa(
    *,
    image_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableFieldImageConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    link_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableFieldLinkConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a02e236036f7bcd69e7ce7530c8eb0d601444a38ffa8ac1e5f30f2714f07c873(
    *,
    table_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_unaggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableUnaggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ceb0d418c99510db7c0c0d9697bc4a52e447eb65699b23c1ca5c0ffe36580475(
    *,
    data_bars: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataBarsOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72989fbf4fb65e8ef177defebf306d8d8586aff29022aa898fc0e7b021461953(
    *,
    cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    header_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    orientation: typing.Optional[builtins.str] = None,
    row_alternate_color_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.RowAlternateColorOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__314e5e5ec10f290574f10eaea635bbed4ba331282f6e96fbb8e6bde77b05863c(
    *,
    overflow_column_header_visibility: typing.Optional[builtins.str] = None,
    vertical_overflow_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b45b9f9c4a8e69871af3d427ee971e1adea8a6f8e95067f90063fb60e3665b0e(
    *,
    pinned_left_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__178cc4da695f91cc458c7388d9d495874b607f05c4a8d391049bccdc3abe00f8(
    *,
    background_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75ad05777fe46c30662f9ad6fe87b26918feac5967802af413b29b7ec3409eb2(
    *,
    bottom: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    inner_horizontal: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    inner_vertical: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    left: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    right: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__903046e28c98a6ec8103ae79dcbc439d13256653096eae7e28c723aca09f5b79(
    *,
    pagination_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PaginationConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb65d9330b2c4bb046bded2bf8120b89581164d4583157da562916af1833ede2(
    *,
    cell_type: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e82e4b250bc24e2b79ecb297f9e7fd6cd917bb5458dd230d700971964e97a7c8(
    *,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.UnaggregatedFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c31b2114cdc370dfdb415437cd997a1b122d96ab50bfd66c8858e768988542e(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb1493e0de2aa92be7a3455753aed11235085d8489c8a548fd1fd5385201a46a(
    *,
    message: typing.Optional[builtins.str] = None,
    type: typing.Optional[builtins.str] = None,
    violated_entities: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.EntityProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2eb54d447b487456995a6fe75d674789538c60109d204f87757468168fcfbc16(
    *,
    arn: builtins.str,
    data_set_references: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataSetReferenceProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb1d67137993dd808f77c6146d2a0e7d0883f456f3cb561e95ee4027432a223f(
    *,
    source_analysis: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TemplateSourceAnalysisProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    source_template: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TemplateSourceTemplateProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55a02d9ca40b6ae3ebb345b5e4f20f1611c0d21074e73a8409fc8e561f3f2a74(
    *,
    arn: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d4d306e9cd0974c594353d10bf810e1540586afcd9054498c6bcf94e7c77c23(
    *,
    data_set_configurations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataSetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    analysis_defaults: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AnalysisDefaultsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    calculated_fields: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CalculatedFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    column_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    filter_groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilterGroupProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AssetOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    parameter_declarations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sheets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SheetDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c759b390e0d16c21bc3df51154c4360b603f025efdaadfe88ca2354d9636209a(
    *,
    created_time: typing.Optional[builtins.str] = None,
    data_set_configurations: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataSetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    description: typing.Optional[builtins.str] = None,
    errors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TemplateErrorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sheets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SheetProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source_entity_arn: typing.Optional[builtins.str] = None,
    status: typing.Optional[builtins.str] = None,
    theme_arn: typing.Optional[builtins.str] = None,
    version_number: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04e1b06dd8d8aeb96baf17821f8818292b8efdd6c06dd06193c5819e54d5ad4d(
    *,
    info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SheetControlInfoIconLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    placeholder_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TextControlPlaceholderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0cfb74106da673cde065347bf00164a682139cd3391baf58da9c690beb2eaf32(
    *,
    background_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    icon: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__705a4841c70945143c7c371c4652bcb6b5c6a9722fb8e4fc3af64ab07671a2d8(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9189931dd3dea3d3adfef97b11c024be8f5817050e174439da9430a8401f1b02(
    *,
    info_icon_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SheetControlInfoIconLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    placeholder_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TextControlPlaceholderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d397da7da8f8895e7843dea41197da2adbdc9b496633b24de5e2d22287e28a4(
    *,
    symbol: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dffa84bb07637bef19d754175e4eda7df87f5f7097f441bea214447c5d4025e7(
    *,
    lower_boundary: typing.Optional[jsii.Number] = None,
    periods_backward: typing.Optional[jsii.Number] = None,
    periods_forward: typing.Optional[jsii.Number] = None,
    prediction_interval: typing.Optional[jsii.Number] = None,
    seasonality: typing.Optional[jsii.Number] = None,
    upper_boundary: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__82db54c77dc59198ed92925f9b6bc9b69debc632b93c4881c3529a02b9edca8c(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    parameter_name: typing.Optional[builtins.str] = None,
    rolling_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.RollingDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
    value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c503912fc54359682621ec49956c2f237650db649a7d27c61ad26698186d635(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    range_maximum: builtins.str,
    range_minimum: builtins.str,
    time_granularity: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb817873f5ab1f408bed6b52d8d4d3817058206f1fb7c09f1a9797b874c435ef(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    null_option: builtins.str,
    exclude_period_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ExcludePeriodConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
    include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
    range_maximum_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TimeRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    range_minimum_value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TimeRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37d1329b88307470ba01e1e0bdfb1b76dc8193e46c14138f78fa539b25cae9d1(
    *,
    parameter: typing.Optional[builtins.str] = None,
    rolling_date: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.RollingDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9be9027b1eafcc625e1d8b7fffbdba8895eff81af1a15884d0f05a079acc904(
    *,
    column_tooltip_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnTooltipItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_tooltip_item: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldTooltipItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d3ad67242a50351d99986e8e684ea5c64b14ae1d1c1ec30709396ec79d71789(
    *,
    field_based_tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldBasedTooltipProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selected_tooltip_type: typing.Optional[builtins.str] = None,
    tooltip_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__41846fec1e1aa2e86614deee24ef480c9bac3d7f16c2108ff36087831ed73155(
    *,
    aggregation_sort_configurations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AggregationSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    limit: typing.Optional[jsii.Number] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f37be253a5e5d32ec97edc66b99be2af738b88ef98625f19eb8dadef6cbfe392(
    *,
    computation_id: builtins.str,
    type: builtins.str,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mover_size: typing.Optional[jsii.Number] = None,
    name: typing.Optional[builtins.str] = None,
    sort_order: typing.Optional[builtins.str] = None,
    time: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e72ca65aab34d2a096e9fdfec9e7be28828777768797ebe577480319b4c1de0(
    *,
    computation_id: builtins.str,
    type: builtins.str,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    name: typing.Optional[builtins.str] = None,
    result_size: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7147e0c586db8a2c6e5a828daf02618345defd5d932f01e6255b2284a7240ec3(
    *,
    computation_id: builtins.str,
    name: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f85fb3c95e3ca79dd60b64c25ed1804935d18e91465877fa56574694d5206233(
    *,
    simple_total_aggregation_function: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84172644037d22fa48e11f8e13bcb01c3ea8c0255c9d3cf400ea9cc5811bcdf9(
    *,
    field_id: builtins.str,
    total_aggregation_function: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TotalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a496edcf300ce3343e7814a6546bd962adb9fc4f21bb9108e16a344e13767696(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    placement: typing.Optional[builtins.str] = None,
    scroll_status: typing.Optional[builtins.str] = None,
    total_aggregation_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TotalAggregationOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    total_cell_style: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58d9f611360a00b5cbb0082e1a3b44fc0cba018dcac0afe98725ca272b084516(
    *,
    colors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    groups: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sizes: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__277052b6ad49367c36f4513a47753b3482edefbd6fbfe6ca4c3328b3cf0715e9(
    *,
    color_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_scale: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColorScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TreeMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    group_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    size_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TreeMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2f25f599e767f8263a820c3fab79c28f80a2012bd07d4892a3e11360691c87c(
    *,
    tree_map_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TreeMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5acae2a51dd77d02772040e7588a09566143b3f2f3305d214225a8d72bb7813c(
    *,
    tree_map_group_items_limit_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tree_map_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c62c9ffa127290e2244bd59d4483c71075aed723f631b2404be11bfdb044c0a(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TreeMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2839b234a31139976acf12941e6957dbd01494e54f63fe8824575853b04b1429(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6503062ec15a4691568519426046f7b1fbb537e033f2db33f6547d6394260812(
    *,
    column: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__354e3ff926eebcfb6d7f61649d46d0ae27d05164eff8e46e79271a6862cda687(
    *,
    computation_id: builtins.str,
    category: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4031b4f0222cb7dbd9d665663f64e810d1a958d165896f18e01058d8e035b5d7(
    *,
    mode: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f86673dd492374c4a12f9c7568b336f404aba0ab679a3d7dd6cdcd2186ed954(
    *,
    percent_range: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PercentVisibleRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8f60b8a1ca99ae307f7c54ffa4387b522534f9ccb2bb011dee92f65ff8c1902(
    *,
    filter_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CustomActionFilterOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    navigation_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CustomActionNavigationOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    set_parameters_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CustomActionSetParametersOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    url_operation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CustomActionURLOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ce5758fd282e2d9cb311d8afd2daf9144e12ab11e45a2064dae74e24dcdcb88(
    *,
    action_operations: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionOperationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    custom_action_id: builtins.str,
    name: builtins.str,
    trigger: builtins.str,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2eb5e88c498a04f3ec75fcac7df165e17071f53c0213813bd77bbf1cdde2e0b6(
    *,
    chart_color: typing.Optional[builtins.str] = None,
    color_map: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataPathColorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e016b1dfd9b52a4c51b4649fe1d589d5b5decc781c92161cd3e4357408f9e1aa(
    *,
    bar_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.BarChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    box_plot_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.BoxPlotVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    combo_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ComboChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_content_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.CustomContentVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    empty_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.EmptyVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    filled_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FilledMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    funnel_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FunnelChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    gauge_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GaugeChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    geospatial_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.GeospatialMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    heat_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.HeatMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    histogram_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.HistogramVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    insight_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.InsightVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    kpi_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.KPIVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    line_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LineChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    pie_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PieChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    pivot_table_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.PivotTableVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    radar_chart_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.RadarChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sankey_diagram_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.SankeyDiagramVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scatter_plot_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ScatterPlotVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TableVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tree_map_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TreeMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    waterfall_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.WaterfallVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    word_cloud_visual: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.WordCloudVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77f056b91edf67b9eb6d2edf30db13be84e63331a18191b0be77fda65b9e1645(
    *,
    format_text: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LongFormatTextProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4081fd93b26340a2623abcc387e340e4e86c84b5fe06a999e9624a073a5ae7c(
    *,
    format_text: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ShortFormatTextProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f76a10e007767a1bd8eb5fb8f4c89350bf25a61bdb5b90a2ce86691c3eb18232(
    *,
    breakdowns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    categories: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__54bbc24a1dd04bcd0aad8a335f4a58fa4babda621916af65ddb36b0f40eef74c(
    *,
    category_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.WaterfallChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.WaterfallChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    waterfall_chart_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.WaterfallChartOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57a9a9f048061ae2b7250714c2ac7324600fad13206aec0183b583e44a8b198a(
    *,
    waterfall_chart_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.WaterfallChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d123204084888211a2e5a8a1d205b983db8a2f34e90a9658c1c8c534e8c10fa(
    *,
    total_bar_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__23ecd8c91f5df966f8913e29661ef9cce50438c11d1523bfcf7bee7f58dd4105(
    *,
    breakdown_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__993bd48ff03f371b23b46d677f72614348b973d834986e7d6f6ebb85a1f480ed(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.WaterfallChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd8bcd47cf9adcab51a68cc6d74f4924df11d6f9c921ed0cfa36db3bcdb72b44(
    *,
    date: builtins.str,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d39af50e14c0edaacd4dbd28782b722f217bfdcdd74e5200090464f9dfc5c20(
    *,
    end_date: builtins.str,
    start_date: builtins.str,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c863ec6153fd0fac1389fb1373a5428303e58d1ea2588e9bbd851d04625322d0(
    *,
    group_by: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    size: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22ddb296c5840988b4af8d2eb9932adec9a6e97a6e2409a17e2251dc5aba565c(
    *,
    category_label_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.WordCloudFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.WordCloudSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    word_cloud_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.WordCloudOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25ac92e12dc71a0c6280682ffc55baa9600576146c16c9dcdc6b10cfe3250091(
    *,
    word_cloud_aggregated_field_wells: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.WordCloudAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3780da32cf5efc14579531e18e4aea181730bd8570295951a9c435f4a020980(
    *,
    cloud_layout: typing.Optional[builtins.str] = None,
    maximum_string_length: typing.Optional[jsii.Number] = None,
    word_casing: typing.Optional[builtins.str] = None,
    word_orientation: typing.Optional[builtins.str] = None,
    word_padding: typing.Optional[builtins.str] = None,
    word_scaling: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cd5fb0239e8addc760e1695522bdbe004b3acf6afa69a76bf9814487a89d06b8(
    *,
    category_items_limit: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b09284c311f9b3aaed0ac05c126480ae5985daf6d0e0bc27b670595ca9e654de(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.WordCloudChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__194696706c08c6a7def262580c9972a430e44c1c526329b77b525a87c76a44ed(
    *,
    aws_account_id: builtins.str,
    template_id: builtins.str,
    definition: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TemplateVersionDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source_entity: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.TemplateSourceEntityProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
    validation_strategy: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTemplate.ValidationStrategyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    version_description: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1cc4ce58f4cafc226ffd62ae865dc8406c4667128fad8afacb6b92f2394c675c(
    scope: _constructs_77d1e7e8.Construct,
    id: builtins.str,
    *,
    aws_account_id: builtins.str,
    base_theme_id: builtins.str,
    configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTheme.ThemeConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    name: builtins.str,
    theme_id: builtins.str,
    permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTheme.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
    version_description: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d05239799ae44473a946ab0823e3e4e4e4311b9c61047c7910aa1e2d5bd5b49(
    inspector: _TreeInspector_488e0dd5,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4db77359b9c4eb831da1e2c00f88a50e63d806b08d83109a29ee9f92f00db46d(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52d1ea4febf327cf12813b6e6f9a8cf790ade3963322dc2ec0e8e0931b6b3749(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b98a6e7f9e431e35bab2bc3e8f863259ef1af8f35a63a3a1ec866d7149956e5a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5729182f5b6dd5994d8da27ef75b86f3ace3522d968d98c6c40b510fc5a6eca(
    value: typing.Union[_IResolvable_da3f097b, CfnTheme.ThemeConfigurationProperty],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a3b50896d86767abb9692a9b97ea93cac0da3aaf22b214452e5a151968af366(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cbaf20f7789ed4589d1496cdccefb1181caf1a1b6fd5db8c7d72b0d19e32a8cb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0714a79adc0c72da405d829e73cb024a318b95c4d924b46c810ad16a58bfab3d(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnTheme.ResourcePermissionProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c24ccf1ba4e30cab8c766f3ceb57c32cd0562ea3ebbd6d69a4b2b13e38b2e38(
    value: typing.Optional[typing.List[_CfnTag_f6864754]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__287b27dd94f3e78eee24b00309f7d9dc35d3c632cf3b8eb1c9a76516643152f9(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7d3c0eae400f4993f620440cd59405cc03cb757913132b40b92519a3498cf2a(
    *,
    show: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05cf0293625cfaba717f34068740d0ebf0c3421b3eb8337b644a8803283af183(
    *,
    colors: typing.Optional[typing.Sequence[builtins.str]] = None,
    empty_fill_color: typing.Optional[builtins.str] = None,
    min_max_gradient: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e01c1ff77a66f6c27599010aee795944a5c515a4ba2eff61abeaaa341a0d101(
    *,
    font_family: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__23cf2f426f832b1905d0fec59fb1ea5c55f5712ce8c2b1255f4a161d799e52e9(
    *,
    show: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c43b9b8222d79d953fd816a99d04dfaa74c0bc05da0298e96c2e8f1113884140(
    *,
    show: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08ece21d06f10f1edfb7bf2ffa1e6c7fbf7ea8804de4b99a07380d0ef2ece8a4(
    *,
    actions: typing.Sequence[builtins.str],
    principal: builtins.str,
    resource: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e786d1c3847105bb2a9d28ff988128838e5c15158f5295b2100991be17292f0(
    *,
    tile: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTheme.TileStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tile_layout: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTheme.TileLayoutStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec4921443ed79b199f5fe67018c89abbaa53ea473997191ff6067f7a58a57554(
    *,
    data_color_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTheme.DataColorPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sheet: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTheme.SheetStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    typography: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTheme.TypographyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    ui_color_palette: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTheme.UIColorPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e678b04d098b0907b9508fe683105cca935519833c5c0f7ead79c924cf3c7943(
    *,
    message: typing.Optional[builtins.str] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0b677e6443b11f79312872fa23db827dfe2cd6aa78ef29af2775e4160492e05(
    *,
    arn: typing.Optional[builtins.str] = None,
    base_theme_id: typing.Optional[builtins.str] = None,
    configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTheme.ThemeConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    created_time: typing.Optional[builtins.str] = None,
    description: typing.Optional[builtins.str] = None,
    errors: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTheme.ThemeErrorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    status: typing.Optional[builtins.str] = None,
    version_number: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3fad0a18f5c86222517f2b5416776d8f96dda5a85036b513e65be064d8ef747(
    *,
    gutter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTheme.GutterStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    margin: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTheme.MarginStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e86af7264a0f9499019c7010f1dcfbaa4c6eff11f846eeb2d217062958ceb6ac(
    *,
    border: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTheme.BorderStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b39e5f4e5fcc8ac9b1a509f53d146e359532865400c4d724e83fc36465088efc(
    *,
    font_families: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTheme.FontProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc061ac7da133cd67e49f491d5008a1ee1aedff1d084050be39461ea733b369e(
    *,
    accent: typing.Optional[builtins.str] = None,
    accent_foreground: typing.Optional[builtins.str] = None,
    danger: typing.Optional[builtins.str] = None,
    danger_foreground: typing.Optional[builtins.str] = None,
    dimension: typing.Optional[builtins.str] = None,
    dimension_foreground: typing.Optional[builtins.str] = None,
    measure: typing.Optional[builtins.str] = None,
    measure_foreground: typing.Optional[builtins.str] = None,
    primary_background: typing.Optional[builtins.str] = None,
    primary_foreground: typing.Optional[builtins.str] = None,
    secondary_background: typing.Optional[builtins.str] = None,
    secondary_foreground: typing.Optional[builtins.str] = None,
    success: typing.Optional[builtins.str] = None,
    success_foreground: typing.Optional[builtins.str] = None,
    warning: typing.Optional[builtins.str] = None,
    warning_foreground: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b7a0f2dda23b22dcd29969c69e7910c3a23a6bab01e03b8b01a7c9628229f03(
    *,
    aws_account_id: builtins.str,
    base_theme_id: builtins.str,
    configuration: typing.Union[_IResolvable_da3f097b, typing.Union[CfnTheme.ThemeConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    name: builtins.str,
    theme_id: builtins.str,
    permissions: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTheme.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
    version_description: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e98a54c810cd62780e1f968a0f83f854bc8baac07e43fc099f3f81b062d8e088(
    scope: _constructs_77d1e7e8.Construct,
    id: builtins.str,
    *,
    aws_account_id: typing.Optional[builtins.str] = None,
    data_sets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.DatasetMetadataProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    description: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
    topic_id: typing.Optional[builtins.str] = None,
    user_experience_version: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba1a40b47a4dd39d8e7c64883710d38ff5623b8e62637a255de8fd05bdba8b49(
    inspector: _TreeInspector_488e0dd5,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76423f09362a227c521d6507f7de1870912e335513ea94129d35b3e421a26224(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f057f56a73762b4877e8579df45fb30889b477dbb063f820ff9ca71e4eb10e1(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__865dd17cdf0180752414a809eb15588349da7941dd91964b989f41ca7cd29ab4(
    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnTopic.DatasetMetadataProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__481ab478962ac0f8201bad9978ce36e28b5065c639475f66dc91f4efd41fe68b(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50731ae547f0d2238bc12670138bf03f65427325a5cb389667f3552b0ddd15fb(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e7ec12bb62b1d230bdac157875cb0b5b7a386f94a0af70696f88bc8f6e69d49(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28aca8d896b27e7d885e956910a7d20f0e3ff34c9aeb0e70ca664673d5f3fb6f(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e1d2f30468c0518adcf31a483375d454f1b9ff53fc490ffa0914de61161db5a(
    *,
    cell_value: typing.Optional[builtins.str] = None,
    synonyms: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99077acddad317cc5c85c778458a3e87554410900cfe93fea410bc7903c1737e(
    *,
    value_list: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__471648aa1c53b0767a1f96087fccfd258d8d0cb568d1b3ae8ddbb3d37596dc80(
    *,
    specifed_order: typing.Optional[typing.Sequence[builtins.str]] = None,
    treat_undefined_specified_values: typing.Optional[builtins.str] = None,
    use_ordering: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6cf5ac3c01c8be3f1bd3d8b91d6b6fa59b49f363c86b67e4f688e399ae84c9d1(
    *,
    dataset_row_date_granularity: typing.Optional[builtins.str] = None,
    default_date_column_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__759725ab113e70f3e650b49659e82a542dc9edfa60adbb5b9934a71cddeebe76(
    *,
    dataset_arn: builtins.str,
    calculated_fields: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.TopicCalculatedFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    columns: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.TopicColumnProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_aggregation: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.DataAggregationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    dataset_description: typing.Optional[builtins.str] = None,
    dataset_name: typing.Optional[builtins.str] = None,
    filters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.TopicFilterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    named_entities: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.TopicNamedEntityProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38757f97f575ef5532a16ecc041416069794e07721d9e59b03ee60c531b9e0cd(
    *,
    display_format: typing.Optional[builtins.str] = None,
    display_format_options: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.DisplayFormatOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a518fe1c79b565f9a3036522dcd63b238ba1fcfe71a03b4910fe1227edcf6aa(
    *,
    blank_cell_format: typing.Optional[builtins.str] = None,
    currency_symbol: typing.Optional[builtins.str] = None,
    date_format: typing.Optional[builtins.str] = None,
    decimal_separator: typing.Optional[builtins.str] = None,
    fraction_digits: typing.Optional[jsii.Number] = None,
    grouping_separator: typing.Optional[builtins.str] = None,
    negative_format: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.NegativeFormatProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    prefix: typing.Optional[builtins.str] = None,
    suffix: typing.Optional[builtins.str] = None,
    unit_scaler: typing.Optional[builtins.str] = None,
    use_blank_cell_format: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
    use_grouping: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30d0de58d685d1a779306717f3357202cfd2cea8b8407c7401ff618901aaca56(
    *,
    aggregation: typing.Optional[builtins.str] = None,
    aggregation_function_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, builtins.str]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38715088c0f5f57a344ffa137a60707c52b9a90db90176d3d99c3faf1af9dfa4(
    *,
    field_name: typing.Optional[builtins.str] = None,
    metric: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.NamedEntityDefinitionMetricProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    property_name: typing.Optional[builtins.str] = None,
    property_role: typing.Optional[builtins.str] = None,
    property_usage: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b70c69387cd6497bee5dd0361aff1afc069ac32a0b5f2ece5581344c3336642(
    *,
    prefix: typing.Optional[builtins.str] = None,
    suffix: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0453d6a9aa80984a83c9fc36baab6d1600c531ebf4b1b82f9e1e1664ece9ed5d(
    *,
    maximum: typing.Optional[builtins.str] = None,
    minimum: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6833ca411e149363a691fb6289ac45f28e170bd28660192519d306e46cf86e0d(
    *,
    sub_type_name: typing.Optional[builtins.str] = None,
    type_name: typing.Optional[builtins.str] = None,
    type_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, builtins.str]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__649f722425d32b10d8f225001fefd47663bcbf814fcf9af9e5876815765949dc(
    *,
    falsey_cell_value: typing.Optional[builtins.str] = None,
    falsey_cell_value_synonyms: typing.Optional[typing.Sequence[builtins.str]] = None,
    sub_type_name: typing.Optional[builtins.str] = None,
    truthy_cell_value: typing.Optional[builtins.str] = None,
    truthy_cell_value_synonyms: typing.Optional[typing.Sequence[builtins.str]] = None,
    type_name: typing.Optional[builtins.str] = None,
    type_parameters: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Mapping[builtins.str, builtins.str]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fffafec4d96f73a0bb2382083323859061af993381915fddf09ecc78fd5d5f36(
    *,
    calculated_field_name: builtins.str,
    expression: builtins.str,
    aggregation: typing.Optional[builtins.str] = None,
    allowed_aggregations: typing.Optional[typing.Sequence[builtins.str]] = None,
    calculated_field_description: typing.Optional[builtins.str] = None,
    calculated_field_synonyms: typing.Optional[typing.Sequence[builtins.str]] = None,
    cell_value_synonyms: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.CellValueSynonymProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    column_data_role: typing.Optional[builtins.str] = None,
    comparative_order: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.ComparativeOrderProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    default_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.DefaultFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    is_included_in_topic: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
    never_aggregate_in_filter: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
    non_additive: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
    not_allowed_aggregations: typing.Optional[typing.Sequence[builtins.str]] = None,
    semantic_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.SemanticTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3441530765d3e507907e4c6dd506e50fa8df155d9a072ac10b181a86a0b314d5(
    *,
    collective_constant: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.CollectiveConstantProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    constant_type: typing.Optional[builtins.str] = None,
    singular_constant: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26614299f4f77619745072528f965f29cbf636bf92ea32101e10fc65b80d3baf(
    *,
    category_filter_function: typing.Optional[builtins.str] = None,
    category_filter_type: typing.Optional[builtins.str] = None,
    constant: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.TopicCategoryFilterConstantProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    inverse: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a7e0dff07bd6260713cf650e291a6e355c22aa55f3c00636ee0c53606b1c548(
    *,
    column_name: builtins.str,
    aggregation: typing.Optional[builtins.str] = None,
    allowed_aggregations: typing.Optional[typing.Sequence[builtins.str]] = None,
    cell_value_synonyms: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.CellValueSynonymProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    column_data_role: typing.Optional[builtins.str] = None,
    column_description: typing.Optional[builtins.str] = None,
    column_friendly_name: typing.Optional[builtins.str] = None,
    column_synonyms: typing.Optional[typing.Sequence[builtins.str]] = None,
    comparative_order: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.ComparativeOrderProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    default_formatting: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.DefaultFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    is_included_in_topic: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
    never_aggregate_in_filter: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
    non_additive: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
    not_allowed_aggregations: typing.Optional[typing.Sequence[builtins.str]] = None,
    semantic_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.SemanticTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__34064d7ce1fb0f0cd683f6101b1454976c569e78c8c96d72543b423a809dc8f5(
    *,
    constant: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.TopicRangeFilterConstantProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    inclusive: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5df6234bc745c16383a8590e30611a315f894b0388a92fdde6f8aac974faf62b(
    *,
    filter_name: builtins.str,
    operand_field_name: builtins.str,
    category_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.TopicCategoryFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    date_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.TopicDateRangeFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    filter_class: typing.Optional[builtins.str] = None,
    filter_description: typing.Optional[builtins.str] = None,
    filter_synonyms: typing.Optional[typing.Sequence[builtins.str]] = None,
    filter_type: typing.Optional[builtins.str] = None,
    numeric_equality_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.TopicNumericEqualityFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_range_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.TopicNumericRangeFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relative_date_filter: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.TopicRelativeDateFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5cb8be66d81e69534c842421108a0a2762c7522d4f6a9a60a9118728d463356(
    *,
    entity_name: builtins.str,
    definition: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.NamedEntityDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    entity_description: typing.Optional[builtins.str] = None,
    entity_synonyms: typing.Optional[typing.Sequence[builtins.str]] = None,
    semantic_entity_type: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.SemanticEntityTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e0e5a7d468fa4347b348c3038af29b5dbbc1b91122f7be6badb3ae8fdf4cb5e(
    *,
    aggregation: typing.Optional[builtins.str] = None,
    constant: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.TopicSingularFilterConstantProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4dfcde0684a467ee1e05ff934af9bf1a4408c2ffd6ec63d92421939754740147(
    *,
    aggregation: typing.Optional[builtins.str] = None,
    constant: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.TopicRangeFilterConstantProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    inclusive: typing.Optional[typing.Union[builtins.bool, _IResolvable_da3f097b]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76c8bc288bc5830e3afb27a78373c5162ba1b999e4c951977b26dacfdcbdb6fc(
    *,
    constant_type: typing.Optional[builtins.str] = None,
    range_constant: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.RangeConstantProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39c00c9a003de5da41ff1db4fa32e0f417a5d14993059ef78829e576578c8a89(
    *,
    constant: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.TopicSingularFilterConstantProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relative_date_filter_function: typing.Optional[builtins.str] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14bc182c255d35e0a589d78db2835512b0f14f93d9d7d7010a94a7258f51a0ea(
    *,
    constant_type: typing.Optional[builtins.str] = None,
    singular_constant: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__594e8a4ec85e161016ae0aa60a6538d619759944135cfd2b531b0f063b24a029(
    *,
    aws_account_id: typing.Optional[builtins.str] = None,
    data_sets: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnTopic.DatasetMetadataProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    description: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
    topic_id: typing.Optional[builtins.str] = None,
    user_experience_version: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef620926701190b6847eccf16ab05ec1e84c9f36be88ca71e3fb46aa455b98f7(
    scope: _constructs_77d1e7e8.Construct,
    id: builtins.str,
    *,
    availability_status: typing.Optional[builtins.str] = None,
    aws_account_id: typing.Optional[builtins.str] = None,
    dns_resolvers: typing.Optional[typing.Sequence[builtins.str]] = None,
    name: typing.Optional[builtins.str] = None,
    role_arn: typing.Optional[builtins.str] = None,
    security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
    subnet_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
    vpc_connection_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dbabc322df97d909bf1356aabd6a09e621b84313d0fa72daff9cf7dc2cc11b77(
    inspector: _TreeInspector_488e0dd5,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__420144ea2ee9a09db7bf5187781e8efeb19163e2f9a6e3cd99c47bbd9fe4fac4(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__832984ca825d6bf8084cb48289d171ff480ae94b38204dfc1ebedcd4f8206a2b(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8658178452a3fcded2ee47d39dcf69f8847c5ffe765c14ccf964342546c84188(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ac506209d6fac914f50d920a1c6663d643dd96d8cbeb0f81c873cfbc67571e7(
    value: typing.Optional[typing.List[builtins.str]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__511918fffce5781d52150f4e23e3ff1a72755f42339f1d83d8598a81d18f34df(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e01de73f6047bb36d86d0fd85a88f84de6a96ee28d9ae346f8cfb34842c304b(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4cfb27ab2b9d66f7838d9fd4f35f59b6d9abe44b247bb339171e7d8f6942fe8d(
    value: typing.Optional[typing.List[builtins.str]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb5467e05e57753947434c47147705ee687d5a5e067c62e562c68422d7aad5ef(
    value: typing.Optional[typing.List[builtins.str]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa21ffd18f0d11f7c59636b3e143ff2b8838b628b1cf0dc74ebef9ad2b519c86(
    value: typing.Optional[typing.List[_CfnTag_f6864754]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__968ed3c0730e6c72a1719a4c488de0314feafcf383509068874dc1e97ace5157(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__739acf70e62b97a09a7f5c798708670a2c0bc24d04d30df3dac04b1b4665abd6(
    *,
    availability_zone: typing.Optional[builtins.str] = None,
    error_message: typing.Optional[builtins.str] = None,
    network_interface_id: typing.Optional[builtins.str] = None,
    status: typing.Optional[builtins.str] = None,
    subnet_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58b1c31b33a7be8b7c5d102f60c41a81d1ffe3d57a15387f2812dfde0bb67d6d(
    *,
    availability_status: typing.Optional[builtins.str] = None,
    aws_account_id: typing.Optional[builtins.str] = None,
    dns_resolvers: typing.Optional[typing.Sequence[builtins.str]] = None,
    name: typing.Optional[builtins.str] = None,
    role_arn: typing.Optional[builtins.str] = None,
    security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
    subnet_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
    vpc_connection_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass
